#-----------------------------------------------------------------------
# Setup path and load IxLoad package.
#-----------------------------------------------------------------------
source ../setup_simple.tcl


#-----------------------------------------------------------------------
# Initialize IxLoad
# IxLoad connect should always be called, even for local scripts.
#-------------------------------------------------------------------
::IxLoad connect $::IxLoadPrivate::SimpleSettings::remoteServer

# Once we've connected, make sure we disconnect, even if there's a problem
if [catch {


#-----------------------------------------------------------------------
# Loads plugins for specific protocols configured in this test.
#-----------------------------------------------------------------------
global ixAppPluginManager
$ixAppPluginManager load "MGCP"


#-----------------------------------------------------------------------
# Logger setup.
#-----------------------------------------------------------------------
set logtag "IxLoad-api"
set logName  "MGCP_Signaling_SM"
set logger [::IxLoad new ixLogger $logtag 1]
set logEngine [$logger getEngine]
$logEngine setLevels $::ixLogger(kLevelDebug) $::ixLogger(kLevelInfo)
$logEngine setFile $logName 2 256 1


#-----------------------------------------------------------------------
# Package require the stat collection utilities.
#-----------------------------------------------------------------------
package require statCollectorUtils
set scu_version [package require statCollectorUtils]
puts "statCollectorUtils package version = $scu_version"


#-----------------------------------------------------------------------
# Build Chassis Chain.
#-----------------------------------------------------------------------
set chassisChain [::IxLoad new ixChassisChain]

$chassisChain addChassis $::IxLoadPrivate::SimpleSettings::chassisName


#-----------------------------------------------------------------------
# Build Client Network.
#-----------------------------------------------------------------------
set clientNetwork [::IxLoad new ixNetworkGroup $chassisChain]

$clientNetwork config \
	-name                 	"ClientNetwork"

$clientNetwork globalPlugins.clear

set Filter_1 [::IxLoad new ixNetFilterPlugin]

$clientNetwork globalPlugins.appendItem -object $Filter_1

$Filter_1 config \
	-name                   "Filter_1"

set GratARP_1 [::IxLoad new ixNetGratArpPlugin]

$clientNetwork globalPlugins.appendItem -object $GratARP_1

$GratARP_1 config \
	-name					"GratARP_1"

set TCP_1 [::IxLoad new ixNetTCPPlugin]

$clientNetwork globalPlugins.appendItem -object $TCP_1

$TCP_1 config \
	-tcp_tw_recycle			true \
	-tcp_keepalive_time		75 \
	-tcp_keepalive_intvl	7200 \
	-tcp_wmem_default		4096 \
	-tcp_port_min			1024 \
	-tcp_port_max			65535 \
	-tcp_window_scaling		false \
	-name					"TCP_1" \
	-tcp_rmem_default		4096

set DNS_1 [::IxLoad new ixNetDnsPlugin]

$clientNetwork globalPlugins.appendItem -object $DNS_1

$DNS_1 config \
	-name                   "DNS_1"

$DNS_1 hostList.clear

$DNS_1 searchList.clear

$DNS_1 nameServerList.clear

set Settings_1 [::IxLoad new ixNetIxLoadSettingsPlugin]

$clientNetwork globalPlugins.appendItem -object $Settings_1

$Settings_1 config \
	-name					"Settings_1"

set Ethernet_1 [$clientNetwork getL1Plugin]

set my_ixNetEthernetELMPlugin_1 [::IxLoad new ixNetEthernetELMPlugin]

$Ethernet_1 config \
	-name					"Ethernet /PHY_1" \
	-cardElm				$my_ixNetEthernetELMPlugin_1

$Ethernet_1 childrenList.clear

set MAC_VLAN_1 [::IxLoad new ixNetL2EthernetPlugin]

$Ethernet_1 childrenList.appendItem -object $MAC_VLAN_1

$MAC_VLAN_1 config \
	-name                   "MAC/VLAN_1"

$MAC_VLAN_1 childrenList.clear

set IP_1 [::IxLoad new ixNetIpV4V6Plugin]

$MAC_VLAN_1 childrenList.appendItem -object $IP_1

$IP_1 config \
	-name					"IP_1"

$IP_1 childrenList.clear

$IP_1 extensionList.clear

$MAC_VLAN_1 extensionList.clear

$Ethernet_1 extensionList.clear


#-----------------------------------------------------------------------
# Setting the ranges starting with the plugin on top of the stack.
#-----------------------------------------------------------------------
$IP_1 rangeList.clear

set IP_R1 [::IxLoad new ixNetIpV4V6Range]

$IP_1 rangeList.appendItem -object $IP_R1

$IP_R1 config \
	-count                  7500 \
	-name                   "IP_R1" \
	-gatewayAddress         "0.0.0.0" \
	-prefix                 16 \
	-mss                    100 \
	-ipAddress              "198.5.0.1"

set MAC_R1 [$IP_R1 getLowerRelatedRange "MacRange"]

$MAC_R1 config \
	-count                  7500 \
	-mac                    "00:AC:13:00:01:00" \
	-name                   "MAC_R1" \
	-incrementBy            "00:00:00:00:01:00" 

set VLAN_R1 [$IP_R1 getLowerRelatedRange "VlanIdRange"]

$VLAN_R1 config \
	-name                   "VLAN_R1" \
	-idIncrMode             1 \
	-priority               0 \
	-innerPriority          0


#-----------------------------------------------------------------------
# Assign Ports to Client Network.
#-----------------------------------------------------------------------
$clientNetwork portList.appendItem \
    -chassisId  			1 \
    -cardId     			$::IxLoadPrivate::SimpleSettings::clientPort(CARD_ID)\
    -portId     			$::IxLoadPrivate::SimpleSettings::clientPort(PORT_ID)


set clientNetwork_3 [::IxLoad new ixNetworkGroup $chassisChain]

$clientNetwork_3 config \
	-name                   "ClientNetwork_3" 

$clientNetwork_3 globalPlugins.clear

set Filter_3 [::IxLoad new ixNetFilterPlugin]

$clientNetwork_3 globalPlugins.appendItem -object $Filter_3

$Filter_3 config \
	-name                   "Filter_3" 

set GratARP_3 [::IxLoad new ixNetGratArpPlugin]

$clientNetwork_3 globalPlugins.appendItem -object $GratARP_3

$GratARP_3 config \
	-enabled                true \
	-name                   "GratARP_3" 

set TCP_3 [::IxLoad new ixNetTCPPlugin]

$clientNetwork_3 globalPlugins.appendItem -object $TCP_3

$TCP_3 config \
	-tcp_tw_recycle         true \
	-tcp_keepalive_time     75 \
	-tcp_keepalive_intvl    7200 \
	-tcp_wmem_default       4096 \
	-tcp_port_min           1024 \
	-tcp_port_max           65535 \
	-tcp_window_scaling     false \
	-name                   "TCP" \
	-tcp_rmem_default       4096 

set DNS_3 [::IxLoad new ixNetDnsPlugin]

$clientNetwork_3 globalPlugins.appendItem -object $DNS_3

$DNS_3 config \
	-name                   "DNS_3" 

$DNS_3 hostList.clear

$DNS_3 searchList.clear

$DNS_3 nameServerList.clear

set Settings_3 [::IxLoad new ixNetIxLoadSettingsPlugin]

$clientNetwork_3 globalPlugins.appendItem -object $Settings_3

$Settings_3 config \
	-name                   "Settings_3" 

set Ethernet_3 [$clientNetwork_3 getL1Plugin]

set my_ixNetEthernetELMPlugin_3 [::IxLoad new ixNetEthernetELMPlugin]

$Ethernet_3 config \
	-name                   "Ethernet /PHY_3" \
	-cardElm                $my_ixNetEthernetELMPlugin_3

$Ethernet_3 childrenList.clear

set MAC_VLAN_3 [::IxLoad new ixNetL2EthernetPlugin]

$Ethernet_3 childrenList.appendItem -object $MAC_VLAN_3

$MAC_VLAN_3 config \
	-name                   "MAC/VLAN_3" 

$MAC_VLAN_3 childrenList.clear

set IP_3 [::IxLoad new ixNetIpV4V6Plugin]

$MAC_VLAN_3 childrenList.appendItem -object $IP_3

$IP_3 config \
	-name                   "IP_3" 

$IP_3 childrenList.clear

$IP_3 extensionList.clear

$MAC_VLAN_3 extensionList.clear

$Ethernet_3 extensionList.clear


#-----------------------------------------------------------------------
# Setting the ranges starting with the plugin on top of the stack.
#-----------------------------------------------------------------------
$IP_3 rangeList.clear

set IP_R3 [::IxLoad new ixNetIpV4V6Range]

$IP_3 rangeList.appendItem -object $IP_R3

$IP_R3 config \
	-count                  7500 \
	-name                   "IP_R3" \
	-gatewayAddress         "0.0.0.0" \
	-prefix                 16 \
	-mss                    100 \
	-ipAddress              "198.5.30.1" 

set MAC_R3 [$IP_R3 getLowerRelatedRange "MacRange"]

$MAC_R3 config \
	-count                  7500 \
	-mac                    "00:AC:13:1D:4D:00" \
	-name                   "MAC_R3" \
	-incrementBy            "00:00:00:00:01:00" 

set VLAN_R3 [$IP_R3 getLowerRelatedRange "VlanIdRange"]

$VLAN_R3 config \
	-name                   "VLAN_R3" \
	-idIncrMode             1 \
	-priority               0 \
	-innerPriority          0 


#-----------------------------------------------------------------------
# Assign Ports to Client Network.
#-----------------------------------------------------------------------
$clientNetwork_3 portList.appendItem \
    -chassisId  			1 \
    -cardId     			$::IxLoadPrivate::SimpleSettings::port3(CARD_ID) \
    -portId     			$::IxLoadPrivate::SimpleSettings::port3(PORT_ID)


#-----------------------------------------------------------------------
# Build Server Network.
#-----------------------------------------------------------------------
set serverNetwork [::IxLoad new ixNetworkGroup $chassisChain]

$serverNetwork config \
	-name                   "ServerNetwork"

$serverNetwork globalPlugins.clear

set Filter_2 [::IxLoad new ixNetFilterPlugin]

$serverNetwork globalPlugins.appendItem -object $Filter_2

$Filter_2 config \
	-name                  	"Filter_2"

set GratARP_2 [::IxLoad new ixNetGratArpPlugin]

$serverNetwork globalPlugins.appendItem -object $GratARP_2

$GratARP_2 config \
	-name                   "GratARP_2"

set TCP_2 [::IxLoad new ixNetTCPPlugin]

$serverNetwork globalPlugins.appendItem -object $TCP_2

$TCP_2 config \
	-tcp_tw_recycle			true \
	-tcp_keepalive_time     75 \
	-tcp_keepalive_intvl    7200 \
	-tcp_wmem_default       4096 \
	-tcp_port_min           1024 \
	-tcp_port_max           65535 \
	-tcp_window_scaling     false \
	-name                   "TCP_2" \
	-tcp_rmem_default       4096

set DNS_2 [::IxLoad new ixNetDnsPlugin]

$serverNetwork globalPlugins.appendItem -object $DNS_2

$DNS_2 config \
	-name					"DNS_2"

$DNS_2 hostList.clear

$DNS_2 searchList.clear

$DNS_2 nameServerList.clear

set Settings_2 [::IxLoad new ixNetIxLoadSettingsPlugin]

$serverNetwork globalPlugins.appendItem -object $Settings_2

$Settings_2 config \
	-name					"Settings_2"

set Ethernet_2 [$serverNetwork getL1Plugin]

set my_ixNetEthernetELMPlugin_2 [::IxLoad new ixNetEthernetELMPlugin]

$Ethernet_2 config \
	-name					"Ethernet /PHY_2" \
	-cardElm                $my_ixNetEthernetELMPlugin_2

$Ethernet_2 childrenList.clear

set MAC_VLAN_2 [::IxLoad new ixNetL2EthernetPlugin]

$Ethernet_2 childrenList.appendItem -object $MAC_VLAN_2

$MAC_VLAN_2 config \
	-name					"MAC/VLAN_2"

$MAC_VLAN_2 childrenList.clear

set IP_2 [::IxLoad new ixNetIpV4V6Plugin]

$MAC_VLAN_2 childrenList.appendItem -object $IP_2

$IP_2 config \
	-name                   "IP_2"

$IP_2 childrenList.clear

$IP_2 extensionList.clear

$MAC_VLAN_2 extensionList.clear

$Ethernet_2 extensionList.clear


#-----------------------------------------------------------------------
# Setting the ranges starting with the plugin on top of the stack.
#-----------------------------------------------------------------------
$IP_2 rangeList.clear

set IP_R2 [::IxLoad new ixNetIpV4V6Range]

$IP_2 rangeList.appendItem -object $IP_R2

$IP_R2 config \
	-name                   "IP_R2" \
	-gatewayAddress         "0.0.0.0" \
	-prefix                 16 \
	-ipAddress              "198.5.100.101" 

set MAC_R2 [$IP_R2 getLowerRelatedRange "MacRange"]

$MAC_R2 config \
	-count                  10 \
	-mac                    "00:C6:12:02:02:00" \
	-name                   "MAC_R2" \
	-incrementBy            "00:00:00:00:01:00" 

set VLAN_R2 [$IP_R2 getLowerRelatedRange "VlanIdRange"]

$VLAN_R2 config \
	-name                   "VLAN_R2" \
	-idIncrMode             1 \
	-priority               0 \
	-innerPriority          0


#-----------------------------------------------------------------------
# Assign Ports to Server Network.
#-----------------------------------------------------------------------
$serverNetwork portList.appendItem \
    -chassisId  			1 \
    -cardId     			$::IxLoadPrivate::SimpleSettings::serverPort(CARD_ID) \
    -portId     			$::IxLoadPrivate::SimpleSettings::serverPort(PORT_ID)


#-----------------------------------------------------------------------
# MGCP Server Configuration.
#-----------------------------------------------------------------------
set serverTraffic [::IxLoad new ixServerTraffic -name "ServerTraffic"]

$serverTraffic agentList.appendItem \
    -name                   "MGCPServer" \
    -protocol               "MGCP" \
    -type                   "Server"

$serverTraffic agentList(0).pm.parameters.config \
	-listen_port_start		2727

$serverTraffic agentList(0).pm.ll_parameters.config \
     -CommandTimeout        120 

$serverTraffic agentList(0).pm.endpoint_parameters.config \
     -NumberOfEndpoints     10 \
     -NumGateways           60 \
     -EndpointPhoneStartAt	1000 \
	 -EndpointPhoneStep		1 \
	 -EndpointNamePrefix	"aaln/" \
	 -EndpointNameExpandOn	1 \
	 -EndpointNameStartAt	0 \
	 -EndpointNameStep		1 \
	 -GatewayNameStartAt	3000 \
	 -GatewayNamePrefix		"ix" \
	 -GatewayNameStep		1 \
	 -GatewayNameSuffix		".ixia-lab.com" \
	 -GatewayNameExpandOn	1

#-----------------------------------------------------------------------
# MGCP Clients Configuration.
#-----------------------------------------------------------------------

set clientTraffic [::IxLoad new ixClientTraffic -name "ClientTraffic"]
$clientTraffic agentList.appendItem \
    -name                   "MGCPClient" \
    -protocol               "MGCP" \
    -type                   "Client"

$clientTraffic agentList(0).pm.parameters.config \
     -CallAgent_port        "ServerTraffic_MGCPServer:2727" \
	 -GatewaySourcePort		2427

$clientTraffic agentList(0).pm.ll_parameters.config \
     -CommandTimeout        120 \
	 -LocalMediaProperties	"v:on, e:off"

$clientTraffic agentList(0).pm.endpoint_parameters.config \
     -NumberOfEndpoints     10 \
     -EndpointPhoneStartAt	1300 \
     -NumGateways           30 \
 	 -GatewayNameStartAt    3000 \
	 -EndpointPhoneStep		1 \
	 -EndpointNamePrefix	"aaln/" \
	 -EndpointNameExpandOn	1 \
	 -EndpointNameStartAt	0 \
	 -EndpointNameStep		1 \
	 -GatewayNamePrefix		"ix" \
	 -GatewayNameStep		1 \
	 -GatewayNameSuffix		".ixia-lab.com" \
	 -GatewayNameExpandOn	1
     
$clientTraffic agentList(0).pm.mediaSettings.config \
    -szCodecName           "G729B" \
    -szCodecDetails        "BF22PT20" \
    -bModifyPowerLevel		0 \
    -bUseJitter				0 \
	-bUseMOS				0

$clientTraffic agentList(0).pm.scenarios.appendItem \
     -id                    "OriginateCall"

$clientTraffic agentList(0).pm.scenarios.appendItem \
     -id                    "VOICESESSION" 
    
$clientTraffic agentList(0).pm.scenarios.appendItem \
     -id                    "EndCall"

set clientTraffic_3 [::IxLoad new ixClientTraffic -name "ClientTraffic_3"]

$clientTraffic_3 agentList.appendItem \
    -name                   "MGCPClient_3" \
    -protocol               "MGCP" \
    -type                   "Client"

$clientTraffic_3 agentList(0).pm.parameters.config \
     -CallAgent_port        "ServerTraffic_MGCPServer:2727" \
	 -GatewaySourcePort		2427

$clientTraffic_3 agentList(0).pm.ll_parameters.config \
     -CommandTimeout        120 \
	 -LocalMediaProperties	"v:on, e:off"

$clientTraffic_3 agentList(0).pm.endpoint_parameters.config \
     -NumberOfEndpoints     10 \
	 -EndpointPhoneStartAt	1000 \
     -NumGateways           30 \
     -GatewayNameStartAt    3030 \
	 -EndpointPhoneStep		1 \
	 -EndpointNamePrefix	"aaln/" \
	 -EndpointNameExpandOn	1 \
	 -EndpointNameStartAt	0 \
	 -EndpointNameStep		1 \
	 -GatewayNamePrefix		"ix" \
	 -GatewayNameStep		1 \
	 -GatewayNameSuffix		".ixia-lab.com" \
	 -GatewayNameExpandOn	1
     
$clientTraffic_3 agentList(0).pm.mediaSettings.config \
    -szCodecName           "G729B" \
    -szCodecDetails        "BF22PT20" \
    -bModifyPowerLevel		0 \
    -bUseJitter				0 \
	-bUseMOS				0

$clientTraffic_3 agentList(0).pm.scenarios.appendItem \
     -id                    "ReceiveCall"

$clientTraffic_3 agentList(0).pm.scenarios.appendItem \
     -id                    "EndCall"


#-----------------------------------------------------------------------
# Create a client and server mapping and bind into the
# network and traffic that they will be employing.
#-----------------------------------------------------------------------
set clientTrafficNetworkMapping [::IxLoad new ixClientTrafficNetworkMapping \
    -network                $clientNetwork \
    -traffic                $clientTraffic \
    -objectiveType          $::ixObjective(kObjectiveTypeSimulatedUsers) \
    -objectiveValue         100 \
    -standbyTime            130 \
    -rampUpValue            100 \
    -sustainTime            320 \
    -rampDownTime           320
]

set clientTrafficNetworkMapping_3 [::IxLoad new ixClientTrafficNetworkMapping \
    -network                $clientNetwork_3 \
    -traffic                $clientTraffic_3 \
    -objectiveType          $::ixObjective(kObjectiveTypeSimulatedUsers) \
    -objectiveValue         100 \
    -standbyTime            10 \
    -rampUpValue            100 \
    -sustainTime            320 \
    -rampDownTime           220
]

set serverTrafficNetworkMapping [::IxLoad new ixServerTrafficNetworkMapping \
    -network                $serverNetwork \
    -traffic                $serverTraffic \
    -matchClientTotalTime   1
]


#-----------------------------------------------------------------------
# Create the test and bind in the network-traffic mapping it is going
# to employ.
#-----------------------------------------------------------------------
set test [::IxLoad new ixTest \
    -name           		"Test" \
    -statsRequired  		1 \
    -enableResetPorts 		1 \
    -enableForceOwnership 	0 \
]

$test clientCommunityList.appendItem -object $clientTrafficNetworkMapping

$test clientCommunityList.appendItem -object $clientTrafficNetworkMapping_3

$test serverCommunityList.appendItem -object $serverTrafficNetworkMapping


#-----------------------------------------------------------------------
# Create a test controller bound to the previosuly allocated
# chassis chain. This will eventually run the test we created earlier.
#-----------------------------------------------------------------------
set testController [::IxLoad new ixTestController -outputDir 1]

$testController setResultDir "RESULTS/$logName"


#-----------------------------------------------------------------------
# Set up stat collection.
#-----------------------------------------------------------------------
set NS statCollectorUtils

set ::test_server_handle [$testController getTestServerHandle]

${NS}::Initialize -testServerHandle $::test_server_handle

#-----------------------------------------------------------------------
# Clear any stats that may have been registered previously.
#-----------------------------------------------------------------------
${NS}::ClearStats


#-----------------------------------------------------------------------
# Define the stats we would like to collect.
#-----------------------------------------------------------------------
set aggregation_type "kSum"

${NS}::AddStat \
    -caption "Watch_Stat_1" \
    -statSourceType "MGCP Client" \
    -statName "MGCP Simulated Users" \
    -aggregationType $aggregation_type \
    -filterList {}

${NS}::AddStat \
    -caption "Watch_Stat_2" \
    -statSourceType "MGCP Client" \
    -statName "MGCP connections initiated" \
    -aggregationType $aggregation_type \
    -filterList {}

${NS}::AddStat \
    -caption "Watch_Stat_3" \
    -statSourceType "MGCP Client" \
    -statName "MGCP connections completed" \
    -aggregationType $aggregation_type \
    -filterList {}

${NS}::AddStat \
    -caption "Watch_Stat_4" \
    -statSourceType "MGCP Client" \
    -statName "RTP Packets Sent" \
    -aggregationType $aggregation_type \
    -filterList {}

${NS}::AddStat \
    -caption "Watch_Stat_4" \
    -statSourceType "MGCP Client" \
    -statName "RTP Packets Received" \
    -aggregationType $aggregation_type \
    -filterList {}


#-----------------------------------------------------------------------
# Start the collector (runs in the tcl event loop).
#-----------------------------------------------------------------------
proc ::my_stat_collector_command {args} {
    puts "====================================="
    puts "INCOMING STAT RECORD >>> $args"
    puts "Len = [llength $args]"
    puts  [lindex $args 0]
    puts  [lindex $args 1]
    puts "====================================="
}

${NS}::StartCollector -command ::my_stat_collector_command

$testController run $test


#-----------------------------------------------------------------------
# Have the script (v)wait until the test is over.
#-----------------------------------------------------------------------
vwait ::ixTestControllerMonitor
puts $::ixTestControllerMonitor


#-----------------------------------------------------------------------
# Stop the collector (running in the tcl event loop).
#-----------------------------------------------------------------------
${NS}::StopCollector

#-----------------------------------------------------------------------
# Cleanup.
#-----------------------------------------------------------------------
$testController releaseConfigWaitFinish

::IxLoad delete $chassisChain

::IxLoad delete $clientNetwork

::IxLoad delete $clientNetwork_3

::IxLoad delete $serverNetwork

::IxLoad delete $clientTraffic

::IxLoad delete $clientTraffic_3

::IxLoad delete $serverTraffic

::IxLoad delete $Filter_1

::IxLoad delete $Filter_2

::IxLoad delete $Filter_3

::IxLoad delete $GratARP_1

::IxLoad delete $GratARP_2

::IxLoad delete $GratARP_3

::IxLoad delete $TCP_1

::IxLoad delete $TCP_2

::IxLoad delete $TCP_3

::IxLoad delete $DNS_1

::IxLoad delete $DNS_2

::IxLoad delete $DNS_3

::IxLoad delete $Settings_1

::IxLoad delete $Settings_2

::IxLoad delete $Settings_3

::IxLoad delete $Ethernet_1

::IxLoad delete $Ethernet_2

::IxLoad delete $Ethernet_3

::IxLoad delete $my_ixNetEthernetELMPlugin_1

::IxLoad delete $my_ixNetEthernetELMPlugin_2

::IxLoad delete $my_ixNetEthernetELMPlugin_3

::IxLoad delete $MAC_VLAN_1

::IxLoad delete $MAC_VLAN_2

::IxLoad delete $MAC_VLAN_3

::IxLoad delete $IP_1

::IxLoad delete $IP_2

::IxLoad delete $IP_3

::IxLoad delete $IP_R1

::IxLoad delete $IP_R2

::IxLoad delete $IP_R3

::IxLoad delete $MAC_R1

::IxLoad delete $MAC_R2

::IxLoad delete $MAC_R3

::IxLoad delete $VLAN_R1

::IxLoad delete $VLAN_R2

::IxLoad delete $VLAN_R3

::IxLoad delete $clientTrafficNetworkMapping

::IxLoad delete $clientTrafficNetworkMapping_3

::IxLoad delete $serverTrafficNetworkMapping

::IxLoad delete $test

::IxLoad delete $testController

::IxLoad delete $logger

::IxLoad delete $logEngine


#-----------------------------------------------------------------------
# Disconnect / Release application lock.
#-----------------------------------------------------------------------

}] {
    puts $errorInfo
}

::IxLoad disconnect

