#-----------------------------------------------------------------------
# Setup path and load IxLoad package.
#-----------------------------------------------------------------------
source ../setup_simple.tcl


#-----------------------------------------------------------------------
# Initialize IxLoad
# IxLoad connect should always be called, even for local scripts.
#-----------------------------------------------------------------------
::IxLoad connect $::IxLoadPrivate::SimpleSettings::remoteServer

# Once we've connected, make sure we disconnect, even if there's a problem
if [catch {


#-----------------------------------------------------------------------
# Loads plugins for specific protocols configured in this test.
#-----------------------------------------------------------------------
global ixAppPluginManager
$ixAppPluginManager load "HTTP"


#-----------------------------------------------------------------------
# Logger setup.
#---------------------------------------------------------------------
set logtag "IxLoad-api"
set logName "HTTP_StateStats_SM"
set logger [::IxLoad new ixLogger $logtag 1]
set logEngine [$logger getEngine]
$logEngine setLevels $::ixLogger(kLevelDebug) $::ixLogger(kLevelInfo)
$logEngine setFile $logName 2 256 1


#-----------------------------------------------------------------------
# Package require the stat collection utilities.
#-----------------------------------------------------------------------
package require statCollectorUtils
set scu_version [package require statCollectorUtils]
puts "statCollectorUtils package version = $scu_version"


#-----------------------------------------------------------------------
# Build Chassis Chain.
#-----------------------------------------------------------------------
set chassisChain [::IxLoad new ixChassisChain]

$chassisChain addChassis $::IxLoadPrivate::SimpleSettings::chassisName


#-----------------------------------------------------------------------
# Build Client Network.
#-----------------------------------------------------------------------
set clientNetwork [::IxLoad new ixNetworkGroup $chassisChain]

$clientNetwork config \
	-name                	"ClientNetwork" 

$clientNetwork globalPlugins.clear

set Filter_1 [::IxLoad new ixNetFilterPlugin]

$clientNetwork globalPlugins.appendItem -object $Filter_1

$Filter_1 config \
	-name                   "Filter_1" 

set GratARP_1 [::IxLoad new ixNetGratArpPlugin]

$clientNetwork globalPlugins.appendItem -object $GratARP_1

$GratARP_1 config \
	-name                   "GratARP_1" 

set TCP_1 [::IxLoad new ixNetTCPPlugin]

$clientNetwork globalPlugins.appendItem -object $TCP_1

$TCP_1 config \
	-tcp_tw_recycle         true \
	-tcp_keepalive_time     75 \
	-tcp_keepalive_intvl    7200 \
	-tcp_wmem_default       4096 \
	-tcp_port_min           1024 \
	-tcp_port_max           65535 \
	-tcp_window_scaling     false \
	-name                   "TCP_1" \
	-tcp_rmem_default       4096 

set DNS_1 [::IxLoad new ixNetDnsPlugin]

$clientNetwork globalPlugins.appendItem -object $DNS_1

$DNS_1 config \
	-name                   "DNS_1" 

$DNS_1 hostList.clear

$DNS_1 searchList.clear

$DNS_1 nameServerList.clear

set Settings_1 [::IxLoad new ixNetIxLoadSettingsPlugin]

$clientNetwork globalPlugins.appendItem -object $Settings_1

$Settings_1 config \
	-name                   "Settings_1" 

set Ethernet_1 [$clientNetwork getL1Plugin]

set my_ixNetEthernetELMPlugin_1 [::IxLoad new ixNetEthernetELMPlugin]

$my_ixNetEthernetELMPlugin_1 config 

$Ethernet_1 config \
	-name                   "Ethernet /PHY_1" \
	-cardElm                 $my_ixNetEthernetELMPlugin_1 

$Ethernet_1 childrenList.clear

set MAC_VLAN_1 [::IxLoad new ixNetL2EthernetPlugin]

$Ethernet_1 childrenList.appendItem -object $MAC_VLAN_1

$MAC_VLAN_1 config \
	-name                   "MAC/VLAN-1" 

$MAC_VLAN_1 childrenList.clear

set IP_1 [::IxLoad new ixNetIpV4V6Plugin]

$MAC_VLAN_1 childrenList.appendItem -object $IP_1

$IP_1 config \
	-name                   "IP-1" 

$IP_1 childrenList.clear

$IP_1 extensionList.clear

$MAC_VLAN_1 extensionList.clear

$Ethernet_1 extensionList.clear

#-----------------------------------------------------------------------
# Setting the ranges starting with the plugin on top of the stack.
#-----------------------------------------------------------------------
$IP_1 rangeList.clear

set IP_R1 [::IxLoad new ixNetIpV4V6Range]

$IP_1 rangeList.appendItem -object $IP_R1

$IP_R1 config \
	-count                  100 \
	-name                   "IP_R1" \
	-gatewayAddress         "0.0.0.0" \
	-autoMacGeneration      true \
	-prefix                 16 \
	-mss                    100 \
	-ipAddress              "198.18.2.1" 

set MAC_R1 [$IP_R1 getLowerRelatedRange "MacRange"]

$MAC_R1 config \
	-count                  100 \
	-mac                    "00:C6:12:02:01:00" \
	-name                   "MAC_R1" 

set VLAN_R1 [$IP_R1 getLowerRelatedRange "VlanIdRange"]

$VLAN_R1 config \
	-name                   "VLAN_R1" \
	-idIncrMode             1 \
	-priority               0 \
	-innerPriority          0 


#-----------------------------------------------------------------------
# Assign Ports to Client Network.
#-----------------------------------------------------------------------
$clientNetwork portList.appendItem \
    -chassisId  			1 \
    -cardId     			$::IxLoadPrivate::SimpleSettings::clientPort(CARD_ID)\
    -portId     			$::IxLoadPrivate::SimpleSettings::clientPort(PORT_ID)

$clientNetwork portList.appendItem \
    -chassisId  			1 \
    -cardId     			$::IxLoadPrivate::SimpleSettings::port3(CARD_ID)\
    -portId     			$::IxLoadPrivate::SimpleSettings::port3(PORT_ID)


#-----------------------------------------------------------------------
# Build Server Network.
#-----------------------------------------------------------------------
set serverNetwork [::IxLoad new ixNetworkGroup $chassisChain]

$serverNetwork config \
	-name          			"ServerNetwork" 

$serverNetwork globalPlugins.clear

set Filter_2 [::IxLoad new ixNetFilterPlugin]

$serverNetwork globalPlugins.appendItem -object $Filter_2

$Filter_2 config \
	-name                   "Filter_2" 

set GratARP_2 [::IxLoad new ixNetGratArpPlugin]

$serverNetwork globalPlugins.appendItem -object $GratARP_2

$GratARP_2 config \
	-name                   "GratARP_2" 

set TCP_2 [::IxLoad new ixNetTCPPlugin]

$serverNetwork globalPlugins.appendItem -object $TCP_2

$TCP_2 config \
	-tcp_tw_recycle			true \
	-tcp_keepalive_time     75 \
	-tcp_keepalive_intvl    7200 \
	-tcp_wmem_default       4096 \
	-tcp_port_min           1024 \
	-tcp_port_max           65535 \
	-tcp_window_scaling     false \
	-name                   "TCP_2" \
	-tcp_rmem_default       4096

set DNS_2 [::IxLoad new ixNetDnsPlugin]

$serverNetwork globalPlugins.appendItem -object $DNS_2

$DNS_2 config \
	-name					"DNS_2"

$DNS_2 hostList.clear

$DNS_2 searchList.clear

$DNS_2 nameServerList.clear

set Settings_2 [::IxLoad new ixNetIxLoadSettingsPlugin]

$serverNetwork globalPlugins.appendItem -object $Settings_2

$Settings_2 config \
	-name					"Settings_2"

set Ethernet_2 [$serverNetwork getL1Plugin]

set my_ixNetEthernetELMPlugin_2 [::IxLoad new ixNetEthernetELMPlugin]

$Ethernet_2 config \
	-name					"Ethernet /PHY_2" \
	-cardElm                $my_ixNetEthernetELMPlugin_2

$Ethernet_2 childrenList.clear

set MAC_VLAN_2 [::IxLoad new ixNetL2EthernetPlugin]

$Ethernet_2 childrenList.appendItem -object $MAC_VLAN_2

$MAC_VLAN_2 config \
	-name					"MAC/VLAN_2"

$MAC_VLAN_2 childrenList.clear

set IP_2 [::IxLoad new ixNetIpV4V6Plugin]

$MAC_VLAN_2 childrenList.appendItem -object $IP_2

$IP_2 config \
	-name                   "IP_2"

$IP_2 childrenList.clear

$IP_2 extensionList.clear

$MAC_VLAN_2 extensionList.clear

$Ethernet_2 extensionList.clear


#-----------------------------------------------------------------------
# Setting the ranges starting with the plugin on top of the stack.
#-----------------------------------------------------------------------
$IP_2 rangeList.clear

set IP_R2 [::IxLoad new ixNetIpV4V6Range]

$IP_2 rangeList.appendItem -object $IP_R2

$IP_R2 config \
	-name                   "IP_R2" \
	-gatewayAddress         "0.0.0.0" \
	-prefix                 16 \
	-mss                    100 \
	-ipAddress              "198.18.200.1" 

set MAC_R2 [$IP_R2 getLowerRelatedRange "MacRange"]

$MAC_R2 config \
	-mac                    "00:C6:12:02:02:00" \
	-name                   "MAC_R2" 

set VLAN_R2 [$IP_R2 getLowerRelatedRange "VlanIdRange"]

$VLAN_R2 config \
	-name					"VLAN_R2" \
	-idIncrMode             1 \
	-priority               0 \
	-innerPriority          0


#-----------------------------------------------------------------------
# Assign Ports to Server Network.
#-----------------------------------------------------------------------
$serverNetwork portList.appendItem \
    -chassisId  			1 \
    -cardId     			$::IxLoadPrivate::SimpleSettings::serverPort(CARD_ID)\
    -portId     			$::IxLoadPrivate::SimpleSettings::serverPort(PORT_ID)


#-----------------------------------------------------------------------
# Construct Client Traffic
# The ActivityModel acts as a factory for creating agents which actually
# generate the test traffic.
#-----------------------------------------------------------------------
set clientTraffic [::IxLoad new ixClientTraffic -name "ClientTraffic"]

$clientTraffic agentList.appendItem \
    -name                   "HTTPClient1" \
    -protocol               "HTTP" \
    -type                   "Client" \
    -maxSessions            3 \
    -httpVersion            $::HTTP_Client(kHttpVersion10) \
    -keepAlive              0 \
    -maxPersistentRequests  3 \
    -followHttpRedirects    0 \
    -enableCookieSupport    0 \
    -enableHttpProxy        0 \
    -enableHttpsProxy       0 \
    -browserEmulation       $::HTTP_Client(kBrowserTypeIE5) \
    -enableSsl              0
                    
#-----------------------------------------------------------------------
# Add actions to this client agent.
#-----------------------------------------------------------------------
foreach {pageObject destination} {
    "/4k.htm" "ServerTraffic_HTTPServer"
    "/8k.htm" "ServerTraffic_HTTPServer"
    "/128k.htm" "ServerTraffic_HTTPServer"
} {
    $clientTraffic agentList(0).actionList.appendItem  \
        -command        "GET" \
        -destination    $destination \
        -pageObject     $pageObject
}

$clientTraffic agentList.appendItem \
    -name                   "HTTPClient2" \
    -protocol               "HTTP" \
    -type                   "Client" \
    -maxSessions            3 \
    -httpVersion            $::HTTP_Client(kHttpVersion11) \
    -keepAlive              0 \
    -maxPersistentRequests  3 \
    -followHttpRedirects    0 \
    -enableCookieSupport    0 \
    -enableHttpProxy        0 \
    -enableHttpsProxy       0 \
    -browserEmulation       $::HTTP_Client(kBrowserTypeIE5) \
    -enableSsl              0  

#-----------------------------------------------------------------------
# Add actions to this client agent.
#-----------------------------------------------------------------------
foreach {pageObject destination} {
    "/4k.htm" "ServerTraffic_HTTPServer"
    "/8k.htm" "ServerTraffic_HTTPServer"
    "/128k.htm" "ServerTraffic_HTTPServer"
} {
    $clientTraffic agentList(1).actionList.appendItem  \
        -command        	"GET" \
        -destination    	$destination \
        -pageObject     	$pageObject
}

#-----------------------------------------------------------------------
# Construct Server Traffic.
#-----------------------------------------------------------------------
set serverTraffic [::IxLoad new ixServerTraffic -name "ServerTraffic"]

$serverTraffic agentList.appendItem \
    -name       			"HTTPServer" \
    -protocol   			"HTTP" \
    -type       			"Server" \
    -httpPort   			80 

for {set idx 0} {$idx < [$serverTraffic agentList(0).responseHeaderList.indexCount]} {incr idx} {
    set response [$serverTraffic agentList(0).responseHeaderList.getItem $idx]
    if {[$response cget -name] == "200_OK"} {
        set response200ok $response
    }
    if {[$response cget -name] == "404_PageNotFound"} {
        set response404_PageNotFound $response
    }
}

#-----------------------------------------------------------------------
# Clear pre-defined web pages, add new web pages.
#-----------------------------------------------------------------------
$serverTraffic agentList(0).webPageList.clear

$serverTraffic agentList(0).webPageList.appendItem \
    -page           		"/4k.html" \
    -payloadType    		"range" \
    -payloadSize    		"4096-4096" \
    -response       		$response200ok

$serverTraffic agentList(0).webPageList.appendItem \
    -page           		"/8k.html" \
    -payloadType    		"range" \
    -payloadSize    		"8192-8192" \
    -response       		$response404_PageNotFound

$serverTraffic agentList(0).webPageList.appendItem \
    -page           		"/128k.html" \
    -payloadType    		"range" \
    -payloadSize    		"131072" \
    -response       		$response200ok


#-----------------------------------------------------------------------
# Create a client and server mapping and bind into the
# network and traffic that they will be employing.
#-----------------------------------------------------------------------
set clientTrafficNetworkMapping [::IxLoad new ixClientTrafficNetworkMapping \
    -network                $clientNetwork \
    -traffic                $clientTraffic \
    -objectiveType          $::ixObjective(kObjectiveTypeSimulatedUsers) \
    -objectiveValue         20 \
    -rampUpValue            5 \
    -sustainTime            60 \
    -rampDownTime           20
]

set serverTrafficNetworkMapping [::IxLoad new ixServerTrafficNetworkMapping \
    -network                $serverNetwork \
    -traffic                $serverTraffic \
    -matchClientTotalTime   1
]


#-----------------------------------------------------------------------
# Set objective type, value and port map for client activity.
#-----------------------------------------------------------------------
$clientTrafficNetworkMapping setObjectiveTypeForActivity "HTTPClient1" $::ixObjective(kObjectiveTypeConnectionRate)

$clientTrafficNetworkMapping setObjectiveValueForActivity "HTTPClient1" 200

$clientTrafficNetworkMapping setPortMapForActivity "HTTPClient1" $::ixPortMap(kPortMapFullMesh)

$clientTrafficNetworkMapping setObjectiveTypeForActivity "HTTPClient2" $::ixObjective(kObjectiveTypeConnectionRate)

$clientTrafficNetworkMapping setObjectiveValueForActivity "HTTPClient2" 200

$clientTrafficNetworkMapping setPortMapForActivity "HTTPClient2" $::ixPortMap(kPortMapFullMesh)


#-----------------------------------------------------------------------
# Create the test and bind in the network-traffic mapping it is going
# to employ.
#-----------------------------------------------------------------------
set test [::IxLoad new ixTest \
    -name               	"Test" \
    -statsRequired      	1 \
    -enableResetPorts   	0
]

$test clientCommunityList.appendItem -object $clientTrafficNetworkMapping

$test serverCommunityList.appendItem -object $serverTrafficNetworkMapping


#-----------------------------------------------------------------------
# Create a test controller bound to the previosuly allocated
# chassis chain. This will eventually run the test we created earlier.
#-----------------------------------------------------------------------
set testController [::IxLoad new ixTestController -outputDir 1]

$testController setResultDir "RESULTS/$logName"


#-----------------------------------------------------------------------
# Set up stat collection.
#-----------------------------------------------------------------------
set NS statCollectorUtils

set ::test_server_handle [$testController getTestServerHandle]

${NS}::Initialize -testServerHandle $::test_server_handle

$test getStatCatalog


#-----------------------------------------------------------------------
# Clear any stats that may have been registered previously.
#-----------------------------------------------------------------------
${NS}::ClearStats


#-----------------------------------------------------------------------
# Define the stats we would like to collect.
#-----------------------------------------------------------------------
${NS}::AddStat \
    -caption "Watch_Stat_11" \
    -statSourceType "HTTP Client" \
    -statName "Run State" \
    -aggregationType kString \
    -filterList {{Activity} {"ClientTraffic@ClientNetwork - HTTPClient1"}}

${NS}::AddStat \
    -caption "Watch_Stat_12" \
    -statSourceType "HTTP Client" \
    -statName "Run State" \
    -aggregationType kString \
    -filterList {{Activity} {"ClientTraffic@ClientNetwork - HTTPClient2"}}

${NS}::AddStat \
    -caption "Watch_Stat_2" \
    -statSourceType "HTTP Client" \
    -statName "Iteration Count" \
    -aggregationType kMax \
    -filterList {}

${NS}::AddStat \
    -caption "Watch_Stat_3" \
    -statSourceType "HTTP Client" \
    -statName "HTTP Time To Last Byte (us)" \
    -aggregationType kWeightedAverage \
    -filterList {}

${NS}::AddStat \
    -caption "Watch_Stat_4" \
    -statSourceType "HTTP Client" \
    -statName "HTTP Bytes Sent" \
    -aggregationType kRate \
    -filterList {}

${NS}::AddStat \
    -caption "Watch_Stat_5" \
    -statSourceType "HTTP Client" \
    -statName "HTTP Bytes Received" \
    -aggregationType kRate \
    -filterList {}

#-----------------------------------------------------------------------
# Start the collector (runs in the tcl event loop).
#-----------------------------------------------------------------------
proc ::my_stat_collector_command {args} {
    puts "====================================="
    puts "INCOMING STAT RECORD >>> $args"
    puts "Len = [llength $args]"
    puts  [lindex $args 0]
    puts  [lindex $args 1]
    puts "====================================="
}

${NS}::StartCollector -command ::my_stat_collector_command -interval 4

$testController run $test


#-----------------------------------------------------------------------
# Start the collector (runs in the tcl event loop).
#-----------------------------------------------------------------------
vwait ::ixTestControllerMonitor
puts $::ixTestControllerMonitor


#-----------------------------------------------------------------------
# Stop the collector (running in the tcl event loop).
#-----------------------------------------------------------------------
${NS}::StopCollector


#-----------------------------------------------------------------------
# Generate report.
#-----------------------------------------------------------------------
#$testController generateReport -detailedReport 1 -format "PDF;HTML"


#-----------------------------------------------------------------------
# Cleanup.
#-----------------------------------------------------------------------
$testController releaseConfigWaitFinish

::IxLoad delete $chassisChain

::IxLoad delete $clientNetwork

::IxLoad delete $serverNetwork

::IxLoad delete $clientTraffic

::IxLoad delete $serverTraffic

::IxLoad delete $Filter_1

::IxLoad delete $Filter_2

::IxLoad delete $GratARP_1

::IxLoad delete $GratARP_2

::IxLoad delete $TCP_1

::IxLoad delete $TCP_2

::IxLoad delete $DNS_1

::IxLoad delete $DNS_2

::IxLoad delete $Settings_1

::IxLoad delete $Settings_2

::IxLoad delete $Ethernet_1

::IxLoad delete $Ethernet_2

::IxLoad delete $my_ixNetEthernetELMPlugin_1

::IxLoad delete $my_ixNetEthernetELMPlugin_2

::IxLoad delete $MAC_VLAN_1

::IxLoad delete $MAC_VLAN_2

::IxLoad delete $IP_1

::IxLoad delete $IP_2

::IxLoad delete $IP_R1

::IxLoad delete $IP_R2

::IxLoad delete $MAC_R1

::IxLoad delete $MAC_R2

::IxLoad delete $VLAN_R1

::IxLoad delete $VLAN_R2

::IxLoad delete $clientTrafficNetworkMapping

::IxLoad delete $serverTrafficNetworkMapping

::IxLoad delete $test

::IxLoad delete $testController

::IxLoad delete $logger

::IxLoad delete $logEngine


#-----------------------------------------------------------------------
# Disconnect / Release application lock.
#-----------------------------------------------------------------------

}] {
    puts $errorInfo
}

::IxLoad disconnect
