from .IxRestPyUtils import *
import inspect
import collections

protocolName = ['stateless', 'HTTP', 'FTP', 'SMTP', 'POP3', 'Streaming', 'Video', 'DNS', 'IMAP', 'VoIP']

class GlobalProperties():

	__instance = None
	testInstance = None
	@staticmethod
	def getInstance():
		""" Static access method. """
		if GlobalProperties.__instance == None:
			GlobalProperties()
		return GlobalProperties.__instance

	def __init__(self):
		""" Virtually private constructor. """
		if GlobalProperties.__instance != None:
			raise Exception("This is a singleton!")
		else:
			GlobalProperties.__instance = self


class IxSessionWrapper():

	def __init__(self, version):
		self.session = createSession(version=version)

	def start(self):
		self.session.start()
		self.ixload = IxLoadRestWrapper(self.session.ixload)
		self.id = self.session.id
		self.remotePid = self.session.remotePid

	def getUrl(self):
		return self.session.getUrl()

	def closeSession(self):
		closeSession(self.session)


class RestObjectBaseClass(object):

	def __init__(self, webObject):
		self.__webObject = webObject

	def setOptions(self, **kwargs):
		self.__webObject.setOptions(**kwargs)


class IxLoadRestWrapper(RestObjectBaseClass):

	def __init__(self, ixload):
		super(IxLoadRestWrapper, self).__init__(ixload)
		self.__ixload = ixload
		self.stats = IxRestStatControllerWrapper(DummyRestStatController())
		self.preferences = IxRestPreferencesWrapper(ixload.preferences)
		self.versions = IxVersionControllerWrapper(ixload.versions)
		self.chassisBuilder = IxChassisBuilderWrapper(ixload.chassisBuilder)
		self.test = IxTestControllerWrapper(ixload.test)
		self.test.setIxLoadRest(self)
		self.sessionOverview = IxRestSessionOverviewWrapper(ixload.sessionOverview)
		self.chassischain = IxChassisChainWrapper(ixload.chassischain)
		self.sessionMetrics = IxSessionMetricsWrapper(ixload.sessionMetrics)

	properties = []

	def __getattribute__(self, name):
		if name in IxLoadRestWrapper.properties and super(IxLoadRestWrapper, self).__getattribute__(name):
			return getattr(super(IxLoadRestWrapper, self).__getattribute__("_IxLoadRestWrapper__ixload"), name)
		else:
			return super(IxLoadRestWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxLoadRestWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxLoadRestWrapper, self).__getattribute__("_IxLoadRestWrapper__ixload"), name, value)
			super(IxLoadRestWrapper, self).__setattr__(name, value)

	def extractDataModelToFile(self, fullPath, asJSON=False):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__ixload.extractDataModelToFile(**kwargs)

	def findURLs(self, urlContains="", propertyName="", propertyValue=""):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__ixload.findURLs(**kwargs)

	def generateIxLoadRestPyWrapper(self, fullPath):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__ixload.generateIxLoadRestPyWrapper(**kwargs)

	def reinit(self):
		super(IxLoadRestWrapper, self).__setattr__("stats", IxRestStatControllerWrapper(self.__ixload.stats))


class IxRestStatControllerWrapper(RestObjectBaseClass):

	def __init__(self, stats):
		super(IxRestStatControllerWrapper, self).__init__(stats)
		self.__stats = stats
		self.IxServer = IxPersistentStatSourceWrapper(getattr(stats, 'IxServer', stats.IxServer))
		self.restStatViews = IxStatViewListWrapper(stats)
		g = GlobalProperties.getInstance()
		if g.testInstance != None:
			protocolSet = set()
			for community in g.testInstance.activeTest.communityList:
				for activity in community.activityList:
					protocolSet.add(activity.protocolAndType)
			for protocol in protocolSet:
				if protocol == 'stateless Peer':
					self.StatelessPeerPerStreamRx = IxPersistentStatSourceWrapper(getattr(stats, 'StatelessPeerPerStreamRx', stats.StatelessPeerPerStreamRx))
					self.StatelessPeer = IxPersistentStatSourceWrapper(getattr(stats, 'StatelessPeer', stats.StatelessPeer))
					self.StatelessPeerPerStreamTx = IxPersistentStatSourceWrapper(getattr(stats, 'StatelessPeerPerStreamTx', stats.StatelessPeerPerStreamTx))
				if protocol == 'HTTP Client':
					self.HTTPClientPerURL = IxPersistentStatSourceWrapper(getattr(stats, 'HTTPClientPerURL', stats.HTTPClientPerURL))
					self.HTTPClient = IxPersistentStatSourceWrapper(getattr(stats, 'HTTPClient', stats.HTTPClient))
				if protocol == 'HTTP Server':
					self.HTTPServerPerURL = IxPersistentStatSourceWrapper(getattr(stats, 'HTTPServerPerURL', stats.HTTPServerPerURL))
					self.HTTPServer = IxPersistentStatSourceWrapper(getattr(stats, 'HTTPServer', stats.HTTPServer))
				if protocol == 'FTP Client':
					self.FTPClient = IxPersistentStatSourceWrapper(getattr(stats, 'FTPClient', stats.FTPClient))
				if protocol == 'FTP Server':
					self.FTPServer = IxPersistentStatSourceWrapper(getattr(stats, 'FTPServer', stats.FTPServer))
				if protocol == 'SMTP Client':
					self.SMTPClient = IxPersistentStatSourceWrapper(getattr(stats, 'SMTPClient', stats.SMTPClient))
				if protocol == 'SMTP Server':
					self.SMTPServer = IxPersistentStatSourceWrapper(getattr(stats, 'SMTPServer', stats.SMTPServer))
				if protocol == 'POP3 Client':
					self.POP3Client = IxPersistentStatSourceWrapper(getattr(stats, 'POP3Client', stats.POP3Client))
				if protocol == 'POP3 Server':
					self.POP3Server = IxPersistentStatSourceWrapper(getattr(stats, 'POP3Server', stats.POP3Server))
				if protocol == 'Streaming Client':
					self.HLSClient = IxPersistentStatSourceWrapper(getattr(stats, 'HLSClient', stats.HLSClient))
					self.HLSHTTPSSL = IxPersistentStatSourceWrapper(getattr(stats, 'HLSHTTPSSL', stats.HLSHTTPSSL))
					self.HTTPStreamingClient = IxPersistentStatSourceWrapper(getattr(stats, 'HTTPStreamingClient', stats.HTTPStreamingClient))
					self.SilverlightClient = IxPersistentStatSourceWrapper(getattr(stats, 'SilverlightClient', stats.SilverlightClient))
					self.HTTPHTTPStreamingClient = IxPersistentStatSourceWrapper(getattr(stats, 'HTTP(HTTPStreamingClient)', stats.HTTPHTTPStreamingClient))
				if protocol == 'Video Client':
					self.VideoClientPerStream = IxPersistentStatSourceWrapper(getattr(stats, 'VideoClientPerStream', stats.VideoClientPerStream))
					self.VideoClientIPTVPerStream = IxPersistentStatSourceWrapper(getattr(stats, 'VideoClientIPTVPerStream', stats.VideoClientIPTVPerStream))
					self.VideoClient = IxPersistentStatSourceWrapper(getattr(stats, 'VideoClient', stats.VideoClient))
				if protocol == 'Video Server':
					self.VideoServer = IxPersistentStatSourceWrapper(getattr(stats, 'VideoServer', stats.VideoServer))
				if protocol == 'DNS Client':
					self.DNSClient = IxPersistentStatSourceWrapper(getattr(stats, 'DNSClient', stats.DNSClient))
				if protocol == 'DNS Server':
					self.DNSServer = IxPersistentStatSourceWrapper(getattr(stats, 'DNSServer', stats.DNSServer))
				if protocol == 'IMAP Client':
					self.IMAPClient = IxPersistentStatSourceWrapper(getattr(stats, 'IMAPClient', stats.IMAPClient))
				if protocol == 'IMAP Server':
					self.IMAPServer = IxPersistentStatSourceWrapper(getattr(stats, 'IMAPServer', stats.IMAPServer))
				if protocol == 'VoIP Peer':
					self.WSWSSConnectionsVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'WSWSSConnections(VoIPSip)', stats.WSWSSConnectionsVoIPSip))
					self.VideoRTPPerChannelVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'VideoRTPPerChannel(VoIPSip)', stats.VideoRTPPerChannelVoIPSip))
					self.RTPPerChannelVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'RTPPerChannel(VoIPSip)', stats.RTPPerChannelVoIPSip))
					self.VoIPPeer = IxPersistentStatSourceWrapper(getattr(stats, 'VoIPPeer', stats.VoIPPeer))
					self.ErrorsVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'Errors(VoIPSip)', stats.ErrorsVoIPSip))
					self.VideoSignalingVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'VideoSignaling(VoIPSip)', stats.VideoSignalingVoIPSip))
					self.MediaFlowsVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'MediaFlows(VoIPSip)', stats.MediaFlowsVoIPSip))
					self.FlowVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'Flow(VoIPSip)', stats.FlowVoIPSip))
					self.SIPVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'SIP(VoIPSip)', stats.SIPVoIPSip))
					self.VideoRTPVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'VideoRTP(VoIPSip)', stats.VideoRTPVoIPSip))
					self.CPSRateVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'CPSRate(VoIPSip)', stats.CPSRateVoIPSip))
					self.SignalingVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'Signaling(VoIPSip)', stats.SignalingVoIPSip))
					self.BHCMVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'BHCM(VoIPSip)', stats.BHCMVoIPSip))
					self.RTPVoIPSip = IxPersistentStatSourceWrapper(getattr(stats, 'RTP(VoIPSip)', stats.RTPVoIPSip))

	properties = []

	def __getattribute__(self, name):
		if name in IxRestStatControllerWrapper.properties and super(IxRestStatControllerWrapper, self).__getattribute__(name):
			return getattr(super(IxRestStatControllerWrapper, self).__getattribute__("_IxRestStatControllerWrapper__stats"), name)
		else:
			return super(IxRestStatControllerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxRestStatControllerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxRestStatControllerWrapper, self).__getattribute__("_IxRestStatControllerWrapper__stats"), name, value)
			super(IxRestStatControllerWrapper, self).__setattr__(name, value)


class DummyPersistentStatSource(object):

	def __init__(self):
		self.availableStats = []
		self.configuredStats = []
		self.values = []
		self.enabled = False


class DummyRestStatController(object):

	def __init__(self):
		self.IxServer = DummyPersistentStatSource()
		self.DNSServer = DummyPersistentStatSource()
		self.restStatViews = []
		self.DNSClient = DummyPersistentStatSource()
		self.IMAPServer = DummyPersistentStatSource()
		self.IMAPClient = DummyPersistentStatSource()
		self.POP3Server = DummyPersistentStatSource()
		self.POP3Client = DummyPersistentStatSource()
		self.SMTPClient = DummyPersistentStatSource()
		self.SMTPServer = DummyPersistentStatSource()
		self.HTTPServerPerURL = DummyPersistentStatSource()
		self.HTTPServer = DummyPersistentStatSource()
		self.HTTPClientPerURL = DummyPersistentStatSource()
		self.HTTPClient = DummyPersistentStatSource()
		self.StatelessPeerPerStreamRx = DummyPersistentStatSource()
		self.StatelessPeer = DummyPersistentStatSource()
		self.StatelessPeerPerStreamTx = DummyPersistentStatSource()
		self.FTPServer = DummyPersistentStatSource()
		self.FTPClient = DummyPersistentStatSource()
		self.HLSClient = DummyPersistentStatSource()
		self.HLSHTTPSSL = DummyPersistentStatSource()
		self.HTTPStreamingClient = DummyPersistentStatSource()
		self.SilverlightClient = DummyPersistentStatSource()
		self.HTTPHTTPStreamingClient = DummyPersistentStatSource()
		self.VideoClientPerStream = DummyPersistentStatSource()
		self.VideoServer = DummyPersistentStatSource()
		self.VideoClientIPTVPerStream = DummyPersistentStatSource()
		self.VideoClient = DummyPersistentStatSource()
		self.WSWSSConnectionsVoIPSip = DummyPersistentStatSource()
		self.VideoRTPPerChannelVoIPSip = DummyPersistentStatSource()
		self.RTPPerChannelVoIPSip = DummyPersistentStatSource()
		self.VoIPPeer = DummyPersistentStatSource()
		self.ErrorsVoIPSip = DummyPersistentStatSource()
		self.VideoSignalingVoIPSip = DummyPersistentStatSource()
		self.MediaFlowsVoIPSip = DummyPersistentStatSource()
		self.FlowVoIPSip = DummyPersistentStatSource()
		self.SIPVoIPSip = DummyPersistentStatSource()
		self.VideoRTPVoIPSip = DummyPersistentStatSource()
		self.CPSRateVoIPSip = DummyPersistentStatSource()
		self.SignalingVoIPSip = DummyPersistentStatSource()
		self.BHCMVoIPSip = DummyPersistentStatSource()
		self.RTPVoIPSip = DummyPersistentStatSource()


class StatsNameDNSClient(object):
	def __init__(self):
		self.kDNSTotalQueriesFailedNotImplemented = "DNS Total Queries Failed (Not Implemented)"
		self.kSOAQueriesSuccessfulWithoutMatch = "SOA Queries Successful Without Match"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kDNSResponseLatencyin1to5ms = "DNS Response Latency in 1 to 5 ms"
		self.kDNSSECAQueriesFailed = "DNSSEC (A) Queries Failed"
		self.kATypeQueriesSuccessfulWithoutMatch = "A Type Queries Successful Without Match"
		self.kDNSSECQueriesFailedNoSignatures = "DNSSEC Queries Failed (No Signature)/s"
		self.kDNSSECCNAMEQueriesSuccessfulWithMatch = "DNSSEC (CNAME) Queries Successful With Match"
		self.kSimulatedUsers = "Simulated Users"
		self.kDNSMaximumResponseLatencyusec = "DNS Maximum Response Latency (usec)"
		self.kDNSSECSOAQueriesSent = "DNSSEC (SOA) Queries Sent"
		self.kDNSSECPTRQueriesFailed = "DNSSEC (PTR) Queries Failed"
		self.kDNSSECPTRQueriesSuccessfulWithMatch = "DNSSEC (PTR) Queries Successful With Match"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kDNSTotalBytesTransmitted = "DNS Total Bytes Transmitted"
		self.kAQueriesFailed = "(A) Queries Failed"
		self.kDNSResponseLatencyin500msto1second = "DNS Response Latency in 500 ms to 1 second"
		self.kAAAAQueriesFailed = "AAAA Queries Failed"
		self.kPTRQueriesSuccessfulWithoutMatch = "PTR Queries Successful Without Match"
		self.kDNSResponseLatencyin20to50ms = "DNS Response Latency in 20 to 50 ms"
		self.kDNSTypeCNAMEQueriesSuccessfulWithMatch = "DNS (Type CNAME) Queries Successful With Match"
		self.kTCPRetries = "TCP Retries"
		self.kMXQueriesSuccessfulWithoutMatch = "MX Queries Successful Without Match"
		self.kCNAMEQueriesSent = "CNAME Queries Sent"
		self.kDNSSECSRVQueriesSent = "DNSSEC (SRV) Queries Sent"
		self.kDNSTypeSOAQueriesSent = "DNS (Type SOA) Queries Sent"
		self.kDNSSECNAPTRQueriesSuccessfulWithMatch = "DNSSEC (NAPTR) Queries Successful With Match"
		self.kAAAATypeQueriesSuccessfulWithoutMatch = "AAAA Type Queries Successful Without Match"
		self.kDNSSECNAPTRQueriesFailed = "DNSSEC (NAPTR) Queries Failed"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kATypeQueriesSuccessfulWithMatch = "A Type Queries Successful With Match"
		self.kSRVQueriesFailed = "(SRV) Queries Failed"
		self.kDNSSECAQueriesSuccessfulWithoutMatch = "DNSSEC (A) Queries Successful Without Match"
		self.kResetsSent = "Resets Sent"
		self.kRetries = "Retries"
		self.kDNSTypeNAPTRQueriesFailed = "DNS (Type NAPTR) Queries Failed"
		self.kDNSMinimumResponseLatencyusec = "DNS Minimum Response Latency (usec)"
		self.kDNSTypeSRVQueriesSuccessfulWithoutMatch = "DNS (Type SRV) Queries Successful Without Match"
		self.kDNSTypeSRVQueriesSuccessfulWithMatch = "DNS (Type SRV) Queries Successful With Match"
		self.kTimeouts = "Timeouts"
		self.kDNSTotalQueriesFailedFormatError = "DNS Total Queries Failed (Format Error)"
		self.kDNSTotalQueriesFailedServerFailure = "DNS Total Queries Failed (Server Failure)"
		self.kAAAAQueriesFailed = "(AAAA) Queries Failed"
		self.kThroughputKbps = "Throughput (Kbps)"
		self.kDNSSECPTRQueriesSent = "DNSSEC (PTR) Queries Sent"
		self.kDNSTypeTXTQueriesSuccessfulWithMatch = "DNS (Type TXT) Queries Successful With Match"
		self.kDNSTypeCNAMEQueriesSuccessfulWithoutMatch = "DNS (Type CNAME) Queries Successful Without Match"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kPTRQueriesSent = "PTR Queries Sent"
		self.kTotalQueriesFailedNotImplemented = "Total Queries Failed (Not Implemented)"
		self.kDNSTypeCNAMEQueriesFailed = "DNS (Type CNAME) Queries Failed"
		self.kDNSSECSOAQueriesSuccessfulWithMatch = "DNSSEC (SOA) Queries Successful With Match"
		self.kNAPTRTypeQueriesSuccessfulWithMatch = "NAPTR Type Queries Successful With Match"
		self.kDNSTotalQueriesSuccessful = "DNS Total Queries Successful"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kDNSTypePTRQueriesSuccessfulWithMatch = "DNS (Type PTR) Queries Successful With Match"
		self.kDNSSECNAPTRQueriesSuccessfulWithoutMatch = "DNSSEC (NAPTR) Queries Successful Without Match"
		self.kDNSSECNSQueriesSuccessfulWithMatch = "DNSSEC (NS) Queries Successful With Match"
		self.kDNSSECCNAMEQueriesSuccessfulWithoutMatch = "DNSSEC (CNAME) Queries Successful Without Match"
		self.kDNSQueriesFailedOthers = "DNS Queries Failed (Other)/s"
		self.kDNSSECAAAAQueriesSuccessfulWithMatch = "DNSSEC (AAAA) Queries Successful With Match"
		self.kFINsReceived = "FINs Received"
		self.kDNSSECAAAAQueriesSent = "DNSSEC (AAAA) Queries Sent"
		self.kSRVQueriesFailed = "SRV Queries Failed"
		self.kPTRQueriesSuccessfulWithMatch = "PTR Queries Successful With Match"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kDNSSECQueriesFailedFormatErrors = "DNSSEC Queries Failed (Format Error)/s"
		self.kNSQueriesSuccessfulWithMatch = "NS Queries Successful With Match"
		self.kDNSTypeSRVQueriesFailed = "DNS (Type SRV) Queries Failed"
		self.kDNSSECTotalQueriesFailedNotImplemented = "DNSSEC Total Queries Failed (Not Implemented)"
		self.kTXTQueriesSent = "TXT Queries Sent"
		self.kDNSSECNSQueriesSuccessfulWithoutMatch = "DNSSEC (NS) Queries Successful Without Match"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kDNSSECQueriesFailedKeyNotFounds = "DNSSEC Queries Failed (Key Not Found)/s"
		self.kMXQueriesFailed = "MX Queries Failed"
		self.kDNSMinimumResponseLatency = "DNS Minimum Response Latency"
		self.kDNSSECTotalQueriesSent = "DNSSEC Total Queries Sent"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kDNSSECCNAMEQueriesFailed = "DNSSEC (CNAME) Queries Failed"
		self.kDNSTypeCNAMEQueriesSent = "DNS (Type CNAME) Queries Sent"
		self.kSYNSYNACKsReceived = "SYN/SYN-ACKs Received"
		self.kDNSSECMXQueriesFailed = "DNSSEC (MX) Queries Failed"
		self.kDNSTypeMXQueriesSuccessfulWithoutMatch = "DNS (Type MX) Queries Successful Without Match"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kDNSSECSOAQueriesSuccessfulWithoutMatch = "DNSSEC (SOA) Queries Successful Without Match"
		self.kAQueriesSent = "A Queries Sent"
		self.kDNSTypeTXTQueriesSuccessfulWithoutMatch = "DNS (Type TXT) Queries Successful Without Match"
		self.kDNSTotalQueriesSent = "DNS Total Queries Sent"
		self.kDNSTypePTRQueriesSuccessfulWithoutMatch = "DNS (Type PTR) Queries Successful Without Match"
		self.kDNSSECNAPTRQueriesSent = "DNSSEC (NAPTR) Queries Sent"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kDNSTypeSRVQueriesSent = "DNS (Type SRV) Queries Sent"
		self.kDNSQueriesFailedFormatErrors = "DNS Queries Failed (Format Error)/s"
		self.kPTRQueriesFailed = "(PTR) Queries Failed"
		self.kDNSSECNSQueriesFailed = "DNSSEC (NS) Queries Failed"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kDNSSECAQueriesSent = "DNSSEC (A) Queries Sent"
		self.kDNSSECAAAAQueriesSuccessfulWithoutMatch = "DNSSEC (AAAA) Queries Successful Without Match"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kTransactionRate = "Transaction Rate"
		self.kDNSSECTXTQueriesFailed = "DNSSEC (TXT) Queries Failed"
		self.kCNAMEQueriesFailed = "CNAME Queries Failed"
		self.kDNSTypeSOAQueriesSuccessfulWithMatch = "DNS (Type SOA) Queries Successful With Match"
		self.kDNSSECCNAMEQueriesSent = "DNSSEC (CNAME) Queries Sent"
		self.kDNSSECQueriesFailedServerFailures = "DNSSEC Queries Failed (Server Failure)/s"
		self.kTotalQueriesFailedFormatError = "Total Queries Failed (Format Error)"
		self.kDNSTotalQueriesFailedRefused = "DNS Total Queries Failed (Refused)"
		self.kDNSTotalQueriesFailedTimeout = "DNS Total Queries Failed (Timeout)"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kDNSBytes = "DNS Bytes"
		self.kDNSSECTotalQueriesFailedInvalidSignature = "DNSSEC Total Queries Failed (Invalid Signature)"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kDNSSimulatedUsers = "DNS Simulated Users"
		self.kDNSTotalQueriesFailed = "DNS Total Queries Failed"
		self.kNSQueriesFailed = "NS Queries Failed"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kDNSSECTotalQueriesFailedServerFailure = "DNSSEC Total Queries Failed (Server Failure)"
		self.kDNSSECAAAAQueriesFailed = "DNSSEC (AAAA) Queries Failed"
		self.kDNSSECTotalQueriesFailedFormatError = "DNSSEC Total Queries Failed (Format Error)"
		self.kTotalQueriesFailedOther = "Total Queries Failed (Other)"
		self.kDNSAverageResponseLatency = "DNS Average Response Latency"
		self.kCNAMEQueriesFailed = "(CNAME) Queries Failed"
		self.kSRVQueriesSuccessfulWithoutMatch = "SRV Queries Successful Without Match"
		self.kDNSSECTXTQueriesSuccessfulWithMatch = "DNSSEC (TXT) Queries Successful With Match"
		self.kDNSSECTotalQueriesFailedNameError = "DNSSEC Total Queries Failed (Name Error)"
		self.kDNSResponseLatencyin1secondto3seconds = "DNS Response Latency in 1 second to 3 seconds"
		self.kDNSSECQueriesFailedNotImplementeds = "DNSSEC Queries Failed (Not Implemented)/s"
		self.kTotalQueriesFailed = "Total Queries Failed"
		self.kDNSResponseLatencyin100to500ms = "DNS Response Latency in 100 to 500 ms"
		self.kDNSResponseLatencymorethan3seconds = "DNS Response Latency more than 3 seconds"
		self.kDNSTypeNAPTRQueriesSuccessfulWithoutMatch = "DNS (Type NAPTR) Queries Successful Without Match"
		self.kDNSTypeAQueriesSuccessfulWithMatch = "DNS (Type A) Queries Successful With Match"
		self.kDNSTypeTXTQueriesSent = "DNS (Type TXT) Queries Sent"
		self.kDNSTransactions = "DNS Transactions"
		self.kDNSTotalBytesReceived = "DNS Total Bytes Received"
		self.kDNSSECTotalQueriesFailedRefused = "DNSSEC Total Queries Failed (Refused)"
		self.kDNSTypeAAAAQueriesSuccessfulWithMatch = "DNS (Type AAAA) Queries Successful With Match"
		self.kDNSSECQueriesFailedTimeouts = "DNSSEC Queries Failed (Timeout)/s"
		self.kDNSTypeMXQueriesSent = "DNS (Type MX) Queries Sent"
		self.kDNSTypeMXQueriesFailed = "DNS (Type MX) Queries Failed"
		self.kFINACKsReceived = "FIN-ACKs Received"
		self.kNAPTRQueriesSent = "NAPTR Queries Sent"
		self.kNAPTRQueriesFailed = "(NAPTR) Queries Failed"
		self.kDNSSECAQueriesSuccessfulWithMatch = "DNSSEC (A) Queries Successful With Match"
		self.kSOAQueriesSuccessfulWithMatch = "SOA Queries Successful With Match"
		self.kSYNsSent = "SYNs Sent"
		self.kDNSSECQueriesFailedNameErrors = "DNSSEC Queries Failed (Name Error)/s"
		self.kTotalQueriesFailedTimeout = "Total Queries Failed (Timeout)"
		self.kDNSAverageResponseLatencyusec = "DNS Average Response Latency (usec)"
		self.kDNSSECPTRQueriesSuccessfulWithoutMatch = "DNSSEC (PTR) Queries Successful Without Match"
		self.kTXTQueriesFailed = "TXT Queries Failed"
		self.kTotalQueriesSuccessful = "Total Queries Successful"
		self.kSecuredQueriesSecond = "Secured Queries/Second"
		self.kDNSSECTotalQueriesFailed = "DNSSEC Total Queries Failed"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kDNSSECTotalQueriesRetried = "DNSSEC Total Queries Retried"
		self.kNSQueriesSent = "NS Queries Sent"
		self.kMXQueriesSuccessfulWithMatch = "MX Queries Successful With Match"
		self.kTotalQueriesFailedAborted = "Total Queries Failed (Aborted)"
		self.kDNSTypePTRQueriesSent = "DNS (Type PTR) Queries Sent"
		self.kDNSTotalQueriesFailedAborted = "DNS Total Queries Failed (Aborted)"
		self.kTxRateKbps = "Tx Rate (Kbps)"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kDNSSECTotalQueriesFailedOther = "DNSSEC Total Queries Failed (Other)"
		self.kDNSSECTotalQueriesFailedKeyNotFound = "DNSSEC Total Queries Failed (Key Not Found)"
		self.kDNSTypeNSQueriesSuccessfulWithoutMatch = "DNS (Type NS) Queries Successful Without Match"
		self.kFINsSent = "FINs Sent"
		self.kDNSQueriesFailedRefuseds = "DNS Queries Failed (Refused)/s"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kDNSTypeAQueriesSuccessfulWithoutMatch = "DNS (Type A) Queries Successful Without Match"
		self.kDNSSECTotalQueriesFailedAborted = "DNSSEC Total Queries Failed (Aborted)"
		self.kQueriesAttemptSecond = "Queries Attempt/Second"
		self.kDNSResponseLatencyin50to100ms = "DNS Response Latency in 50 to 100 ms"
		self.kCNAMEQueriesSuccessfulWithMatch = "CNAME Queries Successful With Match"
		self.kDNSSECMXQueriesSuccessfulWithoutMatch = "DNSSEC (MX) Queries Successful Without Match"
		self.kDNSTypeNAPTRQueriesSent = "DNS (Type NAPTR) Queries Sent"
		self.kTXTQueriesFailed = "(TXT) Queries Failed"
		self.kDNSTypeAAAAQueriesSuccessfulWithoutMatch = "DNS (Type AAAA) Queries Successful Without Match"
		self.kDNSTypeTXTQueriesFailed = "DNS (Type TXT) Queries Failed"
		self.kDNSTypeAAAAQueriesFailed = "DNS (Type AAAA) Queries Failed"
		self.kPTRQueriesFailed = "PTR Queries Failed"
		self.kTXTTypeQueriesSuccessfulWithMatch = "TXT Type Queries Successful With Match"
		self.kDNSSECTotalQueriesFailedNoSignature = "DNSSEC Total Queries Failed (No Signature)"
		self.kDNSQueriesFailedServerFailures = "DNS Queries Failed (Server Failure)/s"
		self.kDNSResponseLatencyin5to10ms = "DNS Response Latency in 5 to 10 ms"
		self.kDNSSECTotalQueriesFailedInvalidKey = "DNSSEC Total Queries Failed (Invalid Key)"
		self.kDNSSECTotalQueriesFaileds = "DNSSEC Total Queries Failed/s"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kDNSSECMXQueriesSuccessfulWithMatch = "DNSSEC (MX) Queries Successful With Match"
		self.kAAAATypeQueriesSuccessfulWithMatch = "AAAA Type Queries Successful With Match"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kSOAQueriesFailed = "(SOA) Queries Failed"
		self.kDNSSECTXTQueriesSuccessfulWithoutMatch = "DNSSEC (TXT) Queries Successful Without Match"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kNSQueriesSuccessfulWithoutMatch = "NS Queries Successful Without Match"
		self.kDNSActiveQueries = "DNS Active Queries"
		self.kDNSSECSOAQueriesFailed = "DNSSEC (SOA) Queries Failed"
		self.kDNSResponseLatencyin0to1ms = "DNS Response Latency in 0 to 1 ms"
		self.kRxRateKbps = "Rx Rate (Kbps)"
		self.kDNSMaximumResponseLatency = "DNS Maximum Response Latency"
		self.kDNSSECTotalQueriesSuccessful = "DNSSEC Total Queries Successful"
		self.kDNSSECTotalQueriesFailedTimeout = "DNSSEC Total Queries Failed (Timeout)"
		self.kSRVQueriesSuccessfulWithMatch = "SRV Queries Successful With Match"
		self.kDNSTypeNAPTRQueriesSuccessfulWithMatch = "DNS (Type NAPTR) Queries Successful With Match"
		self.kDNSTypeNSQueriesSent = "DNS (Type NS) Queries Sent"
		self.kDNSSECQueriesFailedAborteds = "DNSSEC Queries Failed (Aborted)/s"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kTotalQueriesSent = "Total Queries Sent"
		self.kDNSTypeNSQueriesSuccessfulWithMatch = "DNS (Type NS) Queries Successful With Match"
		self.kDNSTypeAAAAQueriesSent = "DNS (Type AAAA) Queries Sent"
		self.kDNSQueriesFailedAborteds = "DNS Queries Failed (Aborted)/s"
		self.kTotalQueriesFailedRefused = "Total Queries Failed (Refused)"
		self.kTotalQueriesFailedNameError = "Total Queries Failed (Name Error)"
		self.kDNSSECQueriesFailedOthers = "DNSSEC Queries Failed (Other)/s"
		self.kDNSResponseLatencyin10to20ms = "DNS Response Latency in 10 to 20 ms"
		self.kMXQueriesFailed = "(MX) Queries Failed"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kDNSQueriesFailedTimeouts = "DNS Queries Failed (Timeout)/s"
		self.kDNSTotalQueriesAttempted = "DNS Total Queries Attempted"
		self.kDNSQueriesFailedNotImplementeds = "DNS Queries Failed (Not Implemented)/s"
		self.kResetsReceived = "Resets Received"
		self.kSOAQueriesFailed = "SOA Queries Failed"
		self.kFINACKsSent = "FIN-ACKs Sent"
		self.kDNSTotalQueriesRetried = "DNS Total Queries Retried"
		self.kDNSSECSRVQueriesFailed = "DNSSEC (SRV) Queries Failed"
		self.kDNSTotalQueriesFaileds = "DNS Total Queries Failed/s"
		self.kDNSQueriesFailedNameErrors = "DNS Queries Failed (Name Error)/s"
		self.kDNSTypeNSQueriesFailed = "DNS (Type NS) Queries Failed"
		self.kAAAAQueriesSent = "AAAA Queries Sent"
		self.kDNSTypeMXQueriesSuccessfulWithMatch = "DNS (Type MX) Queries Successful With Match"
		self.kCNAMEQueriesSuccessfulWithoutMatch = "CNAME Queries Successful Without Match"
		self.kDNSSECQueriesFailedRefuseds = "DNSSEC Queries Failed (Refused)/s"
		self.kDNSTypeSOAQueriesSuccessfulWithoutMatch = "DNS (Type SOA) Queries Successful Without Match"
		self.kDNSSECMXQueriesSent = "DNSSEC (MX) Queries Sent"
		self.kMXQueriesSent = "MX Queries Sent"
		self.kQueriesSecond = "Queries/Second"
		self.kDNSTypeAQueriesFailed = "DNS (Type A) Queries Failed"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kSOAQueriesSent = "SOA Queries Sent"
		self.kNSQueriesFailed = "(NS) Queries Failed"
		self.kDNSTotalQueriesFailedNameError = "DNS Total Queries Failed (Name Error)"
		self.kDNSSECSRVQueriesSuccessfulWithMatch = "DNSSEC (SRV) Queries Successful With Match"
		self.kSRVQueriesSent = "SRV Queries Sent"
		self.kDNSSECSRVQueriesSuccessfulWithoutMatch = "DNSSEC (SRV) Queries Successful Without Match"
		self.kDNSTypeAQueriesSent = "DNS (Type A) Queries Sent"
		self.kNAPTRQueriesSuccessfulWithoutMatch = "NAPTR Queries Successful Without Match"
		self.kAQueriesFailed = "A Queries Failed"
		self.kTotalQueriesFailedServerFailure = "Total Queries Failed (Server Failure)"
		self.kDNSSECNSQueriesSent = "DNSSEC (NS) Queries Sent"
		self.kDNSSECTXTQueriesSent = "DNSSEC (TXT) Queries Sent"
		self.kDNSTotalQueriesFailedOther = "DNS Total Queries Failed (Other)"
		self.kNAPTRQueriesFailed = "NAPTR Queries Failed"
		self.kDNSSECQueriesFailedInvalidSignatures = "DNSSEC Queries Failed (Invalid Signature)/s"
		self.kTXTQueriesSuccessfulWithoutMatch = "TXT Queries Successful Without Match"
		self.kDNSTypePTRQueriesFailed = "DNS (Type PTR) Queries Failed"
		self.kDNSTypeSOAQueriesFailed = "DNS (Type SOA) Queries Failed"
		self.kTotalQueriesRetried = "Total Queries Retried"
		self.kTCPFINReceived = "TCP FIN Received"


class StatsNameIxServer(object):
	def __init__(self):
		self.kBytesReceivedRate = "Bytes Received Rate"
		self.kServerPPSTx = "Server: PPS Tx"
		self.kServerPPSRx = "Server: PPS Rx"
		self.kFramesSent = "Frames Sent"
		self.kServerTotalRxMbps = "Server: Total Rx [Mbps]"
		self.kReceivePingRequest = "Receive Ping Request"
		self.kBitsSentRateKbs = "Bits Sent Rate (Kb/s)"
		self.kClientTotalTxMbps = "Client: Total Tx [Mbps]"
		self.kReceiveArpReply = "Receive Arp Reply"
		self.kInternalBytesReceivedRate = "Internal Bytes Received Rate"
		self.kServerFramesTotalRx = "Server: Frames Total Rx"
		self.kServerFramesTotalTx = "Server: Frames Total Tx"
		self.kTransmitArpReply = "Transmit Arp Reply"
		self.kInternalBytesSentRate = "Internal Bytes Sent Rate"
		self.kClientPPSTx = "Client: PPS Tx"
		self.kTransmitPingRequest = "Transmit Ping Request"
		self.kClientPPSRx = "Client: PPS Rx"
		self.kBitsSent = "Bits Sent"
		self.kClientFramesTotalRx = "Client: Frames Total Rx"
		self.kBytesSent = "Bytes Sent"
		self.kClientFramesTotalTx = "Client: Frames Total Tx"
		self.kBitsReceivedRateKbs = "Bits Received Rate (Kb/s)"
		self.kFramesSentRate = "Frames Sent Rate"
		self.kReceivePingReply = "Receive Ping Reply"
		self.kClientTotalRxMbps = "Client: Total Rx [Mbps]"
		self.kFramesReceived = "Frames Received"
		self.kServerTotalTxMbps = "Server: Total Tx [Mbps]"
		self.kBytesSentRate = "Bytes Sent Rate"
		self.kTransmitPingReply = "Transmit Ping Reply"
		self.kReceiveArpRequest = "Receive Arp Request"
		self.kBitsReceived = "Bits Received"
		self.kFragmentsreceived = "Fragments received"
		self.kTransmitArpRequest = "Transmit Arp Request"
		self.kFramesReceivedRate = "Frames Received Rate"
		self.kBytesReceived = "Bytes Received"


class StatsNameDNSServer(object):
	def __init__(self):
		self.kDNSTotalQueriesFailedNotImplemented = "DNS Total Queries Failed (Not Implemented)"
		self.kAQueriesReceived2 = "A Queries Received2"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kDNSSECTypeAAAAQueriesFailed = "DNSSEC (Type AAAA) Queries Failed"
		self.kDNSTotalQueriesRespondedSuccessfully = "DNS Total Queries Responded Successfully"
		self.kDNSSECTypeAAAAQueriesReceived = "DNSSEC (Type AAAA) Queries Received"
		self.kDNSTypeSRVQueriesReceived = "DNS (Type SRV) Queries Received"
		self.kDNSTypeAAAAQueriesReceived = "DNS (Type AAAA) Queries Received"
		self.kNAPTRQueriesReceived = "NAPTR Queries Received"
		self.kSYNSYNACKsReceived = "SYN/SYN-ACKs Received"
		self.kTotalQueriesRespondedSuccessfully2 = "Total Queries Responded Successfully2"
		self.kDNSTotalBytesTransmitted = "DNS Total Bytes Transmitted"
		self.kAQueriesReceived = "A Queries Received"
		self.kQueriesFailedSec = "Queries Failed/Sec"
		self.kDNSTotalBytesReceived = "DNS Total Bytes Received"
		self.kDNSTypeCNAMEQueriesRespondedSuccessfully = "DNS (Type CNAME) Queries Responded Successfully"
		self.kTotalQueriesReceived = "Total Queries Received"
		self.kNSQueriesReceived2 = "NS Queries Received2"
		self.kPTRQueriesReceived2 = "PTR Queries Received2"
		self.kDNSSECTypeSOAQueriesFailed = "DNSSEC (Type SOA) Queries Failed"
		self.kResetsSent = "Resets Sent"
		self.kDNSTypeNAPTRQueriesFailed = "DNS (Type NAPTR) Queries Failed"
		self.kDNSSECTypeNSQueriesReceived = "DNSSEC (Type NS) Queries Received"
		self.kTimeouts = "Timeouts"
		self.kDNSTotalQueriesFailedFormatError = "DNS Total Queries Failed (Format Error)"
		self.kDNSTotalQueriesFailedServerFailure = "DNS Total Queries Failed (Server Failure)"
		self.kDNSTypePTRQueriesRespondedSuccessfully = "DNS (Type PTR) Queries Responded Successfully"
		self.kTotalQueriesFailedServerFailure = "Total Queries Failed (Server Failure)"
		self.kConnectionRequestsFailed = "Connection Requests Failed"
		self.kAAAAQueriesReceived2 = "AAAA Queries Received2"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kTotalQueriesFailedNotImplemented = "Total Queries Failed (Not Implemented)"
		self.kDNSTypeCNAMEQueriesFailed = "DNS (Type CNAME) Queries Failed"
		self.kDNSSECTypeTXTQueriesRespondedSuccessfully = "DNSSEC (Type TXT) Queries Responded Successfully"
		self.kDNSSECTypeNAPTRQueriesRespondedSuccessfully = "DNSSEC (Type NAPTR) Queries Responded Successfully"
		self.kFINsSent = "FINs Sent"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kSYNACKsSent = "SYN-ACKs Sent"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kDNSTypeSRVQueriesRespondedSuccessfully = "DNS (Type SRV) Queries Responded Successfully"
		self.kDNSTypeNAPTRQueriesReceived = "DNS (Type NAPTR) Queries Received"
		self.kDNSSECTypePTRQueriesReceived = "DNSSEC (Type PTR) Queries Received"
		self.kQueriesRespondedSuccessfullySec = "Queries Responded Successfully/Sec"
		self.kDNSSECTotalQueriesFailedServerFailure = "DNSSEC Total Queries Failed (Server Failure)"
		self.kDNSSECTotalQueriesFailedNotImplemented = "DNSSEC Total Queries Failed (Not Implemented)"
		self.kDNSSECTypePTRQueriesFailed = "DNSSEC (Type PTR) Queries Failed"
		self.kFINACKsReceived = "FIN-ACKs Received"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kSRVQueriesReceived = "SRV Queries Received"
		self.kDNSTotalBytesTransmittedandReceived = "DNS Total Bytes Transmitted and Received"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kDNSTypeAQueriesRespondedSuccessfully = "DNS (Type A) Queries Responded Successfully"
		self.kTotalQueriesFailedFormatError2 = "Total Queries Failed (Format Error)2"
		self.kDNSSECTypeCNAMEQueriesReceived = "DNSSEC (Type CNAME) Queries Received"
		self.kNAPTRQueriesReceived2 = "NAPTR Queries Received2"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kSOAQueriesReceived = "SOA Queries Received"
		self.kDNSTypePTRQueriesReceived = "DNS (Type PTR) Queries Received"
		self.kDNSTypeTXTQueriesRespondedSuccessfully = "DNS (Type TXT) Queries Responded Successfully"
		self.kDNSSECTypeTXTQueriesFailed = "DNSSEC (Type TXT) Queries Failed"
		self.kFINsReceived = "FINs Received"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kDNSTypeNSQueriesRespondedSuccessfully = "DNS (Type NS) Queries Responded Successfully"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kDNSTypeAQueriesReceived = "DNS (Type A) Queries Received"
		self.kDNSSECTotalQueriesRespondedSuccessfully = "DNSSEC Total Queries Responded Successfully"
		self.kQueriesFailedsec = "Queries Failed/sec"
		self.kDNSTypeMXQueriesRespondedSuccessfully = "DNS (Type MX) Queries Responded Successfully"
		self.kTotalQueriesFailedFormatError = "Total Queries Failed (Format Error)"
		self.kDNSTotalQueriesFailedRefused = "DNS Total Queries Failed (Refused)"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kTXTQueriesReceived2 = "TXT Queries Received2"
		self.kDNSSECTotalQueriesReceived = "DNSSEC Total Queries Received"
		self.kDNSTypeTXTQueriesReceived = "DNS (Type TXT) Queries Received"
		self.kDNSTypeSRVQueriesFailed = "DNS (Type SRV) Queries Failed"
		self.kDNSSECTypeTXTQueriesReceived = "DNSSEC (Type TXT) Queries Received"
		self.kDNSSECTotalQueriesFailedFormatError = "DNSSEC Total Queries Failed (Format Error)"
		self.kTotalQueriesFailedOther = "Total Queries Failed (Other)"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kTotalQueriesRespondedSuccessfully = "Total Queries Responded Successfully"
		self.kDNSSECTotalQueriesFailedNameError = "DNSSEC Total Queries Failed (Name Error)"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kTotalQueriesFailed2 = "Total Queries Failed2"
		self.kDNSSECTypeNAPTRQueriesFailed = "DNSSEC (Type NAPTR) Queries Failed"
		self.kPTRQueriesReceived = "PTR Queries Received"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kTotalQueriesFailedNameError2 = "Total Queries Failed (Name Error)2"
		self.kMXQueriesReceived2 = "MX Queries Received2"
		self.kDNSSECTotalQueriesFailedRefused = "DNSSEC Total Queries Failed (Refused)"
		self.kDNSSECTypeAQueriesRespondedSuccessfully = "DNSSEC (Type A) Queries Responded Successfully"
		self.kDNSTypeMXQueriesFailed = "DNS (Type MX) Queries Failed"
		self.kTCPRetries = "TCP Retries"
		self.kDNSSECTypeSRVQueriesReceived = "DNSSEC (Type SRV) Queries Received"
		self.kDNSTypeCNAMEQueriesReceived = "DNS (Type CNAME) Queries Received"
		self.kDNSSECTypeNAPTRQueriesReceived = "DNSSEC (Type NAPTR) Queries Received"
		self.kDNSSECTotalQueriesFailed = "DNSSEC Total Queries Failed"
		self.kTotalQueriesFailedServerFailure2 = "Total Queries Failed (Server Failure)2"
		self.kDNSTypeAAAAQueriesRespondedSuccessfully = "DNS (Type AAAA) Queries Responded Successfully"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kDNSSECTypeCNAMEQueriesFailed = "DNSSEC (Type CNAME) Queries Failed"
		self.kTxRateKbps = "Tx Rate (Kbps)"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kDNSSECTotalQueriesFailedOther = "DNSSEC Total Queries Failed (Other)"
		self.kDNSSECTypeAQueriesReceived = "DNSSEC (Type A) Queries Received"
		self.kQueriesReceivedSec = "Queries Received/Sec"
		self.kRetries = "Retries"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kNSQueriesReceived = "NS Queries Received"
		self.kQueriesRespondedSuccessfullysec = "Queries Responded Successfully/sec"
		self.kTXTQueriesReceived = "TXT Queries Received"
		self.kDNSTypeTXTQueriesFailed = "DNS (Type TXT) Queries Failed"
		self.kDNSTypeAAAAQueriesFailed = "DNS (Type AAAA) Queries Failed"
		self.kDNSTypeMXQueriesReceived = "DNS (Type MX) Queries Received"
		self.kDNSSECTypeAAAAQueriesRespondedSuccessfully = "DNSSEC (Type AAAA) Queries Responded Successfully"
		self.kDNSSECTypeSRVQueriesFailed = "DNSSEC (Type SRV) Queries Failed"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kDNSSECTypeCNAMEQueriesRespondedSuccessfully = "DNSSEC (Type CNAME) Queries Responded Successfully"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kMXQueriesReceived = "MX Queries Received"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kSOAQueriesReceived2 = "SOA Queries Received2"
		self.kDNSTotalQueriesFailed = "DNS Total Queries Failed"
		self.kRxRateKbps = "Rx Rate (Kbps)"
		self.kDNSSECTypeNSQueriesRespondedSuccessfully = "DNSSEC (Type NS) Queries Responded Successfully"
		self.kTotalQueriesFailedNotImplemented2 = "Total Queries Failed (Not Implemented)2"
		self.kTotalQueriesFailedOther2 = "Total Queries Failed (Other)2"
		self.kDNSSECTypeAQueriesFailed = "DNSSEC (Type A) Queries Failed"
		self.kTotalQueriesFailedNameError = "Total Queries Failed (Name Error)"
		self.kDNSSECTypeSRVQueriesRespondedSuccessfully = "DNSSEC (Type SRV) Queries Responded Successfully"
		self.kDNSTotalQueriesReceived = "DNS Total Queries Received"
		self.kDNSTypeSOAQueriesReceived = "DNS (Type SOA) Queries Received"
		self.kDNSSECTypeMXQueriesRespondedSuccessfully = "DNSSEC (Type MX) Queries Responded Successfully"
		self.kCNAMEQueriesReceived = "CNAME Queries Received"
		self.kTotalQueriesFailedRefused = "Total Queries Failed (Refused)"
		self.kQueriesReceivedsec = "Queries Received/sec"
		self.kTotalQueriesReceived2 = "Total Queries Received2"
		self.kDNSSECTypePTRQueriesRespondedSuccessfully = "DNSSEC (Type PTR) Queries Responded Successfully"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kAcceptQueueEntries = "Accept Queue Entries"
		self.kTotalQueriesFailed3 = "Total Queries Failed3"
		self.kResetsReceived = "Resets Received"
		self.kFINACKsSent = "FIN-ACKs Sent"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kCNAMEQueriesReceived2 = "CNAME Queries Received2"
		self.kSRVQueriesReceived2 = "SRV Queries Received2"
		self.kDNSTypeNSQueriesFailed = "DNS (Type NS) Queries Failed"
		self.kDNSTypeNAPTRQueriesRespondedSuccessfully = "DNS (Type NAPTR) Queries Responded Successfully"
		self.kDNSSECTypeNSQueriesFailed = "DNSSEC (Type NS) Queries Failed"
		self.kAAAAQueriesReceived = "AAAA Queries Received"
		self.kDNSSECTypeSOAQueriesRespondedSuccessfully = "DNSSEC (Type SOA) Queries Responded Successfully"
		self.kTotalQueriesFailedRefused2 = "Total Queries Failed (Refused)2"
		self.kTotalQueriesFailed = "Total Queries Failed"
		self.kDNSTypeAQueriesFailed = "DNS (Type A) Queries Failed"
		self.kDNSSECTypeMXQueriesFailed = "DNSSEC (Type MX) Queries Failed"
		self.kThroughputKbps = "Throughput (Kbps)"
		self.kDNSTypeNSQueriesReceived = "DNS (Type NS) Queries Received"
		self.kDNSTotalQueriesFailedNameError = "DNS Total Queries Failed (Name Error)"
		self.kDNSSECTypeMXQueriesReceived = "DNSSEC (Type MX) Queries Received"
		self.kDNSTypeSOAQueriesRespondedSuccessfully = "DNS (Type SOA) Queries Responded Successfully"
		self.kDNSSECTypeSOAQueriesReceived = "DNSSEC (Type SOA) Queries Received"
		self.kListenQueueDrops = "Listen Queue Drops"
		self.kDNSTotalQueriesFailedOther = "DNS Total Queries Failed (Other)"
		self.kDNSTypePTRQueriesFailed = "DNS (Type PTR) Queries Failed"
		self.kDNSTypeSOAQueriesFailed = "DNS (Type SOA) Queries Failed"
		self.kTCPFINReceived = "TCP FIN Received"


class IxRestPreferencesWrapper(RestObjectBaseClass):

	def __init__(self, preferences):
		super(IxRestPreferencesWrapper, self).__init__(preferences)
		self.__preferences = preferences
		self.autoRebootCrashedPorts = preferences.autoRebootCrashedPorts
		self.allowIPOverlapping = preferences.allowIPOverlapping
		self.enableApplicationGlobalStatViews = preferences.enableApplicationGlobalStatViews
		self.licenseServer = preferences.licenseServer
		self.enableL23RestStatViews = preferences.enableL23RestStatViews
		self.detailedChassisMonitoring = preferences.detailedChassisMonitoring
		self.checkLinkStateAtApplyConfig = preferences.checkLinkStateAtApplyConfig
		self.enableRestStatViewsCsvLogging = preferences.enableRestStatViewsCsvLogging
		self.maximumInstances = preferences.maximumInstances
		self.customizeIxLoadVELicenseCount = preferences.customizeIxLoadVELicenseCount
		self.saveDataModelSnapshot = preferences.saveDataModelSnapshot
		self.continueTestOnLoadModuleFail = preferences.continueTestOnLoadModuleFail
		self.enableTcpGlobalStatViews = preferences.enableTcpGlobalStatViews
		self.allowRouteConflicts = preferences.allowRouteConflicts
		self.ntpServer2 = preferences.ntpServer2
		self.ntpServer1 = preferences.ntpServer1
		self.csvThroughputUnits = preferences.csvThroughputUnits
		self.logCollectorSize = preferences.logCollectorSize
		self.enableDebugLogs = preferences.enableDebugLogs
		self.overloadProtection = preferences.overloadProtection
		self.licenseModel = preferences.licenseModel
		self.enableRestStatistics = preferences.enableRestStatistics

	properties = ["autoRebootCrashedPorts", "allowIPOverlapping", "enableApplicationGlobalStatViews", "licenseServer", "enableL23RestStatViews", "detailedChassisMonitoring", "checkLinkStateAtApplyConfig", "enableRestStatViewsCsvLogging", "maximumInstances", "customizeIxLoadVELicenseCount", "saveDataModelSnapshot", "continueTestOnLoadModuleFail", "enableTcpGlobalStatViews", "allowRouteConflicts", "ntpServer2", "ntpServer1", "csvThroughputUnits", "logCollectorSize", "enableDebugLogs", "overloadProtection", "licenseModel", "enableRestStatistics", ]

	def __getattribute__(self, name):
		if name in IxRestPreferencesWrapper.properties and super(IxRestPreferencesWrapper, self).__getattribute__(name):
			return getattr(super(IxRestPreferencesWrapper, self).__getattribute__("_IxRestPreferencesWrapper__preferences"), name)
		else:
			return super(IxRestPreferencesWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxRestPreferencesWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxRestPreferencesWrapper, self).__getattribute__("_IxRestPreferencesWrapper__preferences"), name, value)
			super(IxRestPreferencesWrapper, self).__setattr__(name, value)


class IxVersionControllerWrapper(RestObjectBaseClass):

	def __init__(self, versions):
		super(IxVersionControllerWrapper, self).__init__(versions)
		self.__versions = versions

	properties = []

	def __getattribute__(self, name):
		if name in IxVersionControllerWrapper.properties and super(IxVersionControllerWrapper, self).__getattribute__(name):
			return getattr(super(IxVersionControllerWrapper, self).__getattribute__("_IxVersionControllerWrapper__versions"), name)
		else:
			return super(IxVersionControllerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxVersionControllerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxVersionControllerWrapper, self).__getattribute__("_IxVersionControllerWrapper__versions"), name, value)
			super(IxVersionControllerWrapper, self).__setattr__(name, value)


class IxChassisBuilderWrapper(RestObjectBaseClass):

	def __init__(self, chassisBuilder):
		super(IxChassisBuilderWrapper, self).__init__(chassisBuilder)
		self.__chassisBuilder = chassisBuilder
		self.chassisName = chassisBuilder.chassisName

	properties = ["chassisName", ]

	def __getattribute__(self, name):
		if name in IxChassisBuilderWrapper.properties and super(IxChassisBuilderWrapper, self).__getattribute__(name):
			return getattr(super(IxChassisBuilderWrapper, self).__getattribute__("_IxChassisBuilderWrapper__chassisBuilder"), name)
		else:
			return super(IxChassisBuilderWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxChassisBuilderWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxChassisBuilderWrapper, self).__getattribute__("_IxChassisBuilderWrapper__chassisBuilder"), name, value)
			super(IxChassisBuilderWrapper, self).__setattr__(name, value)

	def addCard(self, managementIp, cardServerId=None, keepAliveTimeout=None):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.addCard(**kwargs)

	def addCredentials(self, serverName, enable, user, password, applianceType):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.addCredentials(**kwargs)

	def addPort(self, cardId, portId, interfaceName, promiscMode=False, mtu=None, lineSpeed=None):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.addPort(**kwargs)

	def clearOwnership(self, cardId):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.clearOwnership(**kwargs)

	def connectCard(self, cardId):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.connectCard(**kwargs)

	def connectToChassis(self, chassisName):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.connectToChassis(**kwargs)

	def deleteCard(self, cardId):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.deleteCard(**kwargs)

	def disconnectCard(self, cardId):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.disconnectCard(**kwargs)

	def getCardById(self, cardId):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.getCardById(**kwargs)

	def getCardPorts(self, cardId):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.getCardPorts(**kwargs)

	def getChassisSettings(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.getChassisSettings(**kwargs)

	def getChassisTopology(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.getChassisTopology(**kwargs)

	def getDiscoveredCredentials(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.getDiscoveredCredentials(**kwargs)

	def getDiscoveredMachines(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.getDiscoveredMachines(**kwargs)

	def getIxVMCardByIP(self, managementIp):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.getIxVMCardByIP(**kwargs)

	def hardChassisReboot(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.hardChassisReboot(**kwargs)

	def hwRebootCardByIDs(self, cardIDs):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.hwRebootCardByIDs(**kwargs)

	def loadTopologyFromCsv(self, path):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.loadTopologyFromCsv(**kwargs)

	def rebuildChassisTopology(self, usePreviousSlotId, promiscMode, appVersion=""):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.rebuildChassisTopology(**kwargs)

	def rediscoverAppliances(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.rediscoverAppliances(**kwargs)

	def removeCredential(self, serverName):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.removeCredential(**kwargs)

	def removePortById(self, cardId, portId):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.removePortById(**kwargs)

	def updateCard(self, cardServerId, managementIp=None, keepAliveTimeout=None):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.updateCard(**kwargs)

	def updateChassisSettings(self, enableLicenseCheck=None, licenseServer=None, ntpServer=None, txDelay=None):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.updateChassisSettings(**kwargs)

	def updatePortById(self, cardId, portId, promiscMode=None, mtu=None, lineSpeed=None):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassisBuilder.updatePortById(**kwargs)


class IxTestControllerWrapper(RestObjectBaseClass):

	def setIxLoadRest(self, ixLoadRest):
		self.__ixLoadRest = ixLoadRest

	def __init__(self, test):
		super(IxTestControllerWrapper, self).__init__(test)
		g = GlobalProperties.getInstance()
		g.testInstance = test
		self.__test = test
		self.expirationTimer = test.expirationTimer
		self.activeTest = IxTestEnvelopeWrapper(test.activeTest)
		self.logs = IxRestLogCollectorWrapper(test)
		self.loadedRxf = test.loadedRxf
		self.runResultDirFull = test.runResultDirFull
		self.logFile = test.logFile
		self.outputDir = test.outputDir

	properties = ["expirationTimer", "loadedRxf", "runResultDirFull", "logFile", "outputDir", ]

	def __getattribute__(self, name):
		if name in IxTestControllerWrapper.properties and super(IxTestControllerWrapper, self).__getattribute__(name):
			return getattr(super(IxTestControllerWrapper, self).__getattribute__("_IxTestControllerWrapper__test"), name)
		else:
			return super(IxTestControllerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTestControllerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTestControllerWrapper, self).__getattribute__("_IxTestControllerWrapper__test"), name, value)
			super(IxTestControllerWrapper, self).__setattr__(name, value)

	def abortAndReleaseConfigWaitFinish(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.abortAndReleaseConfigWaitFinish(**kwargs)

	def applyConfiguration(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.applyConfiguration(**kwargs)

	def deleteTestResultDirectory(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.deleteTestResultDirectory(**kwargs)

	def exportConfig(self, destFile):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.exportConfig(**kwargs)

	def generateRestReport(self, reportFile):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.generateRestReport(**kwargs)

	def gracefulStopRun(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.gracefulStopRun(**kwargs)

	def importConfig(self, srcFile, destRxf):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.importConfig(**kwargs)

	def loadEmptyConfig(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.loadEmptyConfig(**kwargs)

	def loadTest(self, fullPath):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.loadTest(**kwargs)

	def runTest(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.runTest(**kwargs)
		self.__ixLoadRest.reinit()

	def save(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.save(**kwargs)

	def saveAs(self, fullPath, overWrite=False):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.saveAs(**kwargs)

	def waitForAllCaptureData(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__test.waitForAllCaptureData(**kwargs)


class IxRestSessionOverviewWrapper(RestObjectBaseClass):

	def __init__(self, sessionOverview):
		super(IxRestSessionOverviewWrapper, self).__init__(sessionOverview)
		self.__sessionOverview = sessionOverview
		self.applicationName = sessionOverview.applicationName
		self.applicationVersion = sessionOverview.applicationVersion
		self.logInUserName = sessionOverview.logInUserName
		self.testElapsedDuration = sessionOverview.testElapsedDuration
		self.chassisList = sessionOverview.chassisList
		self.testName = sessionOverview.testName
		self.runResultDirFull = sessionOverview.runResultDirFull
		self.testConfigurationSummary = sessionOverview.testConfigurationSummary
		self.communityNameList = sessionOverview.communityNameList
		self.testState = sessionOverview.testState
		self.repositoryName = sessionOverview.repositoryName
		self.chassisLoginName = sessionOverview.chassisLoginName
		self.testTotalDuration = sessionOverview.testTotalDuration

	properties = ["applicationName", "applicationVersion", "logInUserName", "testElapsedDuration", "chassisList", "testName", "runResultDirFull", "testConfigurationSummary", "communityNameList", "testState", "repositoryName", "chassisLoginName", "testTotalDuration", ]

	def __getattribute__(self, name):
		if name in IxRestSessionOverviewWrapper.properties and super(IxRestSessionOverviewWrapper, self).__getattribute__(name):
			return getattr(super(IxRestSessionOverviewWrapper, self).__getattribute__("_IxRestSessionOverviewWrapper__sessionOverview"), name)
		else:
			return super(IxRestSessionOverviewWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxRestSessionOverviewWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxRestSessionOverviewWrapper, self).__getattribute__("_IxRestSessionOverviewWrapper__sessionOverview"), name, value)
			super(IxRestSessionOverviewWrapper, self).__setattr__(name, value)


class IxChassisChainWrapper(RestObjectBaseClass):

	def __init__(self, chassischain):
		super(IxChassisChainWrapper, self).__init__(chassischain)
		self.__chassischain = chassischain
		self.loginName = chassischain.loginName
		self.chassisList = IxChassisSequenceContainerWrapper(chassischain)

	properties = ["loginName", ]

	def __getattribute__(self, name):
		if name in IxChassisChainWrapper.properties and super(IxChassisChainWrapper, self).__getattribute__(name):
			return getattr(super(IxChassisChainWrapper, self).__getattribute__("_IxChassisChainWrapper__chassischain"), name)
		else:
			return super(IxChassisChainWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxChassisChainWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxChassisChainWrapper, self).__getattribute__("_IxChassisChainWrapper__chassischain"), name, value)
			super(IxChassisChainWrapper, self).__setattr__(name, value)

	def changeCardsInterfaceMode(self, chassisIp, cardIdList, mode):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassischain.changeCardsInterfaceMode(**kwargs)

	def setCardsAggregationMode(self, chassisIp, cardIdList, mode):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__chassischain.setCardsAggregationMode(**kwargs)


class IxSessionMetricsWrapper(RestObjectBaseClass):

	def __init__(self, sessionMetrics):
		super(IxSessionMetricsWrapper, self).__init__(sessionMetrics)
		self.__sessionMetrics = sessionMetrics
		self.workingSet = sessionMetrics.workingSet
		self.pid = sessionMetrics.pid
		self.virtualMemorySize = sessionMetrics.virtualMemorySize
		self.numberOfThreads = sessionMetrics.numberOfThreads
		self.cpuUtilization = sessionMetrics.cpuUtilization

	properties = ["workingSet", "pid", "virtualMemorySize", "numberOfThreads", "cpuUtilization", ]

	def __getattribute__(self, name):
		if name in IxSessionMetricsWrapper.properties and super(IxSessionMetricsWrapper, self).__getattribute__(name):
			return getattr(super(IxSessionMetricsWrapper, self).__getattribute__("_IxSessionMetricsWrapper__sessionMetrics"), name)
		else:
			return super(IxSessionMetricsWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxSessionMetricsWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxSessionMetricsWrapper, self).__getattribute__("_IxSessionMetricsWrapper__sessionMetrics"), name, value)
			super(IxSessionMetricsWrapper, self).__setattr__(name, value)


class IxPersistentStatSourceWrapper(RestObjectBaseClass):

	def __init__(self, statSource):
		super(IxPersistentStatSourceWrapper, self).__init__(statSource)
		self.__statSource = statSource
		self.availableStats = IxAvailableStatsListWrapper(statSource)
		self.configuredStats = IxConfiguredStatsListWrapper(statSource)
		self.values = statSource.values
		self.enabled = statSource.enabled

	properties = ["values", "enabled", ]

	def __getattribute__(self, name):
		if name in IxPersistentStatSourceWrapper.properties and super(IxPersistentStatSourceWrapper, self).__getattribute__(name):
			return getattr(super(IxPersistentStatSourceWrapper, self).__getattribute__("_IxPersistentStatSourceWrapper__statSource"), name)
		else:
			return super(IxPersistentStatSourceWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPersistentStatSourceWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPersistentStatSourceWrapper, self).__getattribute__("_IxPersistentStatSourceWrapper__statSource"), name, value)
			super(IxPersistentStatSourceWrapper, self).__setattr__(name, value)

	def filterValues(self, timestamp = "enter value or will get latest", stats = []):
		local_values = self.values
		keys = list(local_values.keys())
		if len(keys) < 1 or (not keys[0].isdigit()):
			return ""

		if timestamp == "enter value or will get latest":
			timestamp = keys[-1]
		elif timestamp not in keys:
			return "Timestamp does not exist"

		result = {}
		for stat in stats:
			result.update({stat:local_values[timestamp][stat]})

		return result

	def getValuesForStat(self, statName):
		local_values = self.values
		keys = list(local_values.keys())
		if len(keys) < 1 or (not keys[0].isdigit()):
			return ""

		result = {}
		for timestamp in keys:
			result.update({timestamp:local_values[timestamp][statName]})

		ordered_result = collections.OrderedDict(sorted(result.items()))
		return ordered_result


class IxStatViewListWrapper(RestObjectBaseClass):

	def __init__(self, stats):
		self.__stats = stats

	def getItemIxStatView(self, objectID):
		itemList = self.__stats.restStatViews
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixStatView":
				return IxStatViewWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStatView(self, caption=None):
		kwargs = {}
		kwargs.update({"caption": caption})
		return IxStatViewWrapper(self.__stats.restStatViews.appendItem(**kwargs))

	def getItemIxRestGlobalAppStatView(self, objectID):
		itemList = self.__stats.restStatViews
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixRestGlobalAppStatView":
				return IxRestGlobalAppStatViewWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxRestGlobalAppStatView(self, caption=None):
		kwargs = {}
		kwargs.update({"caption": caption})
		return IxRestGlobalAppStatViewWrapper(self.__stats.restStatViews.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__stats.restStatViews
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, caption=None):
		kwargs = {}
		kwargs.update({"caption": caption})
		return self.__stats.restStatViews.appendItem(**kwargs)

	def getList(self):
		return self.__stats.restStatViews

	def clear(self):
		return self.__stats.restStatViews.clear()


class IxStatViewWrapper(RestObjectBaseClass):

	def __init__(self, ixStatView):
		super(IxStatViewWrapper, self).__init__(ixStatView)
		self.__ixStatView = ixStatView
		self.statList = IxStatViewStatsListWrapper(ixStatView)
		self.caption = ixStatView.caption
		self.values = ixStatView.values

	properties = ["caption", "values", ]

	def __getattribute__(self, name):
		if name in IxStatViewWrapper.properties and super(IxStatViewWrapper, self).__getattribute__(name):
			return getattr(super(IxStatViewWrapper, self).__getattribute__("_IxStatViewWrapper__ixStatView"), name)
		else:
			return super(IxStatViewWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxStatViewWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxStatViewWrapper, self).__getattribute__("_IxStatViewWrapper__ixStatView"), name, value)
			super(IxStatViewWrapper, self).__setattr__(name, value)

	def filterValues(self, timestamp = "enter value or will get latest", stats = []):
		local_values = self.values
		keys = list(local_values.keys())
		if len(keys) < 1 or (not keys[0].isdigit()):
			return ""

		if timestamp == "enter value or will get latest":
			timestamp = keys[-1]
		elif timestamp not in keys:
			return "Timestamp does not exist"

		result = {}
		for stat in stats:
			result.update({stat:local_values[timestamp][stat]})

		return result

	def getValuesForStat(self, statName):
		local_values = self.values
		keys = list(local_values.keys())
		if len(keys) < 1 or (not keys[0].isdigit()):
			return ""

		result = {}
		for timestamp in keys:
			result.update({timestamp:local_values[timestamp][statName]})

		ordered_result = collections.OrderedDict(sorted(result.items()))
		return ordered_result


class IxRestGlobalAppStatViewWrapper(RestObjectBaseClass):

	def __init__(self, ixRestGlobalAppStatView):
		super(IxRestGlobalAppStatViewWrapper, self).__init__(ixRestGlobalAppStatView)
		self.__ixRestGlobalAppStatView = ixRestGlobalAppStatView
		self.values = ixRestGlobalAppStatView.values
		self.caption = ixRestGlobalAppStatView.caption

	properties = ["values", "caption", ]

	def __getattribute__(self, name):
		if name in IxRestGlobalAppStatViewWrapper.properties and super(IxRestGlobalAppStatViewWrapper, self).__getattribute__(name):
			return getattr(super(IxRestGlobalAppStatViewWrapper, self).__getattribute__("_IxRestGlobalAppStatViewWrapper__ixRestGlobalAppStatView"), name)
		else:
			return super(IxRestGlobalAppStatViewWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxRestGlobalAppStatViewWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxRestGlobalAppStatViewWrapper, self).__getattribute__("_IxRestGlobalAppStatViewWrapper__ixRestGlobalAppStatView"), name, value)
			super(IxRestGlobalAppStatViewWrapper, self).__setattr__(name, value)

	def filterValues(self, timestamp = "enter value or will get latest", stats = []):
		local_values = self.values
		keys = list(local_values.keys())
		if len(keys) < 1 or (not keys[0].isdigit()):
			return ""

		if timestamp == "enter value or will get latest":
			timestamp = keys[-1]
		elif timestamp not in keys:
			return "Timestamp does not exist"

		result = {}
		for stat in stats:
			result.update({stat:local_values[timestamp][stat]})

		return result

	def getValuesForStat(self, statName):
		local_values = self.values
		keys = list(local_values.keys())
		if len(keys) < 1 or (not keys[0].isdigit()):
			return ""

		result = {}
		for timestamp in keys:
			result.update({timestamp:local_values[timestamp][statName]})

		ordered_result = collections.OrderedDict(sorted(result.items()))
		return ordered_result


class IxTestEnvelopeWrapper(RestObjectBaseClass):

	def __init__(self, activeTest):
		super(IxTestEnvelopeWrapper, self).__init__(activeTest)
		self.__activeTest = activeTest
		self.comment = activeTest.comment
		self.networkFailureThreshold = activeTest.networkFailureThreshold
		self.timelineList = IxTimelineListWrapper(activeTest)
		self.statViewThroughputUnits = activeTest.statViewThroughputUnits
		self.showNetworkDiagnosticsFromApplyConfig = activeTest.showNetworkDiagnosticsFromApplyConfig
		self.csvThroughputScalingFactor = activeTest.csvThroughputScalingFactor
		self.activitiesGroupedByObjective = activeTest.activitiesGroupedByObjective
		self.sessionSpecificDataList = IxNetSessionSpecificDataListWrapper(activeTest)
		self.resetNetworkDiagnosticsAtStartRun = activeTest.resetNetworkDiagnosticsAtStartRun
		self.testRunError = activeTest.testRunError
		self.enableForceNetworkUpdateCloud = activeTest.enableForceNetworkUpdateCloud
		self.enableFrameSizeDistributionStats = activeTest.enableFrameSizeDistributionStats
		self.enableTcpAdvancedStats = activeTest.enableTcpAdvancedStats
		self.communityList = _communityListSequenceContainerWrapper(activeTest)
		self.showNetworkDiagnosticsAfterRunStops = activeTest.showNetworkDiagnosticsAfterRunStops
		self.enableResetPorts = activeTest.enableResetPorts
		self.enableNetworkDiagnosticsLogging = activeTest.enableNetworkDiagnosticsLogging
		self.eventHandlerSettings = IxEventHandlerSettingsWrapper(activeTest.eventHandlerSettings)
		self.csvInterval = activeTest.csvInterval
		self.name = activeTest.name
		self.downgradeAppLibFlowsToLatestValidVersion = activeTest.downgradeAppLibFlowsToLatestValidVersion
		self.statsRequired = activeTest.statsRequired
		self.captureViewOptions = IxViewOptionsWrapper(activeTest.captureViewOptions)
		self.isFrameSizeDistributionViewSupported = activeTest.isFrameSizeDistributionViewSupported
		self.enableForceOwnership = activeTest.enableForceOwnership
		self.enableNetworkDiagnostics = activeTest.enableNetworkDiagnostics
		self.allowMixedObjectiveTypes = activeTest.allowMixedObjectiveTypes
		self.currentState = activeTest.currentState

	properties = ["comment", "networkFailureThreshold", "statViewThroughputUnits", "showNetworkDiagnosticsFromApplyConfig", "csvThroughputScalingFactor", "activitiesGroupedByObjective", "resetNetworkDiagnosticsAtStartRun", "testRunError", "enableForceNetworkUpdateCloud", "enableFrameSizeDistributionStats", "enableTcpAdvancedStats", "showNetworkDiagnosticsAfterRunStops", "enableResetPorts", "enableNetworkDiagnosticsLogging", "csvInterval", "name", "downgradeAppLibFlowsToLatestValidVersion", "statsRequired", "isFrameSizeDistributionViewSupported", "enableForceOwnership", "enableNetworkDiagnostics", "allowMixedObjectiveTypes", "currentState", ]

	def __getattribute__(self, name):
		if name in IxTestEnvelopeWrapper.properties and super(IxTestEnvelopeWrapper, self).__getattribute__(name):
			return getattr(super(IxTestEnvelopeWrapper, self).__getattribute__("_IxTestEnvelopeWrapper__activeTest"), name)
		else:
			return super(IxTestEnvelopeWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTestEnvelopeWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTestEnvelopeWrapper, self).__getattribute__("_IxTestEnvelopeWrapper__activeTest"), name, value)
			super(IxTestEnvelopeWrapper, self).__setattr__(name, value)

	def collectDiagnostics(self, zipFileLocation, clientOnly=False):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__activeTest.collectDiagnostics(**kwargs)


class IxRestLogCollectorWrapper(RestObjectBaseClass):

	def __init__(self, test):
		self.__test = test

	def getItem(self, objectID):
		itemList = self.__test.logs
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixRestLogEntry":
				return IxRestLogEntryWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxRestLogEntryWrapper(self.__test.logs.appendItem(**kwargs))

	def getList(self):
		return self.__test.logs

	def clear(self):
		return self.__test.logs.clear()


class IxRestLogEntryWrapper(RestObjectBaseClass):

	def __init__(self, ixRestLogEntry):
		super(IxRestLogEntryWrapper, self).__init__(ixRestLogEntry)
		self.__ixRestLogEntry = ixRestLogEntry
		self.moduleName = ixRestLogEntry.moduleName
		self.severity = ixRestLogEntry.severity
		self.timeStamp = ixRestLogEntry.timeStamp
		self.message = ixRestLogEntry.message

	properties = ["moduleName", "severity", "timeStamp", "message", ]

	def __getattribute__(self, name):
		if name in IxRestLogEntryWrapper.properties and super(IxRestLogEntryWrapper, self).__getattribute__(name):
			return getattr(super(IxRestLogEntryWrapper, self).__getattribute__("_IxRestLogEntryWrapper__ixRestLogEntry"), name)
		else:
			return super(IxRestLogEntryWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxRestLogEntryWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxRestLogEntryWrapper, self).__getattribute__("_IxRestLogEntryWrapper__ixRestLogEntry"), name, value)
			super(IxRestLogEntryWrapper, self).__setattr__(name, value)


class IxChassisSequenceContainerWrapper(RestObjectBaseClass):

	def __init__(self, chassischain):
		self.__chassischain = chassischain

	def getItem(self, objectID):
		itemList = self.__chassischain.chassisList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixChassis":
				return IxChassisWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, name=None):
		kwargs = {}
		kwargs.update({"name": name})
		return IxChassisWrapper(self.__chassischain.chassisList.appendItem(**kwargs))

	def getList(self):
		return self.__chassischain.chassisList

	def clear(self):
		return self.__chassischain.chassisList.clear()


class IxChassisWrapper(RestObjectBaseClass):

	def __init__(self, ixChassis):
		super(IxChassisWrapper, self).__init__(ixChassis)
		self.__ixChassis = ixChassis
		self.chassisIp = ixChassis.chassisIp
		self.name = ixChassis.name
		self.cardList = IxCardSequenceContainerWrapper(ixChassis)
		self.isConnected = ixChassis.isConnected
		self.version = ixChassis.version
		self.ixOsVersion = ixChassis.ixOsVersion
		self.chassisType = ixChassis.chassisType
		self.id = ixChassis.id
		self.isDisconnected = ixChassis.isDisconnected

	properties = ["chassisIp", "name", "isConnected", "version", "ixOsVersion", "chassisType", "id", "isDisconnected", ]

	def __getattribute__(self, name):
		if name in IxChassisWrapper.properties and super(IxChassisWrapper, self).__getattribute__(name):
			return getattr(super(IxChassisWrapper, self).__getattribute__("_IxChassisWrapper__ixChassis"), name)
		else:
			return super(IxChassisWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxChassisWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxChassisWrapper, self).__getattribute__("_IxChassisWrapper__ixChassis"), name, value)
			super(IxChassisWrapper, self).__setattr__(name, value)

	def refreshConnection(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__ixChassis.refreshConnection(**kwargs)


class IxAvailableStatsListWrapper(RestObjectBaseClass):

	def __init__(self, statSource):
		self.__statSource = statSource

	def getItem(self, objectID):
		itemList = self.__statSource.availableStats
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixAvailableStat":
				return IxAvailableStatWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, caption=None, statName=None, aggregationType=None):
		kwargs = {}
		kwargs.update({"caption": caption})
		kwargs.update({"statName": statName})
		kwargs.update({"aggregationType": aggregationType})
		return IxAvailableStatWrapper(self.__statSource.availableStats.appendItem(**kwargs))

	def getList(self):
		return self.__statSource.availableStats

	def clear(self):
		return self.__statSource.availableStats.clear()


class IxAvailableStatWrapper(RestObjectBaseClass):

	def __init__(self, ixAvailableStat):
		super(IxAvailableStatWrapper, self).__init__(ixAvailableStat)
		self.__ixAvailableStat = ixAvailableStat
		self.caption = ixAvailableStat.caption
		self.aggregationType = ixAvailableStat.aggregationType
		self.statName = ixAvailableStat.statName

	properties = ["caption", "aggregationType", "statName", ]

	def __getattribute__(self, name):
		if name in IxAvailableStatWrapper.properties and super(IxAvailableStatWrapper, self).__getattribute__(name):
			return getattr(super(IxAvailableStatWrapper, self).__getattribute__("_IxAvailableStatWrapper__ixAvailableStat"), name)
		else:
			return super(IxAvailableStatWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxAvailableStatWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxAvailableStatWrapper, self).__getattribute__("_IxAvailableStatWrapper__ixAvailableStat"), name, value)
			super(IxAvailableStatWrapper, self).__setattr__(name, value)


class IxConfiguredStatsListWrapper(RestObjectBaseClass):

	def __init__(self, statSource):
		self.__statSource = statSource

	def getItem(self, objectID):
		itemList = self.__statSource.configuredStats
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixConfiguredStat":
				return IxConfiguredStatWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, caption=None, statName=None, aggregationType=None):
		kwargs = {}
		kwargs.update({"caption": caption})
		kwargs.update({"statName": statName})
		kwargs.update({"aggregationType": aggregationType})
		return IxConfiguredStatWrapper(self.__statSource.configuredStats.appendItem(**kwargs))

	def getList(self):
		return self.__statSource.configuredStats

	def clear(self):
		return self.__statSource.configuredStats.clear()


class IxConfiguredStatWrapper(RestObjectBaseClass):

	def __init__(self, ixConfiguredStat):
		super(IxConfiguredStatWrapper, self).__init__(ixConfiguredStat)
		self.__ixConfiguredStat = ixConfiguredStat
		self.enabled = ixConfiguredStat.enabled
		self.filterList = IxRestFiltersWrapper(ixConfiguredStat.filterList)
		self.caption = ixConfiguredStat.caption
		self.aggregationType = ixConfiguredStat.aggregationType
		self.statName = ixConfiguredStat.statName

	properties = ["enabled", "caption", "aggregationType", "statName", ]

	def __getattribute__(self, name):
		if name in IxConfiguredStatWrapper.properties and super(IxConfiguredStatWrapper, self).__getattribute__(name):
			return getattr(super(IxConfiguredStatWrapper, self).__getattribute__("_IxConfiguredStatWrapper__ixConfiguredStat"), name)
		else:
			return super(IxConfiguredStatWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxConfiguredStatWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxConfiguredStatWrapper, self).__getattribute__("_IxConfiguredStatWrapper__ixConfiguredStat"), name, value)
			super(IxConfiguredStatWrapper, self).__setattr__(name, value)


class IxStatViewStatsListWrapper(RestObjectBaseClass):

	def __init__(self, ixStatView):
		self.__ixStatView = ixStatView

	def getItem(self, objectID):
		itemList = self.__ixStatView.statList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixStatViewStat":
				return IxStatViewStatWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, caption=None, statName=None, aggregationType=None):
		kwargs = {}
		kwargs.update({"caption": caption})
		kwargs.update({"statName": statName})
		kwargs.update({"aggregationType": aggregationType})
		return IxStatViewStatWrapper(self.__ixStatView.statList.appendItem(**kwargs))

	def getList(self):
		return self.__ixStatView.statList

	def clear(self):
		return self.__ixStatView.statList.clear()


class IxStatViewStatWrapper(RestObjectBaseClass):

	def __init__(self, ixStatViewStat):
		super(IxStatViewStatWrapper, self).__init__(ixStatViewStat)
		self.__ixStatViewStat = ixStatViewStat
		self.caption = ixStatViewStat.caption
		self.aggregationType = ixStatViewStat.aggregationType
		self.statName = ixStatViewStat.statName

	properties = ["caption", "aggregationType", "statName", ]

	def __getattribute__(self, name):
		if name in IxStatViewStatWrapper.properties and super(IxStatViewStatWrapper, self).__getattribute__(name):
			return getattr(super(IxStatViewStatWrapper, self).__getattribute__("_IxStatViewStatWrapper__ixStatViewStat"), name)
		else:
			return super(IxStatViewStatWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxStatViewStatWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxStatViewStatWrapper, self).__getattribute__("_IxStatViewStatWrapper__ixStatViewStat"), name, value)
			super(IxStatViewStatWrapper, self).__setattr__(name, value)


class IxTimelineListWrapper(RestObjectBaseClass):

	def __init__(self, activeTest):
		self.__activeTest = activeTest

	def getItemIxTimeline(self, objectID):
		itemList = self.__activeTest.timelineList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixTimeline":
				return IxTimelineWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxTimeline(self):
		kwargs = {}
		return IxTimelineWrapper(self.__activeTest.timelineList.appendItem(**kwargs))

	def getItemIxMatchLongestTimeline(self, objectID):
		itemList = self.__activeTest.timelineList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixMatchLongestTimeline":
				return IxMatchLongestTimelineWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxMatchLongestTimeline(self):
		kwargs = {}
		return IxMatchLongestTimelineWrapper(self.__activeTest.timelineList.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__activeTest.timelineList
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return self.__activeTest.timelineList.appendItem(**kwargs)

	def getList(self):
		return self.__activeTest.timelineList

	def clear(self):
		return self.__activeTest.timelineList.clear()


class IxTimelineWrapper(RestObjectBaseClass):

	def __init__(self, ixTimeline):
		super(IxTimelineWrapper, self).__init__(ixTimeline)
		self.__ixTimeline = ixTimeline
		self.iterations = ixTimeline.iterations
		self.rampUpType = ixTimeline.rampUpType
		self.rampUpValue = ixTimeline.rampUpValue
		self.rampUpTime = ixTimeline.rampUpTime
		self.rampDownTime = ixTimeline.rampDownTime
		self.standbyTime = ixTimeline.standbyTime
		self.rampDownValue = ixTimeline.rampDownValue
		self.rampUpInterval = ixTimeline.rampUpInterval
		self.offlineTime = ixTimeline.offlineTime
		self.sustainTime = ixTimeline.sustainTime
		self.name = ixTimeline.name
		self.timelineType = ixTimeline.timelineType


	properties = ['rampUpType', 'rampUpTime', 'offlineTime', 'rampDownTime', 'standbyTime', 'rampDownValue', 'iterations', 'rampUpInterval', 'sustainTime', 'name', 'timelineType', 'rampUpValue']

	

	def __getattribute__(self, name):
		if name in IxTimelineWrapper.properties and super(IxTimelineWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineWrapper, self).__getattribute__("_IxTimelineWrapper__ixTimeline"), name)
		else:
			return super(IxTimelineWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineWrapper, self).__getattribute__("_IxTimelineWrapper__ixTimeline"), name, value)
			super(IxTimelineWrapper, self).__setattr__(name, value)


class IxMatchLongestTimelineWrapper(RestObjectBaseClass):

	def __init__(self, ixMatchLongestTimeline):
		super(IxMatchLongestTimelineWrapper, self).__init__(ixMatchLongestTimeline)
		self.__ixMatchLongestTimeline = ixMatchLongestTimeline
		self.name = ixMatchLongestTimeline.name
		self.standbyTime = ixMatchLongestTimeline.standbyTime
		self.iterations = ixMatchLongestTimeline.iterations
		self.sustainTime = ixMatchLongestTimeline.sustainTime

	properties = ["name", "standbyTime", "iterations", "sustainTime", ]

	def __getattribute__(self, name):
		if name in IxMatchLongestTimelineWrapper.properties and super(IxMatchLongestTimelineWrapper, self).__getattribute__(name):
			return getattr(super(IxMatchLongestTimelineWrapper, self).__getattribute__("_IxMatchLongestTimelineWrapper__ixMatchLongestTimeline"), name)
		else:
			return super(IxMatchLongestTimelineWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxMatchLongestTimelineWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxMatchLongestTimelineWrapper, self).__getattribute__("_IxMatchLongestTimelineWrapper__ixMatchLongestTimeline"), name, value)
			super(IxMatchLongestTimelineWrapper, self).__setattr__(name, value)


class IxNetSessionSpecificDataListWrapper(RestObjectBaseClass):

	def __init__(self, activeTest):
		self.__activeTest = activeTest

	def getItemIxNetMacSessionData(self, objectID):
		itemList = self.__activeTest.sessionSpecificDataList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetMacSessionData":
				return IxNetMacSessionDataWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxNetMacSessionData(self):
		kwargs = {}
		return IxNetMacSessionDataWrapper(self.__activeTest.sessionSpecificDataList.appendItem(**kwargs))

	def getItemIxNetIpSessionData(self, objectID):
		itemList = self.__activeTest.sessionSpecificDataList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetIpSessionData":
				return IxNetIpSessionDataWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxNetIpSessionData(self):
		kwargs = {}
		return IxNetIpSessionDataWrapper(self.__activeTest.sessionSpecificDataList.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__activeTest.sessionSpecificDataList
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return self.__activeTest.sessionSpecificDataList.appendItem(**kwargs)

	def getList(self):
		return self.__activeTest.sessionSpecificDataList

	def clear(self):
		return self.__activeTest.sessionSpecificDataList.clear()


class IxNetMacSessionDataWrapper(RestObjectBaseClass):

	def __init__(self, ixNetMacSessionData):
		super(IxNetMacSessionDataWrapper, self).__init__(ixNetMacSessionData)
		self.__ixNetMacSessionData = ixNetMacSessionData
		self.itemType = ixNetMacSessionData.itemType
		self.duplicateCheckingScope = ixNetMacSessionData.duplicateCheckingScope

	properties = ["itemType", "duplicateCheckingScope", ]

	def __getattribute__(self, name):
		if name in IxNetMacSessionDataWrapper.properties and super(IxNetMacSessionDataWrapper, self).__getattribute__(name):
			return getattr(super(IxNetMacSessionDataWrapper, self).__getattribute__("_IxNetMacSessionDataWrapper__ixNetMacSessionData"), name)
		else:
			return super(IxNetMacSessionDataWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetMacSessionDataWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetMacSessionDataWrapper, self).__getattribute__("_IxNetMacSessionDataWrapper__ixNetMacSessionData"), name, value)
			super(IxNetMacSessionDataWrapper, self).__setattr__(name, value)


class IxNetIpSessionDataWrapper(RestObjectBaseClass):

	def __init__(self, ixNetIpSessionData):
		super(IxNetIpSessionDataWrapper, self).__init__(ixNetIpSessionData)
		self.__ixNetIpSessionData = ixNetIpSessionData
		self.enableGatewayArp = ixNetIpSessionData.enableGatewayArp
		self.itemType = ixNetIpSessionData.itemType
		self.ignoreUnresolvedIPs = ixNetIpSessionData.ignoreUnresolvedIPs
		self.individualARPTimeOut = ixNetIpSessionData.individualARPTimeOut
		self.maxOutstandingGatewayArpRequests = ixNetIpSessionData.maxOutstandingGatewayArpRequests
		self.sendAllRequests = ixNetIpSessionData.sendAllRequests
		self.gatewayArpRequestRate = ixNetIpSessionData.gatewayArpRequestRate
		self.duplicateCheckingScope = ixNetIpSessionData.duplicateCheckingScope

	properties = ["enableGatewayArp", "itemType", "ignoreUnresolvedIPs", "individualARPTimeOut", "maxOutstandingGatewayArpRequests", "sendAllRequests", "gatewayArpRequestRate", "duplicateCheckingScope", ]

	def __getattribute__(self, name):
		if name in IxNetIpSessionDataWrapper.properties and super(IxNetIpSessionDataWrapper, self).__getattribute__(name):
			return getattr(super(IxNetIpSessionDataWrapper, self).__getattribute__("_IxNetIpSessionDataWrapper__ixNetIpSessionData"), name)
		else:
			return super(IxNetIpSessionDataWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetIpSessionDataWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetIpSessionDataWrapper, self).__getattribute__("_IxNetIpSessionDataWrapper__ixNetIpSessionData"), name, value)
			super(IxNetIpSessionDataWrapper, self).__setattr__(name, value)


class _communityListSequenceContainerWrapper(RestObjectBaseClass):

	def __init__(self, activeTest):
		self.__activeTest = activeTest

	def getItem(self, objectID):
		itemList = self.__activeTest.communityList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetTraffic":
				return IxNetTrafficWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxNetTrafficWrapper(self.__activeTest.communityList.appendItem(**kwargs))

	def getList(self):
		return self.__activeTest.communityList

	def clear(self):
		return self.__activeTest.communityList.clear()


class IxNetTrafficWrapper(RestObjectBaseClass):

	def __init__(self, ixNetTraffic):
		super(IxNetTrafficWrapper, self).__init__(ixNetTraffic)
		self.__ixNetTraffic = ixNetTraffic
		self.enable = ixNetTraffic.enable
		self.name = ixNetTraffic.name
		self.activityFunction = ixNetTraffic.activityFunction
		self.totalUserObjectiveValue = ixNetTraffic.totalUserObjectiveValue
		self.activityList = IxActivityListProxyWrapper(ixNetTraffic)
		self.network = IxNetworkGroupWrapper(ixNetTraffic.network)
		self.traffic = IxTrafficWrapper(ixNetTraffic.traffic)
		self.showActualCPUUtilizationMode = ixNetTraffic.showActualCPUUtilizationMode
		self.tcpAccelerationAllowedFlag = ixNetTraffic.tcpAccelerationAllowedFlag
		self.throughputAcceleration = ixNetTraffic.throughputAcceleration
		self.networkType = ixNetTraffic.networkType
		self.role = ixNetTraffic.role
		self.activeRole = ixNetTraffic.activeRole
		self.performanceAcceleration = ixNetTraffic.performanceAcceleration
		self.userObjectiveType = ixNetTraffic.userObjectiveType
		self.scenarioElementType = ixNetTraffic.scenarioElementType

	properties = ["enable", "name", "activityFunction", "totalUserObjectiveValue", "showActualCPUUtilizationMode", "tcpAccelerationAllowedFlag", "throughputAcceleration", "networkType", "role", "activeRole", "performanceAcceleration", "userObjectiveType", "scenarioElementType", ]

	def __getattribute__(self, name):
		if name in IxNetTrafficWrapper.properties and super(IxNetTrafficWrapper, self).__getattribute__(name):
			return getattr(super(IxNetTrafficWrapper, self).__getattribute__("_IxNetTrafficWrapper__ixNetTraffic"), name)
		else:
			return super(IxNetTrafficWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetTrafficWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetTrafficWrapper, self).__getattribute__("_IxNetTrafficWrapper__ixNetTraffic"), name, value)
			super(IxNetTrafficWrapper, self).__setattr__(name, value)


class IxEventHandlerSettingsWrapper(RestObjectBaseClass):

	def __init__(self, eventHandlerSettings):
		super(IxEventHandlerSettingsWrapper, self).__init__(eventHandlerSettings)
		self.__eventHandlerSettings = eventHandlerSettings
		self.disabledEventClasses = eventHandlerSettings.disabledEventClasses
		self.disabledPorts = eventHandlerSettings.disabledPorts

	properties = ["disabledEventClasses", "disabledPorts", ]

	def __getattribute__(self, name):
		if name in IxEventHandlerSettingsWrapper.properties and super(IxEventHandlerSettingsWrapper, self).__getattribute__(name):
			return getattr(super(IxEventHandlerSettingsWrapper, self).__getattribute__("_IxEventHandlerSettingsWrapper__eventHandlerSettings"), name)
		else:
			return super(IxEventHandlerSettingsWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxEventHandlerSettingsWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxEventHandlerSettingsWrapper, self).__getattribute__("_IxEventHandlerSettingsWrapper__eventHandlerSettings"), name, value)
			super(IxEventHandlerSettingsWrapper, self).__setattr__(name, value)


class IxViewOptionsWrapper(RestObjectBaseClass):

	def __init__(self, captureViewOptions):
		super(IxViewOptionsWrapper, self).__init__(captureViewOptions)
		self.__captureViewOptions = captureViewOptions
		self.captureRunAfter = captureViewOptions.captureRunAfter
		self.allocatedBufferMemoryPercentage = captureViewOptions.allocatedBufferMemoryPercentage
		self.captureRunDuration = captureViewOptions.captureRunDuration
		self.runMode = captureViewOptions.runMode
		self.collectScheme = captureViewOptions.collectScheme

	properties = ["captureRunAfter", "allocatedBufferMemoryPercentage", "captureRunDuration", "runMode", "collectScheme", ]

	def __getattribute__(self, name):
		if name in IxViewOptionsWrapper.properties and super(IxViewOptionsWrapper, self).__getattribute__(name):
			return getattr(super(IxViewOptionsWrapper, self).__getattribute__("_IxViewOptionsWrapper__captureViewOptions"), name)
		else:
			return super(IxViewOptionsWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxViewOptionsWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxViewOptionsWrapper, self).__getattribute__("_IxViewOptionsWrapper__captureViewOptions"), name, value)
			super(IxViewOptionsWrapper, self).__setattr__(name, value)


class IxCardSequenceContainerWrapper(RestObjectBaseClass):

	def __init__(self, ixChassis):
		self.__ixChassis = ixChassis

	def getItemIxBreakOutLineSpeedCard(self, objectID):
		itemList = self.__ixChassis.cardList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixBreakOutLineSpeedCard":
				return IxBreakOutLineSpeedCardWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxBreakOutLineSpeedCard(self):
		kwargs = {}
		return IxBreakOutLineSpeedCardWrapper(self.__ixChassis.cardList.appendItem(**kwargs))

	def getItemIxBreakOutCard(self, objectID):
		itemList = self.__ixChassis.cardList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixBreakOutCard":
				return IxBreakOutCardWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxBreakOutCard(self):
		kwargs = {}
		return IxBreakOutCardWrapper(self.__ixChassis.cardList.appendItem(**kwargs))

	def getItemIxCard(self, objectID):
		itemList = self.__ixChassis.cardList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixCard":
				return IxCardWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxCard(self):
		kwargs = {}
		return IxCardWrapper(self.__ixChassis.cardList.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__ixChassis.cardList
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return self.__ixChassis.cardList.appendItem(**kwargs)

	def getList(self):
		return self.__ixChassis.cardList

	def clear(self):
		return self.__ixChassis.cardList.clear()


class IxBreakOutLineSpeedCardWrapper(RestObjectBaseClass):

	def __init__(self, ixBreakOutLineSpeedCard):
		super(IxBreakOutLineSpeedCardWrapper, self).__init__(ixBreakOutLineSpeedCard)
		self.__ixBreakOutLineSpeedCard = ixBreakOutLineSpeedCard
		self.name = ixBreakOutLineSpeedCard.name
		self.chassisId = ixBreakOutLineSpeedCard.chassisId
		self.cardType = ixBreakOutLineSpeedCard.cardType
		self.portList = _portListSequenceContainerWrapper(ixBreakOutLineSpeedCard)
		self.operationMode = ixBreakOutLineSpeedCard.operationMode

	properties = ["name", "chassisId", "cardType", "operationMode", ]

	def __getattribute__(self, name):
		if name in IxBreakOutLineSpeedCardWrapper.properties and super(IxBreakOutLineSpeedCardWrapper, self).__getattribute__(name):
			return getattr(super(IxBreakOutLineSpeedCardWrapper, self).__getattribute__("_IxBreakOutLineSpeedCardWrapper__ixBreakOutLineSpeedCard"), name)
		else:
			return super(IxBreakOutLineSpeedCardWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxBreakOutLineSpeedCardWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxBreakOutLineSpeedCardWrapper, self).__getattribute__("_IxBreakOutLineSpeedCardWrapper__ixBreakOutLineSpeedCard"), name, value)
			super(IxBreakOutLineSpeedCardWrapper, self).__setattr__(name, value)


class IxBreakOutCardWrapper(RestObjectBaseClass):

	def __init__(self, ixBreakOutCard):
		super(IxBreakOutCardWrapper, self).__init__(ixBreakOutCard)
		self.__ixBreakOutCard = ixBreakOutCard
		self.name = ixBreakOutCard.name
		self.chassisId = ixBreakOutCard.chassisId
		self.cardType = ixBreakOutCard.cardType
		self.portList = _portListSequenceContainerWrapper(ixBreakOutCard)
		self.operationMode = ixBreakOutCard.operationMode

	properties = ["name", "chassisId", "cardType", "operationMode", ]

	def __getattribute__(self, name):
		if name in IxBreakOutCardWrapper.properties and super(IxBreakOutCardWrapper, self).__getattribute__(name):
			return getattr(super(IxBreakOutCardWrapper, self).__getattribute__("_IxBreakOutCardWrapper__ixBreakOutCard"), name)
		else:
			return super(IxBreakOutCardWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxBreakOutCardWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxBreakOutCardWrapper, self).__getattribute__("_IxBreakOutCardWrapper__ixBreakOutCard"), name, value)
			super(IxBreakOutCardWrapper, self).__setattr__(name, value)


class IxCardWrapper(RestObjectBaseClass):

	def __init__(self, ixCard):
		super(IxCardWrapper, self).__init__(ixCard)
		self.__ixCard = ixCard
		self.name = ixCard.name
		self.chassisId = ixCard.chassisId
		self.cardType = ixCard.cardType
		self.portList = _portListSequenceContainerWrapper(ixCard)
		self.operationMode = ixCard.operationMode

	properties = ["name", "chassisId", "cardType", "operationMode", ]

	def __getattribute__(self, name):
		if name in IxCardWrapper.properties and super(IxCardWrapper, self).__getattribute__(name):
			return getattr(super(IxCardWrapper, self).__getattribute__("_IxCardWrapper__ixCard"), name)
		else:
			return super(IxCardWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxCardWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxCardWrapper, self).__getattribute__("_IxCardWrapper__ixCard"), name, value)
			super(IxCardWrapper, self).__setattr__(name, value)


class IxRestFiltersWrapper(RestObjectBaseClass):

	def __init__(self, filterList):
		super(IxRestFiltersWrapper, self).__init__(filterList)
		self.__filterList = filterList

	properties = []

	def __getattribute__(self, name):
		if name in IxRestFiltersWrapper.properties and super(IxRestFiltersWrapper, self).__getattribute__(name):
			return getattr(super(IxRestFiltersWrapper, self).__getattribute__("_IxRestFiltersWrapper__filterList"), name)
		else:
			return super(IxRestFiltersWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxRestFiltersWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxRestFiltersWrapper, self).__getattribute__("_IxRestFiltersWrapper__filterList"), name, value)
			super(IxRestFiltersWrapper, self).__setattr__(name, value)


class IxActivityListProxyWrapper(RestObjectBaseClass):

	def __init__(self, ixNetTraffic):
		self.__ixNetTraffic = ixNetTraffic
		self.optionsDict = {
			('DNS Client',): "IxActivityDNSClient",
			('DNS Server',): "IxActivityDNSServer",
			('IMAP Client',): "IxActivityIMAPClient",
			('IMAP Server',): "IxActivityIMAPServer",
			('POP3 Client',): "IxActivityPOP3Client",
			('POP3 Server',): "IxActivityPOP3Server",
			('SMTP Server',): "IxActivitySMTPServer",
			('SMTP Client',): "IxActivitySMTPClient",
			('HTTP Server',): "IxActivityHTTPServer",
			('HTTP Client',): "IxActivityHTTPClient",
			('stateless Peer',): "IxActivitystatelessPeer",
			('FTP Server',): "IxActivityFTPServer",
			('FTP Client',): "IxActivityFTPClient",
			('Streaming Client',): "IxActivityStreamingClient",
			('Video Client',): "IxActivityVideoClient",
			('Video Server',): "IxActivityVideoServer",
			('VoIP Peer',): "IxActivityVoIPPeer",
		}

	def getItemIxActivityDNSClient(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "DNS Client":
				return IxActivityDNSClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityDNSClient(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "DNS Client"})
		return IxActivityDNSClientWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivityDNSServer(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "DNS Server":
				return IxActivityDNSServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityDNSServer(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "DNS Server"})
		return IxActivityDNSServerWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, protocolAndType=None):
		kwargs = {}
		kwargs.update({"protocolAndType": protocolAndType})
		return self.__ixNetTraffic.activityList.appendItem(**kwargs)

	def getList(self):
		return self.__ixNetTraffic.activityList

	def clear(self):
		return self.__ixNetTraffic.activityList.clear()

	def getItemIxActivityIMAPClient(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "IMAP Client":
				return IxActivityIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityIMAPClient(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "IMAP Client"})
		return IxActivityIMAPClientWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivityIMAPServer(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "IMAP Server":
				return IxActivityIMAPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityIMAPServer(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "IMAP Server"})
		return IxActivityIMAPServerWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivityPOP3Client(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "POP3 Client":
				return IxActivityPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityPOP3Client(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "POP3 Client"})
		return IxActivityPOP3ClientWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivityPOP3Server(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "POP3 Server":
				return IxActivityPOP3ServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityPOP3Server(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "POP3 Server"})
		return IxActivityPOP3ServerWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivitySMTPClient(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "SMTP Client":
				return IxActivitySMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivitySMTPClient(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "SMTP Client"})
		return IxActivitySMTPClientWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivitySMTPServer(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "SMTP Server":
				return IxActivitySMTPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivitySMTPServer(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "SMTP Server"})
		return IxActivitySMTPServerWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivityHTTPClient(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "HTTP Client":
				return IxActivityHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityHTTPClient(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "HTTP Client"})
		return IxActivityHTTPClientWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivityHTTPServer(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "HTTP Server":
				return IxActivityHTTPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityHTTPServer(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "HTTP Server"})
		return IxActivityHTTPServerWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivitystatelessPeer(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "stateless Peer":
				return IxActivitystatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivitystatelessPeer(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "stateless Peer"})
		return IxActivitystatelessPeerWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivityFTPClient(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "FTP Client":
				return IxActivityFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityFTPClient(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "FTP Client"})
		return IxActivityFTPClientWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivityFTPServer(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "FTP Server":
				return IxActivityFTPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityFTPServer(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "FTP Server"})
		return IxActivityFTPServerWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivityStreamingClient(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "Streaming Client":
				return IxActivityStreamingClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityStreamingClient(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "Streaming Client"})
		return IxActivityStreamingClientWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivityVideoClient(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "Video Client":
				return IxActivityVideoClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityVideoClient(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "Video Client"})
		return IxActivityVideoClientWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivityVideoServer(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "Video Server":
				return IxActivityVideoServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityVideoServer(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "Video Server"})
		return IxActivityVideoServerWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))

	def getItemIxActivityVoIPPeer(self, objectID):
		itemList = self.__ixNetTraffic.activityList
		for elem in itemList:
			if elem.objectID == objectID and elem.protocolAndType == "VoIP Peer":
				return IxActivityVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxActivityVoIPPeer(self):
		kwargs = {}
		kwargs.update({"protocolAndType": "VoIP Peer"})
		return IxActivityVoIPPeerWrapper(self.__ixNetTraffic.activityList.appendItem(**kwargs))


class IxActivityDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityDNSClientWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.secondaryEnableConstraint = ixActivity.secondaryEnableConstraint
		self.protocol = ixActivity.protocol
		self.userIpMapping = ixActivity.userIpMapping
		self.enableConstraint = ixActivity.enableConstraint
		self.agent = PluginDNSClientWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.constraintValue = ixActivity.constraintValue
		self.customParameters = ixActivity.customParameters
		self.timelineId = ixActivity.timelineId
		self.role = ixActivity.role
		self.timeline = IxTimelineProxyDNSClientWrapper(ixActivity.timeline)
		self.activeRole = ixActivity.activeRole
		self.type = ixActivity.type
		self.secondaryConstraintValue = ixActivity.secondaryConstraintValue
		self.enable = ixActivity.enable
		self.protocolAndType = ixActivity.protocolAndType
		self.userObjectiveType = ixActivity.userObjectiveType
		self.destinationIpMapping = ixActivity.destinationIpMapping
		self.name = ixActivity.name
		self.secondaryConstraintType = ixActivity.secondaryConstraintType
		self.userObjectiveValue = ixActivity.userObjectiveValue
		self.constraintType = ixActivity.constraintType

	properties = ["secondaryEnableConstraint", "protocol", "userIpMapping", "enableConstraint", "objectivePercent", "constraintValue", "customParameters", "timelineId", "role", "activeRole", "type", "secondaryConstraintValue", "enable", "protocolAndType", "userObjectiveType", "destinationIpMapping", "name", "secondaryConstraintType", "userObjectiveValue", "constraintType", ]

	def __getattribute__(self, name):
		if name in IxActivityDNSClientWrapper.properties and super(IxActivityDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityDNSClientWrapper, self).__getattribute__("_IxActivityDNSClientWrapper__ixActivity"), name)
		else:
			return super(IxActivityDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityDNSClientWrapper, self).__getattribute__("_IxActivityDNSClientWrapper__ixActivity"), name, value)
			super(IxActivityDNSClientWrapper, self).__setattr__(name, value)


class IxNetworkGroupWrapper(RestObjectBaseClass):

	def __init__(self, network):
		super(IxNetworkGroupWrapper, self).__init__(network)
		self.__network = network
		self.comment = network.comment
		self.name = network.name
		self.aggregation = network.aggregation
		self.globalPlugins = IxNetGlobalPluginListWrapper(network)
		self.role = network.role
		self.lineSpeed = network.lineSpeed
		self.portList = IxNetworkPortListSequenceContainerWrapper(network)
		self.networkType = network.networkType
		self.stack = IxNetL1EthernetPluginWrapper(network.stack)
		self.portL1Settings = IxPortL1SettingsWrapper(network.portL1Settings)

	properties = ["comment", "name", "aggregation", "role", "lineSpeed", "networkType", ]

	def __getattribute__(self, name):
		if name in IxNetworkGroupWrapper.properties and super(IxNetworkGroupWrapper, self).__getattribute__(name):
			return getattr(super(IxNetworkGroupWrapper, self).__getattribute__("_IxNetworkGroupWrapper__network"), name)
		else:
			return super(IxNetworkGroupWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetworkGroupWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetworkGroupWrapper, self).__getattribute__("_IxNetworkGroupWrapper__network"), name, value)
			super(IxNetworkGroupWrapper, self).__setattr__(name, value)

	def getIPPlugins(self):
		visited = []
		queue = []
		node = self.__network.stack
		visited.append(node)
		queue.append(node)
		result = []
		while queue:
			currentPlugin = queue.pop(0)
			if currentPlugin.restObjectType == "ixNetIpV4V6Plugin":
				result.append(IxNetIpV4V6PluginWrapper(currentPlugin))
			for neighbour in currentPlugin.childrenList:
				if neighbour not in visited:
					visited.append(neighbour)
					queue.append(neighbour)

		return result

	def getEthernetPlugins(self):
		visited = []
		queue = []
		node = self.__network.stack
		visited.append(node)
		queue.append(node)
		result = []
		while queue:
			currentPlugin = queue.pop(0)
			if currentPlugin.restObjectType == "ixNetL1EthernetPlugin":
				result.append(IxNetL1EthernetPluginWrapper(currentPlugin))
			for neighbour in currentPlugin.childrenList:
				if neighbour not in visited:
					visited.append(neighbour)
					queue.append(neighbour)

		return result

	def getMACVLANPlugins(self):
		visited = []
		queue = []
		node = self.__network.stack
		visited.append(node)
		queue.append(node)
		result = []
		while queue:
			currentPlugin = queue.pop(0)
			if currentPlugin.restObjectType == "ixNetL2EthernetPlugin":
				result.append(IxNetL2EthernetPluginWrapper(currentPlugin))
			for neighbour in currentPlugin.childrenList:
				if neighbour not in visited:
					visited.append(neighbour)
					queue.append(neighbour)

		return result



class IxTrafficWrapper(RestObjectBaseClass):

	def __init__(self, traffic):
		super(IxTrafficWrapper, self).__init__(traffic)
		self.__traffic = traffic
		self.activityFunction = traffic.activityFunction
		self.role = traffic.role
		self.name = traffic.name

	properties = ["activityFunction", "role", "name", ]

	def __getattribute__(self, name):
		if name in IxTrafficWrapper.properties and super(IxTrafficWrapper, self).__getattribute__(name):
			return getattr(super(IxTrafficWrapper, self).__getattribute__("_IxTrafficWrapper__traffic"), name)
		else:
			return super(IxTrafficWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTrafficWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTrafficWrapper, self).__getattribute__("_IxTrafficWrapper__traffic"), name, value)
			super(IxTrafficWrapper, self).__setattr__(name, value)


class IxActivityDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityDNSServerWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.customParameters = IxPropertyClass_ixCustomActivityParametersDNSServerWrapper(ixActivity.customParameters)
		self.enable = ixActivity.enable
		self.protocol = ixActivity.protocol
		self.name = ixActivity.name
		self.role = ixActivity.role
		self.agent = PluginDNSServerWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.protocolAndType = ixActivity.protocolAndType
		self.timeline = IxTimelineProxyDNSServerWrapper(ixActivity.timeline)
		self.timelineId = ixActivity.timelineId
		self.type = ixActivity.type
		self.activeRole = ixActivity.activeRole

	properties = ["enable", "protocol", "name", "role", "objectivePercent", "protocolAndType", "timelineId", "type", "activeRole", ]

	def __getattribute__(self, name):
		if name in IxActivityDNSServerWrapper.properties and super(IxActivityDNSServerWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityDNSServerWrapper, self).__getattribute__("_IxActivityDNSServerWrapper__ixActivity"), name)
		else:
			return super(IxActivityDNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityDNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityDNSServerWrapper, self).__getattribute__("_IxActivityDNSServerWrapper__ixActivity"), name, value)
			super(IxActivityDNSServerWrapper, self).__setattr__(name, value)


class _portListSequenceContainerWrapper(RestObjectBaseClass):

	def __init__(self, ixBreakOutLineSpeedCard):
		self.__ixBreakOutLineSpeedCard = ixBreakOutLineSpeedCard

	def getItem(self, objectID):
		itemList = self.__ixBreakOutLineSpeedCard.portList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPort":
				return IxPortWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPortWrapper(self.__ixBreakOutLineSpeedCard.portList.appendItem(**kwargs))

	def getList(self):
		return self.__ixBreakOutLineSpeedCard.portList

	def clear(self):
		return self.__ixBreakOutLineSpeedCard.portList.clear()


class IxPortWrapper(RestObjectBaseClass):

	def __init__(self, ixPort):
		super(IxPortWrapper, self).__init__(ixPort)
		self.__ixPort = ixPort
		self.enableCapture = ixPort.enableCapture
		self.portId = ixPort.portId
		self.name = ixPort.name
		self.managementIp = ixPort.managementIp
		self.portSpeed = ixPort.portSpeed
		self.cardType = ixPort.cardType
		self.analyzerPartialCapture = ixPort.analyzerPartialCapture
		self.chassisId = ixPort.chassisId
		self.portPersistentSetting = IxPortPersistentSettingWrapper(ixPort.portPersistentSetting)
		self.cardId = ixPort.cardId
		self.owner = ixPort.owner
		self.linkUp = ixPort.linkUp
		self.id = ixPort.id
		self.ownerStateAndDuration = ixPort.ownerStateAndDuration

	properties = ["enableCapture", "portId", "name", "managementIp", "portSpeed", "cardType", "analyzerPartialCapture", "chassisId", "cardId", "owner", "linkUp", "id", "ownerStateAndDuration", ]

	def __getattribute__(self, name):
		if name in IxPortWrapper.properties and super(IxPortWrapper, self).__getattribute__(name):
			return getattr(super(IxPortWrapper, self).__getattribute__("_IxPortWrapper__ixPort"), name)
		else:
			return super(IxPortWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPortWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPortWrapper, self).__getattribute__("_IxPortWrapper__ixPort"), name, value)
			super(IxPortWrapper, self).__setattr__(name, value)

	def clearOwnership(self, force=False):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__ixPort.clearOwnership(**kwargs)

	def reboot(self):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__ixPort.reboot(**kwargs)

	def takeOwnership(self, force=False):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__ixPort.takeOwnership(**kwargs)


class IxPortFilterListWrapper(RestObjectBaseClass):

	def __init__(self, filterList):
		self.__filterList = filterList

	def getItem(self, objectID):
		itemList = self.__filterList.portFilters
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixRestFilter":
				return IxRestFilterWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, value=None):
		kwargs = {}
		kwargs.update({"value": value})
		return IxRestFilterWrapper(self.__filterList.portFilters.appendItem(**kwargs))

	def getList(self):
		return self.__filterList.portFilters

	def clear(self):
		return self.__filterList.portFilters.clear()


class IxRestFilterWrapper(RestObjectBaseClass):

	def __init__(self, ixRestFilter):
		super(IxRestFilterWrapper, self).__init__(ixRestFilter)
		self.__ixRestFilter = ixRestFilter
		self.value = ixRestFilter.value

	properties = ["value", ]

	def __getattribute__(self, name):
		if name in IxRestFilterWrapper.properties and super(IxRestFilterWrapper, self).__getattribute__(name):
			return getattr(super(IxRestFilterWrapper, self).__getattribute__("_IxRestFilterWrapper__ixRestFilter"), name)
		else:
			return super(IxRestFilterWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxRestFilterWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxRestFilterWrapper, self).__getattribute__("_IxRestFilterWrapper__ixRestFilter"), name, value)
			super(IxRestFilterWrapper, self).__setattr__(name, value)


class PluginDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginDNSClientWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.pm = IxPropertyMap_DNSDNSClientWrapper(agent.pm)
		self.flowPercentage = agent.flowPercentage

	properties = ["cmdListLoops", "flowPercentage", ]

	def __getattribute__(self, name):
		if name in PluginDNSClientWrapper.properties and super(PluginDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(PluginDNSClientWrapper, self).__getattribute__("_PluginDNSClientWrapper__agent"), name)
		else:
			return super(PluginDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginDNSClientWrapper, self).__getattribute__("_PluginDNSClientWrapper__agent"), name, value)
			super(PluginDNSClientWrapper, self).__setattr__(name, value)


class IxTimelineProxyDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyDNSClientWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.iterations = timeline.iterations
		self.rampUpType = timeline.rampUpType
		self.rampUpValue = timeline.rampUpValue
		self.rampUpTime = timeline.rampUpTime
		self.rampDownTime = timeline.rampDownTime
		self.standbyTime = timeline.standbyTime
		self.rampDownValue = timeline.rampDownValue
		self.rampUpInterval = timeline.rampUpInterval
		self.offlineTime = timeline.offlineTime
		self.sustainTime = timeline.sustainTime
		self.name = timeline.name
		self.timelineType = timeline.timelineType

	properties = ["iterations", "rampUpType", "rampUpValue", "rampUpTime", "rampDownTime", "standbyTime", "rampDownValue", "rampUpInterval", "offlineTime", "sustainTime", "name", "timelineType", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyDNSClientWrapper.properties and super(IxTimelineProxyDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyDNSClientWrapper, self).__getattribute__("_IxTimelineProxyDNSClientWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyDNSClientWrapper, self).__getattribute__("_IxTimelineProxyDNSClientWrapper__timeline"), name, value)
			super(IxTimelineProxyDNSClientWrapper, self).__setattr__(name, value)


class IxNetGlobalPluginListWrapper(RestObjectBaseClass):

	def __init__(self, network):
		self.__network = network

	def getItemIxNetIxLoadSettingsPlugin(self, objectID):
		itemList = self.__network.globalPlugins
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetIxLoadSettingsPlugin":
				return IxNetIxLoadSettingsPluginWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxNetIxLoadSettingsPlugin(self):
		kwargs = {}
		return IxNetIxLoadSettingsPluginWrapper(self.__network.globalPlugins.appendItem(**kwargs))

	def getItemIxNetDnsPlugin(self, objectID):
		itemList = self.__network.globalPlugins
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetDnsPlugin":
				return IxNetDnsPluginWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxNetDnsPlugin(self):
		kwargs = {}
		return IxNetDnsPluginWrapper(self.__network.globalPlugins.appendItem(**kwargs))

	def getItemIxNetFilterPlugin(self, objectID):
		itemList = self.__network.globalPlugins
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetFilterPlugin":
				return IxNetFilterPluginWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxNetFilterPlugin(self):
		kwargs = {}
		return IxNetFilterPluginWrapper(self.__network.globalPlugins.appendItem(**kwargs))

	def getItemIxNetTCPPlugin(self, objectID):
		itemList = self.__network.globalPlugins
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetTCPPlugin":
				return IxNetTCPPluginWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxNetTCPPlugin(self):
		kwargs = {}
		return IxNetTCPPluginWrapper(self.__network.globalPlugins.appendItem(**kwargs))

	def getItemIxNetGratArpPlugin(self, objectID):
		itemList = self.__network.globalPlugins
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetGratArpPlugin":
				return IxNetGratArpPluginWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxNetGratArpPlugin(self):
		kwargs = {}
		return IxNetGratArpPluginWrapper(self.__network.globalPlugins.appendItem(**kwargs))

	def getItemIxNetMeshingPlugin(self, objectID):
		itemList = self.__network.globalPlugins
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetMeshingPlugin":
				return IxNetMeshingPluginWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxNetMeshingPlugin(self):
		kwargs = {}
		return IxNetMeshingPluginWrapper(self.__network.globalPlugins.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__network.globalPlugins
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return self.__network.globalPlugins.appendItem(**kwargs)

	def getList(self):
		return self.__network.globalPlugins

	def clear(self):
		return self.__network.globalPlugins.clear()


class IxNetIxLoadSettingsPluginWrapper(RestObjectBaseClass):

	def __init__(self, ixNetIxLoadSettingsPlugin):
		super(IxNetIxLoadSettingsPluginWrapper, self).__init__(ixNetIxLoadSettingsPlugin)
		self.__ixNetIxLoadSettingsPlugin = ixNetIxLoadSettingsPlugin
		self.name = ixNetIxLoadSettingsPlugin.name
		self.interfaceBehavior = ixNetIxLoadSettingsPlugin.interfaceBehavior
		self.teardownInterfaceWithUser = ixNetIxLoadSettingsPlugin.teardownInterfaceWithUser
		self.itemType = ixNetIxLoadSettingsPlugin.itemType

	properties = ["name", "interfaceBehavior", "teardownInterfaceWithUser", "itemType", ]

	def __getattribute__(self, name):
		if name in IxNetIxLoadSettingsPluginWrapper.properties and super(IxNetIxLoadSettingsPluginWrapper, self).__getattribute__(name):
			return getattr(super(IxNetIxLoadSettingsPluginWrapper, self).__getattribute__("_IxNetIxLoadSettingsPluginWrapper__ixNetIxLoadSettingsPlugin"), name)
		else:
			return super(IxNetIxLoadSettingsPluginWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetIxLoadSettingsPluginWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetIxLoadSettingsPluginWrapper, self).__getattribute__("_IxNetIxLoadSettingsPluginWrapper__ixNetIxLoadSettingsPlugin"), name, value)
			super(IxNetIxLoadSettingsPluginWrapper, self).__setattr__(name, value)


class IxNetDnsPluginWrapper(RestObjectBaseClass):

	def __init__(self, ixNetDnsPlugin):
		super(IxNetDnsPluginWrapper, self).__init__(ixNetDnsPlugin)
		self.__ixNetDnsPlugin = ixNetDnsPlugin
		self.domain = ixNetDnsPlugin.domain
		self.itemType = ixNetDnsPlugin.itemType
		self.timeout = ixNetDnsPlugin.timeout
		self.name = ixNetDnsPlugin.name

	properties = ["domain", "itemType", "timeout", "name", ]

	def __getattribute__(self, name):
		if name in IxNetDnsPluginWrapper.properties and super(IxNetDnsPluginWrapper, self).__getattribute__(name):
			return getattr(super(IxNetDnsPluginWrapper, self).__getattribute__("_IxNetDnsPluginWrapper__ixNetDnsPlugin"), name)
		else:
			return super(IxNetDnsPluginWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetDnsPluginWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetDnsPluginWrapper, self).__getattribute__("_IxNetDnsPluginWrapper__ixNetDnsPlugin"), name, value)
			super(IxNetDnsPluginWrapper, self).__setattr__(name, value)


class IxNetFilterPluginWrapper(RestObjectBaseClass):

	def __init__(self, ixNetFilterPlugin):
		super(IxNetFilterPluginWrapper, self).__init__(ixNetFilterPlugin)
		self.__ixNetFilterPlugin = ixNetFilterPlugin
		self.ip = ixNetFilterPlugin.ip
		self.all = ixNetFilterPlugin.all
		self.pppoecontrol = ixNetFilterPlugin.pppoecontrol
		self.isis = ixNetFilterPlugin.isis
		self.itemType = ixNetFilterPlugin.itemType
		self.udp = ixNetFilterPlugin.udp
		self.tcp = ixNetFilterPlugin.tcp
		self.mac = ixNetFilterPlugin.mac
		self.pppoenetwork = ixNetFilterPlugin.pppoenetwork
		self.auto = ixNetFilterPlugin.auto
		self.icmp = ixNetFilterPlugin.icmp
		self.name = ixNetFilterPlugin.name

	properties = ["ip", "all", "pppoecontrol", "isis", "itemType", "udp", "tcp", "mac", "pppoenetwork", "auto", "icmp", "name", ]

	def __getattribute__(self, name):
		if name in IxNetFilterPluginWrapper.properties and super(IxNetFilterPluginWrapper, self).__getattribute__(name):
			return getattr(super(IxNetFilterPluginWrapper, self).__getattribute__("_IxNetFilterPluginWrapper__ixNetFilterPlugin"), name)
		else:
			return super(IxNetFilterPluginWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetFilterPluginWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetFilterPluginWrapper, self).__getattribute__("_IxNetFilterPluginWrapper__ixNetFilterPlugin"), name, value)
			super(IxNetFilterPluginWrapper, self).__setattr__(name, value)


class IxNetTCPPluginWrapper(RestObjectBaseClass):

	def __init__(self, ixNetTCPPlugin):
		super(IxNetTCPPluginWrapper, self).__init__(ixNetTCPPlugin)
		self.__ixNetTCPPlugin = ixNetTCPPlugin
		self.tcp_bic_low_window = ixNetTCPPlugin.tcp_bic_low_window
		self.tcp_bic = ixNetTCPPlugin.tcp_bic
		self.tcp_tw_recycle = ixNetTCPPlugin.tcp_tw_recycle
		self.tcp_vegas_alpha = ixNetTCPPlugin.tcp_vegas_alpha
		self.itemType = ixNetTCPPlugin.itemType
		self.disable_min_max_buffer_size = ixNetTCPPlugin.disable_min_max_buffer_size
		self.tcp_retries1 = ixNetTCPPlugin.tcp_retries1
		self.tcp_keepalive_time = ixNetTCPPlugin.tcp_keepalive_time
		self.tcp_rfc1337 = ixNetTCPPlugin.tcp_rfc1337
		self.tcp_mgmt_rmem = ixNetTCPPlugin.tcp_mgmt_rmem
		self.tcp_keepalive_intvl = ixNetTCPPlugin.tcp_keepalive_intvl
		self.tcp_window_scaling = ixNetTCPPlugin.tcp_window_scaling
		self.tcp_mem_low = ixNetTCPPlugin.tcp_mem_low
		self.adjust_tcp_buffers = ixNetTCPPlugin.adjust_tcp_buffers
		self.tcp_syn_retries = ixNetTCPPlugin.tcp_syn_retries
		self.udp_port_randomization = ixNetTCPPlugin.udp_port_randomization
		self.tcp_retries2 = ixNetTCPPlugin.tcp_retries2
		self.tcp_wmem_max = ixNetTCPPlugin.tcp_wmem_max
		self.tcp_reordering = ixNetTCPPlugin.tcp_reordering
		self.tcp_ecn = ixNetTCPPlugin.tcp_ecn
		self.tcp_westwood = ixNetTCPPlugin.tcp_westwood
		self.delayed_acks_segments = ixNetTCPPlugin.delayed_acks_segments
		self.inter_packet_delay = ixNetTCPPlugin.inter_packet_delay
		self.tcp_vegas_cong_avoid = ixNetTCPPlugin.tcp_vegas_cong_avoid
		self.tcp_tw_rfc1323_strict = ixNetTCPPlugin.tcp_tw_rfc1323_strict
		self.tcp_rmem_max = ixNetTCPPlugin.tcp_rmem_max
		self.tcp_orphan_retries = ixNetTCPPlugin.tcp_orphan_retries
		self.bestPerfSettings = ixNetTCPPlugin.bestPerfSettings
		self.tcp_max_tw_buckets = ixNetTCPPlugin.tcp_max_tw_buckets
		self.tcp_low_latency = ixNetTCPPlugin.tcp_low_latency
		self.tcp_rmem_min = ixNetTCPPlugin.tcp_rmem_min
		self.accept_ra_all = ixNetTCPPlugin.accept_ra_all
		self.tcp_adv_win_scale = ixNetTCPPlugin.tcp_adv_win_scale
		self.tcp_wmem_default = ixNetTCPPlugin.tcp_wmem_default
		self.tcp_wmem_min = ixNetTCPPlugin.tcp_wmem_min
		self.tcp_port_min = ixNetTCPPlugin.tcp_port_min
		self.tcp_rto_max = ixNetTCPPlugin.tcp_rto_max
		self.tcp_stdurg = ixNetTCPPlugin.tcp_stdurg
		self.tcp_port_max = ixNetTCPPlugin.tcp_port_max
		self.tcp_fin_timeout = ixNetTCPPlugin.tcp_fin_timeout
		self.tcp_max_syn_backlog = ixNetTCPPlugin.tcp_max_syn_backlog
		self.tcp_dsack = ixNetTCPPlugin.tcp_dsack
		self.tcp_mgmt_wmem = ixNetTCPPlugin.tcp_mgmt_wmem
		self.tcp_mem_high = ixNetTCPPlugin.tcp_mem_high
		self.tcp_frto = ixNetTCPPlugin.tcp_frto
		self.tcp_ipfrag_time = ixNetTCPPlugin.tcp_ipfrag_time
		self.rps_needed = ixNetTCPPlugin.rps_needed
		self.llm_hdr_gap = ixNetTCPPlugin.llm_hdr_gap
		self.tcp_max_orphans = ixNetTCPPlugin.tcp_max_orphans
		self.accept_ra_default = ixNetTCPPlugin.accept_ra_default
		self.tcp_vegas_beta = ixNetTCPPlugin.tcp_vegas_beta
		self.tcp_moderate_rcvbuf = ixNetTCPPlugin.tcp_moderate_rcvbuf
		self.tcp_no_metrics_save = ixNetTCPPlugin.tcp_no_metrics_save
		self.tcp_rto_min = ixNetTCPPlugin.tcp_rto_min
		self.name = ixNetTCPPlugin.name
		self.tcp_retrans_collapse = ixNetTCPPlugin.tcp_retrans_collapse
		self.inter_packet_granular_delay = ixNetTCPPlugin.inter_packet_granular_delay
		self.llm_hdr_gap_ns = ixNetTCPPlugin.llm_hdr_gap_ns
		self.tcp_large_icwnd = ixNetTCPPlugin.tcp_large_icwnd
		self.tcp_rmem_default = ixNetTCPPlugin.tcp_rmem_default
		self.tcp_keepalive_probes = ixNetTCPPlugin.tcp_keepalive_probes
		self.tcp_abort_on_overflow = ixNetTCPPlugin.tcp_abort_on_overflow
		self.tcp_tw_reuse = ixNetTCPPlugin.tcp_tw_reuse
		self.delayed_acks_timeout = ixNetTCPPlugin.delayed_acks_timeout
		self.tcp_vegas_gamma = ixNetTCPPlugin.tcp_vegas_gamma
		self.delayed_acks = ixNetTCPPlugin.delayed_acks
		self.tcp_synack_retries = ixNetTCPPlugin.tcp_synack_retries
		self.tcp_timestamps = ixNetTCPPlugin.tcp_timestamps
		self.tcp_fack = ixNetTCPPlugin.tcp_fack
		self.ip_no_pmtu_disc = ixNetTCPPlugin.ip_no_pmtu_disc
		self.tcp_sack = ixNetTCPPlugin.tcp_sack
		self.tcp_bic_fast_convergence = ixNetTCPPlugin.tcp_bic_fast_convergence
		self.tcp_mem_pressure = ixNetTCPPlugin.tcp_mem_pressure
		self.tcp_app_win = ixNetTCPPlugin.tcp_app_win

	properties = ["tcp_bic_low_window", "tcp_bic", "tcp_tw_recycle", "tcp_vegas_alpha", "itemType", "disable_min_max_buffer_size", "tcp_retries1", "tcp_keepalive_time", "tcp_rfc1337", "tcp_mgmt_rmem", "tcp_keepalive_intvl", "tcp_window_scaling", "tcp_mem_low", "adjust_tcp_buffers", "tcp_syn_retries", "udp_port_randomization", "tcp_retries2", "tcp_wmem_max", "tcp_reordering", "tcp_ecn", "tcp_westwood", "delayed_acks_segments", "inter_packet_delay", "tcp_vegas_cong_avoid", "tcp_tw_rfc1323_strict", "tcp_rmem_max", "tcp_orphan_retries", "bestPerfSettings", "tcp_max_tw_buckets", "tcp_low_latency", "tcp_rmem_min", "accept_ra_all", "tcp_adv_win_scale", "tcp_wmem_default", "tcp_wmem_min", "tcp_port_min", "tcp_rto_max", "tcp_stdurg", "tcp_port_max", "tcp_fin_timeout", "tcp_max_syn_backlog", "tcp_dsack", "tcp_mgmt_wmem", "tcp_mem_high", "tcp_frto", "tcp_ipfrag_time", "rps_needed", "llm_hdr_gap", "tcp_max_orphans", "accept_ra_default", "tcp_vegas_beta", "tcp_moderate_rcvbuf", "tcp_no_metrics_save", "tcp_rto_min", "name", "tcp_retrans_collapse", "inter_packet_granular_delay", "llm_hdr_gap_ns", "tcp_large_icwnd", "tcp_rmem_default", "tcp_keepalive_probes", "tcp_abort_on_overflow", "tcp_tw_reuse", "delayed_acks_timeout", "tcp_vegas_gamma", "delayed_acks", "tcp_synack_retries", "tcp_timestamps", "tcp_fack", "ip_no_pmtu_disc", "tcp_sack", "tcp_bic_fast_convergence", "tcp_mem_pressure", "tcp_app_win", ]

	def __getattribute__(self, name):
		if name in IxNetTCPPluginWrapper.properties and super(IxNetTCPPluginWrapper, self).__getattribute__(name):
			return getattr(super(IxNetTCPPluginWrapper, self).__getattribute__("_IxNetTCPPluginWrapper__ixNetTCPPlugin"), name)
		else:
			return super(IxNetTCPPluginWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetTCPPluginWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetTCPPluginWrapper, self).__getattribute__("_IxNetTCPPluginWrapper__ixNetTCPPlugin"), name, value)
			super(IxNetTCPPluginWrapper, self).__setattr__(name, value)


class IxNetGratArpPluginWrapper(RestObjectBaseClass):

	def __init__(self, ixNetGratArpPlugin):
		super(IxNetGratArpPluginWrapper, self).__init__(ixNetGratArpPlugin)
		self.__ixNetGratArpPlugin = ixNetGratArpPlugin
		self.itemType = ixNetGratArpPlugin.itemType
		self.forwardGratArp = ixNetGratArpPlugin.forwardGratArp
		self.enabled = ixNetGratArpPlugin.enabled
		self.maxFramesPerSecond = ixNetGratArpPlugin.maxFramesPerSecond
		self.rateControlEnabled = ixNetGratArpPlugin.rateControlEnabled
		self.forwardUnsolicitedNA = ixNetGratArpPlugin.forwardUnsolicitedNA
		self.name = ixNetGratArpPlugin.name

	properties = ["itemType", "forwardGratArp", "enabled", "maxFramesPerSecond", "rateControlEnabled", "forwardUnsolicitedNA", "name", ]

	def __getattribute__(self, name):
		if name in IxNetGratArpPluginWrapper.properties and super(IxNetGratArpPluginWrapper, self).__getattribute__(name):
			return getattr(super(IxNetGratArpPluginWrapper, self).__getattribute__("_IxNetGratArpPluginWrapper__ixNetGratArpPlugin"), name)
		else:
			return super(IxNetGratArpPluginWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetGratArpPluginWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetGratArpPluginWrapper, self).__getattribute__("_IxNetGratArpPluginWrapper__ixNetGratArpPlugin"), name, value)
			super(IxNetGratArpPluginWrapper, self).__setattr__(name, value)


class IxNetMeshingPluginWrapper(RestObjectBaseClass):

	def __init__(self, ixNetMeshingPlugin):
		super(IxNetMeshingPluginWrapper, self).__init__(ixNetMeshingPlugin)
		self.__ixNetMeshingPlugin = ixNetMeshingPlugin
		self.itemType = ixNetMeshingPlugin.itemType
		self.name = ixNetMeshingPlugin.name

	properties = ["itemType", "name", ]

	def __getattribute__(self, name):
		if name in IxNetMeshingPluginWrapper.properties and super(IxNetMeshingPluginWrapper, self).__getattribute__(name):
			return getattr(super(IxNetMeshingPluginWrapper, self).__getattribute__("_IxNetMeshingPluginWrapper__ixNetMeshingPlugin"), name)
		else:
			return super(IxNetMeshingPluginWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetMeshingPluginWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetMeshingPluginWrapper, self).__getattribute__("_IxNetMeshingPluginWrapper__ixNetMeshingPlugin"), name, value)
			super(IxNetMeshingPluginWrapper, self).__setattr__(name, value)


class IxNetworkPortListSequenceContainerWrapper(RestObjectBaseClass):

	def __init__(self, network):
		self.__network = network

	def getItem(self, objectID):
		itemList = self.__network.portList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPort":
				return IxPortWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, chassisId=None, portId=None, cardId=None):
		kwargs = {}
		kwargs.update({"chassisId": chassisId})
		kwargs.update({"portId": portId})
		kwargs.update({"cardId": cardId})
		return IxPortWrapper(self.__network.portList.appendItem(**kwargs))

	def getList(self):
		return self.__network.portList

	def clear(self):
		return self.__network.portList.clear()


class IxNetPluginWrapper(object):
	def __init__(self, plugin):
		self.__plugin = plugin
		self.childrenList = IxNetLayerPluginListWrapper(plugin.childrenList)


class IxNetL1EthernetPluginWrapper(IxNetPluginWrapper):

	def __init__(self, stack):
		super(IxNetL1EthernetPluginWrapper, self).__init__(stack)
		self.__stack = stack
		self.advertise10Full = stack.advertise10Full
		self.dataCenter = IxNetDataCenterSettingsWrapper(stack.dataCenter)
		self.itemType = stack.itemType
		self.name = stack.name
		self.directedAddress = stack.directedAddress
		self.autoNegotiate = stack.autoNegotiate
		self.advertise5000Full = stack.advertise5000Full
		self.advertise100Half = stack.advertise100Half
		self.cardElm = IxNetEthernetELMPluginWrapper(stack.cardElm)
		self.cardDualPhy = IxNetDualPhyPluginWrapper(stack.cardDualPhy)
		self.advertise10000Full = stack.advertise10000Full
		self.advertise10Half = stack.advertise10Half
		self.enableFlowControl = stack.enableFlowControl
		self.advertise1000Full = stack.advertise1000Full
		self.speed = stack.speed
		self.advertise2500Full = stack.advertise2500Full
		self.advertise100Full = stack.advertise100Full

	properties = ["advertise10Full", "itemType", "name", "directedAddress", "autoNegotiate", "advertise5000Full", "advertise100Half", "advertise10000Full", "advertise10Half", "enableFlowControl", "advertise1000Full", "speed", "advertise2500Full", "advertise100Full", ]

	def __getattribute__(self, name):
		if name in IxNetL1EthernetPluginWrapper.properties and super(IxNetL1EthernetPluginWrapper, self).__getattribute__(name):
			return getattr(super(IxNetL1EthernetPluginWrapper, self).__getattribute__("_IxNetL1EthernetPluginWrapper__stack"), name)
		else:
			return super(IxNetL1EthernetPluginWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetL1EthernetPluginWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetL1EthernetPluginWrapper, self).__getattribute__("_IxNetL1EthernetPluginWrapper__stack"), name, value)
			super(IxNetL1EthernetPluginWrapper, self).__setattr__(name, value)

	def insertParentPlugin(self, pluginType):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__stack.insertParentPlugin(**kwargs)


class IxPortL1SettingsWrapper(RestObjectBaseClass):

	def __init__(self, portL1Settings):
		super(IxPortL1SettingsWrapper, self).__init__(portL1Settings)
		self.__portL1Settings = portL1Settings
		self.useIEEEDefaults = portL1Settings.useIEEEDefaults
		self.requestRSFEC = portL1Settings.requestRSFEC
		self.autoNegotiate = portL1Settings.autoNegotiate
		self.enableRSFECStatistics = portL1Settings.enableRSFECStatistics
		self.fecValue = portL1Settings.fecValue
		self.advertiseRSFEC = portL1Settings.advertiseRSFEC
		self.requestFCFEC = portL1Settings.requestFCFEC
		self.enableRSFEC = portL1Settings.enableRSFEC
		self.advertiseFCFEC = portL1Settings.advertiseFCFEC

	properties = ["useIEEEDefaults", "requestRSFEC", "autoNegotiate", "enableRSFECStatistics", "fecValue", "advertiseRSFEC", "requestFCFEC", "enableRSFEC", "advertiseFCFEC", ]

	def __getattribute__(self, name):
		if name in IxPortL1SettingsWrapper.properties and super(IxPortL1SettingsWrapper, self).__getattribute__(name):
			return getattr(super(IxPortL1SettingsWrapper, self).__getattribute__("_IxPortL1SettingsWrapper__portL1Settings"), name)
		else:
			return super(IxPortL1SettingsWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPortL1SettingsWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPortL1SettingsWrapper, self).__getattribute__("_IxPortL1SettingsWrapper__portL1Settings"), name, value)
			super(IxPortL1SettingsWrapper, self).__setattr__(name, value)


class IxPropertyClass_ixCustomActivityParametersDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, customParameters):
		super(IxPropertyClass_ixCustomActivityParametersDNSServerWrapper, self).__init__(customParameters)
		self.__customParameters = customParameters

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_ixCustomActivityParametersDNSServerWrapper.properties and super(IxPropertyClass_ixCustomActivityParametersDNSServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ixCustomActivityParametersDNSServerWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersDNSServerWrapper__customParameters"), name)
		else:
			return super(IxPropertyClass_ixCustomActivityParametersDNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ixCustomActivityParametersDNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ixCustomActivityParametersDNSServerWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersDNSServerWrapper__customParameters"), name, value)
			super(IxPropertyClass_ixCustomActivityParametersDNSServerWrapper, self).__setattr__(name, value)


class PluginDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginDNSServerWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.pm = IxPropertyMap_DNSDNSServerWrapper(agent.pm)
		self.flowPercentage = agent.flowPercentage

	properties = ["cmdListLoops", "flowPercentage", ]

	def __getattribute__(self, name):
		if name in PluginDNSServerWrapper.properties and super(PluginDNSServerWrapper, self).__getattribute__(name):
			return getattr(super(PluginDNSServerWrapper, self).__getattribute__("_PluginDNSServerWrapper__agent"), name)
		else:
			return super(PluginDNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginDNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginDNSServerWrapper, self).__getattribute__("_PluginDNSServerWrapper__agent"), name, value)
			super(PluginDNSServerWrapper, self).__setattr__(name, value)


class IxTimelineProxyDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyDNSServerWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.name = timeline.name
		self.standbyTime = timeline.standbyTime
		self.iterations = timeline.iterations
		self.sustainTime = timeline.sustainTime

	properties = ["name", "standbyTime", "iterations", "sustainTime", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyDNSServerWrapper.properties and super(IxTimelineProxyDNSServerWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyDNSServerWrapper, self).__getattribute__("_IxTimelineProxyDNSServerWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyDNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyDNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyDNSServerWrapper, self).__getattribute__("_IxTimelineProxyDNSServerWrapper__timeline"), name, value)
			super(IxTimelineProxyDNSServerWrapper, self).__setattr__(name, value)


class IxPortPersistentSettingWrapper(RestObjectBaseClass):

	def __init__(self, portPersistentSetting):
		super(IxPortPersistentSettingWrapper, self).__init__(portPersistentSetting)
		self.__portPersistentSetting = portPersistentSetting
		self.viewFilter = IxViewFilterWrapper(portPersistentSetting.viewFilter)

	properties = []

	def __getattribute__(self, name):
		if name in IxPortPersistentSettingWrapper.properties and super(IxPortPersistentSettingWrapper, self).__getattribute__(name):
			return getattr(super(IxPortPersistentSettingWrapper, self).__getattribute__("_IxPortPersistentSettingWrapper__portPersistentSetting"), name)
		else:
			return super(IxPortPersistentSettingWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPortPersistentSettingWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPortPersistentSettingWrapper, self).__getattribute__("_IxPortPersistentSettingWrapper__portPersistentSetting"), name, value)
			super(IxPortPersistentSettingWrapper, self).__setattr__(name, value)


class IxPropertyMap_DNSDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		super(IxPropertyMap_DNSDNSClientWrapper, self).__init__(pm)
		self.__pm = pm
		self.advancedOptions = IxPropertyClass_AdvancedOptionsDNSClientWrapper(pm.advancedOptions)
		self.seqGenExample = IxPropertyClass_seqgenexampleDNSClientWrapper(pm.seqGenExample)
		self.dnsConfig = IxPropertyClass_DnsConfigDNSClientWrapper(pm.dnsConfig)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyMap_DNSDNSClientWrapper.properties and super(IxPropertyMap_DNSDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyMap_DNSDNSClientWrapper, self).__getattribute__("_IxPropertyMap_DNSDNSClientWrapper__pm"), name)
		else:
			return super(IxPropertyMap_DNSDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyMap_DNSDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyMap_DNSDNSClientWrapper, self).__getattribute__("_IxPropertyMap_DNSDNSClientWrapper__pm"), name, value)
			super(IxPropertyMap_DNSDNSClientWrapper, self).__setattr__(name, value)


class IxNetDataCenterSettingsWrapper(RestObjectBaseClass):

	def __init__(self, dataCenter):
		super(IxNetDataCenterSettingsWrapper, self).__init__(dataCenter)
		self.__dataCenter = dataCenter
		self.dcSupported = dataCenter.dcSupported
		self.itemType = dataCenter.itemType
		self.dcEnabled = dataCenter.dcEnabled
		self.dcPfcPauseDelay = dataCenter.dcPfcPauseDelay
		self.dcMode = dataCenter.dcMode
		self.dcPfcPauseEnable = dataCenter.dcPfcPauseEnable
		self.dcFlowControl = dataCenter.dcFlowControl

	properties = ["dcSupported", "itemType", "dcEnabled", "dcPfcPauseDelay", "dcMode", "dcPfcPauseEnable", "dcFlowControl", ]

	def __getattribute__(self, name):
		if name in IxNetDataCenterSettingsWrapper.properties and super(IxNetDataCenterSettingsWrapper, self).__getattribute__(name):
			return getattr(super(IxNetDataCenterSettingsWrapper, self).__getattribute__("_IxNetDataCenterSettingsWrapper__dataCenter"), name)
		else:
			return super(IxNetDataCenterSettingsWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetDataCenterSettingsWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetDataCenterSettingsWrapper, self).__getattribute__("_IxNetDataCenterSettingsWrapper__dataCenter"), name, value)
			super(IxNetDataCenterSettingsWrapper, self).__setattr__(name, value)


class IxNetEthernetELMPluginWrapper(RestObjectBaseClass):

	def __init__(self, cardElm):
		super(IxNetEthernetELMPluginWrapper, self).__init__(cardElm)
		self.__cardElm = cardElm
		self.negotiateMasterSlave = cardElm.negotiateMasterSlave
		self.negotiationType = cardElm.negotiationType
		self.itemType = cardElm.itemType

	properties = ["negotiateMasterSlave", "negotiationType", "itemType", ]

	def __getattribute__(self, name):
		if name in IxNetEthernetELMPluginWrapper.properties and super(IxNetEthernetELMPluginWrapper, self).__getattribute__(name):
			return getattr(super(IxNetEthernetELMPluginWrapper, self).__getattribute__("_IxNetEthernetELMPluginWrapper__cardElm"), name)
		else:
			return super(IxNetEthernetELMPluginWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetEthernetELMPluginWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetEthernetELMPluginWrapper, self).__getattribute__("_IxNetEthernetELMPluginWrapper__cardElm"), name, value)
			super(IxNetEthernetELMPluginWrapper, self).__setattr__(name, value)


class IxNetDualPhyPluginWrapper(RestObjectBaseClass):

	def __init__(self, cardDualPhy):
		super(IxNetDualPhyPluginWrapper, self).__init__(cardDualPhy)
		self.__cardDualPhy = cardDualPhy
		self.medium = cardDualPhy.medium
		self.itemType = cardDualPhy.itemType

	properties = ["medium", "itemType", ]

	def __getattribute__(self, name):
		if name in IxNetDualPhyPluginWrapper.properties and super(IxNetDualPhyPluginWrapper, self).__getattribute__(name):
			return getattr(super(IxNetDualPhyPluginWrapper, self).__getattribute__("_IxNetDualPhyPluginWrapper__cardDualPhy"), name)
		else:
			return super(IxNetDualPhyPluginWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetDualPhyPluginWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetDualPhyPluginWrapper, self).__getattribute__("_IxNetDualPhyPluginWrapper__cardDualPhy"), name, value)
			super(IxNetDualPhyPluginWrapper, self).__setattr__(name, value)


class IxNetLayerPluginListWrapper(RestObjectBaseClass):

	def __init__(self, stack):
		self.__stack = stack

	def appendItem(self):
		kwargs = {}
		return IxNetPluginWrapper(self.__stack.childrenList.appendItem(**kwargs))

	def getList(self):
		return self.__stack.childrenList

	def clear(self):
		return self.__stack.childrenList.clear()


class IxNetL2EthernetPluginWrapper(IxNetPluginWrapper):

	def __init__(self, ixNetL2EthernetPlugin):
		super(IxNetL2EthernetPluginWrapper, self).__init__(ixNetL2EthernetPlugin)
		self.__ixNetL2EthernetPlugin = ixNetL2EthernetPlugin
		self.itemType = ixNetL2EthernetPlugin.itemType
		self.macRangeList = IxNetMacRangeListWrapper(ixNetL2EthernetPlugin)
		self.vlanRangeList = IxNetVlanIdRangeListWrapper(ixNetL2EthernetPlugin)
		self.name = ixNetL2EthernetPlugin.name

	properties = ["itemType", "name", ]

	def __getattribute__(self, name):
		if name in IxNetL2EthernetPluginWrapper.properties and super(IxNetL2EthernetPluginWrapper, self).__getattribute__(name):
			return getattr(super(IxNetL2EthernetPluginWrapper, self).__getattribute__("_IxNetL2EthernetPluginWrapper__ixNetL2EthernetPlugin"), name)
		else:
			return super(IxNetL2EthernetPluginWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetL2EthernetPluginWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetL2EthernetPluginWrapper, self).__getattribute__("_IxNetL2EthernetPluginWrapper__ixNetL2EthernetPlugin"), name, value)
			super(IxNetL2EthernetPluginWrapper, self).__setattr__(name, value)

	def insertParentPlugin(self, pluginType):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__ixNetL2EthernetPlugin.insertParentPlugin(**kwargs)


class IxPropertyMap_DNSDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		super(IxPropertyMap_DNSDNSServerWrapper, self).__init__(pm)
		self.__pm = pm
		self.zoneConfig = IxPropertyClass_ZoneConfigDNSServerWrapper(pm.zoneConfig)
		self.advancedOptions = IxPropertyClass_AdvancedOptionsDNSServerWrapper(pm.advancedOptions)
		self.zoneMgr = IxPropertyClass_ZoneMgrDNSServerWrapper(pm.zoneMgr)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyMap_DNSDNSServerWrapper.properties and super(IxPropertyMap_DNSDNSServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyMap_DNSDNSServerWrapper, self).__getattribute__("_IxPropertyMap_DNSDNSServerWrapper__pm"), name)
		else:
			return super(IxPropertyMap_DNSDNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyMap_DNSDNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyMap_DNSDNSServerWrapper, self).__getattribute__("_IxPropertyMap_DNSDNSServerWrapper__pm"), name, value)
			super(IxPropertyMap_DNSDNSServerWrapper, self).__setattr__(name, value)


class IxViewFilterWrapper(RestObjectBaseClass):

	def __init__(self, viewFilter):
		super(IxViewFilterWrapper, self).__init__(viewFilter)
		self.__viewFilter = viewFilter
		self.filterString = viewFilter.filterString

	properties = ["filterString", ]

	def __getattribute__(self, name):
		if name in IxViewFilterWrapper.properties and super(IxViewFilterWrapper, self).__getattribute__(name):
			return getattr(super(IxViewFilterWrapper, self).__getattribute__("_IxViewFilterWrapper__viewFilter"), name)
		else:
			return super(IxViewFilterWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxViewFilterWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxViewFilterWrapper, self).__getattribute__("_IxViewFilterWrapper__viewFilter"), name, value)
			super(IxViewFilterWrapper, self).__setattr__(name, value)


class IxViewCustomFilterWrapper(RestObjectBaseClass):

	def __init__(self, viewFilter):
		super(IxViewCustomFilterWrapper, self).__init__(viewFilter)
		self.__viewFilter = viewFilter
		self.packetType = viewFilter.packetType
		self.filterString = viewFilter.filterString
		self.packetSize = viewFilter.packetSize

	properties = ["packetType", "filterString", "packetSize", ]

	def __getattribute__(self, name):
		if name in IxViewCustomFilterWrapper.properties and super(IxViewCustomFilterWrapper, self).__getattribute__(name):
			return getattr(super(IxViewCustomFilterWrapper, self).__getattribute__("_IxViewCustomFilterWrapper__viewFilter"), name)
		else:
			return super(IxViewCustomFilterWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxViewCustomFilterWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxViewCustomFilterWrapper, self).__getattribute__("_IxViewCustomFilterWrapper__viewFilter"), name, value)
			super(IxViewCustomFilterWrapper, self).__setattr__(name, value)


class IxViewProtocolFilterWrapper(RestObjectBaseClass):

	def __init__(self, viewFilter):
		super(IxViewProtocolFilterWrapper, self).__init__(viewFilter)
		self.__viewFilter = viewFilter
		self.filterString = viewFilter.filterString
		self.agentProtoFilterMap = viewFilter.agentProtoFilterMap

	properties = ["filterString", "agentProtoFilterMap", ]

	def __getattribute__(self, name):
		if name in IxViewProtocolFilterWrapper.properties and super(IxViewProtocolFilterWrapper, self).__getattribute__(name):
			return getattr(super(IxViewProtocolFilterWrapper, self).__getattribute__("_IxViewProtocolFilterWrapper__viewFilter"), name)
		else:
			return super(IxViewProtocolFilterWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxViewProtocolFilterWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxViewProtocolFilterWrapper, self).__getattribute__("_IxViewProtocolFilterWrapper__viewFilter"), name, value)
			super(IxViewProtocolFilterWrapper, self).__setattr__(name, value)


class IxPropertyClass_AdvancedOptionsDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, advancedOptions):
		super(IxPropertyClass_AdvancedOptionsDNSClientWrapper, self).__init__(advancedOptions)
		self.__advancedOptions = advancedOptions
		self.lowerLayerTransport = advancedOptions.lowerLayerTransport
		self.publicKeyPath = advancedOptions.publicKeyPath
		self.version = advancedOptions.version
		self.responseTimeout = advancedOptions.responseTimeout
		self.noWaitForResp = advancedOptions.noWaitForResp
		self.numberOfRetries = advancedOptions.numberOfRetries
		self.ttlValue = advancedOptions.ttlValue

	properties = ["lowerLayerTransport", "publicKeyPath", "version", "responseTimeout", "noWaitForResp", "numberOfRetries", "ttlValue", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AdvancedOptionsDNSClientWrapper.properties and super(IxPropertyClass_AdvancedOptionsDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AdvancedOptionsDNSClientWrapper, self).__getattribute__("_IxPropertyClass_AdvancedOptionsDNSClientWrapper__advancedOptions"), name)
		else:
			return super(IxPropertyClass_AdvancedOptionsDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AdvancedOptionsDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AdvancedOptionsDNSClientWrapper, self).__getattribute__("_IxPropertyClass_AdvancedOptionsDNSClientWrapper__advancedOptions"), name, value)
			super(IxPropertyClass_AdvancedOptionsDNSClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_seqgenexampleDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, seqGenExample):
		super(IxPropertyClass_seqgenexampleDNSClientWrapper, self).__init__(seqGenExample)
		self.__seqGenExample = seqGenExample
		self.dummy = seqGenExample.dummy

	properties = ["dummy", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_seqgenexampleDNSClientWrapper.properties and super(IxPropertyClass_seqgenexampleDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_seqgenexampleDNSClientWrapper, self).__getattribute__("_IxPropertyClass_seqgenexampleDNSClientWrapper__seqGenExample"), name)
		else:
			return super(IxPropertyClass_seqgenexampleDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_seqgenexampleDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_seqgenexampleDNSClientWrapper, self).__getattribute__("_IxPropertyClass_seqgenexampleDNSClientWrapper__seqGenExample"), name, value)
			super(IxPropertyClass_seqgenexampleDNSClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_DnsConfigDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, dnsConfig):
		super(IxPropertyClass_DnsConfigDNSClientWrapper, self).__init__(dnsConfig)
		self.__dnsConfig = dnsConfig
		self.dnsQueries = IxPropertyGroupSequence_DnsConfig_dnsQueriesDNSClientWrapper(dnsConfig)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_DnsConfigDNSClientWrapper.properties and super(IxPropertyClass_DnsConfigDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_DnsConfigDNSClientWrapper, self).__getattribute__("_IxPropertyClass_DnsConfigDNSClientWrapper__dnsConfig"), name)
		else:
			return super(IxPropertyClass_DnsConfigDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_DnsConfigDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_DnsConfigDNSClientWrapper, self).__getattribute__("_IxPropertyClass_DnsConfigDNSClientWrapper__dnsConfig"), name, value)
			super(IxPropertyClass_DnsConfigDNSClientWrapper, self).__setattr__(name, value)


class IxNetMacRangeListWrapper(RestObjectBaseClass):

	def __init__(self, ixNetL2EthernetPlugin):
		self.__ixNetL2EthernetPlugin = ixNetL2EthernetPlugin

	def getItem(self, objectID):
		itemList = self.__ixNetL2EthernetPlugin.macRangeList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetMacRange":
				return IxNetMacRangeWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxNetMacRangeWrapper(self.__ixNetL2EthernetPlugin.macRangeList.appendItem(**kwargs))

	def getList(self):
		return self.__ixNetL2EthernetPlugin.macRangeList

	def clear(self):
		return self.__ixNetL2EthernetPlugin.macRangeList.clear()


class IxNetMacRangeWrapper(RestObjectBaseClass):

	def __init__(self, ixNetMacRange):
		super(IxNetMacRangeWrapper, self).__init__(ixNetMacRange)
		self.__ixNetMacRange = ixNetMacRange
		self.count = ixNetMacRange.count
		self.itemType = ixNetMacRange.itemType
		self.enabled = ixNetMacRange.enabled
		self.incrementBy = ixNetMacRange.incrementBy
		self.mac = ixNetMacRange.mac
		self.mtu = ixNetMacRange.mtu
		self.name = ixNetMacRange.name

	properties = ["count", "itemType", "enabled", "incrementBy", "mac", "mtu", "name", ]

	def __getattribute__(self, name):
		if name in IxNetMacRangeWrapper.properties and super(IxNetMacRangeWrapper, self).__getattribute__(name):
			return getattr(super(IxNetMacRangeWrapper, self).__getattribute__("_IxNetMacRangeWrapper__ixNetMacRange"), name)
		else:
			return super(IxNetMacRangeWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetMacRangeWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetMacRangeWrapper, self).__getattribute__("_IxNetMacRangeWrapper__ixNetMacRange"), name, value)
			super(IxNetMacRangeWrapper, self).__setattr__(name, value)


class IxNetVlanIdRangeListWrapper(RestObjectBaseClass):

	def __init__(self, ixNetL2EthernetPlugin):
		self.__ixNetL2EthernetPlugin = ixNetL2EthernetPlugin

	def getItem(self, objectID):
		itemList = self.__ixNetL2EthernetPlugin.vlanRangeList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetVlanIdRange":
				return IxNetVlanIdRangeWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxNetVlanIdRangeWrapper(self.__ixNetL2EthernetPlugin.vlanRangeList.appendItem(**kwargs))

	def getList(self):
		return self.__ixNetL2EthernetPlugin.vlanRangeList

	def clear(self):
		return self.__ixNetL2EthernetPlugin.vlanRangeList.clear()


class IxNetVlanIdRangeWrapper(RestObjectBaseClass):

	def __init__(self, ixNetVlanIdRange):
		super(IxNetVlanIdRangeWrapper, self).__init__(ixNetVlanIdRange)
		self.__ixNetVlanIdRange = ixNetVlanIdRange
		self.incrementStep = ixNetVlanIdRange.incrementStep
		self.innerIncrement = ixNetVlanIdRange.innerIncrement
		self.itemType = ixNetVlanIdRange.itemType
		self.uniqueCount = ixNetVlanIdRange.uniqueCount
		self.idIncrMode = ixNetVlanIdRange.idIncrMode
		self.tpid = ixNetVlanIdRange.tpid
		self.enabled = ixNetVlanIdRange.enabled
		self.innerFirstId = ixNetVlanIdRange.innerFirstId
		self.innerIncrementStep = ixNetVlanIdRange.innerIncrementStep
		self.priority = ixNetVlanIdRange.priority
		self.innerPriority = ixNetVlanIdRange.innerPriority
		self.firstId = ixNetVlanIdRange.firstId
		self.increment = ixNetVlanIdRange.increment
		self.innerTpid = ixNetVlanIdRange.innerTpid
		self.innerUniqueCount = ixNetVlanIdRange.innerUniqueCount
		self.innerEnable = ixNetVlanIdRange.innerEnable
		self.name = ixNetVlanIdRange.name

	properties = ["incrementStep", "innerIncrement", "itemType", "uniqueCount", "idIncrMode", "tpid", "enabled", "innerFirstId", "innerIncrementStep", "priority", "innerPriority", "firstId", "increment", "innerTpid", "innerUniqueCount", "innerEnable", "name", ]

	def __getattribute__(self, name):
		if name in IxNetVlanIdRangeWrapper.properties and super(IxNetVlanIdRangeWrapper, self).__getattribute__(name):
			return getattr(super(IxNetVlanIdRangeWrapper, self).__getattribute__("_IxNetVlanIdRangeWrapper__ixNetVlanIdRange"), name)
		else:
			return super(IxNetVlanIdRangeWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetVlanIdRangeWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetVlanIdRangeWrapper, self).__getattribute__("_IxNetVlanIdRangeWrapper__ixNetVlanIdRange"), name, value)
			super(IxNetVlanIdRangeWrapper, self).__setattr__(name, value)


class IxNetIpV4V6PluginWrapper(IxNetPluginWrapper):

	def __init__(self, ixNetIpV4V6Plugin):
		super(IxNetIpV4V6PluginWrapper, self).__init__(ixNetIpV4V6Plugin)
		self.__ixNetIpV4V6Plugin = ixNetIpV4V6Plugin
		self.rangeGroups = IxNetRangeGroupList2Wrapper(ixNetIpV4V6Plugin)
		self.itemType = ixNetIpV4V6Plugin.itemType
		self.rangeList = IxNetIpV4V6RangeListWrapper(ixNetIpV4V6Plugin)
		self.name = ixNetIpV4V6Plugin.name

	properties = ["itemType", "name", ]

	def __getattribute__(self, name):
		if name in IxNetIpV4V6PluginWrapper.properties and super(IxNetIpV4V6PluginWrapper, self).__getattribute__(name):
			return getattr(super(IxNetIpV4V6PluginWrapper, self).__getattribute__("_IxNetIpV4V6PluginWrapper__ixNetIpV4V6Plugin"), name)
		else:
			return super(IxNetIpV4V6PluginWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetIpV4V6PluginWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetIpV4V6PluginWrapper, self).__getattribute__("_IxNetIpV4V6PluginWrapper__ixNetIpV4V6Plugin"), name, value)
			super(IxNetIpV4V6PluginWrapper, self).__setattr__(name, value)

	def insertParentPlugin(self, pluginType):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__ixNetIpV4V6Plugin.insertParentPlugin(**kwargs)


class IxPropertyClass_ZoneConfigDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, zoneConfig):
		super(IxPropertyClass_ZoneConfigDNSServerWrapper, self).__init__(zoneConfig)
		self.__zoneConfig = zoneConfig
		self.zoneList = IxPropertyGroupSequence_ZoneConfig_zoneListDNSServerWrapper(zoneConfig)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_ZoneConfigDNSServerWrapper.properties and super(IxPropertyClass_ZoneConfigDNSServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ZoneConfigDNSServerWrapper, self).__getattribute__("_IxPropertyClass_ZoneConfigDNSServerWrapper__zoneConfig"), name)
		else:
			return super(IxPropertyClass_ZoneConfigDNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ZoneConfigDNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ZoneConfigDNSServerWrapper, self).__getattribute__("_IxPropertyClass_ZoneConfigDNSServerWrapper__zoneConfig"), name, value)
			super(IxPropertyClass_ZoneConfigDNSServerWrapper, self).__setattr__(name, value)


class IxPropertyClass_AdvancedOptionsDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, advancedOptions):
		super(IxPropertyClass_AdvancedOptionsDNSServerWrapper, self).__init__(advancedOptions)
		self.__advancedOptions = advancedOptions
		self.listeningPort = advancedOptions.listeningPort
		self.enableDNSSEC = advancedOptions.enableDNSSEC
		self.enableHighPerformanceDNS = advancedOptions.enableHighPerformanceDNS
		self.ttlValue = advancedOptions.ttlValue

	properties = ["listeningPort", "enableDNSSEC", "enableHighPerformanceDNS", "ttlValue", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AdvancedOptionsDNSServerWrapper.properties and super(IxPropertyClass_AdvancedOptionsDNSServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AdvancedOptionsDNSServerWrapper, self).__getattribute__("_IxPropertyClass_AdvancedOptionsDNSServerWrapper__advancedOptions"), name)
		else:
			return super(IxPropertyClass_AdvancedOptionsDNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AdvancedOptionsDNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AdvancedOptionsDNSServerWrapper, self).__getattribute__("_IxPropertyClass_AdvancedOptionsDNSServerWrapper__advancedOptions"), name, value)
			super(IxPropertyClass_AdvancedOptionsDNSServerWrapper, self).__setattr__(name, value)


class IxPropertyClass_ZoneMgrDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, zoneMgr):
		super(IxPropertyClass_ZoneMgrDNSServerWrapper, self).__init__(zoneMgr)
		self.__zoneMgr = zoneMgr
		self.zoneChoices = IxPropertyGroupSequence_ZoneMgr_zoneChoicesDNSServerWrapper(zoneMgr)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_ZoneMgrDNSServerWrapper.properties and super(IxPropertyClass_ZoneMgrDNSServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ZoneMgrDNSServerWrapper, self).__getattribute__("_IxPropertyClass_ZoneMgrDNSServerWrapper__zoneMgr"), name)
		else:
			return super(IxPropertyClass_ZoneMgrDNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ZoneMgrDNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ZoneMgrDNSServerWrapper, self).__getattribute__("_IxPropertyClass_ZoneMgrDNSServerWrapper__zoneMgr"), name, value)
			super(IxPropertyClass_ZoneMgrDNSServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_DnsConfig_dnsQueriesDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, dnsConfig):
		self.__dnsConfig = dnsConfig
		self.optionsDict = {
			('DnsQuery',): "IxPropertyClass_DnsQueryDNSClient",
			('LoopBeginCommand',): "IxPropertyCommandLoopBeginDNSClient",
			('LoopEndCommand',): "IxPropertyCommandLoopEndDNSClient",
			('START',): "IxPropertyCommandStartDNSClient",
			('STOP',): "IxPropertyCommandStopDNSClient",
			('THINK',): "IxPropertyCommandThinkDNSClient",
		}

	def getItemIxDnsqueryCommand(self, objectID):
		itemList = self.__dnsConfig.dnsQueries
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_DnsQuery":
				return IxPropertyClass_DnsQueryDNSClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxDnsqueryCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "DnsQuery"})
		return IxPropertyClass_DnsQueryDNSClientWrapper(self.__dnsConfig.dnsQueries.appendItem(**kwargs))

	def getItemIxLoopbegincommandCommand(self, objectID):
		itemList = self.__dnsConfig.dnsQueries
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandLoopBegin":
				return IxPropertyCommandLoopBeginDNSClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopbegincommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopBeginCommand"})
		return IxPropertyCommandLoopBeginDNSClientWrapper(self.__dnsConfig.dnsQueries.appendItem(**kwargs))

	def getItemIxLoopendcommandCommand(self, objectID):
		itemList = self.__dnsConfig.dnsQueries
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandLoopEnd":
				return IxPropertyCommandLoopEndDNSClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopendcommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopEndCommand"})
		return IxPropertyCommandLoopEndDNSClientWrapper(self.__dnsConfig.dnsQueries.appendItem(**kwargs))

	def getItemIxStartCommand(self, objectID):
		itemList = self.__dnsConfig.dnsQueries
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandStart":
				return IxPropertyCommandStartDNSClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStartCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "START"})
		return IxPropertyCommandStartDNSClientWrapper(self.__dnsConfig.dnsQueries.appendItem(**kwargs))

	def getItemIxStopCommand(self, objectID):
		itemList = self.__dnsConfig.dnsQueries
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandStop":
				return IxPropertyCommandStopDNSClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STOP"})
		return IxPropertyCommandStopDNSClientWrapper(self.__dnsConfig.dnsQueries.appendItem(**kwargs))

	def getItemIxThinkCommand(self, objectID):
		itemList = self.__dnsConfig.dnsQueries
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandThink":
				return IxPropertyCommandThinkDNSClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxThinkCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "THINK"})
		return IxPropertyCommandThinkDNSClientWrapper(self.__dnsConfig.dnsQueries.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__dnsConfig.dnsQueries
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, commandType=None):
		kwargs = {}
		kwargs.update({"commandType": commandType})
		return self.__dnsConfig.dnsQueries.appendItem(**kwargs)

	def getList(self):
		return self.__dnsConfig.dnsQueries

	def clear(self):
		return self.__dnsConfig.dnsQueries.clear()


class IxPropertyCommandStartDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStart):
		super(IxPropertyCommandStartDNSClientWrapper, self).__init__(ixPropertyCommandStart)
		self.__ixPropertyCommandStart = ixPropertyCommandStart
		self.commandType = ixPropertyCommandStart.commandType
		self.cmdName = ixPropertyCommandStart.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandStartDNSClientWrapper.properties and super(IxPropertyCommandStartDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandStartDNSClientWrapper, self).__getattribute__("_IxPropertyCommandStartDNSClientWrapper__ixPropertyCommandStart"), name)
		else:
			return super(IxPropertyCommandStartDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandStartDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandStartDNSClientWrapper, self).__getattribute__("_IxPropertyCommandStartDNSClientWrapper__ixPropertyCommandStart"), name, value)
			super(IxPropertyCommandStartDNSClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_DnsQueryDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_DnsQuery):
		super(IxPropertyClass_DnsQueryDNSClientWrapper, self).__init__(ixPropertyClass_DnsQuery)
		self.__ixPropertyClass_DnsQuery = ixPropertyClass_DnsQuery
		self.dnsServer = ixPropertyClass_DnsQuery.dnsServer
		self.recursionDesired = ixPropertyClass_DnsQuery.recursionDesired
		self.hostName = ixPropertyClass_DnsQuery.hostName
		self.expectList = IxPropertyGroupSequence_DnsQuery_expectListDNSClientWrapper(ixPropertyClass_DnsQuery)
		self.cmdName = ixPropertyClass_DnsQuery.cmdName
		self.commandType = ixPropertyClass_DnsQuery.commandType
		self.enableDNSSEC = ixPropertyClass_DnsQuery.enableDNSSEC
		self.enablePCO = ixPropertyClass_DnsQuery.enablePCO
		self.queryType = ixPropertyClass_DnsQuery.queryType
		self.expect = ixPropertyClass_DnsQuery.expect

	properties = ["dnsServer", "recursionDesired", "hostName", "cmdName", "commandType", "enableDNSSEC", "enablePCO", "queryType", "expect", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_DnsQueryDNSClientWrapper.properties and super(IxPropertyClass_DnsQueryDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_DnsQueryDNSClientWrapper, self).__getattribute__("_IxPropertyClass_DnsQueryDNSClientWrapper__ixPropertyClass_DnsQuery"), name)
		else:
			return super(IxPropertyClass_DnsQueryDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_DnsQueryDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_DnsQueryDNSClientWrapper, self).__getattribute__("_IxPropertyClass_DnsQueryDNSClientWrapper__ixPropertyClass_DnsQuery"), name, value)
			super(IxPropertyClass_DnsQueryDNSClientWrapper, self).__setattr__(name, value)


class IxPropertyCommandLoopBeginDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandLoopBegin):
		super(IxPropertyCommandLoopBeginDNSClientWrapper, self).__init__(ixPropertyCommandLoopBegin)
		self.__ixPropertyCommandLoopBegin = ixPropertyCommandLoopBegin
		self.commandType = ixPropertyCommandLoopBegin.commandType
		self.cmdName = ixPropertyCommandLoopBegin.cmdName
		self.LoopCount = ixPropertyCommandLoopBegin.LoopCount

	properties = ["commandType", "cmdName", "LoopCount", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandLoopBeginDNSClientWrapper.properties and super(IxPropertyCommandLoopBeginDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandLoopBeginDNSClientWrapper, self).__getattribute__("_IxPropertyCommandLoopBeginDNSClientWrapper__ixPropertyCommandLoopBegin"), name)
		else:
			return super(IxPropertyCommandLoopBeginDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandLoopBeginDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandLoopBeginDNSClientWrapper, self).__getattribute__("_IxPropertyCommandLoopBeginDNSClientWrapper__ixPropertyCommandLoopBegin"), name, value)
			super(IxPropertyCommandLoopBeginDNSClientWrapper, self).__setattr__(name, value)


class IxPropertyCommandLoopEndDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandLoopEnd):
		super(IxPropertyCommandLoopEndDNSClientWrapper, self).__init__(ixPropertyCommandLoopEnd)
		self.__ixPropertyCommandLoopEnd = ixPropertyCommandLoopEnd
		self.commandType = ixPropertyCommandLoopEnd.commandType
		self.cmdName = ixPropertyCommandLoopEnd.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandLoopEndDNSClientWrapper.properties and super(IxPropertyCommandLoopEndDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandLoopEndDNSClientWrapper, self).__getattribute__("_IxPropertyCommandLoopEndDNSClientWrapper__ixPropertyCommandLoopEnd"), name)
		else:
			return super(IxPropertyCommandLoopEndDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandLoopEndDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandLoopEndDNSClientWrapper, self).__getattribute__("_IxPropertyCommandLoopEndDNSClientWrapper__ixPropertyCommandLoopEnd"), name, value)
			super(IxPropertyCommandLoopEndDNSClientWrapper, self).__setattr__(name, value)


class IxPropertyCommandThinkDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandThink):
		super(IxPropertyCommandThinkDNSClientWrapper, self).__init__(ixPropertyCommandThink)
		self.__ixPropertyCommandThink = ixPropertyCommandThink
		self.minimumInterval = ixPropertyCommandThink.minimumInterval
		self.cmdName = ixPropertyCommandThink.cmdName
		self.commandType = ixPropertyCommandThink.commandType
		self.maximumInterval = ixPropertyCommandThink.maximumInterval

	properties = ["minimumInterval", "cmdName", "commandType", "maximumInterval", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandThinkDNSClientWrapper.properties and super(IxPropertyCommandThinkDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandThinkDNSClientWrapper, self).__getattribute__("_IxPropertyCommandThinkDNSClientWrapper__ixPropertyCommandThink"), name)
		else:
			return super(IxPropertyCommandThinkDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandThinkDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandThinkDNSClientWrapper, self).__getattribute__("_IxPropertyCommandThinkDNSClientWrapper__ixPropertyCommandThink"), name, value)
			super(IxPropertyCommandThinkDNSClientWrapper, self).__setattr__(name, value)


class IxPropertyCommandStopDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStop):
		super(IxPropertyCommandStopDNSClientWrapper, self).__init__(ixPropertyCommandStop)
		self.__ixPropertyCommandStop = ixPropertyCommandStop
		self.commandType = ixPropertyCommandStop.commandType
		self.cmdName = ixPropertyCommandStop.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandStopDNSClientWrapper.properties and super(IxPropertyCommandStopDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandStopDNSClientWrapper, self).__getattribute__("_IxPropertyCommandStopDNSClientWrapper__ixPropertyCommandStop"), name)
		else:
			return super(IxPropertyCommandStopDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandStopDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandStopDNSClientWrapper, self).__getattribute__("_IxPropertyCommandStopDNSClientWrapper__ixPropertyCommandStop"), name, value)
			super(IxPropertyCommandStopDNSClientWrapper, self).__setattr__(name, value)


class IxNetRangeGroupList2Wrapper(RestObjectBaseClass):

	def __init__(self, ixNetIpV4V6Plugin):
		self.__ixNetIpV4V6Plugin = ixNetIpV4V6Plugin

	def getItem(self, objectID):
		itemList = self.__ixNetIpV4V6Plugin.rangeGroups
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetRangeGroup":
				return IxNetRangeGroupWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxNetRangeGroupWrapper(self.__ixNetIpV4V6Plugin.rangeGroups.appendItem(**kwargs))

	def getList(self):
		return self.__ixNetIpV4V6Plugin.rangeGroups

	def clear(self):
		return self.__ixNetIpV4V6Plugin.rangeGroups.clear()


class IxNetRangeGroupWrapper(RestObjectBaseClass):

	def __init__(self, ixNetRangeGroup):
		super(IxNetRangeGroupWrapper, self).__init__(ixNetRangeGroup)
		self.__ixNetRangeGroup = ixNetRangeGroup
		self.itemType = ixNetRangeGroup.itemType
		self.distribType = ixNetRangeGroup.distribType
		self.rangeList = IxNetLayerRangeList2Wrapper(ixNetRangeGroup)
		self.name = ixNetRangeGroup.name

	properties = ["itemType", "distribType", "name", ]

	def __getattribute__(self, name):
		if name in IxNetRangeGroupWrapper.properties and super(IxNetRangeGroupWrapper, self).__getattribute__(name):
			return getattr(super(IxNetRangeGroupWrapper, self).__getattribute__("_IxNetRangeGroupWrapper__ixNetRangeGroup"), name)
		else:
			return super(IxNetRangeGroupWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetRangeGroupWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetRangeGroupWrapper, self).__getattribute__("_IxNetRangeGroupWrapper__ixNetRangeGroup"), name, value)
			super(IxNetRangeGroupWrapper, self).__setattr__(name, value)


class IxNetIpV4V6RangeListWrapper(RestObjectBaseClass):

	def __init__(self, ixNetIpV4V6Plugin):
		self.__ixNetIpV4V6Plugin = ixNetIpV4V6Plugin

	def getItem(self, objectID):
		itemList = self.__ixNetIpV4V6Plugin.rangeList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetIpV4V6Range":
				return IxNetIpV4V6RangeWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxNetIpV4V6RangeWrapper(self.__ixNetIpV4V6Plugin.rangeList.appendItem(**kwargs))

	def getList(self):
		return self.__ixNetIpV4V6Plugin.rangeList

	def clear(self):
		return self.__ixNetIpV4V6Plugin.rangeList.clear()


class IxNetIpV4V6RangeWrapper(RestObjectBaseClass):

	def __init__(self, ixNetIpV4V6Range):
		super(IxNetIpV4V6RangeWrapper, self).__init__(ixNetIpV4V6Range)
		self.__ixNetIpV4V6Range = ixNetIpV4V6Range
		self.itemType = ixNetIpV4V6Range.itemType
		self.autoCountEnabled = ixNetIpV4V6Range.autoCountEnabled
		self.hostCount = ixNetIpV4V6Range.hostCount
		self.gatewayIncrementMode = ixNetIpV4V6Range.gatewayIncrementMode
		self.autoMacGeneration = ixNetIpV4V6Range.autoMacGeneration
		self.publishStats = ixNetIpV4V6Range.publishStats
		self.prefix = ixNetIpV4V6Range.prefix
		self.randomizeAddress = ixNetIpV4V6Range.randomizeAddress
		self.ipv6AutoMacGenerationAlgorithm = ixNetIpV4V6Range.ipv6AutoMacGenerationAlgorithm
		self.mss = ixNetIpV4V6Range.mss
		self.incrementBy = ixNetIpV4V6Range.incrementBy
		self.macRange = IxNetMacRangeWrapper(ixNetIpV4V6Range.macRange)
		self.generateStatistics = ixNetIpV4V6Range.generateStatistics
		self.vlanRange = IxNetVlanIdRangeWrapper(ixNetIpV4V6Range.vlanRange)
		self.hostIncrementBy = ixNetIpV4V6Range.hostIncrementBy
		self.enableGatewayArp = ixNetIpV4V6Range.enableGatewayArp
		self.autoIpTypeEnabled = ixNetIpV4V6Range.autoIpTypeEnabled
		self.ipType = ixNetIpV4V6Range.ipType
		self.count = ixNetIpV4V6Range.count
		self.name = ixNetIpV4V6Range.name
		self.gatewayAddress = ixNetIpV4V6Range.gatewayAddress
		self.enabled = ixNetIpV4V6Range.enabled
		self.gatewayIncrement = ixNetIpV4V6Range.gatewayIncrement
		self.randomizeSeed = ixNetIpV4V6Range.randomizeSeed
		self.ipAddress = ixNetIpV4V6Range.ipAddress

	properties = ["itemType", "autoCountEnabled", "hostCount", "gatewayIncrementMode", "autoMacGeneration", "publishStats", "prefix", "randomizeAddress", "ipv6AutoMacGenerationAlgorithm", "mss", "incrementBy", "generateStatistics", "hostIncrementBy", "enableGatewayArp", "autoIpTypeEnabled", "ipType", "count", "name", "gatewayAddress", "enabled", "gatewayIncrement", "randomizeSeed", "ipAddress", ]

	def __getattribute__(self, name):
		if name in IxNetIpV4V6RangeWrapper.properties and super(IxNetIpV4V6RangeWrapper, self).__getattribute__(name):
			return getattr(super(IxNetIpV4V6RangeWrapper, self).__getattribute__("_IxNetIpV4V6RangeWrapper__ixNetIpV4V6Range"), name)
		else:
			return super(IxNetIpV4V6RangeWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetIpV4V6RangeWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetIpV4V6RangeWrapper, self).__getattribute__("_IxNetIpV4V6RangeWrapper__ixNetIpV4V6Range"), name, value)
			super(IxNetIpV4V6RangeWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_ZoneConfig_zoneListDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, zoneConfig):
		self.__zoneConfig = zoneConfig

	def getItem(self, objectID):
		itemList = self.__zoneConfig.zoneList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_ZoneList":
				return IxPropertyClass_ZoneListDNSServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_ZoneListDNSServerWrapper(self.__zoneConfig.zoneList.appendItem(**kwargs))

	def getList(self):
		return self.__zoneConfig.zoneList

	def clear(self):
		return self.__zoneConfig.zoneList.clear()


class IxPropertyClass_ZoneListDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_ZoneList):
		super(IxPropertyClass_ZoneListDNSServerWrapper, self).__init__(ixPropertyClass_ZoneList)
		self.__ixPropertyClass_ZoneList = ixPropertyClass_ZoneList
		self.name = ixPropertyClass_ZoneList.name
		self.algorithm = ixPropertyClass_ZoneList.algorithm
		self.keylength = ixPropertyClass_ZoneList.keylength
		self.signedzone = ixPropertyClass_ZoneList.signedzone

	properties = ["name", "algorithm", "keylength", "signedzone", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_ZoneListDNSServerWrapper.properties and super(IxPropertyClass_ZoneListDNSServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ZoneListDNSServerWrapper, self).__getattribute__("_IxPropertyClass_ZoneListDNSServerWrapper__ixPropertyClass_ZoneList"), name)
		else:
			return super(IxPropertyClass_ZoneListDNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ZoneListDNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ZoneListDNSServerWrapper, self).__getattribute__("_IxPropertyClass_ZoneListDNSServerWrapper__ixPropertyClass_ZoneList"), name, value)
			super(IxPropertyClass_ZoneListDNSServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_ZoneMgr_zoneChoicesDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, zoneMgr):
		self.__zoneMgr = zoneMgr

	def getItem(self, objectID):
		itemList = self.__zoneMgr.zoneChoices
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_Zone":
				return IxPropertyClass_ZoneDNSServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_ZoneDNSServerWrapper(self.__zoneMgr.zoneChoices.appendItem(**kwargs))

	def getList(self):
		return self.__zoneMgr.zoneChoices

	def clear(self):
		return self.__zoneMgr.zoneChoices.clear()


class IxPropertyClass_ZoneDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Zone):
		super(IxPropertyClass_ZoneDNSServerWrapper, self).__init__(ixPropertyClass_Zone)
		self.__ixPropertyClass_Zone = ixPropertyClass_Zone
		self.name = ixPropertyClass_Zone.name
		self.masterServer = ixPropertyClass_Zone.masterServer
		self.predefine = ixPropertyClass_Zone.predefine
		self.expire = ixPropertyClass_Zone.expire
		self.serial = ixPropertyClass_Zone.serial
		self.resourceRecordList = IxPropertyGroupSequence_Zone_resourceRecordListDNSServerWrapper(ixPropertyClass_Zone)

	properties = ["name", "masterServer", "predefine", "expire", "serial", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_ZoneDNSServerWrapper.properties and super(IxPropertyClass_ZoneDNSServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ZoneDNSServerWrapper, self).__getattribute__("_IxPropertyClass_ZoneDNSServerWrapper__ixPropertyClass_Zone"), name)
		else:
			return super(IxPropertyClass_ZoneDNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ZoneDNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ZoneDNSServerWrapper, self).__getattribute__("_IxPropertyClass_ZoneDNSServerWrapper__ixPropertyClass_Zone"), name, value)
			super(IxPropertyClass_ZoneDNSServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_DnsQuery_expectListDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_DnsQuery):
		self.__ixPropertyClass_DnsQuery = ixPropertyClass_DnsQuery

	def getItem(self, objectID):
		itemList = self.__ixPropertyClass_DnsQuery.expectList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_ExpectString":
				return IxPropertyClass_ExpectStringDNSClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_ExpectStringDNSClientWrapper(self.__ixPropertyClass_DnsQuery.expectList.appendItem(**kwargs))

	def getList(self):
		return self.__ixPropertyClass_DnsQuery.expectList

	def clear(self):
		return self.__ixPropertyClass_DnsQuery.expectList.clear()


class IxPropertyClass_ExpectStringDNSClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_ExpectString):
		super(IxPropertyClass_ExpectStringDNSClientWrapper, self).__init__(ixPropertyClass_ExpectString)
		self.__ixPropertyClass_ExpectString = ixPropertyClass_ExpectString
		self.expectStr = ixPropertyClass_ExpectString.expectStr

	properties = ["expectStr", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_ExpectStringDNSClientWrapper.properties and super(IxPropertyClass_ExpectStringDNSClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ExpectStringDNSClientWrapper, self).__getattribute__("_IxPropertyClass_ExpectStringDNSClientWrapper__ixPropertyClass_ExpectString"), name)
		else:
			return super(IxPropertyClass_ExpectStringDNSClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ExpectStringDNSClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ExpectStringDNSClientWrapper, self).__getattribute__("_IxPropertyClass_ExpectStringDNSClientWrapper__ixPropertyClass_ExpectString"), name, value)
			super(IxPropertyClass_ExpectStringDNSClientWrapper, self).__setattr__(name, value)


class IxNetLayerRangeList2Wrapper(RestObjectBaseClass):

	def __init__(self, ixNetRangeGroup):
		self.__ixNetRangeGroup = ixNetRangeGroup

	def getItem(self, objectID):
		itemList = self.__ixNetRangeGroup.rangeList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetIpV4V6Range":
				return IxNetIpV4V6RangeWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxNetIpV4V6RangeWrapper(self.__ixNetRangeGroup.rangeList.appendItem(**kwargs))

	def getList(self):
		return self.__ixNetRangeGroup.rangeList

	def clear(self):
		return self.__ixNetRangeGroup.rangeList.clear()


class IxPropertyGroupSequence_Zone_resourceRecordListDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Zone):
		self.__ixPropertyClass_Zone = ixPropertyClass_Zone
		self.optionsDict = {
			('A',): "IxPropertyClass_ADNSServer",
			('NS',): "IxPropertyClass_NSDNSServer",
		}

	def getItemIxPropertyClass_ADNSServer(self, objectID):
		itemList = self.__ixPropertyClass_Zone.resourceRecordList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_A":
				return IxPropertyClass_ADNSServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxPropertyClass_ADNSServer(self):
		kwargs = {}
		kwargs.update({"id": "A"})
		return IxPropertyClass_ADNSServerWrapper(self.__ixPropertyClass_Zone.resourceRecordList.appendItem(**kwargs))

	def getItemIxPropertyClass_NSDNSServer(self, objectID):
		itemList = self.__ixPropertyClass_Zone.resourceRecordList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_NS":
				return IxPropertyClass_NSDNSServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxPropertyClass_NSDNSServer(self):
		kwargs = {}
		kwargs.update({"id": "NS"})
		return IxPropertyClass_NSDNSServerWrapper(self.__ixPropertyClass_Zone.resourceRecordList.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__ixPropertyClass_Zone.resourceRecordList
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, id=None):
		kwargs = {}
		kwargs.update({"id": id})
		return self.__ixPropertyClass_Zone.resourceRecordList.appendItem(**kwargs)

	def getList(self):
		return self.__ixPropertyClass_Zone.resourceRecordList

	def clear(self):
		return self.__ixPropertyClass_Zone.resourceRecordList.clear()


class IxPropertyClass_ADNSServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_A):
		super(IxPropertyClass_ADNSServerWrapper, self).__init__(ixPropertyClass_A)
		self.__ixPropertyClass_A = ixPropertyClass_A
		self.hostName = ixPropertyClass_A.hostName
		self.address = ixPropertyClass_A.address

	properties = ["hostName", "address", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_ADNSServerWrapper.properties and super(IxPropertyClass_ADNSServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ADNSServerWrapper, self).__getattribute__("_IxPropertyClass_ADNSServerWrapper__ixPropertyClass_A"), name)
		else:
			return super(IxPropertyClass_ADNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ADNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ADNSServerWrapper, self).__getattribute__("_IxPropertyClass_ADNSServerWrapper__ixPropertyClass_A"), name, value)
			super(IxPropertyClass_ADNSServerWrapper, self).__setattr__(name, value)


class IxPropertyClass_NSDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_NS):
		super(IxPropertyClass_NSDNSServerWrapper, self).__init__(ixPropertyClass_NS)
		self.__ixPropertyClass_NS = ixPropertyClass_NS
		self.nameServer = ixPropertyClass_NS.nameServer
		self.zoneName = ixPropertyClass_NS.zoneName

	properties = ["nameServer", "zoneName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_NSDNSServerWrapper.properties and super(IxPropertyClass_NSDNSServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_NSDNSServerWrapper, self).__getattribute__("_IxPropertyClass_NSDNSServerWrapper__ixPropertyClass_NS"), name)
		else:
			return super(IxPropertyClass_NSDNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_NSDNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_NSDNSServerWrapper, self).__getattribute__("_IxPropertyClass_NSDNSServerWrapper__ixPropertyClass_NS"), name, value)
			super(IxPropertyClass_NSDNSServerWrapper, self).__setattr__(name, value)


class IxPropertyClass_CNAMEDNSServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_CNAME):
		super(IxPropertyClass_CNAMEDNSServerWrapper, self).__init__(ixPropertyClass_CNAME)
		self.__ixPropertyClass_CNAME = ixPropertyClass_CNAME
		self.realName = ixPropertyClass_CNAME.realName
		self.name = ixPropertyClass_CNAME.name

	properties = ["realName", "name", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_CNAMEDNSServerWrapper.properties and super(IxPropertyClass_CNAMEDNSServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_CNAMEDNSServerWrapper, self).__getattribute__("_IxPropertyClass_CNAMEDNSServerWrapper__ixPropertyClass_CNAME"), name)
		else:
			return super(IxPropertyClass_CNAMEDNSServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_CNAMEDNSServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_CNAMEDNSServerWrapper, self).__getattribute__("_IxPropertyClass_CNAMEDNSServerWrapper__ixPropertyClass_CNAME"), name, value)
			super(IxPropertyClass_CNAMEDNSServerWrapper, self).__setattr__(name, value)


class StatsNameIMAPServer(object):
	def __init__(self):
		self.kIMAPuid_storeResponseSent = "IMAP uid_store Response Sent"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kIMAPuid_fetchSentFailed = "IMAP uid_fetch Sent Failed"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kTotaluid_storeCommandsFailed = "Total uid_store Commands Failed"
		self.kTotalcapabilityCommandsFailed = "Total capability Commands Failed"
		self.kTotallogoutResponsesSent = "Total logout Responses Sent"
		self.kSYNSYNACKsReceived = "SYN/SYN-ACKs Received"
		self.kTotallistCommandsFailed = "Total list Commands Failed"
		self.kTCPRetries = "TCP Retries"
		self.kTotalcapabilityResponsesSent = "Total capability Responses Sent"
		self.kIMAPcapabilityCommandReceived = "IMAP capability Command Received"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kTotalnoopCommandsFailed = "Total noop Commands Failed"
		self.kResetsSent = "Resets Sent"
		self.kTimeouts = "Timeouts"
		self.kTotallistResponsesSent = "Total list Responses Sent"
		self.kIMAPloginResponseSent = "IMAP login Response Sent"
		self.kThroughputKbps = "Throughput (Kbps)"
		self.kIMAPstoreResponseSent = "IMAP store Response Sent"
		self.kTotalexpungeResponsesSent = "Total expunge Responses Sent"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kTotalselectCommandsReceived = "Total select Commands Received"
		self.kIMAPdeleteResponseSent = "IMAP delete Response Sent"
		self.kIMAPselectResponseSent = "IMAP select Response Sent"
		self.kTotallogoutCommandsReceived = "Total logout Commands Received"
		self.kFINsSent = "FINs Sent"
		self.kTotalexpungeCommandsReceived = "Total expunge Commands Received"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kSYNACKsSent = "SYN-ACKs Sent"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kSessionRequestsCompleteds = "Session Requests Completed/s"
		self.kIMAPTotalMailsSent = "IMAP Total Mails Sent"
		self.kIMAPuid_fetchCommandReceived = "IMAP uid_fetch Command Received"
		self.kIMAPloginSentFailed = "IMAP login Sent Failed"
		self.kFINsReceived = "FINs Received"
		self.kIMAPuid_fetchResponseSent = "IMAP uid_fetch Response Sent"
		self.kIMAPTotalAttachmentsSent = "IMAP Total Attachments Sent"
		self.kTotalcloseCommandsFailed = "Total close Commands Failed"
		self.kFINACKsReceived = "FIN-ACKs Received"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kTotalcloseCommandsReceived = "Total close Commands Received"
		self.kTotalselectCommandsFailed = "Total select Commands Failed"
		self.kIMAPTotalMailBytesSent = "IMAP Total Mail Bytes Sent"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kIMAPexpungeCommandReceived = "IMAP expunge Command Received"
		self.kIMAPnoopResponseSent = "IMAP noop Response Sent"
		self.kSessionRequestsReceiveds = "Session Requests Received/s"
		self.kIMAPfetchResponseSent = "IMAP fetch Response Sent"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kIMAPloginCommandReceived = "IMAP login Command Received"
		self.kTotaluid_storeResponsesSent = "Total uid_store Responses Sent"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kIMAPcreateCommandReceived = "IMAP create Command Received"
		self.kTotalloginCommandsFailed = "Total login Commands Failed"
		self.kTotalfetchCommandsFailed = "Total fetch Commands Failed"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kIMAPselectCommandReceived = "IMAP select Command Received"
		self.kIMAPTotalBytesSentandReceived = "IMAP Total Bytes Sent and Received"
		self.kTotaluid_fetchCommandsFailed = "Total uid_fetch Commands Failed"
		self.kTotalstoreResponsesSent = "Total store Responses Sent"
		self.kIMAPlistCommandReceived = "IMAP list Command Received"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kIMAPdeleteCommandReceived = "IMAP delete Command Received"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kIMAPSessionRequestsFailed = "IMAP Session Requests Failed"
		self.kIMAPselectSentFailed = "IMAP select Sent Failed"
		self.kTotalfetchResponsesSent = "Total fetch Responses Sent"
		self.kIMAPcloseCommandReceived = "IMAP close Command Received"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kTotallistCommandsReceived = "Total list Commands Received"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kIMAPlistResponseSent = "IMAP list Response Sent"
		self.kIMAPlogoutSentFailed = "IMAP logout Sent Failed"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kIMAPcreateSentFailed = "IMAP create Sent Failed"
		self.kIMAPstoreSentFailed = "IMAP store Sent Failed"
		self.kIMAPexpungeResponseSent = "IMAP expunge Response Sent"
		self.kIMAPfetchCommandReceived = "IMAP fetch Command Received"
		self.kIMAPnoopSentFailed = "IMAP noop Sent Failed"
		self.kTotalexpungeCommandsFailed = "Total expunge Commands Failed"
		self.kTotalnoopCommandsReceived = "Total noop Commands Received"
		self.kIMAPstoreCommandReceived = "IMAP store Command Received"
		self.kSessionRequestsFaileds = "Session Requests Failed/s"
		self.kIMAPnoopCommandReceived = "IMAP noop Command Received"
		self.kIMAPuid_storeCommandReceived = "IMAP uid_store Command Received"
		self.kIMAPTotalBytesSent = "IMAP Total Bytes Sent"
		self.kTotalcreateCommandsFailed = "Total create Commands Failed"
		self.kIMAPSessionRequestsReceived = "IMAP Session Requests Received"
		self.kIMAPcloseSentFailed = "IMAP close Sent Failed"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kIMAPexpungeSentFailed = "IMAP expunge Sent Failed"
		self.kTxRateKbps = "Tx Rate (Kbps)"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kTotalstoreCommandsReceived = "Total store Commands Received"
		self.kRetries = "Retries"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kTotaldeleteCommandsFailed = "Total delete Commands Failed"
		self.kTotalcreateResponsesSent = "Total create Responses Sent"
		self.kIMAPActiveConnections = "IMAP Active Connections"
		self.kTotaluid_fetchResponsesSent = "Total uid_fetch Responses Sent"
		self.kTotalnoopResponsesSent = "Total noop Responses Sent"
		self.kConnectionRequestsFailed = "Connection Requests Failed"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kTotalcloseResponsesSent = "Total close Responses Sent"
		self.kIMAPcapabilitySentFailed = "IMAP capability Sent Failed"
		self.kIMAPuid_storeSentFailed = "IMAP uid_store Sent Failed"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kIMAPcapabilityResponseSent = "IMAP capability Response Sent"
		self.kIMAPTotalBytesReceived = "IMAP Total Bytes Received"
		self.kRxRateKbps = "Rx Rate (Kbps)"
		self.kTotalloginResponsesSent = "Total login Responses Sent"
		self.kTotalfetchCommandsReceived = "Total fetch Commands Received"
		self.kTotaluid_fetchCommandsReceived = "Total uid_fetch Commands Received"
		self.kTotallogoutCommandsFailed = "Total logout Commands Failed"
		self.kMailTxRateKbps = "Mail Tx Rate (Kbps)"
		self.kIMAPcreateResponseSent = "IMAP create Response Sent"
		self.kAcceptQueueEntries = "Accept Queue Entries"
		self.kTotaldeleteCommandsReceived = "Total delete Commands Received"
		self.kIMAPlogoutCommandReceived = "IMAP logout Command Received"
		self.kTotaldeleteResponsesSent = "Total delete Responses Sent"
		self.kFINACKsSent = "FIN-ACKs Sent"
		self.kIMAPlistSentFailed = "IMAP list Sent Failed"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kIMAPTotalMailswithAttachmentsSent = "IMAP Total Mails with Attachments Sent"
		self.kTotalselectResponsesSent = "Total select Responses Sent"
		self.kIMAPdeleteSentFailed = "IMAP delete Sent Failed"
		self.kTotalstoreCommandsFailed = "Total store Commands Failed"
		self.kIMAPfetchSentFailed = "IMAP fetch Sent Failed"
		self.kIMAPcloseResponseSent = "IMAP close Response Sent"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kTotalcapabilityCommandsReceived = "Total capability Commands Received"
		self.kIMAPlogoutResponseSent = "IMAP logout Response Sent"
		self.kTotalcreateCommandsReceived = "Total create Commands Received"
		self.kIMAPSessionRequestsCompleted = "IMAP Session Requests Completed"
		self.kListenQueueDrops = "Listen Queue Drops"
		self.kTotaluid_storeCommandsReceived = "Total uid_store Commands Received"
		self.kTotalloginCommandsReceived = "Total login Commands Received"
		self.kResetsReceived = "Resets Received"
		self.kTCPFINReceived = "TCP FIN Received"


class StatsNameIMAPClient(object):
	def __init__(self):
		self.kTotalselectCommandsSent = "Total select Commands Sent"
		self.kIMAPdeleteCommandSent = "IMAP delete Command Sent"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kTotallogoutCommandsSent = "Total logout Commands Sent"
		self.kTotallistCommandsSent = "Total list Commands Sent"
		self.kIMAPcloseCommandOK = "IMAP close Command OK"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kIMAPdeleteCommandFailed = "IMAP delete Command Failed"
		self.kIMAPlogoutCommandFailed = "IMAP logout Command Failed"
		self.kIMAPnoopCommandAborted = "IMAP noop Command Aborted"
		self.kIMAPfetchCommandSent = "IMAP fetch Command Sent"
		self.kTotalcapabilityCommandsFailed = "Total capability Commands Failed"
		self.kSYNSYNACKsReceived = "SYN/SYN-ACKs Received"
		self.kTotallistCommandsFailed = "Total list Commands Failed"
		self.kTotalloginCommandsOK = "Total login Commands OK"
		self.kIMAPSessionsEstablished = "IMAP Sessions Established"
		self.kTotalloginCommandsSent = "Total login Commands Sent"
		self.kTCPRetries = "TCP Retries"
		self.kTotaluidstoreCommandsSent = "Total uid store Commands Sent"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kIMAPselectCommandOK = "IMAP select Command OK"
		self.kTotaluidfetchCommandsSent = "Total uid fetch Commands Sent"
		self.kTotalcapabilityCommandsSent = "Total capability Commands Sent"
		self.kIMAPSimulatedUsers = "IMAP Simulated Users"
		self.kIMAPstoreCommandFailed = "IMAP store Command Failed"
		self.kResetsSent = "Resets Sent"
		self.kIMAPselectCommandFailed = "IMAP select Command Failed"
		self.kTimeouts = "Timeouts"
		self.kTotalloginCommandsFailed = "Total login Commands Failed"
		self.kThroughputKbps = "Throughput (Kbps)"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kIMAPlistCommandOK = "IMAP list Command OK"
		self.kTotalfetchCommandsOK = "Total fetch Commands OK"
		self.kIMAPnoopCommandFailed = "IMAP noop Command Failed"
		self.kIMAPloginCommandFailed = "IMAP login Command Failed"
		self.kIMAPcreateCommandSent = "IMAP create Command Sent"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kTotalnoopCommandsSent = "Total noop Commands Sent"
		self.kTotalstoreCommandsSent = "Total store Commands Sent"
		self.kIMAPfetchCommandOK = "IMAP fetch Command OK"
		self.kIMAPdeleteCommandOK = "IMAP delete Command OK"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kFINsReceived = "FINs Received"
		self.kTransactionRate = "Transaction Rate"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kIMAPstoreCommandOK = "IMAP store Command OK"
		self.kIMAPfetchCommandFailed = "IMAP fetch Command Failed"
		self.kFINACKsReceived = "FIN-ACKs Received"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kTotalselectCommandsFailed = "Total select Commands Failed"
		self.kIMAPSessionsRequested = "IMAP Sessions Requested"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kIMAPMailBytesReceived = "IMAP Mail Bytes Received"
		self.kIMAPlistCommandAborted = "IMAP list Command Aborted"
		self.kIMAPnoopCommandSent = "IMAP noop Command Sent"
		self.kTotaldeleteCommandsSent = "Total delete Commands Sent"
		self.kIMAPloginCommandSent = "IMAP login Command Sent"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kIMAPuidstoreCommandSent = "IMAP uid store Command Sent"
		self.kIMAPstoreCommandAborted = "IMAP store Command Aborted"
		self.kIMAPCommandAborteds = "IMAP Command Aborted/s"
		self.kSessionsFaileds = "Sessions Failed/s"
		self.kSimulatedUsers = "Simulated Users"
		self.kIMAPlistCommandSent = "IMAP list Command Sent"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kTotaldeleteCommandsOK = "Total delete Commands OK"
		self.kTotalfetchCommandsFailed = "Total fetch Commands Failed"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kIMAPuidstoreCommandOK = "IMAP uid store Command OK"
		self.kIMAPTotalBytesSentandReceived = "IMAP Total Bytes Sent and Received"
		self.kIMAPexpungeCommandOK = "IMAP expunge Command OK"
		self.kTotaluidstoreCommandsFailed = "Total uid store Commands Failed"
		self.kIMAPuidfetchCommandOK = "IMAP uid fetch Command OK"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kSessionsRequesteds = "Sessions Requested/s"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kTotalcreateCommandsSent = "Total create Commands Sent"
		self.kIMAPstoreCommandSent = "IMAP store Command Sent"
		self.kIMAPexpungeCommandSent = "IMAP expunge Command Sent"
		self.kIMAPClientTotalDataIntegrityCheckFailed = "IMAP Client Total Data Integrity Check Failed"
		self.kTotaluidfetchCommandsOK = "Total uid fetch Commands OK"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kIMAPselectCommandSent = "IMAP select Command Sent"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kTotalexpungeCommandsSent = "Total expunge Commands Sent"
		self.kIMAPuidfetchCommandFailed = "IMAP uid fetch Command Failed"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kIMAPcloseCommandSent = "IMAP close Command Sent"
		self.kIMAPnoopCommandOK = "IMAP noop Command OK"
		self.kIMAPlistCommandFailed = "IMAP list Command Failed"
		self.kIMAPConnectionEstablished = "IMAP Connection Established"
		self.kIMAPcreateCommandOK = "IMAP create Command OK"
		self.kTotaluidstoreCommandsOK = "Total uid store Commands OK"
		self.kTotalcloseCommandsOK = "Total close Commands OK"
		self.kSYNsSent = "SYNs Sent"
		self.kIMAPselectCommandAborted = "IMAP select Command Aborted"
		self.kIMAPTotalBytesSent = "IMAP Total Bytes Sent"
		self.kTotalcreateCommandsFailed = "Total create Commands Failed"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kTotallistCommandsOK = "Total list Commands OK"
		self.kTxRateKbps = "Tx Rate (Kbps)"
		self.kIMAPlogoutCommandOK = "IMAP logout Command OK"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kIMAPuidstoreCommandFailed = "IMAP uid store Command Failed"
		self.kIMAPloginCommandOK = "IMAP login Command OK"
		self.kFINsSent = "FINs Sent"
		self.kRetries = "Retries"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kIMAPcapabilityCommandOK = "IMAP capability Command OK"
		self.kTotalstoreCommandsOK = "Total store Commands OK"
		self.kIMAPexpungeCommandAborted = "IMAP expunge Command Aborted"
		self.kTotaluidfetchCommandsFailed = "Total uid fetch Commands Failed"
		self.kTotalcloseCommandsSent = "Total close Commands Sent"
		self.kIMAPSessionsAborted = "IMAP Sessions Aborted"
		self.kTotalnoopCommandsFailed = "Total noop Commands Failed"
		self.kIMAPcapabilityCommandAborted = "IMAP capability Command Aborted"
		self.kIMAPfetchCommandAborted = "IMAP fetch Command Aborted"
		self.kIMAPcapabilityCommandFailed = "IMAP capability Command Failed"
		self.kIMAPcloseCommandFailed = "IMAP close Command Failed"
		self.kIMAPCommandsTimeout = "IMAP Commands Timeout"
		self.kTotalexpungeCommandsFailed = "Total expunge Commands Failed"
		self.kConnectionRequestsFailed = "Connection Requests Failed"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kIMAPcapabilityCommandSent = "IMAP capability Command Sent"
		self.kTotalfetchCommandsSent = "Total fetch Commands Sent"
		self.kIMAPTransactions = "IMAP Transactions"
		self.kIMAPdeleteCommandAborted = "IMAP delete Command Aborted"
		self.kIMAPlogoutCommandAborted = "IMAP logout Command Aborted"
		self.kIMAPTotalBytesReceived = "IMAP Total Bytes Received"
		self.kRxRateKbps = "Rx Rate (Kbps)"
		self.kTotalcapabilityCommandsOK = "Total capability Commands OK"
		self.kSessionsEstablisheds = "Sessions Established/s"
		self.kIMAPuidstoreCommandAborted = "IMAP uid store Command Aborted"
		self.kIMAPcreateCommandAborted = "IMAP create Command Aborted"
		self.kConnectionRate = "Connection Rate"
		self.kIMAPSessionsFailed = "IMAP Sessions Failed"
		self.kTotallogoutCommandsOK = "Total logout Commands OK"
		self.kMailRxRateKbps = "Mail Rx Rate (Kbps)"
		self.kIMAPuidfetchCommandSent = "IMAP uid fetch Command Sent"
		self.kTotallogoutCommandsFailed = "Total logout Commands Failed"
		self.kIMAPConcurrentConnections = "IMAP Concurrent Connections"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kTotaldeleteCommandsFailed = "Total delete Commands Failed"
		self.kResetsReceived = "Resets Received"
		self.kFINACKsSent = "FIN-ACKs Sent"
		self.kIMAPConnections = "IMAP Connections"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kIMAPClientTotalDataIntegrityCheckSucceeded = "IMAP Client Total Data Integrity Check Succeeded"
		self.kIMAPcloseCommandAborted = "IMAP close Command Aborted"
		self.kTotalcreateCommandsOK = "Total create Commands OK"
		self.kTotalcloseCommandsFailed = "Total close Commands Failed"
		self.kIMAPTotalMailsReceived = "IMAP Total Mails Received"
		self.kTotalstoreCommandsFailed = "Total store Commands Failed"
		self.kIMAPexpungeCommandFailed = "IMAP expunge Command Failed"
		self.kIMAPuidfetchCommandAborted = "IMAP uid fetch Command Aborted"
		self.kTotalnoopCommandsOK = "Total noop Commands OK"
		self.kIMAPloginCommandAborted = "IMAP login Command Aborted"
		self.kIMAPSessionsAborteds = "IMAP Sessions Aborted/s"
		self.kTotalexpungeCommandsOK = "Total expunge Commands OK"
		self.kConcurrentConnection = "Concurrent Connection"
		self.kIMAPcreateCommandFailed = "IMAP create Command Failed"
		self.kIMAPlogoutCommandSent = "IMAP logout Command Sent"
		self.kTotalselectCommandsOK = "Total select Commands OK"
		self.kTCPFINReceived = "TCP FIN Received"


class IxActivityIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityIMAPClientWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.secondaryEnableConstraint = ixActivity.secondaryEnableConstraint
		self.protocol = ixActivity.protocol
		self.userIpMapping = ixActivity.userIpMapping
		self.enableConstraint = ixActivity.enableConstraint
		self.agent = PluginIMAPClientWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.constraintValue = ixActivity.constraintValue
		self.customParameters = IxPropertyClass_ixCustomActivityParametersIMAPClientWrapper(ixActivity.customParameters)
		self.timelineId = ixActivity.timelineId
		self.role = ixActivity.role
		self.timeline = IxTimelineProxyIMAPClientWrapper(ixActivity.timeline)
		self.activeRole = ixActivity.activeRole
		self.type = ixActivity.type
		self.secondaryConstraintValue = ixActivity.secondaryConstraintValue
		self.enable = ixActivity.enable
		self.protocolAndType = ixActivity.protocolAndType
		self.userObjectiveType = ixActivity.userObjectiveType
		self.destinationIpMapping = ixActivity.destinationIpMapping
		self.name = ixActivity.name
		self.secondaryConstraintType = ixActivity.secondaryConstraintType
		self.userObjectiveValue = ixActivity.userObjectiveValue
		self.constraintType = ixActivity.constraintType

	properties = ["secondaryEnableConstraint", "protocol", "userIpMapping", "enableConstraint", "objectivePercent", "constraintValue", "timelineId", "role", "activeRole", "type", "secondaryConstraintValue", "enable", "protocolAndType", "userObjectiveType", "destinationIpMapping", "name", "secondaryConstraintType", "userObjectiveValue", "constraintType", ]

	def __getattribute__(self, name):
		if name in IxActivityIMAPClientWrapper.properties and super(IxActivityIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityIMAPClientWrapper, self).__getattribute__("_IxActivityIMAPClientWrapper__ixActivity"), name)
		else:
			return super(IxActivityIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityIMAPClientWrapper, self).__getattribute__("_IxActivityIMAPClientWrapper__ixActivity"), name, value)
			super(IxActivityIMAPClientWrapper, self).__setattr__(name, value)


class IxActivityModelWrapper(RestObjectBaseClass):

	def __init__(self, traffic):
		super(IxActivityModelWrapper, self).__init__(traffic)
		self.__traffic = traffic
		self.activityFunction = traffic.activityFunction
		self.role = traffic.role
		self.name = traffic.name

	properties = ["activityFunction", "role", "name", ]

	def __getattribute__(self, name):
		if name in IxActivityModelWrapper.properties and super(IxActivityModelWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityModelWrapper, self).__getattribute__("_IxActivityModelWrapper__traffic"), name)
		else:
			return super(IxActivityModelWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityModelWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityModelWrapper, self).__getattribute__("_IxActivityModelWrapper__traffic"), name, value)
			super(IxActivityModelWrapper, self).__setattr__(name, value)


class IxActivityIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityIMAPServerWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.customParameters = IxPropertyClass_ixCustomActivityParametersIMAPServerWrapper(ixActivity.customParameters)
		self.enable = ixActivity.enable
		self.protocol = ixActivity.protocol
		self.name = ixActivity.name
		self.role = ixActivity.role
		self.agent = PluginIMAPServerWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.protocolAndType = ixActivity.protocolAndType
		self.timeline = IxTimelineProxyIMAPServerWrapper(ixActivity.timeline)
		self.timelineId = ixActivity.timelineId
		self.type = ixActivity.type
		self.activeRole = ixActivity.activeRole

	properties = ["enable", "protocol", "name", "role", "objectivePercent", "protocolAndType", "timelineId", "type", "activeRole", ]

	def __getattribute__(self, name):
		if name in IxActivityIMAPServerWrapper.properties and super(IxActivityIMAPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityIMAPServerWrapper, self).__getattribute__("_IxActivityIMAPServerWrapper__ixActivity"), name)
		else:
			return super(IxActivityIMAPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityIMAPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityIMAPServerWrapper, self).__getattribute__("_IxActivityIMAPServerWrapper__ixActivity"), name, value)
			super(IxActivityIMAPServerWrapper, self).__setattr__(name, value)


class PluginIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginIMAPClientWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.pm = IxPropertyMap_IMAPIMAPClientWrapper(agent.pm)
		self.flowPercentage = agent.flowPercentage

	properties = ["cmdListLoops", "flowPercentage", ]

	def __getattribute__(self, name):
		if name in PluginIMAPClientWrapper.properties and super(PluginIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(PluginIMAPClientWrapper, self).__getattribute__("_PluginIMAPClientWrapper__agent"), name)
		else:
			return super(PluginIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginIMAPClientWrapper, self).__getattribute__("_PluginIMAPClientWrapper__agent"), name, value)
			super(PluginIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_ixCustomActivityParametersIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, customParameters):
		super(IxPropertyClass_ixCustomActivityParametersIMAPClientWrapper, self).__init__(customParameters)
		self.__customParameters = customParameters

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_ixCustomActivityParametersIMAPClientWrapper.properties and super(IxPropertyClass_ixCustomActivityParametersIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ixCustomActivityParametersIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersIMAPClientWrapper__customParameters"), name)
		else:
			return super(IxPropertyClass_ixCustomActivityParametersIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ixCustomActivityParametersIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ixCustomActivityParametersIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersIMAPClientWrapper__customParameters"), name, value)
			super(IxPropertyClass_ixCustomActivityParametersIMAPClientWrapper, self).__setattr__(name, value)


class IxTimelineProxyIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyIMAPClientWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.iterations = timeline.iterations
		self.rampUpType = timeline.rampUpType
		self.rampUpValue = timeline.rampUpValue
		self.rampUpTime = timeline.rampUpTime
		self.rampDownTime = timeline.rampDownTime
		self.standbyTime = timeline.standbyTime
		self.rampDownValue = timeline.rampDownValue
		self.rampUpInterval = timeline.rampUpInterval
		self.offlineTime = timeline.offlineTime
		self.sustainTime = timeline.sustainTime
		self.name = timeline.name
		self.timelineType = timeline.timelineType

	properties = ["iterations", "rampUpType", "rampUpValue", "rampUpTime", "rampDownTime", "standbyTime", "rampDownValue", "rampUpInterval", "offlineTime", "sustainTime", "name", "timelineType", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyIMAPClientWrapper.properties and super(IxTimelineProxyIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyIMAPClientWrapper, self).__getattribute__("_IxTimelineProxyIMAPClientWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyIMAPClientWrapper, self).__getattribute__("_IxTimelineProxyIMAPClientWrapper__timeline"), name, value)
			super(IxTimelineProxyIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_ixCustomActivityParametersIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, customParameters):
		super(IxPropertyClass_ixCustomActivityParametersIMAPServerWrapper, self).__init__(customParameters)
		self.__customParameters = customParameters

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_ixCustomActivityParametersIMAPServerWrapper.properties and super(IxPropertyClass_ixCustomActivityParametersIMAPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ixCustomActivityParametersIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersIMAPServerWrapper__customParameters"), name)
		else:
			return super(IxPropertyClass_ixCustomActivityParametersIMAPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ixCustomActivityParametersIMAPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ixCustomActivityParametersIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersIMAPServerWrapper__customParameters"), name, value)
			super(IxPropertyClass_ixCustomActivityParametersIMAPServerWrapper, self).__setattr__(name, value)


class PluginIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginIMAPServerWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.pm = IxPropertyMap_IMAPIMAPServerWrapper(agent.pm)
		self.flowPercentage = agent.flowPercentage

	properties = ["cmdListLoops", "flowPercentage", ]

	def __getattribute__(self, name):
		if name in PluginIMAPServerWrapper.properties and super(PluginIMAPServerWrapper, self).__getattribute__(name):
			return getattr(super(PluginIMAPServerWrapper, self).__getattribute__("_PluginIMAPServerWrapper__agent"), name)
		else:
			return super(PluginIMAPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginIMAPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginIMAPServerWrapper, self).__getattribute__("_PluginIMAPServerWrapper__agent"), name, value)
			super(PluginIMAPServerWrapper, self).__setattr__(name, value)


class IxTimelineProxyIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyIMAPServerWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.name = timeline.name
		self.standbyTime = timeline.standbyTime
		self.iterations = timeline.iterations
		self.sustainTime = timeline.sustainTime

	properties = ["name", "standbyTime", "iterations", "sustainTime", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyIMAPServerWrapper.properties and super(IxTimelineProxyIMAPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyIMAPServerWrapper, self).__getattribute__("_IxTimelineProxyIMAPServerWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyIMAPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyIMAPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyIMAPServerWrapper, self).__getattribute__("_IxTimelineProxyIMAPServerWrapper__timeline"), name, value)
			super(IxTimelineProxyIMAPServerWrapper, self).__setattr__(name, value)


class IxPropertyMap_IMAPIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		super(IxPropertyMap_IMAPIMAPClientWrapper, self).__init__(pm)
		self.__pm = pm
		self.imapCommands = IxPropertyGroupSequence_IMAP_imapCommandsIMAPClientWrapper(pm)
		self.advOptions = IxPropertyClass_advOptionsIMAPClientWrapper(pm.advOptions)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyMap_IMAPIMAPClientWrapper.properties and super(IxPropertyMap_IMAPIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyMap_IMAPIMAPClientWrapper, self).__getattribute__("_IxPropertyMap_IMAPIMAPClientWrapper__pm"), name)
		else:
			return super(IxPropertyMap_IMAPIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyMap_IMAPIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyMap_IMAPIMAPClientWrapper, self).__getattribute__("_IxPropertyMap_IMAPIMAPClientWrapper__pm"), name, value)
			super(IxPropertyMap_IMAPIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyMap_IMAPIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		super(IxPropertyMap_IMAPIMAPServerWrapper, self).__init__(pm)
		self.__pm = pm
		self.imapServerConfig = IxPropertyClass_mailConfigIMAPServerWrapper(pm.imapServerConfig)
		self.advOptions = IxPropertyClass_advOptionsIMAPServerWrapper(pm.advOptions)
		self.allMailMessages = IxPropertyClass_mailMessageInstListIMAPServerWrapper(pm.allMailMessages)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyMap_IMAPIMAPServerWrapper.properties and super(IxPropertyMap_IMAPIMAPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyMap_IMAPIMAPServerWrapper, self).__getattribute__("_IxPropertyMap_IMAPIMAPServerWrapper__pm"), name)
		else:
			return super(IxPropertyMap_IMAPIMAPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyMap_IMAPIMAPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyMap_IMAPIMAPServerWrapper, self).__getattribute__("_IxPropertyMap_IMAPIMAPServerWrapper__pm"), name, value)
			super(IxPropertyMap_IMAPIMAPServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_IMAP_imapCommandsIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm
		self.optionsDict = {
			('LOGIN',): "IxPropertyClass_LOGINIMAPClient",
			('LoopBeginCommand',): "IxPropertyClass_LoopBeginCommandIMAPClient",
			('OPEN',): "IxPropertyClass_OPENIMAPClient",
			('FETCH',): "IxPropertyClass_FETCHIMAPClient",
			('STOP',): "IxPropertyCommandStopIMAPClient",
			('SELECT',): "IxPropertyClass_SELECTIMAPClient",
			('STORE',): "IxPropertyClass_STOREIMAPClient",
			('DELETE',): "IxPropertyClass_DELETEIMAPClient",
			('CREATE',): "IxPropertyClass_CREATEIMAPClient",
			('DELMAILS',): "IxPropertyClass_DELMAILSIMAPClient",
			('CAPABILITY',): "IxPropertyClass_CAPABILITYIMAPClient",
			('NOOP',): "IxPropertyClass_NOOPIMAPClient",
			('LoopEndCommand',): "IxPropertyClass_LoopEndCommandIMAPClient",
			('START',): "IxPropertyCommandStartIMAPClient",
			('LIST',): "IxPropertyClass_LISTIMAPClient",
			('EXPUNGE',): "IxPropertyClass_EXPUNGEIMAPClient",
			('GETMAILS',): "IxPropertyClass_GETMAILSIMAPClient",
			('THINK',): "IxPropertyClass_THINKIMAPClient",
			('CLOSE',): "IxPropertyClass_CLOSEIMAPClient",
			('LOGOUT',): "IxPropertyClass_LOGOUTIMAPClient",
		}

	def getItemIxLoginCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_LOGIN":
				return IxPropertyClass_LOGINIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoginCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LOGIN"})
		return IxPropertyClass_LOGINIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxLoopbegincommandCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_LoopBeginCommand":
				return IxPropertyClass_LoopBeginCommandIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopbegincommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopBeginCommand"})
		return IxPropertyClass_LoopBeginCommandIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxOpenCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_OPEN":
				return IxPropertyClass_OPENIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxOpenCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "OPEN"})
		return IxPropertyClass_OPENIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxFetchCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_FETCH":
				return IxPropertyClass_FETCHIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxFetchCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "FETCH"})
		return IxPropertyClass_FETCHIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxStopCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandStop":
				return IxPropertyCommandStopIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STOP"})
		return IxPropertyCommandStopIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxSelectCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_SELECT":
				return IxPropertyClass_SELECTIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxSelectCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "SELECT"})
		return IxPropertyClass_SELECTIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxStoreCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_STORE":
				return IxPropertyClass_STOREIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStoreCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STORE"})
		return IxPropertyClass_STOREIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxDeleteCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_DELETE":
				return IxPropertyClass_DELETEIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxDeleteCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "DELETE"})
		return IxPropertyClass_DELETEIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxCreateCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_CREATE":
				return IxPropertyClass_CREATEIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxCreateCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "CREATE"})
		return IxPropertyClass_CREATEIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxDelmailsCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_DELMAILS":
				return IxPropertyClass_DELMAILSIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxDelmailsCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "DELMAILS"})
		return IxPropertyClass_DELMAILSIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxCapabilityCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_CAPABILITY":
				return IxPropertyClass_CAPABILITYIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxCapabilityCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "CAPABILITY"})
		return IxPropertyClass_CAPABILITYIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxNoopCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_NOOP":
				return IxPropertyClass_NOOPIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxNoopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "NOOP"})
		return IxPropertyClass_NOOPIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxLoopendcommandCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_LoopEndCommand":
				return IxPropertyClass_LoopEndCommandIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopendcommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopEndCommand"})
		return IxPropertyClass_LoopEndCommandIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxStartCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandStart":
				return IxPropertyCommandStartIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStartCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "START"})
		return IxPropertyCommandStartIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxListCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_LIST":
				return IxPropertyClass_LISTIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxListCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LIST"})
		return IxPropertyClass_LISTIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxExpungeCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_EXPUNGE":
				return IxPropertyClass_EXPUNGEIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxExpungeCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "EXPUNGE"})
		return IxPropertyClass_EXPUNGEIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxGetmailsCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_GETMAILS":
				return IxPropertyClass_GETMAILSIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxGetmailsCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "GETMAILS"})
		return IxPropertyClass_GETMAILSIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxThinkCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_THINK":
				return IxPropertyClass_THINKIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxThinkCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "THINK"})
		return IxPropertyClass_THINKIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxCloseCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_CLOSE":
				return IxPropertyClass_CLOSEIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxCloseCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "CLOSE"})
		return IxPropertyClass_CLOSEIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItemIxLogoutCommand(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_LOGOUT":
				return IxPropertyClass_LOGOUTIMAPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLogoutCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LOGOUT"})
		return IxPropertyClass_LOGOUTIMAPClientWrapper(self.__pm.imapCommands.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__pm.imapCommands
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, commandType=None):
		kwargs = {}
		kwargs.update({"commandType": commandType})
		return self.__pm.imapCommands.appendItem(**kwargs)

	def getList(self):
		return self.__pm.imapCommands

	def clear(self):
		return self.__pm.imapCommands.clear()


class IxPropertyCommandStartIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStart):
		super(IxPropertyCommandStartIMAPClientWrapper, self).__init__(ixPropertyCommandStart)
		self.__ixPropertyCommandStart = ixPropertyCommandStart
		self.commandType = ixPropertyCommandStart.commandType
		self.cmdName = ixPropertyCommandStart.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandStartIMAPClientWrapper.properties and super(IxPropertyCommandStartIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandStartIMAPClientWrapper, self).__getattribute__("_IxPropertyCommandStartIMAPClientWrapper__ixPropertyCommandStart"), name)
		else:
			return super(IxPropertyCommandStartIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandStartIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandStartIMAPClientWrapper, self).__getattribute__("_IxPropertyCommandStartIMAPClientWrapper__ixPropertyCommandStart"), name, value)
			super(IxPropertyCommandStartIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_GETMAILSIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_GETMAILS):
		super(IxPropertyClass_GETMAILSIMAPClientWrapper, self).__init__(ixPropertyClass_GETMAILS)
		self.__ixPropertyClass_GETMAILS = ixPropertyClass_GETMAILS
		self.Username = ixPropertyClass_GETMAILS.Username
		self.enableDataIntegrity = ixPropertyClass_GETMAILS.enableDataIntegrity
		self.cmdName = ixPropertyClass_GETMAILS.cmdName
		self.imapServerIp = ixPropertyClass_GETMAILS.imapServerIp
		self.commandType = ixPropertyClass_GETMAILS.commandType
		self.Message_data_items = ixPropertyClass_GETMAILS.Message_data_items
		self.Password = ixPropertyClass_GETMAILS.Password
		self.Mailbox_name = ixPropertyClass_GETMAILS.Mailbox_name

	properties = ["Username", "enableDataIntegrity", "cmdName", "imapServerIp", "commandType", "Message_data_items", "Password", "Mailbox_name", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_GETMAILSIMAPClientWrapper.properties and super(IxPropertyClass_GETMAILSIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_GETMAILSIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_GETMAILSIMAPClientWrapper__ixPropertyClass_GETMAILS"), name)
		else:
			return super(IxPropertyClass_GETMAILSIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_GETMAILSIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_GETMAILSIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_GETMAILSIMAPClientWrapper__ixPropertyClass_GETMAILS"), name, value)
			super(IxPropertyClass_GETMAILSIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_DELMAILSIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_DELMAILS):
		super(IxPropertyClass_DELMAILSIMAPClientWrapper, self).__init__(ixPropertyClass_DELMAILS)
		self.__ixPropertyClass_DELMAILS = ixPropertyClass_DELMAILS
		self.commandType = ixPropertyClass_DELMAILS.commandType
		self.Mailbox_name = ixPropertyClass_DELMAILS.Mailbox_name
		self.cmdName = ixPropertyClass_DELMAILS.cmdName

	properties = ["commandType", "Mailbox_name", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_DELMAILSIMAPClientWrapper.properties and super(IxPropertyClass_DELMAILSIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_DELMAILSIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_DELMAILSIMAPClientWrapper__ixPropertyClass_DELMAILS"), name)
		else:
			return super(IxPropertyClass_DELMAILSIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_DELMAILSIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_DELMAILSIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_DELMAILSIMAPClientWrapper__ixPropertyClass_DELMAILS"), name, value)
			super(IxPropertyClass_DELMAILSIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_CAPABILITYIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_CAPABILITY):
		super(IxPropertyClass_CAPABILITYIMAPClientWrapper, self).__init__(ixPropertyClass_CAPABILITY)
		self.__ixPropertyClass_CAPABILITY = ixPropertyClass_CAPABILITY
		self.capDescription = ixPropertyClass_CAPABILITY.capDescription
		self.commandType = ixPropertyClass_CAPABILITY.commandType
		self.cmdName = ixPropertyClass_CAPABILITY.cmdName

	properties = ["capDescription", "commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_CAPABILITYIMAPClientWrapper.properties and super(IxPropertyClass_CAPABILITYIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_CAPABILITYIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_CAPABILITYIMAPClientWrapper__ixPropertyClass_CAPABILITY"), name)
		else:
			return super(IxPropertyClass_CAPABILITYIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_CAPABILITYIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_CAPABILITYIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_CAPABILITYIMAPClientWrapper__ixPropertyClass_CAPABILITY"), name, value)
			super(IxPropertyClass_CAPABILITYIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_CLOSEIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_CLOSE):
		super(IxPropertyClass_CLOSEIMAPClientWrapper, self).__init__(ixPropertyClass_CLOSE)
		self.__ixPropertyClass_CLOSE = ixPropertyClass_CLOSE
		self.commandType = ixPropertyClass_CLOSE.commandType
		self.closeDescription = ixPropertyClass_CLOSE.closeDescription
		self.cmdName = ixPropertyClass_CLOSE.cmdName

	properties = ["commandType", "closeDescription", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_CLOSEIMAPClientWrapper.properties and super(IxPropertyClass_CLOSEIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_CLOSEIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_CLOSEIMAPClientWrapper__ixPropertyClass_CLOSE"), name)
		else:
			return super(IxPropertyClass_CLOSEIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_CLOSEIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_CLOSEIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_CLOSEIMAPClientWrapper__ixPropertyClass_CLOSE"), name, value)
			super(IxPropertyClass_CLOSEIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_CREATEIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_CREATE):
		super(IxPropertyClass_CREATEIMAPClientWrapper, self).__init__(ixPropertyClass_CREATE)
		self.__ixPropertyClass_CREATE = ixPropertyClass_CREATE
		self.commandType = ixPropertyClass_CREATE.commandType
		self.Mailbox_name = ixPropertyClass_CREATE.Mailbox_name
		self.cmdName = ixPropertyClass_CREATE.cmdName

	properties = ["commandType", "Mailbox_name", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_CREATEIMAPClientWrapper.properties and super(IxPropertyClass_CREATEIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_CREATEIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_CREATEIMAPClientWrapper__ixPropertyClass_CREATE"), name)
		else:
			return super(IxPropertyClass_CREATEIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_CREATEIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_CREATEIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_CREATEIMAPClientWrapper__ixPropertyClass_CREATE"), name, value)
			super(IxPropertyClass_CREATEIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_DELETEIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_DELETE):
		super(IxPropertyClass_DELETEIMAPClientWrapper, self).__init__(ixPropertyClass_DELETE)
		self.__ixPropertyClass_DELETE = ixPropertyClass_DELETE
		self.commandType = ixPropertyClass_DELETE.commandType
		self.Mailbox_name = ixPropertyClass_DELETE.Mailbox_name
		self.cmdName = ixPropertyClass_DELETE.cmdName

	properties = ["commandType", "Mailbox_name", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_DELETEIMAPClientWrapper.properties and super(IxPropertyClass_DELETEIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_DELETEIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_DELETEIMAPClientWrapper__ixPropertyClass_DELETE"), name)
		else:
			return super(IxPropertyClass_DELETEIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_DELETEIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_DELETEIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_DELETEIMAPClientWrapper__ixPropertyClass_DELETE"), name, value)
			super(IxPropertyClass_DELETEIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_EXPUNGEIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_EXPUNGE):
		super(IxPropertyClass_EXPUNGEIMAPClientWrapper, self).__init__(ixPropertyClass_EXPUNGE)
		self.__ixPropertyClass_EXPUNGE = ixPropertyClass_EXPUNGE
		self.commandType = ixPropertyClass_EXPUNGE.commandType
		self.expungeDescription = ixPropertyClass_EXPUNGE.expungeDescription
		self.cmdName = ixPropertyClass_EXPUNGE.cmdName

	properties = ["commandType", "expungeDescription", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_EXPUNGEIMAPClientWrapper.properties and super(IxPropertyClass_EXPUNGEIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_EXPUNGEIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_EXPUNGEIMAPClientWrapper__ixPropertyClass_EXPUNGE"), name)
		else:
			return super(IxPropertyClass_EXPUNGEIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_EXPUNGEIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_EXPUNGEIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_EXPUNGEIMAPClientWrapper__ixPropertyClass_EXPUNGE"), name, value)
			super(IxPropertyClass_EXPUNGEIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_FETCHIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_FETCH):
		super(IxPropertyClass_FETCHIMAPClientWrapper, self).__init__(ixPropertyClass_FETCH)
		self.__ixPropertyClass_FETCH = ixPropertyClass_FETCH
		self.enableDataIntegrity = ixPropertyClass_FETCH.enableDataIntegrity
		self.Message_sequence_set = ixPropertyClass_FETCH.Message_sequence_set
		self.cmdName = ixPropertyClass_FETCH.cmdName
		self.Message_data_items = ixPropertyClass_FETCH.Message_data_items
		self.commandType = ixPropertyClass_FETCH.commandType

	properties = ["enableDataIntegrity", "Message_sequence_set", "cmdName", "Message_data_items", "commandType", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_FETCHIMAPClientWrapper.properties and super(IxPropertyClass_FETCHIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_FETCHIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_FETCHIMAPClientWrapper__ixPropertyClass_FETCH"), name)
		else:
			return super(IxPropertyClass_FETCHIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_FETCHIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_FETCHIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_FETCHIMAPClientWrapper__ixPropertyClass_FETCH"), name, value)
			super(IxPropertyClass_FETCHIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_LISTIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_LIST):
		super(IxPropertyClass_LISTIMAPClientWrapper, self).__init__(ixPropertyClass_LIST)
		self.__ixPropertyClass_LIST = ixPropertyClass_LIST
		self.Mail_box_name_with_wildcards = ixPropertyClass_LIST.Mail_box_name_with_wildcards
		self.Reference_name = ixPropertyClass_LIST.Reference_name
		self.cmdName = ixPropertyClass_LIST.cmdName
		self.commandType = ixPropertyClass_LIST.commandType

	properties = ["Mail_box_name_with_wildcards", "Reference_name", "cmdName", "commandType", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_LISTIMAPClientWrapper.properties and super(IxPropertyClass_LISTIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_LISTIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_LISTIMAPClientWrapper__ixPropertyClass_LIST"), name)
		else:
			return super(IxPropertyClass_LISTIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_LISTIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_LISTIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_LISTIMAPClientWrapper__ixPropertyClass_LIST"), name, value)
			super(IxPropertyClass_LISTIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_LOGINIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_LOGIN):
		super(IxPropertyClass_LOGINIMAPClientWrapper, self).__init__(ixPropertyClass_LOGIN)
		self.__ixPropertyClass_LOGIN = ixPropertyClass_LOGIN
		self.Username = ixPropertyClass_LOGIN.Username
		self.cmdName = ixPropertyClass_LOGIN.cmdName
		self.commandType = ixPropertyClass_LOGIN.commandType
		self.Password = ixPropertyClass_LOGIN.Password

	properties = ["Username", "cmdName", "commandType", "Password", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_LOGINIMAPClientWrapper.properties and super(IxPropertyClass_LOGINIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_LOGINIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_LOGINIMAPClientWrapper__ixPropertyClass_LOGIN"), name)
		else:
			return super(IxPropertyClass_LOGINIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_LOGINIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_LOGINIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_LOGINIMAPClientWrapper__ixPropertyClass_LOGIN"), name, value)
			super(IxPropertyClass_LOGINIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_LOGOUTIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_LOGOUT):
		super(IxPropertyClass_LOGOUTIMAPClientWrapper, self).__init__(ixPropertyClass_LOGOUT)
		self.__ixPropertyClass_LOGOUT = ixPropertyClass_LOGOUT
		self.commandType = ixPropertyClass_LOGOUT.commandType
		self.logoutDescription = ixPropertyClass_LOGOUT.logoutDescription
		self.cmdName = ixPropertyClass_LOGOUT.cmdName

	properties = ["commandType", "logoutDescription", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_LOGOUTIMAPClientWrapper.properties and super(IxPropertyClass_LOGOUTIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_LOGOUTIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_LOGOUTIMAPClientWrapper__ixPropertyClass_LOGOUT"), name)
		else:
			return super(IxPropertyClass_LOGOUTIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_LOGOUTIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_LOGOUTIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_LOGOUTIMAPClientWrapper__ixPropertyClass_LOGOUT"), name, value)
			super(IxPropertyClass_LOGOUTIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_NOOPIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_NOOP):
		super(IxPropertyClass_NOOPIMAPClientWrapper, self).__init__(ixPropertyClass_NOOP)
		self.__ixPropertyClass_NOOP = ixPropertyClass_NOOP
		self.commandType = ixPropertyClass_NOOP.commandType
		self.cmdName = ixPropertyClass_NOOP.cmdName
		self.noopDescription = ixPropertyClass_NOOP.noopDescription

	properties = ["commandType", "cmdName", "noopDescription", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_NOOPIMAPClientWrapper.properties and super(IxPropertyClass_NOOPIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_NOOPIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_NOOPIMAPClientWrapper__ixPropertyClass_NOOP"), name)
		else:
			return super(IxPropertyClass_NOOPIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_NOOPIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_NOOPIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_NOOPIMAPClientWrapper__ixPropertyClass_NOOP"), name, value)
			super(IxPropertyClass_NOOPIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_OPENIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_OPEN):
		super(IxPropertyClass_OPENIMAPClientWrapper, self).__init__(ixPropertyClass_OPEN)
		self.__ixPropertyClass_OPEN = ixPropertyClass_OPEN
		self.commandType = ixPropertyClass_OPEN.commandType
		self.IMAP_Server_IP = ixPropertyClass_OPEN.IMAP_Server_IP
		self.cmdName = ixPropertyClass_OPEN.cmdName

	properties = ["commandType", "IMAP_Server_IP", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_OPENIMAPClientWrapper.properties and super(IxPropertyClass_OPENIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_OPENIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_OPENIMAPClientWrapper__ixPropertyClass_OPEN"), name)
		else:
			return super(IxPropertyClass_OPENIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_OPENIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_OPENIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_OPENIMAPClientWrapper__ixPropertyClass_OPEN"), name, value)
			super(IxPropertyClass_OPENIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_SELECTIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_SELECT):
		super(IxPropertyClass_SELECTIMAPClientWrapper, self).__init__(ixPropertyClass_SELECT)
		self.__ixPropertyClass_SELECT = ixPropertyClass_SELECT
		self.commandType = ixPropertyClass_SELECT.commandType
		self.Mailbox_name = ixPropertyClass_SELECT.Mailbox_name
		self.cmdName = ixPropertyClass_SELECT.cmdName

	properties = ["commandType", "Mailbox_name", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_SELECTIMAPClientWrapper.properties and super(IxPropertyClass_SELECTIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_SELECTIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_SELECTIMAPClientWrapper__ixPropertyClass_SELECT"), name)
		else:
			return super(IxPropertyClass_SELECTIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_SELECTIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_SELECTIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_SELECTIMAPClientWrapper__ixPropertyClass_SELECT"), name, value)
			super(IxPropertyClass_SELECTIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_STOREIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_STORE):
		super(IxPropertyClass_STOREIMAPClientWrapper, self).__init__(ixPropertyClass_STORE)
		self.__ixPropertyClass_STORE = ixPropertyClass_STORE
		self.Message_sequence_set = ixPropertyClass_STORE.Message_sequence_set
		self.cmdName = ixPropertyClass_STORE.cmdName
		self.Data_items = ixPropertyClass_STORE.Data_items
		self.commandType = ixPropertyClass_STORE.commandType
		self.Flags = ixPropertyClass_STORE.Flags

	properties = ["Message_sequence_set", "cmdName", "Data_items", "commandType", "Flags", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_STOREIMAPClientWrapper.properties and super(IxPropertyClass_STOREIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_STOREIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_STOREIMAPClientWrapper__ixPropertyClass_STORE"), name)
		else:
			return super(IxPropertyClass_STOREIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_STOREIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_STOREIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_STOREIMAPClientWrapper__ixPropertyClass_STORE"), name, value)
			super(IxPropertyClass_STOREIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_LoopBeginCommandIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_LoopBeginCommand):
		super(IxPropertyClass_LoopBeginCommandIMAPClientWrapper, self).__init__(ixPropertyClass_LoopBeginCommand)
		self.__ixPropertyClass_LoopBeginCommand = ixPropertyClass_LoopBeginCommand
		self.commandType = ixPropertyClass_LoopBeginCommand.commandType
		self.cmdName = ixPropertyClass_LoopBeginCommand.cmdName
		self.LoopCount = ixPropertyClass_LoopBeginCommand.LoopCount

	properties = ["commandType", "cmdName", "LoopCount", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_LoopBeginCommandIMAPClientWrapper.properties and super(IxPropertyClass_LoopBeginCommandIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_LoopBeginCommandIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_LoopBeginCommandIMAPClientWrapper__ixPropertyClass_LoopBeginCommand"), name)
		else:
			return super(IxPropertyClass_LoopBeginCommandIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_LoopBeginCommandIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_LoopBeginCommandIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_LoopBeginCommandIMAPClientWrapper__ixPropertyClass_LoopBeginCommand"), name, value)
			super(IxPropertyClass_LoopBeginCommandIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_LoopEndCommandIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_LoopEndCommand):
		super(IxPropertyClass_LoopEndCommandIMAPClientWrapper, self).__init__(ixPropertyClass_LoopEndCommand)
		self.__ixPropertyClass_LoopEndCommand = ixPropertyClass_LoopEndCommand
		self.commandType = ixPropertyClass_LoopEndCommand.commandType
		self.cmdName = ixPropertyClass_LoopEndCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_LoopEndCommandIMAPClientWrapper.properties and super(IxPropertyClass_LoopEndCommandIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_LoopEndCommandIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_LoopEndCommandIMAPClientWrapper__ixPropertyClass_LoopEndCommand"), name)
		else:
			return super(IxPropertyClass_LoopEndCommandIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_LoopEndCommandIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_LoopEndCommandIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_LoopEndCommandIMAPClientWrapper__ixPropertyClass_LoopEndCommand"), name, value)
			super(IxPropertyClass_LoopEndCommandIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_THINKIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_THINK):
		super(IxPropertyClass_THINKIMAPClientWrapper, self).__init__(ixPropertyClass_THINK)
		self.__ixPropertyClass_THINK = ixPropertyClass_THINK
		self.minimumInterval = ixPropertyClass_THINK.minimumInterval
		self.cmdName = ixPropertyClass_THINK.cmdName
		self.commandType = ixPropertyClass_THINK.commandType
		self.maximumInterval = ixPropertyClass_THINK.maximumInterval

	properties = ["minimumInterval", "cmdName", "commandType", "maximumInterval", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_THINKIMAPClientWrapper.properties and super(IxPropertyClass_THINKIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_THINKIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_THINKIMAPClientWrapper__ixPropertyClass_THINK"), name)
		else:
			return super(IxPropertyClass_THINKIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_THINKIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_THINKIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_THINKIMAPClientWrapper__ixPropertyClass_THINK"), name, value)
			super(IxPropertyClass_THINKIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyCommandStopIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStop):
		super(IxPropertyCommandStopIMAPClientWrapper, self).__init__(ixPropertyCommandStop)
		self.__ixPropertyCommandStop = ixPropertyCommandStop
		self.commandType = ixPropertyCommandStop.commandType
		self.cmdName = ixPropertyCommandStop.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandStopIMAPClientWrapper.properties and super(IxPropertyCommandStopIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandStopIMAPClientWrapper, self).__getattribute__("_IxPropertyCommandStopIMAPClientWrapper__ixPropertyCommandStop"), name)
		else:
			return super(IxPropertyCommandStopIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandStopIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandStopIMAPClientWrapper, self).__getattribute__("_IxPropertyCommandStopIMAPClientWrapper__ixPropertyCommandStop"), name, value)
			super(IxPropertyCommandStopIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_advOptionsIMAPClientWrapper(RestObjectBaseClass):

	def __init__(self, advOptions):
		super(IxPropertyClass_advOptionsIMAPClientWrapper, self).__init__(advOptions)
		self.__advOptions = advOptions
		self.commandTimeout = advOptions.commandTimeout
		self.vlan_priority = advOptions.vlan_priority
		self.ipPreference = advOptions.ipPreference
		self.enableEsm = advOptions.enableEsm
		self.esm = advOptions.esm
		self.enableVlanPriority = advOptions.enableVlanPriority

	properties = ["commandTimeout", "vlan_priority", "ipPreference", "enableEsm", "esm", "enableVlanPriority", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_advOptionsIMAPClientWrapper.properties and super(IxPropertyClass_advOptionsIMAPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_advOptionsIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_advOptionsIMAPClientWrapper__advOptions"), name)
		else:
			return super(IxPropertyClass_advOptionsIMAPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_advOptionsIMAPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_advOptionsIMAPClientWrapper, self).__getattribute__("_IxPropertyClass_advOptionsIMAPClientWrapper__advOptions"), name, value)
			super(IxPropertyClass_advOptionsIMAPClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_mailConfigIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, imapServerConfig):
		super(IxPropertyClass_mailConfigIMAPServerWrapper, self).__init__(imapServerConfig)
		self.__imapServerConfig = imapServerConfig
		self.mails = IxPropertyGroupSequence_mailConfig_mailsIMAPServerWrapper(imapServerConfig)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_mailConfigIMAPServerWrapper.properties and super(IxPropertyClass_mailConfigIMAPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_mailConfigIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_mailConfigIMAPServerWrapper__imapServerConfig"), name)
		else:
			return super(IxPropertyClass_mailConfigIMAPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_mailConfigIMAPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_mailConfigIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_mailConfigIMAPServerWrapper__imapServerConfig"), name, value)
			super(IxPropertyClass_mailConfigIMAPServerWrapper, self).__setattr__(name, value)


class IxPropertyClass_advOptionsIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, advOptions):
		super(IxPropertyClass_advOptionsIMAPServerWrapper, self).__init__(advOptions)
		self.__advOptions = advOptions
		self.vlan_priority = advOptions.vlan_priority
		self.listening_port = advOptions.listening_port
		self.enableEsm = advOptions.enableEsm
		self.esm = advOptions.esm
		self.enableVlanPriority = advOptions.enableVlanPriority

	properties = ["vlan_priority", "listening_port", "enableEsm", "esm", "enableVlanPriority", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_advOptionsIMAPServerWrapper.properties and super(IxPropertyClass_advOptionsIMAPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_advOptionsIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_advOptionsIMAPServerWrapper__advOptions"), name)
		else:
			return super(IxPropertyClass_advOptionsIMAPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_advOptionsIMAPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_advOptionsIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_advOptionsIMAPServerWrapper__advOptions"), name, value)
			super(IxPropertyClass_advOptionsIMAPServerWrapper, self).__setattr__(name, value)


class IxPropertyClass_mailMessageInstListIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, allMailMessages):
		super(IxPropertyClass_mailMessageInstListIMAPServerWrapper, self).__init__(allMailMessages)
		self.__allMailMessages = allMailMessages
		self.mailMessageInstList = IxPropertyGroupSequence_mailMessageInstList_mailMessageInstListIMAPServerWrapper(allMailMessages)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_mailMessageInstListIMAPServerWrapper.properties and super(IxPropertyClass_mailMessageInstListIMAPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_mailMessageInstListIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_mailMessageInstListIMAPServerWrapper__allMailMessages"), name)
		else:
			return super(IxPropertyClass_mailMessageInstListIMAPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_mailMessageInstListIMAPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_mailMessageInstListIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_mailMessageInstListIMAPServerWrapper__allMailMessages"), name, value)
			super(IxPropertyClass_mailMessageInstListIMAPServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_mailConfig_mailsIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, imapServerConfig):
		self.__imapServerConfig = imapServerConfig

	def getItem(self, objectID):
		itemList = self.__imapServerConfig.mails
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_mailMessageList":
				return IxPropertyClass_mailMessageListIMAPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_mailMessageListIMAPServerWrapper(self.__imapServerConfig.mails.appendItem(**kwargs))

	def getList(self):
		return self.__imapServerConfig.mails

	def clear(self):
		return self.__imapServerConfig.mails.clear()


class IxPropertyClass_mailMessageListIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_mailMessageList):
		super(IxPropertyClass_mailMessageListIMAPServerWrapper, self).__init__(ixPropertyClass_mailMessageList)
		self.__ixPropertyClass_mailMessageList = ixPropertyClass_mailMessageList
		self.mail_name = ixPropertyClass_mailMessageList.mail_name
		self.mail_mesg_count = ixPropertyClass_mailMessageList.mail_mesg_count

	properties = ["mail_name", "mail_mesg_count", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_mailMessageListIMAPServerWrapper.properties and super(IxPropertyClass_mailMessageListIMAPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_mailMessageListIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_mailMessageListIMAPServerWrapper__ixPropertyClass_mailMessageList"), name)
		else:
			return super(IxPropertyClass_mailMessageListIMAPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_mailMessageListIMAPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_mailMessageListIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_mailMessageListIMAPServerWrapper__ixPropertyClass_mailMessageList"), name, value)
			super(IxPropertyClass_mailMessageListIMAPServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_mailMessageInstList_mailMessageInstListIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, allMailMessages):
		self.__allMailMessages = allMailMessages

	def getItem(self, objectID):
		itemList = self.__allMailMessages.mailMessageInstList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_mailMessage":
				return IxPropertyClass_mailMessageIMAPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_mailMessageIMAPServerWrapper(self.__allMailMessages.mailMessageInstList.appendItem(**kwargs))

	def getList(self):
		return self.__allMailMessages.mailMessageInstList

	def clear(self):
		return self.__allMailMessages.mailMessageInstList.clear()


class IxPropertyClass_mailMessageIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_mailMessage):
		super(IxPropertyClass_mailMessageIMAPServerWrapper, self).__init__(ixPropertyClass_mailMessage)
		self.__ixPropertyClass_mailMessage = ixPropertyClass_mailMessage
		self.UI_mail_body_filename = ixPropertyClass_mailMessage.UI_mail_body_filename
		self.Answered = ixPropertyClass_mailMessage.Answered
		self.custom_mail_body_encode = ixPropertyClass_mailMessage.custom_mail_body_encode
		self.Draft = ixPropertyClass_mailMessage.Draft
		self.custom_mail_body_use_real_file = ixPropertyClass_mailMessage.custom_mail_body_use_real_file
		self.mail_message_name = ixPropertyClass_mailMessage.mail_message_name
		self.Deleted = ixPropertyClass_mailMessage.Deleted
		self.enablePatternGen = ixPropertyClass_mailMessage.enablePatternGen
		self.mail_size_random_max_len = ixPropertyClass_mailMessage.mail_size_random_max_len
		self.Recent = ixPropertyClass_mailMessage.Recent
		self.description = ixPropertyClass_mailMessage.description
		self.custom_mail_body_content = ixPropertyClass_mailMessage.custom_mail_body_content
		self.mail_size = ixPropertyClass_mailMessage.mail_size
		self.headerList = IxPropertyGroupSequence_mailMessage_headerListIMAPServerWrapper(ixPropertyClass_mailMessage)
		self.mail_size_fixed_len = ixPropertyClass_mailMessage.mail_size_fixed_len
		self.Flagged = ixPropertyClass_mailMessage.Flagged
		self.mail_format = ixPropertyClass_mailMessage.mail_format
		self.cpyfrom = ixPropertyClass_mailMessage.cpyfrom
		self.Seen = ixPropertyClass_mailMessage.Seen
		self.mail_size_random_min_len = ixPropertyClass_mailMessage.mail_size_random_min_len
		self.mail_body_type = ixPropertyClass_mailMessage.mail_body_type

	properties = ["UI_mail_body_filename", "Answered", "custom_mail_body_encode", "Draft", "custom_mail_body_use_real_file", "mail_message_name", "Deleted", "enablePatternGen", "mail_size_random_max_len", "Recent", "description", "custom_mail_body_content", "mail_size", "mail_size_fixed_len", "Flagged", "mail_format", "cpyfrom", "Seen", "mail_size_random_min_len", "mail_body_type", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_mailMessageIMAPServerWrapper.properties and super(IxPropertyClass_mailMessageIMAPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_mailMessageIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_mailMessageIMAPServerWrapper__ixPropertyClass_mailMessage"), name)
		else:
			return super(IxPropertyClass_mailMessageIMAPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_mailMessageIMAPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_mailMessageIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_mailMessageIMAPServerWrapper__ixPropertyClass_mailMessage"), name, value)
			super(IxPropertyClass_mailMessageIMAPServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_mailMessage_headerListIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_mailMessage):
		self.__ixPropertyClass_mailMessage = ixPropertyClass_mailMessage

	def getItem(self, objectID):
		itemList = self.__ixPropertyClass_mailMessage.headerList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_mailHeader":
				return IxPropertyClass_mailHeaderIMAPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_mailHeaderIMAPServerWrapper(self.__ixPropertyClass_mailMessage.headerList.appendItem(**kwargs))

	def getList(self):
		return self.__ixPropertyClass_mailMessage.headerList

	def clear(self):
		return self.__ixPropertyClass_mailMessage.headerList.clear()


class IxPropertyClass_mailHeaderIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_mailHeader):
		super(IxPropertyClass_mailHeaderIMAPServerWrapper, self).__init__(ixPropertyClass_mailHeader)
		self.__ixPropertyClass_mailHeader = ixPropertyClass_mailHeader
		self.field_body = ixPropertyClass_mailHeader.field_body
		self.field_name = ixPropertyClass_mailHeader.field_name

	properties = ["field_body", "field_name", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_mailHeaderIMAPServerWrapper.properties and super(IxPropertyClass_mailHeaderIMAPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_mailHeaderIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_mailHeaderIMAPServerWrapper__ixPropertyClass_mailHeader"), name)
		else:
			return super(IxPropertyClass_mailHeaderIMAPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_mailHeaderIMAPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_mailHeaderIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_mailHeaderIMAPServerWrapper__ixPropertyClass_mailHeader"), name, value)
			super(IxPropertyClass_mailHeaderIMAPServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_mailMessage_attachmentListIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_mailMessage):
		self.__ixPropertyClass_mailMessage = ixPropertyClass_mailMessage

	def getItem(self, objectID):
		itemList = self.__ixPropertyClass_mailMessage.attachmentList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_mailAttachment":
				return IxPropertyClass_mailAttachmentIMAPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_mailAttachmentIMAPServerWrapper(self.__ixPropertyClass_mailMessage.attachmentList.appendItem(**kwargs))

	def getList(self):
		return self.__ixPropertyClass_mailMessage.attachmentList

	def clear(self):
		return self.__ixPropertyClass_mailMessage.attachmentList.clear()


class IxPropertyClass_mailAttachmentIMAPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_mailAttachment):
		super(IxPropertyClass_mailAttachmentIMAPServerWrapper, self).__init__(ixPropertyClass_mailAttachment)
		self.__ixPropertyClass_mailAttachment = ixPropertyClass_mailAttachment
		self.UI_attach_filename = ixPropertyClass_mailAttachment.UI_attach_filename
		self.attachment_data_type = ixPropertyClass_mailAttachment.attachment_data_type
		self.number_of_attachment = ixPropertyClass_mailAttachment.number_of_attachment
		self.attachStr = ixPropertyClass_mailAttachment.attachStr
		self.attachment_size_range = ixPropertyClass_mailAttachment.attachment_size_range
		self.attachment_type = ixPropertyClass_mailAttachment.attachment_type

	properties = ["UI_attach_filename", "attachment_data_type", "number_of_attachment", "attachStr", "attachment_size_range", "attachment_type", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_mailAttachmentIMAPServerWrapper.properties and super(IxPropertyClass_mailAttachmentIMAPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_mailAttachmentIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_mailAttachmentIMAPServerWrapper__ixPropertyClass_mailAttachment"), name)
		else:
			return super(IxPropertyClass_mailAttachmentIMAPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_mailAttachmentIMAPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_mailAttachmentIMAPServerWrapper, self).__getattribute__("_IxPropertyClass_mailAttachmentIMAPServerWrapper__ixPropertyClass_mailAttachment"), name, value)
			super(IxPropertyClass_mailAttachmentIMAPServerWrapper, self).__setattr__(name, value)


class StatsNamePOP3Client(object):
	def __init__(self):
		self.kSessionsEstablished = "Sessions Established"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kPOP3LISTOk = "POP3 LIST Ok"
		self.kPOP3ClientTotalDataIntegrityCheckSucceeded = "POP3 Client Total Data Integrity Check Succeeded"
		self.kPOP3AuthenticationOk = "POP3 Authentication Ok"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kPOP3RETROk = "POP3 RETR Ok"
		self.kPOP3TOPOk = "POP3 TOP Ok"
		self.kSYNSYNACKsReceived = "SYN/SYN-ACKs Received"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kTCPRetries = "TCP Retries"
		self.kPOP3ConcurrentConnections = "POP3 Concurrent Connections"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kMailsReceiveds = "Mails Received/s"
		self.kResetsSent = "Resets Sent"
		self.kTimeouts = "Timeouts"
		self.kPOP3RSETOk = "POP3 RSET Ok"
		self.kThroughputKbps = "Throughput (Kbps)"
		self.kPOP3LISTFailed = "POP3 LIST Failed"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kPOP3DELESent = "POP3 DELE Sent"
		self.kPOP3RSETFailed = "POP3 RSET Failed"
		self.kFINsSent = "FINs Sent"
		self.kPOP3STATOk = "POP3 STAT Ok"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kFINsReceived = "FINs Received"
		self.kConcurrentConnections = "Concurrent Connections"
		self.kPOP3QUITSent = "POP3 QUIT Sent"
		self.kPOP3QUITFailed = "POP3 QUIT Failed"
		self.kFINACKsReceived = "FIN-ACKs Received"
		self.kMailsReceived = "Mails Received"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kAuthenticationsFailed = "Authentications Failed"
		self.kPOP3LISTSent = "POP3 LIST Sent"
		self.kSessionsRequested = "Sessions Requested"
		self.kPOP3SessionsActive = "POP3 Sessions Active"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kPOP3TOPFailed = "POP3 TOP Failed"
		self.kSessionsFaileds = "Sessions Failed/s"
		self.kSimulatedUsers = "Simulated Users"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kTransactionRate = "Transaction Rate"
		self.kPOP3STATSent = "POP3 STAT Sent"
		self.kAuthenticationsOK = "Authentications OK"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kSessionsRequesteds = "Sessions Requested/s"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kPOP3AuthenticationSent = "POP3 Authentication Sent"
		self.kPOP3NOOPFailed = "POP3 NOOP Failed"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kPOP3UIDLFailed = "POP3 UIDL Failed"
		self.kPOP3SessionsFailed = "POP3 Sessions Failed"
		self.kPOP3RETRSent = "POP3 RETR Sent"
		self.kPOP3SimulatedUsers = "POP3 Simulated Users"
		self.kPOP3MailBytesReceived = "POP3 Mail Bytes Received"
		self.kSYNsSent = "SYNs Sent"
		self.kPOP3Bytes = "POP3 Bytes"
		self.kPOP3RSETSent = "POP3 RSET Sent"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kPOP3AuthenticationFailed = "POP3 Authentication Failed"
		self.kPOP3Connections = "POP3 Connections"
		self.kTxRateKbps = "Tx Rate (Kbps)"
		self.kRetries = "Retries"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kPOP3TOPSent = "POP3 TOP Sent"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kPOP3STATFailed = "POP3 STAT Failed"
		self.kPOP3Transactions = "POP3 Transactions"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kPOP3SessionsRequested = "POP3 Sessions Requested"
		self.kRxRateKbps = "Rx Rate (Kbps)"
		self.kAuthenticationsSent = "Authentications Sent"
		self.kPOP3MailsReceived = "POP3 Mails Received"
		self.kPOP3ClientTotalDataIntegrityCheckFailed = "POP3 Client Total Data Integrity Check Failed"
		self.kConnectionRate = "Connection Rate"
		self.kSessionsEstablisheds = "Sessions Established/s"
		self.kPOP3TotalBytesSent = "POP3 Total Bytes Sent"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kResetsReceived = "Resets Received"
		self.kFINACKsSent = "FIN-ACKs Sent"
		self.kPOP3UIDLSent = "POP3 UIDL Sent"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kPOP3QUITOk = "POP3 QUIT Ok"
		self.kPOP3NOOPOk = "POP3 NOOP Ok"
		self.kPOP3SessionsEstablished = "POP3 Sessions Established"
		self.kPOP3NOOPSent = "POP3 NOOP Sent"
		self.kPOP3RETRFailed = "POP3 RETR Failed"
		self.kSessionsFailed = "Sessions Failed"
		self.kPOP3DELEFailed = "POP3 DELE Failed"
		self.kPOP3DELEOk = "POP3 DELE Ok"
		self.kPOP3UIDLOk = "POP3 UIDL Ok"
		self.kPOP3TotalBytesReceived = "POP3 Total Bytes Received"
		self.kTCPFINReceived = "TCP FIN Received"


class StatsNamePOP3Server(object):
	def __init__(self):
		self.kSessionRequestsFailed = "Session Requests Failed"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kSessionRequestsSuccs = "Session Requests Succ/s"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kPOP3NOOPCmdsReceived = "POP3 NOOP Cmds Received"
		self.kSessionRequestesRecvd = "Session Requestes Recvd"
		self.kFINACKsReceived = "FIN-ACKs Received"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kFINACKsSent = "FIN-ACKs Sent"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kPOP3RSETCmdsReceived = "POP3 RSET Cmds Received"
		self.kPOP3RETRCmdsReceived = "POP3 RETR Cmds Received"
		self.kPOP3SessionRequestsReceived = "POP3 Session Requests Received"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kPOP3PASSCmdsReceived = "POP3 PASS Cmds Received"
		self.kListenQueueDrops = "Listen Queue Drops"
		self.kPOP3TotalBytesSent = "POP3 Total Bytes Sent"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kAcceptQueueEntries = "Accept Queue Entries"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kPOP3APOPCmdsReceived = "POP3 APOP Cmds Received"
		self.kResetsReceived = "Resets Received"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kTCPRetries = "TCP Retries"
		self.kFINsReceived = "FINs Received"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kPOP3LISTCmdsReceived = "POP3 LIST Cmds Received"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kTxRateKbps = "Tx Rate (Kbps)"
		self.kPOP3TOPCmdsReceived = "POP3 TOP Cmds Received"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kAttachmentsSent = "Attachments Sent"
		self.kResetsSent = "Resets Sent"
		self.kRetries = "Retries"
		self.kFINsSent = "FINs Sent"
		self.kMailsSents = "Mails Sent/s"
		self.kSYNSYNACKsReceived = "SYN/SYN-ACKs Received"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kPOP3USERCmdsReceived = "POP3 USER Cmds Received"
		self.kPOP3TotalAttachmentsSent = "POP3 Total Attachments Sent"
		self.kTimeouts = "Timeouts"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kSessionRequestsRecvds = "Session Requests Recvd/s"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kMailsWithAttachmentsSent = "Mails With Attachments Sent"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kPOP3SessionRequestsSuccessful = "POP3 Session Requests Successful"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kConnectionRequestsFailed = "Connection Requests Failed"
		self.kPOP3SessionRequestsFailed = "POP3 Session Requests Failed"
		self.kPOP3UIDLCmdsReceived = "POP3 UIDL Cmds Received"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kSYNACKsSent = "SYN-ACKs Sent"
		self.kPOP3TotalMailsSent = "POP3 Total Mails Sent"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kPOP3TotalMailsWithAttachmentsSent = "POP3 Total Mails With Attachments Sent"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kRxRateKbps = "Rx Rate (Kbps)"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kPOP3DELECmdsReceived = "POP3 DELE Cmds Received"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kSessionsRequestsFaileds = "Sessions Requests Failed/s"
		self.kMailsSent = "Mails Sent"
		self.kPOP3STATCmdsReceived = "POP3 STAT Cmds Received"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kPOP3QUITCmdsReceived = "POP3 QUIT Cmds Received"
		self.kSessionRequestsSuccessful = "Session Requests Successful"
		self.kPOP3TotalBytesReceived = "POP3 Total Bytes Received"
		self.kTCPFINReceived = "TCP FIN Received"


class IxActivityPOP3ClientWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityPOP3ClientWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.secondaryEnableConstraint = ixActivity.secondaryEnableConstraint
		self.protocol = ixActivity.protocol
		self.userIpMapping = ixActivity.userIpMapping
		self.enableConstraint = ixActivity.enableConstraint
		self.agent = PluginPOP3ClientWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.constraintValue = ixActivity.constraintValue
		self.customParameters = ixActivity.customParameters
		self.timelineId = ixActivity.timelineId
		self.role = ixActivity.role
		self.timeline = IxTimelineProxyPOP3ClientWrapper(ixActivity.timeline)
		self.activeRole = ixActivity.activeRole
		self.type = ixActivity.type
		self.secondaryConstraintValue = ixActivity.secondaryConstraintValue
		self.enable = ixActivity.enable
		self.protocolAndType = ixActivity.protocolAndType
		self.userObjectiveType = ixActivity.userObjectiveType
		self.destinationIpMapping = ixActivity.destinationIpMapping
		self.name = ixActivity.name
		self.secondaryConstraintType = ixActivity.secondaryConstraintType
		self.userObjectiveValue = ixActivity.userObjectiveValue
		self.constraintType = ixActivity.constraintType

	properties = ["secondaryEnableConstraint", "protocol", "userIpMapping", "enableConstraint", "objectivePercent", "constraintValue", "customParameters", "timelineId", "role", "activeRole", "type", "secondaryConstraintValue", "enable", "protocolAndType", "userObjectiveType", "destinationIpMapping", "name", "secondaryConstraintType", "userObjectiveValue", "constraintType", ]

	def __getattribute__(self, name):
		if name in IxActivityPOP3ClientWrapper.properties and super(IxActivityPOP3ClientWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityPOP3ClientWrapper, self).__getattribute__("_IxActivityPOP3ClientWrapper__ixActivity"), name)
		else:
			return super(IxActivityPOP3ClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityPOP3ClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityPOP3ClientWrapper, self).__getattribute__("_IxActivityPOP3ClientWrapper__ixActivity"), name, value)
			super(IxActivityPOP3ClientWrapper, self).__setattr__(name, value)


class IxActivityPOP3ServerWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityPOP3ServerWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.customParameters = ixActivity.customParameters
		self.enable = ixActivity.enable
		self.protocol = ixActivity.protocol
		self.name = ixActivity.name
		self.role = ixActivity.role
		self.agent = PluginPOP3ServerWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.protocolAndType = ixActivity.protocolAndType
		self.timeline = IxTimelineProxyPOP3ServerWrapper(ixActivity.timeline)
		self.timelineId = ixActivity.timelineId
		self.type = ixActivity.type
		self.activeRole = ixActivity.activeRole

	properties = ["customParameters", "enable", "protocol", "name", "role", "objectivePercent", "protocolAndType", "timelineId", "type", "activeRole", ]

	def __getattribute__(self, name):
		if name in IxActivityPOP3ServerWrapper.properties and super(IxActivityPOP3ServerWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityPOP3ServerWrapper, self).__getattribute__("_IxActivityPOP3ServerWrapper__ixActivity"), name)
		else:
			return super(IxActivityPOP3ServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityPOP3ServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityPOP3ServerWrapper, self).__getattribute__("_IxActivityPOP3ServerWrapper__ixActivity"), name, value)
			super(IxActivityPOP3ServerWrapper, self).__setattr__(name, value)


class PluginPOP3ClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginPOP3ClientWrapper, self).__init__(agent)
		self.__agent = agent
		self.username = agent.username
		self.cmdListLoops = agent.cmdListLoops
		self.commandTimeout = agent.commandTimeout
		self.ipPreference = agent.ipPreference
		self.flowPercentage = agent.flowPercentage
		self.vlanPriority = agent.vlanPriority
		self.enableSharedSecret = agent.enableSharedSecret
		self.commandList = Pop3CommandListPOP3ClientWrapper(agent)
		self.password = agent.password
		self.enableVlanPriority = agent.enableVlanPriority
		self.sharedSecret = agent.sharedSecret

	properties = ["username", "cmdListLoops", "commandTimeout", "ipPreference", "flowPercentage", "vlanPriority", "enableSharedSecret", "password", "enableVlanPriority", "sharedSecret", ]

	def __getattribute__(self, name):
		if name in PluginPOP3ClientWrapper.properties and super(PluginPOP3ClientWrapper, self).__getattribute__(name):
			return getattr(super(PluginPOP3ClientWrapper, self).__getattribute__("_PluginPOP3ClientWrapper__agent"), name)
		else:
			return super(PluginPOP3ClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginPOP3ClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginPOP3ClientWrapper, self).__getattribute__("_PluginPOP3ClientWrapper__agent"), name, value)
			super(PluginPOP3ClientWrapper, self).__setattr__(name, value)


class IxTimelineProxyPOP3ClientWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyPOP3ClientWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.iterations = timeline.iterations
		self.rampUpType = timeline.rampUpType
		self.rampUpValue = timeline.rampUpValue
		self.rampUpTime = timeline.rampUpTime
		self.rampDownTime = timeline.rampDownTime
		self.standbyTime = timeline.standbyTime
		self.rampDownValue = timeline.rampDownValue
		self.rampUpInterval = timeline.rampUpInterval
		self.offlineTime = timeline.offlineTime
		self.sustainTime = timeline.sustainTime
		self.name = timeline.name
		self.timelineType = timeline.timelineType

	properties = ["iterations", "rampUpType", "rampUpValue", "rampUpTime", "rampDownTime", "standbyTime", "rampDownValue", "rampUpInterval", "offlineTime", "sustainTime", "name", "timelineType", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyPOP3ClientWrapper.properties and super(IxTimelineProxyPOP3ClientWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyPOP3ClientWrapper, self).__getattribute__("_IxTimelineProxyPOP3ClientWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyPOP3ClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyPOP3ClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyPOP3ClientWrapper, self).__getattribute__("_IxTimelineProxyPOP3ClientWrapper__timeline"), name, value)
			super(IxTimelineProxyPOP3ClientWrapper, self).__setattr__(name, value)


class PluginPOP3ServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginPOP3ServerWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.Server_Listening_Port = agent.Server_Listening_Port
		self.flowPercentage = agent.flowPercentage
		self.vlanPriority = agent.vlanPriority
		self.concurrentSessionLimit = agent.concurrentSessionLimit
		self.mailBox = MailBoxPOP3ServerWrapper(agent)
		self.mailMessageList = MailMessageListPOP3ServerWrapper(agent)
		self.enableVlanPriority = agent.enableVlanPriority

	properties = ["cmdListLoops", "Server_Listening_Port", "flowPercentage", "vlanPriority", "concurrentSessionLimit", "enableVlanPriority", ]

	def __getattribute__(self, name):
		if name in PluginPOP3ServerWrapper.properties and super(PluginPOP3ServerWrapper, self).__getattribute__(name):
			return getattr(super(PluginPOP3ServerWrapper, self).__getattribute__("_PluginPOP3ServerWrapper__agent"), name)
		else:
			return super(PluginPOP3ServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginPOP3ServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginPOP3ServerWrapper, self).__getattribute__("_PluginPOP3ServerWrapper__agent"), name, value)
			super(PluginPOP3ServerWrapper, self).__setattr__(name, value)


class IxTimelineProxyPOP3ServerWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyPOP3ServerWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.name = timeline.name
		self.standbyTime = timeline.standbyTime
		self.iterations = timeline.iterations
		self.sustainTime = timeline.sustainTime

	properties = ["name", "standbyTime", "iterations", "sustainTime", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyPOP3ServerWrapper.properties and super(IxTimelineProxyPOP3ServerWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyPOP3ServerWrapper, self).__getattribute__("_IxTimelineProxyPOP3ServerWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyPOP3ServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyPOP3ServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyPOP3ServerWrapper, self).__getattribute__("_IxTimelineProxyPOP3ServerWrapper__timeline"), name, value)
			super(IxTimelineProxyPOP3ServerWrapper, self).__setattr__(name, value)


class Pop3CommandListPOP3ClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent
		self.optionsDict = {
			('UIDL',): "IxPop3CommandPOP3Client",
			('LoopBeginCommand',): "IxLoopBeginCommandPOP3Client",
			('{Get}',): "IxPop3CommandPOP3Client",
			('RETR',): "IxPop3CommandPOP3Client",
			('QUIT',): "IxPop3CommandPOP3Client",
			('OPEN',): "IxPop3CommandPOP3Client",
			('STAT',): "IxPop3CommandPOP3Client",
			('THINK',): "IxThinkCommandPOP3Client",
			('STOP',): "IxStopCommandPOP3Client",
			('DELE',): "IxPop3CommandPOP3Client",
			('TOP',): "IxPop3CommandPOP3Client",
			('LoopEndCommand',): "IxLoopEndCommandPOP3Client",
			('START',): "IxStartCommandPOP3Client",
			('LIST',): "IxPop3CommandPOP3Client",
			('RSET',): "IxPop3CommandPOP3Client",
			('NOOP',): "IxPop3CommandPOP3Client",
		}

	def getItemIxUidlCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPop3Command":
				return IxPop3CommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxUidlCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "UIDL"})
		return IxPop3CommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxLoopbegincommandCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixLoopBeginCommand":
				return IxLoopBeginCommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopbegincommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopBeginCommand"})
		return IxLoopBeginCommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxGetCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPop3Command":
				return IxPop3CommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxGetCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "{Get}"})
		return IxPop3CommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxRetrCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPop3Command":
				return IxPop3CommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxRetrCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "RETR"})
		return IxPop3CommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxQuitCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPop3Command":
				return IxPop3CommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxQuitCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "QUIT"})
		return IxPop3CommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxOpenCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPop3Command":
				return IxPop3CommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxOpenCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "OPEN"})
		return IxPop3CommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxStatCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPop3Command":
				return IxPop3CommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStatCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STAT"})
		return IxPop3CommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxThinkCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixThinkCommand":
				return IxThinkCommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxThinkCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "THINK"})
		return IxThinkCommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxStopCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixStopCommand":
				return IxStopCommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STOP"})
		return IxStopCommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxDeleCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPop3Command":
				return IxPop3CommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxDeleCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "DELE"})
		return IxPop3CommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxTopCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPop3Command":
				return IxPop3CommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxTopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "TOP"})
		return IxPop3CommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxLoopendcommandCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixLoopEndCommand":
				return IxLoopEndCommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopendcommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopEndCommand"})
		return IxLoopEndCommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxStartCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixStartCommand":
				return IxStartCommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStartCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "START"})
		return IxStartCommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxListCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPop3Command":
				return IxPop3CommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxListCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LIST"})
		return IxPop3CommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxRsetCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPop3Command":
				return IxPop3CommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxRsetCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "RSET"})
		return IxPop3CommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxNoopCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPop3Command":
				return IxPop3CommandPOP3ClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxNoopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "NOOP"})
		return IxPop3CommandPOP3ClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, commandType=None):
		kwargs = {}
		kwargs.update({"commandType": commandType})
		return self.__agent.commandList.appendItem(**kwargs)

	def getList(self):
		return self.__agent.commandList

	def clear(self):
		return self.__agent.commandList.clear()


class IxStartCommandPOP3ClientWrapper(RestObjectBaseClass):

	def __init__(self, ixStartCommand):
		super(IxStartCommandPOP3ClientWrapper, self).__init__(ixStartCommand)
		self.__ixStartCommand = ixStartCommand
		self.commandType = ixStartCommand.commandType
		self.cmdName = ixStartCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxStartCommandPOP3ClientWrapper.properties and super(IxStartCommandPOP3ClientWrapper, self).__getattribute__(name):
			return getattr(super(IxStartCommandPOP3ClientWrapper, self).__getattribute__("_IxStartCommandPOP3ClientWrapper__ixStartCommand"), name)
		else:
			return super(IxStartCommandPOP3ClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxStartCommandPOP3ClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxStartCommandPOP3ClientWrapper, self).__getattribute__("_IxStartCommandPOP3ClientWrapper__ixStartCommand"), name, value)
			super(IxStartCommandPOP3ClientWrapper, self).__setattr__(name, value)


class IxPop3CommandPOP3ClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPop3Command):
		super(IxPop3CommandPOP3ClientWrapper, self).__init__(ixPop3Command)
		self.__ixPop3Command = ixPop3Command
		self.enableDataIntegrity = ixPop3Command.enableDataIntegrity
		self.cmdName = ixPop3Command.cmdName
		self.commandType = ixPop3Command.commandType
		self.arguments = ixPop3Command.arguments

	properties = ["enableDataIntegrity", "cmdName", "commandType", "arguments", ]

	def __getattribute__(self, name):
		if name in IxPop3CommandPOP3ClientWrapper.properties and super(IxPop3CommandPOP3ClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPop3CommandPOP3ClientWrapper, self).__getattribute__("_IxPop3CommandPOP3ClientWrapper__ixPop3Command"), name)
		else:
			return super(IxPop3CommandPOP3ClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPop3CommandPOP3ClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPop3CommandPOP3ClientWrapper, self).__getattribute__("_IxPop3CommandPOP3ClientWrapper__ixPop3Command"), name, value)
			super(IxPop3CommandPOP3ClientWrapper, self).__setattr__(name, value)


class IxLoopBeginCommandPOP3ClientWrapper(RestObjectBaseClass):

	def __init__(self, ixLoopBeginCommand):
		super(IxLoopBeginCommandPOP3ClientWrapper, self).__init__(ixLoopBeginCommand)
		self.__ixLoopBeginCommand = ixLoopBeginCommand
		self.commandType = ixLoopBeginCommand.commandType
		self.cmdName = ixLoopBeginCommand.cmdName
		self.LoopCount = ixLoopBeginCommand.LoopCount

	properties = ["commandType", "cmdName", "LoopCount", ]

	def __getattribute__(self, name):
		if name in IxLoopBeginCommandPOP3ClientWrapper.properties and super(IxLoopBeginCommandPOP3ClientWrapper, self).__getattribute__(name):
			return getattr(super(IxLoopBeginCommandPOP3ClientWrapper, self).__getattribute__("_IxLoopBeginCommandPOP3ClientWrapper__ixLoopBeginCommand"), name)
		else:
			return super(IxLoopBeginCommandPOP3ClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxLoopBeginCommandPOP3ClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxLoopBeginCommandPOP3ClientWrapper, self).__getattribute__("_IxLoopBeginCommandPOP3ClientWrapper__ixLoopBeginCommand"), name, value)
			super(IxLoopBeginCommandPOP3ClientWrapper, self).__setattr__(name, value)


class IxLoopEndCommandPOP3ClientWrapper(RestObjectBaseClass):

	def __init__(self, ixLoopEndCommand):
		super(IxLoopEndCommandPOP3ClientWrapper, self).__init__(ixLoopEndCommand)
		self.__ixLoopEndCommand = ixLoopEndCommand
		self.commandType = ixLoopEndCommand.commandType
		self.cmdName = ixLoopEndCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxLoopEndCommandPOP3ClientWrapper.properties and super(IxLoopEndCommandPOP3ClientWrapper, self).__getattribute__(name):
			return getattr(super(IxLoopEndCommandPOP3ClientWrapper, self).__getattribute__("_IxLoopEndCommandPOP3ClientWrapper__ixLoopEndCommand"), name)
		else:
			return super(IxLoopEndCommandPOP3ClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxLoopEndCommandPOP3ClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxLoopEndCommandPOP3ClientWrapper, self).__getattribute__("_IxLoopEndCommandPOP3ClientWrapper__ixLoopEndCommand"), name, value)
			super(IxLoopEndCommandPOP3ClientWrapper, self).__setattr__(name, value)


class IxThinkCommandPOP3ClientWrapper(RestObjectBaseClass):

	def __init__(self, ixThinkCommand):
		super(IxThinkCommandPOP3ClientWrapper, self).__init__(ixThinkCommand)
		self.__ixThinkCommand = ixThinkCommand
		self.minimumInterval = ixThinkCommand.minimumInterval
		self.cmdName = ixThinkCommand.cmdName
		self.commandType = ixThinkCommand.commandType
		self.maximumInterval = ixThinkCommand.maximumInterval

	properties = ["minimumInterval", "cmdName", "commandType", "maximumInterval", ]

	def __getattribute__(self, name):
		if name in IxThinkCommandPOP3ClientWrapper.properties and super(IxThinkCommandPOP3ClientWrapper, self).__getattribute__(name):
			return getattr(super(IxThinkCommandPOP3ClientWrapper, self).__getattribute__("_IxThinkCommandPOP3ClientWrapper__ixThinkCommand"), name)
		else:
			return super(IxThinkCommandPOP3ClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxThinkCommandPOP3ClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxThinkCommandPOP3ClientWrapper, self).__getattribute__("_IxThinkCommandPOP3ClientWrapper__ixThinkCommand"), name, value)
			super(IxThinkCommandPOP3ClientWrapper, self).__setattr__(name, value)


class IxStopCommandPOP3ClientWrapper(RestObjectBaseClass):

	def __init__(self, ixStopCommand):
		super(IxStopCommandPOP3ClientWrapper, self).__init__(ixStopCommand)
		self.__ixStopCommand = ixStopCommand
		self.commandType = ixStopCommand.commandType
		self.cmdName = ixStopCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxStopCommandPOP3ClientWrapper.properties and super(IxStopCommandPOP3ClientWrapper, self).__getattribute__(name):
			return getattr(super(IxStopCommandPOP3ClientWrapper, self).__getattribute__("_IxStopCommandPOP3ClientWrapper__ixStopCommand"), name)
		else:
			return super(IxStopCommandPOP3ClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxStopCommandPOP3ClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxStopCommandPOP3ClientWrapper, self).__getattribute__("_IxStopCommandPOP3ClientWrapper__ixStopCommand"), name, value)
			super(IxStopCommandPOP3ClientWrapper, self).__setattr__(name, value)


class MailBoxPOP3ServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent

	def getItem(self, objectID):
		itemList = self.__agent.mailBox
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "MailBoxItem":
				return MailBoxItemPOP3ServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return MailBoxItemPOP3ServerWrapper(self.__agent.mailBox.appendItem(**kwargs))

	def getList(self):
		return self.__agent.mailBox

	def clear(self):
		return self.__agent.mailBox.clear()


class MailBoxItemPOP3ServerWrapper(RestObjectBaseClass):

	def __init__(self, MailBoxItem):
		super(MailBoxItemPOP3ServerWrapper, self).__init__(MailBoxItem)
		self.__MailBoxItem = MailBoxItem
		self.count = MailBoxItem.count
		self.mailMessageId = MailBoxItem.mailMessageId

	properties = ["count", "mailMessageId", ]

	def __getattribute__(self, name):
		if name in MailBoxItemPOP3ServerWrapper.properties and super(MailBoxItemPOP3ServerWrapper, self).__getattribute__(name):
			return getattr(super(MailBoxItemPOP3ServerWrapper, self).__getattribute__("_MailBoxItemPOP3ServerWrapper__MailBoxItem"), name)
		else:
			return super(MailBoxItemPOP3ServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(MailBoxItemPOP3ServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(MailBoxItemPOP3ServerWrapper, self).__getattribute__("_MailBoxItemPOP3ServerWrapper__MailBoxItem"), name, value)
			super(MailBoxItemPOP3ServerWrapper, self).__setattr__(name, value)


class MailMessageListPOP3ServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent

	def getItem(self, objectID):
		itemList = self.__agent.mailMessageList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "MailMessage":
				return MailMessagePOP3ServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return MailMessagePOP3ServerWrapper(self.__agent.mailMessageList.appendItem(**kwargs))

	def getList(self):
		return self.__agent.mailMessageList

	def clear(self):
		return self.__agent.mailMessageList.clear()


class MailMessagePOP3ServerWrapper(RestObjectBaseClass):

	def __init__(self, MailMessage):
		super(MailMessagePOP3ServerWrapper, self).__init__(MailMessage)
		self.__MailMessage = MailMessage
		self.bodySizeType = MailMessage.bodySizeType
		self.textContentAsBody = MailMessage.textContentAsBody
		self.fileNameAsBody = MailMessage.fileNameAsBody
		self.enablePatternGen = MailMessage.enablePatternGen
		self.mimeTypeAndEncode = MailMessage.mimeTypeAndEncode
		self.description = MailMessage.description
		self.bodySizeRandomMax = MailMessage.bodySizeRandomMax
		self.bodySizeFixed = MailMessage.bodySizeFixed
		self.headerList = HeaderListPOP3ServerWrapper(MailMessage)
		self.readOnly = MailMessage.readOnly
		self.bodySizeRandomMin = MailMessage.bodySizeRandomMin
		self.bodyDataType = MailMessage.bodyDataType
		self.useFileAsBody = MailMessage.useFileAsBody
		self.bodyFormat = MailMessage.bodyFormat
		self.name = MailMessage.name

	properties = ["bodySizeType", "textContentAsBody", "fileNameAsBody", "enablePatternGen", "mimeTypeAndEncode", "description", "bodySizeRandomMax", "bodySizeFixed", "readOnly", "bodySizeRandomMin", "bodyDataType", "useFileAsBody", "bodyFormat", "name", ]

	def __getattribute__(self, name):
		if name in MailMessagePOP3ServerWrapper.properties and super(MailMessagePOP3ServerWrapper, self).__getattribute__(name):
			return getattr(super(MailMessagePOP3ServerWrapper, self).__getattribute__("_MailMessagePOP3ServerWrapper__MailMessage"), name)
		else:
			return super(MailMessagePOP3ServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(MailMessagePOP3ServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(MailMessagePOP3ServerWrapper, self).__getattribute__("_MailMessagePOP3ServerWrapper__MailMessage"), name, value)
			super(MailMessagePOP3ServerWrapper, self).__setattr__(name, value)


class HeaderListPOP3ServerWrapper(RestObjectBaseClass):

	def __init__(self, MailMessage):
		self.__MailMessage = MailMessage

	def getItem(self, objectID):
		itemList = self.__MailMessage.headerList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "Header":
				return HeaderPOP3ServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return HeaderPOP3ServerWrapper(self.__MailMessage.headerList.appendItem(**kwargs))

	def getList(self):
		return self.__MailMessage.headerList

	def clear(self):
		return self.__MailMessage.headerList.clear()


class HeaderPOP3ServerWrapper(RestObjectBaseClass):

	def __init__(self, Header):
		super(HeaderPOP3ServerWrapper, self).__init__(Header)
		self.__Header = Header
		self.isCustomHdr = Header.isCustomHdr
		self.name = Header.name
		self.value = Header.value

	properties = ["isCustomHdr", "name", "value", ]

	def __getattribute__(self, name):
		if name in HeaderPOP3ServerWrapper.properties and super(HeaderPOP3ServerWrapper, self).__getattribute__(name):
			return getattr(super(HeaderPOP3ServerWrapper, self).__getattribute__("_HeaderPOP3ServerWrapper__Header"), name)
		else:
			return super(HeaderPOP3ServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(HeaderPOP3ServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(HeaderPOP3ServerWrapper, self).__getattribute__("_HeaderPOP3ServerWrapper__Header"), name, value)
			super(HeaderPOP3ServerWrapper, self).__setattr__(name, value)


class AttachmentListPOP3ServerWrapper(RestObjectBaseClass):

	def __init__(self, MailMessage):
		self.__MailMessage = MailMessage

	def getItem(self, objectID):
		itemList = self.__MailMessage.attachmentList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "Attachment":
				return AttachmentPOP3ServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return AttachmentPOP3ServerWrapper(self.__MailMessage.attachmentList.appendItem(**kwargs))

	def getList(self):
		return self.__MailMessage.attachmentList

	def clear(self):
		return self.__MailMessage.attachmentList.clear()


class AttachmentPOP3ServerWrapper(RestObjectBaseClass):

	def __init__(self, Attachment):
		super(AttachmentPOP3ServerWrapper, self).__init__(Attachment)
		self.__Attachment = Attachment
		self.sizeMax = Attachment.sizeMax
		self.countMax = Attachment.countMax
		self.dataType = Attachment.dataType
		self.countMin = Attachment.countMin
		self.fileName = Attachment.fileName
		self.attchStr = Attachment.attchStr
		self.type = Attachment.type
		self.sizeMin = Attachment.sizeMin

	properties = ["sizeMax", "countMax", "dataType", "countMin", "fileName", "attchStr", "type", "sizeMin", ]

	def __getattribute__(self, name):
		if name in AttachmentPOP3ServerWrapper.properties and super(AttachmentPOP3ServerWrapper, self).__getattribute__(name):
			return getattr(super(AttachmentPOP3ServerWrapper, self).__getattribute__("_AttachmentPOP3ServerWrapper__Attachment"), name)
		else:
			return super(AttachmentPOP3ServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(AttachmentPOP3ServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(AttachmentPOP3ServerWrapper, self).__getattribute__("_AttachmentPOP3ServerWrapper__Attachment"), name, value)
			super(AttachmentPOP3ServerWrapper, self).__setattr__(name, value)


class StatsNameSMTPServer(object):
	def __init__(self):
		self.kSessionRequestsFailed = "Session Requests Failed"
		self.kMailsReceived = "Mails Received"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kSessionRequestsSuccs = "Session Requests Succ/s"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kSMTPSessionRequestsReceived = "SMTP Session Requests Received"
		self.kSMTPSessionRequestsSuccessful = "SMTP Session Requests Successful"
		self.kFINACKsReceived = "FIN-ACKs Received"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kSMTPNOOPReceived = "SMTP NOOP Received"
		self.kBytesSents = "Bytes Sent/s"
		self.kTimeouts = "Timeouts"
		self.kAcceptQueueEntries = "Accept Queue Entries"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kSYNSYNACKsReceived = "SYN/SYN-ACKs Received"
		self.kSMTPRSETReceived = "SMTP RSET Received"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kSMTPHELOReceived = "SMTP HELO Received"
		self.kSMTPRCPTReceived = "SMTP RCPT Received"
		self.kResetsReceived = "Resets Received"
		self.kTCPRetries = "TCP Retries"
		self.kFINACKsSent = "FIN-ACKs Sent"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kMailsReceiveds = "Mails Received/s"
		self.kResetsSent = "Resets Sent"
		self.kRetries = "Retries"
		self.kSMTPTotalBytesReceived = "SMTP Total Bytes Received"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kConnectionRequestsFailed = "Connection Requests Failed"
		self.kBytesReceiveds = "Bytes Received/s"
		self.kSMTPDATAReceived = "SMTP DATA Received"
		self.kSessionRequestsRecvds = "Session Requests Recvd/s"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kSMTPMailBytesReceived = "SMTP Mail Bytes Received"
		self.kSMTPMailsReceived = "SMTP Mails Received"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kSessionRequestesRecvd = "Session Requestes Recvd"
		self.kFINsSent = "FINs Sent"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kSMTPQUITReceived = "SMTP QUIT Received"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kSMTPEHLOReceived = "SMTP EHLO Received"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kSYNACKsSent = "SYN-ACKs Sent"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kSMTPTotalBytesSent = "SMTP Total Bytes Sent"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kSMTPSessionRequestsFailed = "SMTP Session Requests Failed"
		self.kFINsReceived = "FINs Received"
		self.kListenQueueDrops = "Listen Queue Drops"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kSessionsRequestsFaileds = "Sessions Requests Failed/s"
		self.kSessionRequestsSuccessful = "Session Requests Successful"
		self.kSMTPMAILReceived = "SMTP MAIL Received"
		self.kTCPFINReceived = "TCP FIN Received"


class StatsNameSMTPClient(object):
	def __init__(self):
		self.kSessionsEstablished = "Sessions Established"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kSMTPRSETOk = "SMTP RSET Ok"
		self.kSMTPConnections = "SMTP Connections"
		self.kSMTPSessionsRequested = "SMTP Sessions Requested"
		self.kSYNSYNACKsReceived = "SYN/SYN-ACKs Received"
		self.kSMTPDATASent = "SMTP DATA Sent"
		self.kSMTPQUITOk = "SMTP QUIT Ok"
		self.kSMTPBytes = "SMTP Bytes"
		self.kTCPRetries = "TCP Retries"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kResetsSent = "Resets Sent"
		self.kSMTPTotalBytesReceived = "SMTP Total Bytes Received"
		self.kTimeouts = "Timeouts"
		self.kThroughputKbps = "Throughput (Kbps)"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kFINsSent = "FINs Sent"
		self.kSMTPTotalAttachmentsSent = "SMTP Total Attachments Sent"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kSMTPSimulatedUsers = "SMTP Simulated Users"
		self.kFINsReceived = "FINs Received"
		self.kSMTPSessionsEstablished = "SMTP Sessions Established"
		self.kConcurrentConnections = "Concurrent Connections"
		self.kFINACKsReceived = "FIN-ACKs Received"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kSMTPHELOOk = "SMTP HELO Ok"
		self.kSMTPEHLOOk = "SMTP EHLO Ok"
		self.kSMTPMessagesFailed = "SMTP Messages Failed"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kSessionsRequested = "Sessions Requested"
		self.kSMTPSessionsActive = "SMTP Sessions Active"
		self.kSessionsFaileds = "Sessions Failed/s"
		self.kSMTPQUITFailed = "SMTP QUIT Failed"
		self.kSimulatedUsers = "Simulated Users"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kTransactionRate = "Transaction Rate"
		self.kSMTPRSETFailed = "SMTP RSET Failed"
		self.kSMTPRSETSent = "SMTP RSET Sent"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kSessionsRequesteds = "Sessions Requested/s"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kSMTPNOOPSent = "SMTP NOOP Sent"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kSMTPRCPTFailed = "SMTP RCPT Failed"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kSMTPTotalBytesSent = "SMTP Total Bytes Sent"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kSMTPEHLOFailed = "SMTP EHLO Failed"
		self.kSMTPRCPTSent = "SMTP RCPT Sent"
		self.kSMTPTransactions = "SMTP Transactions"
		self.kSMTPMAILFailed = "SMTP MAIL Failed"
		self.kSMTPMessageTimeouts = "SMTP Message Timeouts"
		self.kSMTPMailsSent = "SMTP Mails Sent"
		self.kSYNsSent = "SYNs Sent"
		self.kAttachmentsSents = "Attachments Sent/s"
		self.kSMTPMAILOk = "SMTP MAIL Ok"
		self.kSMTPNOOPFailed = "SMTP NOOP Failed"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kTxRateKbps = "Tx Rate (Kbps)"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kSMTPSessionsFailed = "SMTP Sessions Failed"
		self.kMailsSents = "Mails Sent/s"
		self.kRetries = "Retries"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kSMTPMAILSent = "SMTP MAIL Sent"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kSMTPHELOSent = "SMTP HELO Sent"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kMailsWithAttachments = "Mails With Attachments"
		self.kRxRateKbps = "Rx Rate (Kbps)"
		self.kSMTPRCPTOk = "SMTP RCPT Ok"
		self.kSMTPTotalMailsWithAttachmentsSent = "SMTP Total Mails With Attachments Sent"
		self.kConnectionRate = "Connection Rate"
		self.kSMTPConcurrentConnections = "SMTP Concurrent Connections"
		self.kSessionsEstablisheds = "Sessions Established/s"
		self.kSMTPHELOFailed = "SMTP HELO Failed"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kResetsReceived = "Resets Received"
		self.kFINACKsSent = "FIN-ACKs Sent"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kAttachmentsSent = "Attachments Sent"
		self.kSMTPEHLOSent = "SMTP EHLO Sent"
		self.kSMTPDATAFailed = "SMTP DATA Failed"
		self.kSessionsFailed = "Sessions Failed"
		self.kSMTPDATAOk = "SMTP DATA Ok"
		self.kSMTPQUITSent = "SMTP QUIT Sent"
		self.kSMTPNOOPOk = "SMTP NOOP Ok"
		self.kMailsSent = "Mails Sent"
		self.kTCPFINReceived = "TCP FIN Received"


class IxActivitySMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivitySMTPClientWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.secondaryEnableConstraint = ixActivity.secondaryEnableConstraint
		self.protocol = ixActivity.protocol
		self.userIpMapping = ixActivity.userIpMapping
		self.enableConstraint = ixActivity.enableConstraint
		self.agent = PluginSMTPClientWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.constraintValue = ixActivity.constraintValue
		self.customParameters = ixActivity.customParameters
		self.timelineId = ixActivity.timelineId
		self.role = ixActivity.role
		self.timeline = IxTimelineProxySMTPClientWrapper(ixActivity.timeline)
		self.activeRole = ixActivity.activeRole
		self.type = ixActivity.type
		self.secondaryConstraintValue = ixActivity.secondaryConstraintValue
		self.enable = ixActivity.enable
		self.protocolAndType = ixActivity.protocolAndType
		self.userObjectiveType = ixActivity.userObjectiveType
		self.destinationIpMapping = ixActivity.destinationIpMapping
		self.name = ixActivity.name
		self.secondaryConstraintType = ixActivity.secondaryConstraintType
		self.userObjectiveValue = ixActivity.userObjectiveValue
		self.constraintType = ixActivity.constraintType

	properties = ["secondaryEnableConstraint", "protocol", "userIpMapping", "enableConstraint", "objectivePercent", "constraintValue", "customParameters", "timelineId", "role", "activeRole", "type", "secondaryConstraintValue", "enable", "protocolAndType", "userObjectiveType", "destinationIpMapping", "name", "secondaryConstraintType", "userObjectiveValue", "constraintType", ]

	def __getattribute__(self, name):
		if name in IxActivitySMTPClientWrapper.properties and super(IxActivitySMTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxActivitySMTPClientWrapper, self).__getattribute__("_IxActivitySMTPClientWrapper__ixActivity"), name)
		else:
			return super(IxActivitySMTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivitySMTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivitySMTPClientWrapper, self).__getattribute__("_IxActivitySMTPClientWrapper__ixActivity"), name, value)
			super(IxActivitySMTPClientWrapper, self).__setattr__(name, value)


class IxActivitySMTPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivitySMTPServerWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.customParameters = ixActivity.customParameters
		self.enable = ixActivity.enable
		self.protocol = ixActivity.protocol
		self.name = ixActivity.name
		self.role = ixActivity.role
		self.agent = PluginSMTPServerWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.protocolAndType = ixActivity.protocolAndType
		self.timeline = IxTimelineProxySMTPServerWrapper(ixActivity.timeline)
		self.timelineId = ixActivity.timelineId
		self.type = ixActivity.type
		self.activeRole = ixActivity.activeRole

	properties = ["customParameters", "enable", "protocol", "name", "role", "objectivePercent", "protocolAndType", "timelineId", "type", "activeRole", ]

	def __getattribute__(self, name):
		if name in IxActivitySMTPServerWrapper.properties and super(IxActivitySMTPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxActivitySMTPServerWrapper, self).__getattribute__("_IxActivitySMTPServerWrapper__ixActivity"), name)
		else:
			return super(IxActivitySMTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivitySMTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivitySMTPServerWrapper, self).__getattribute__("_IxActivitySMTPServerWrapper__ixActivity"), name, value)
			super(IxActivitySMTPServerWrapper, self).__setattr__(name, value)


class PluginSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginSMTPClientWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.commandTimeout = agent.commandTimeout
		self.ipPreference = agent.ipPreference
		self.flowPercentage = agent.flowPercentage
		self.vlanPriority = agent.vlanPriority
		self.commandList = SmtpCommandListSMTPClientWrapper(agent)
		self.helloType = agent.helloType
		self.mailMessageList = MailMessageListSMTPClientWrapper(agent)
		self.enableVlanPriority = agent.enableVlanPriority

	properties = ["cmdListLoops", "commandTimeout", "ipPreference", "flowPercentage", "vlanPriority", "helloType", "enableVlanPriority", ]

	def __getattribute__(self, name):
		if name in PluginSMTPClientWrapper.properties and super(PluginSMTPClientWrapper, self).__getattribute__(name):
			return getattr(super(PluginSMTPClientWrapper, self).__getattribute__("_PluginSMTPClientWrapper__agent"), name)
		else:
			return super(PluginSMTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginSMTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginSMTPClientWrapper, self).__getattribute__("_PluginSMTPClientWrapper__agent"), name, value)
			super(PluginSMTPClientWrapper, self).__setattr__(name, value)


class IxTimelineProxySMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxySMTPClientWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.iterations = timeline.iterations
		self.rampUpType = timeline.rampUpType
		self.rampUpValue = timeline.rampUpValue
		self.rampUpTime = timeline.rampUpTime
		self.rampDownTime = timeline.rampDownTime
		self.standbyTime = timeline.standbyTime
		self.rampDownValue = timeline.rampDownValue
		self.rampUpInterval = timeline.rampUpInterval
		self.offlineTime = timeline.offlineTime
		self.sustainTime = timeline.sustainTime
		self.name = timeline.name
		self.timelineType = timeline.timelineType

	properties = ["iterations", "rampUpType", "rampUpValue", "rampUpTime", "rampDownTime", "standbyTime", "rampDownValue", "rampUpInterval", "offlineTime", "sustainTime", "name", "timelineType", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxySMTPClientWrapper.properties and super(IxTimelineProxySMTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxySMTPClientWrapper, self).__getattribute__("_IxTimelineProxySMTPClientWrapper__timeline"), name)
		else:
			return super(IxTimelineProxySMTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxySMTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxySMTPClientWrapper, self).__getattribute__("_IxTimelineProxySMTPClientWrapper__timeline"), name, value)
			super(IxTimelineProxySMTPClientWrapper, self).__setattr__(name, value)


class PluginSMTPServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginSMTPServerWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.Server_Listening_Port = agent.Server_Listening_Port
		self.flowPercentage = agent.flowPercentage
		self.vlanPriority = agent.vlanPriority
		self.concurrentSessionLimit = agent.concurrentSessionLimit
		self.enableVlanPriority = agent.enableVlanPriority

	properties = ["cmdListLoops", "Server_Listening_Port", "flowPercentage", "vlanPriority", "concurrentSessionLimit", "enableVlanPriority", ]

	def __getattribute__(self, name):
		if name in PluginSMTPServerWrapper.properties and super(PluginSMTPServerWrapper, self).__getattribute__(name):
			return getattr(super(PluginSMTPServerWrapper, self).__getattribute__("_PluginSMTPServerWrapper__agent"), name)
		else:
			return super(PluginSMTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginSMTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginSMTPServerWrapper, self).__getattribute__("_PluginSMTPServerWrapper__agent"), name, value)
			super(PluginSMTPServerWrapper, self).__setattr__(name, value)


class IxTimelineProxySMTPServerWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxySMTPServerWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.name = timeline.name
		self.standbyTime = timeline.standbyTime
		self.iterations = timeline.iterations
		self.sustainTime = timeline.sustainTime

	properties = ["name", "standbyTime", "iterations", "sustainTime", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxySMTPServerWrapper.properties and super(IxTimelineProxySMTPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxySMTPServerWrapper, self).__getattribute__("_IxTimelineProxySMTPServerWrapper__timeline"), name)
		else:
			return super(IxTimelineProxySMTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxySMTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxySMTPServerWrapper, self).__getattribute__("_IxTimelineProxySMTPServerWrapper__timeline"), name, value)
			super(IxTimelineProxySMTPServerWrapper, self).__setattr__(name, value)


class SmtpCommandListSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent
		self.optionsDict = {
			('LoopBeginCommand',): "IxLoopBeginCommandSMTPClient",
			('QUIT',): "IxSmtpCommandSMTPClient",
			('OPEN',): "IxSmtpCommandSMTPClient",
			('THINK',): "IxThinkCommandSMTPClient",
			('{Send}',): "IxSmtpCommandSMTPClient",
			('LoopEndCommand',): "IxLoopEndCommandSMTPClient",
			('START',): "IxStartCommandSMTPClient",
			('STOP',): "IxStopCommandSMTPClient",
			('RSET',): "IxSmtpCommandSMTPClient",
			('MAIL',): "IxSmtpCommandSMTPClient",
			('NOOP',): "IxSmtpCommandSMTPClient",
		}

	def getItemIxLoopbegincommandCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixLoopBeginCommand":
				return IxLoopBeginCommandSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopbegincommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopBeginCommand"})
		return IxLoopBeginCommandSMTPClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxQuitCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixSmtpCommand":
				return IxSmtpCommandSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxQuitCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "QUIT"})
		return IxSmtpCommandSMTPClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxOpenCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixSmtpCommand":
				return IxSmtpCommandSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxOpenCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "OPEN"})
		return IxSmtpCommandSMTPClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxThinkCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixThinkCommand":
				return IxThinkCommandSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxThinkCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "THINK"})
		return IxThinkCommandSMTPClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxSendCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixSmtpCommand":
				return IxSmtpCommandSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxSendCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "{Send}"})
		return IxSmtpCommandSMTPClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxLoopendcommandCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixLoopEndCommand":
				return IxLoopEndCommandSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopendcommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopEndCommand"})
		return IxLoopEndCommandSMTPClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxStartCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixStartCommand":
				return IxStartCommandSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStartCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "START"})
		return IxStartCommandSMTPClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxStopCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixStopCommand":
				return IxStopCommandSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STOP"})
		return IxStopCommandSMTPClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxRsetCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixSmtpCommand":
				return IxSmtpCommandSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxRsetCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "RSET"})
		return IxSmtpCommandSMTPClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxMailCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixSmtpCommand":
				return IxSmtpCommandSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxMailCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "MAIL"})
		return IxSmtpCommandSMTPClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItemIxNoopCommand(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixSmtpCommand":
				return IxSmtpCommandSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxNoopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "NOOP"})
		return IxSmtpCommandSMTPClientWrapper(self.__agent.commandList.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__agent.commandList
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, commandType=None):
		kwargs = {}
		kwargs.update({"commandType": commandType})
		return self.__agent.commandList.appendItem(**kwargs)

	def getList(self):
		return self.__agent.commandList

	def clear(self):
		return self.__agent.commandList.clear()


class IxStartCommandSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixStartCommand):
		super(IxStartCommandSMTPClientWrapper, self).__init__(ixStartCommand)
		self.__ixStartCommand = ixStartCommand
		self.commandType = ixStartCommand.commandType
		self.cmdName = ixStartCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxStartCommandSMTPClientWrapper.properties and super(IxStartCommandSMTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxStartCommandSMTPClientWrapper, self).__getattribute__("_IxStartCommandSMTPClientWrapper__ixStartCommand"), name)
		else:
			return super(IxStartCommandSMTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxStartCommandSMTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxStartCommandSMTPClientWrapper, self).__getattribute__("_IxStartCommandSMTPClientWrapper__ixStartCommand"), name, value)
			super(IxStartCommandSMTPClientWrapper, self).__setattr__(name, value)


class IxSmtpCommandSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixSmtpCommand):
		super(IxSmtpCommandSMTPClientWrapper, self).__init__(ixSmtpCommand)
		self.__ixSmtpCommand = ixSmtpCommand
		self.mailMessageId = ixSmtpCommand.mailMessageId
		self.destination = ixSmtpCommand.destination
		self.cmdName = ixSmtpCommand.cmdName
		self.commandType = ixSmtpCommand.commandType
		self.arguments = ixSmtpCommand.arguments

	properties = ["mailMessageId", "destination", "cmdName", "commandType", "arguments", ]

	def __getattribute__(self, name):
		if name in IxSmtpCommandSMTPClientWrapper.properties and super(IxSmtpCommandSMTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxSmtpCommandSMTPClientWrapper, self).__getattribute__("_IxSmtpCommandSMTPClientWrapper__ixSmtpCommand"), name)
		else:
			return super(IxSmtpCommandSMTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxSmtpCommandSMTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxSmtpCommandSMTPClientWrapper, self).__getattribute__("_IxSmtpCommandSMTPClientWrapper__ixSmtpCommand"), name, value)
			super(IxSmtpCommandSMTPClientWrapper, self).__setattr__(name, value)


class IxLoopBeginCommandSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixLoopBeginCommand):
		super(IxLoopBeginCommandSMTPClientWrapper, self).__init__(ixLoopBeginCommand)
		self.__ixLoopBeginCommand = ixLoopBeginCommand
		self.commandType = ixLoopBeginCommand.commandType
		self.cmdName = ixLoopBeginCommand.cmdName
		self.LoopCount = ixLoopBeginCommand.LoopCount

	properties = ["commandType", "cmdName", "LoopCount", ]

	def __getattribute__(self, name):
		if name in IxLoopBeginCommandSMTPClientWrapper.properties and super(IxLoopBeginCommandSMTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxLoopBeginCommandSMTPClientWrapper, self).__getattribute__("_IxLoopBeginCommandSMTPClientWrapper__ixLoopBeginCommand"), name)
		else:
			return super(IxLoopBeginCommandSMTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxLoopBeginCommandSMTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxLoopBeginCommandSMTPClientWrapper, self).__getattribute__("_IxLoopBeginCommandSMTPClientWrapper__ixLoopBeginCommand"), name, value)
			super(IxLoopBeginCommandSMTPClientWrapper, self).__setattr__(name, value)


class IxLoopEndCommandSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixLoopEndCommand):
		super(IxLoopEndCommandSMTPClientWrapper, self).__init__(ixLoopEndCommand)
		self.__ixLoopEndCommand = ixLoopEndCommand
		self.commandType = ixLoopEndCommand.commandType
		self.cmdName = ixLoopEndCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxLoopEndCommandSMTPClientWrapper.properties and super(IxLoopEndCommandSMTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxLoopEndCommandSMTPClientWrapper, self).__getattribute__("_IxLoopEndCommandSMTPClientWrapper__ixLoopEndCommand"), name)
		else:
			return super(IxLoopEndCommandSMTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxLoopEndCommandSMTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxLoopEndCommandSMTPClientWrapper, self).__getattribute__("_IxLoopEndCommandSMTPClientWrapper__ixLoopEndCommand"), name, value)
			super(IxLoopEndCommandSMTPClientWrapper, self).__setattr__(name, value)


class IxThinkCommandSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixThinkCommand):
		super(IxThinkCommandSMTPClientWrapper, self).__init__(ixThinkCommand)
		self.__ixThinkCommand = ixThinkCommand
		self.minimumInterval = ixThinkCommand.minimumInterval
		self.cmdName = ixThinkCommand.cmdName
		self.commandType = ixThinkCommand.commandType
		self.maximumInterval = ixThinkCommand.maximumInterval

	properties = ["minimumInterval", "cmdName", "commandType", "maximumInterval", ]

	def __getattribute__(self, name):
		if name in IxThinkCommandSMTPClientWrapper.properties and super(IxThinkCommandSMTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxThinkCommandSMTPClientWrapper, self).__getattribute__("_IxThinkCommandSMTPClientWrapper__ixThinkCommand"), name)
		else:
			return super(IxThinkCommandSMTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxThinkCommandSMTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxThinkCommandSMTPClientWrapper, self).__getattribute__("_IxThinkCommandSMTPClientWrapper__ixThinkCommand"), name, value)
			super(IxThinkCommandSMTPClientWrapper, self).__setattr__(name, value)


class IxStopCommandSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixStopCommand):
		super(IxStopCommandSMTPClientWrapper, self).__init__(ixStopCommand)
		self.__ixStopCommand = ixStopCommand
		self.commandType = ixStopCommand.commandType
		self.cmdName = ixStopCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxStopCommandSMTPClientWrapper.properties and super(IxStopCommandSMTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxStopCommandSMTPClientWrapper, self).__getattribute__("_IxStopCommandSMTPClientWrapper__ixStopCommand"), name)
		else:
			return super(IxStopCommandSMTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxStopCommandSMTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxStopCommandSMTPClientWrapper, self).__getattribute__("_IxStopCommandSMTPClientWrapper__ixStopCommand"), name, value)
			super(IxStopCommandSMTPClientWrapper, self).__setattr__(name, value)


class MailMessageListSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent

	def getItem(self, objectID):
		itemList = self.__agent.mailMessageList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "MailMessage":
				return MailMessageSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return MailMessageSMTPClientWrapper(self.__agent.mailMessageList.appendItem(**kwargs))

	def getList(self):
		return self.__agent.mailMessageList

	def clear(self):
		return self.__agent.mailMessageList.clear()


class MailMessageSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, MailMessage):
		super(MailMessageSMTPClientWrapper, self).__init__(MailMessage)
		self.__MailMessage = MailMessage
		self.bodySizeType = MailMessage.bodySizeType
		self.textContentAsBody = MailMessage.textContentAsBody
		self.fileNameAsBody = MailMessage.fileNameAsBody
		self.enablePatternGen = MailMessage.enablePatternGen
		self.mimeTypeAndEncode = MailMessage.mimeTypeAndEncode
		self.description = MailMessage.description
		self.bodySizeRandomMax = MailMessage.bodySizeRandomMax
		self.bodySizeFixed = MailMessage.bodySizeFixed
		self.headerList = HeaderListSMTPClientWrapper(MailMessage)
		self.readOnly = MailMessage.readOnly
		self.bodySizeRandomMin = MailMessage.bodySizeRandomMin
		self.bodyDataType = MailMessage.bodyDataType
		self.useFileAsBody = MailMessage.useFileAsBody
		self.bodyFormat = MailMessage.bodyFormat
		self.name = MailMessage.name

	properties = ["bodySizeType", "textContentAsBody", "fileNameAsBody", "enablePatternGen", "mimeTypeAndEncode", "description", "bodySizeRandomMax", "bodySizeFixed", "readOnly", "bodySizeRandomMin", "bodyDataType", "useFileAsBody", "bodyFormat", "name", ]

	def __getattribute__(self, name):
		if name in MailMessageSMTPClientWrapper.properties and super(MailMessageSMTPClientWrapper, self).__getattribute__(name):
			return getattr(super(MailMessageSMTPClientWrapper, self).__getattribute__("_MailMessageSMTPClientWrapper__MailMessage"), name)
		else:
			return super(MailMessageSMTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(MailMessageSMTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(MailMessageSMTPClientWrapper, self).__getattribute__("_MailMessageSMTPClientWrapper__MailMessage"), name, value)
			super(MailMessageSMTPClientWrapper, self).__setattr__(name, value)


class HeaderListSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, MailMessage):
		self.__MailMessage = MailMessage

	def getItem(self, objectID):
		itemList = self.__MailMessage.headerList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "Header":
				return HeaderSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return HeaderSMTPClientWrapper(self.__MailMessage.headerList.appendItem(**kwargs))

	def getList(self):
		return self.__MailMessage.headerList

	def clear(self):
		return self.__MailMessage.headerList.clear()


class HeaderSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, Header):
		super(HeaderSMTPClientWrapper, self).__init__(Header)
		self.__Header = Header
		self.isCustomHdr = Header.isCustomHdr
		self.name = Header.name
		self.value = Header.value

	properties = ["isCustomHdr", "name", "value", ]

	def __getattribute__(self, name):
		if name in HeaderSMTPClientWrapper.properties and super(HeaderSMTPClientWrapper, self).__getattribute__(name):
			return getattr(super(HeaderSMTPClientWrapper, self).__getattribute__("_HeaderSMTPClientWrapper__Header"), name)
		else:
			return super(HeaderSMTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(HeaderSMTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(HeaderSMTPClientWrapper, self).__getattribute__("_HeaderSMTPClientWrapper__Header"), name, value)
			super(HeaderSMTPClientWrapper, self).__setattr__(name, value)


class AttachmentListSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, MailMessage):
		self.__MailMessage = MailMessage

	def getItem(self, objectID):
		itemList = self.__MailMessage.attachmentList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "Attachment":
				return AttachmentSMTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return AttachmentSMTPClientWrapper(self.__MailMessage.attachmentList.appendItem(**kwargs))

	def getList(self):
		return self.__MailMessage.attachmentList

	def clear(self):
		return self.__MailMessage.attachmentList.clear()


class AttachmentSMTPClientWrapper(RestObjectBaseClass):

	def __init__(self, Attachment):
		super(AttachmentSMTPClientWrapper, self).__init__(Attachment)
		self.__Attachment = Attachment
		self.sizeMax = Attachment.sizeMax
		self.countMax = Attachment.countMax
		self.dataType = Attachment.dataType
		self.countMin = Attachment.countMin
		self.fileName = Attachment.fileName
		self.attchStr = Attachment.attchStr
		self.type = Attachment.type
		self.sizeMin = Attachment.sizeMin

	properties = ["sizeMax", "countMax", "dataType", "countMin", "fileName", "attchStr", "type", "sizeMin", ]

	def __getattribute__(self, name):
		if name in AttachmentSMTPClientWrapper.properties and super(AttachmentSMTPClientWrapper, self).__getattribute__(name):
			return getattr(super(AttachmentSMTPClientWrapper, self).__getattribute__("_AttachmentSMTPClientWrapper__Attachment"), name)
		else:
			return super(AttachmentSMTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(AttachmentSMTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(AttachmentSMTPClientWrapper, self).__getattribute__("_AttachmentSMTPClientWrapper__Attachment"), name, value)
			super(AttachmentSMTPClientWrapper, self).__setattr__(name, value)


class StatsNameHTTPServer(object):
	def __init__(self):
		self.kSSLAlertsSentunsupported_certificate = "SSL Alerts Sent (unsupported_certificate)"
		self.kSSLAlertsReceiveddecryption_failed = "SSL Alerts Received (decryption_failed)"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kSSLSNIextensionmismatch = "SSL SNI extension mismatch"
		self.kSSLAlertsSentcertificate_revoked = "SSL Alerts Sent (certificate_revoked)"
		self.kServerHelloReceived = "Server Hello Received"
		self.kSSLAlertsReceivedbad_record_mac = "SSL Alerts Received (bad_record_mac)"
		self.kSSLAlertsSentcertificate_expired = "SSL Alerts Sent (certificate_expired)"
		self.kClientHelloReceived = "Client Hello Received"
		self.kSSLearlydatafailure = "SSL early data failure"
		self.kHTTPRequestsFailed404 = "HTTP Requests Failed (404)"
		self.kRequestsFailed = "Requests Failed"
		self.kSSLBytesReceived = "SSL Bytes Received"
		self.kHTTPCookiesSent = "HTTP Cookies Sent"
		self.kConnectionRequestsFailed = "Connection Requests Failed"
		self.kSYNSYNACKsReceived = "SYN/SYN-ACKs Received"
		self.kSSLAlertsReceivedbad_certificate = "SSL Alerts Received (bad_certificate)"
		self.kHTTP2StreamsSucceededClienttoServer = "HTTP2 Streams Succeeded Client to Server"
		self.kHTTPResponsesSentOther = "HTTP Responses Sent (Other)"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kHTTP2WINDOWUPDATEFramesReceived = "HTTP2 WINDOWUPDATE Frames Received"
		self.kHTTP2PINGFramesReceived = "HTTP2 PING Frames Received"
		self.k404 = "404"
		self.kHTTP2DNSTotalQueriesRespondedSuccessfully = "HTTP2 DNS Total Queries Responded Successfully"
		self.kSSLAlertsSentdecode_error = "SSL Alerts Sent (decode_error)"
		self.kHTTPSessionsRejected503 = "HTTP Sessions Rejected (503)"
		self.kResetsSent = "Resets Sent"
		self.kSSLAlertsSent = "SSL Alerts Sent"
		self.kSSLAlertsReceiveduser_canceled = "SSL Alerts Received (user_canceled)"
		self.kHTTPCookiesReceivedWithMatchingServerID = "HTTP Cookies Received With Matching ServerID"
		self.kHTTP2StreamsSucceededServertoClient = "HTTP2 Streams Succeeded Server to Client"
		self.kWriteError = "Write Error"
		self.kHTTPResponsesSent1xx = "HTTP Responses Sent (1xx)"
		self.kSSLErrorsSentnocipher = "SSL Errors Sent (no cipher)"
		self.k5xx = "5xx"
		self.kHTTP2CompressionError = "HTTP2 Compression Error"
		self.kSSLErrorsSentbadcertificate = "SSL Errors Sent (bad certificate)"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kHTTPResponsesSent2xx = "HTTP Responses Sent (2xx)"
		self.kHTTP2GOAWAYFramesReceived = "HTTP2 GOAWAY Frames Received"
		self.kSSLAlertsReceivedcertificate_revoked = "SSL Alerts Received (certificate_revoked)"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kHTTPRequestsSuccessful = "HTTP Requests Successful"
		self.kHTTP2CONTINUATIONFramesSent = "HTTP2 CONTINUATION Frames Sent"
		self.kHTTP2StreamsInitiatedbyServer = "HTTP2 Streams Initiated by Server"
		self.kSYNACKsSent = "SYN-ACKs Sent"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kHTTP2PRIORITYFramesReceived = "HTTP2 PRIORITY Frames Received"
		self.kResponsesSent2xx = "Responses Sent (2xx)"
		self.kHTTP2CONTINUATIONFramesReceived = "HTTP2 CONTINUATION Frames Received"
		self.kTransmittedDataRateKbps = "Transmitted Data Rate (Kbps)"
		self.kHTTP2DNSTotalQueriesFailedServerFailure = "HTTP2 DNS Total Queries Failed (Server Failure)"
		self.kSSLErrorsSent = "SSL Errors Sent"
		self.kSSLAlertsSentno_certificate = "SSL Alerts Sent (no_certificate)"
		self.kSSLsessionpskreusesuccess = "SSL session psk reuse success"
		self.kFINACKsReceived = "FIN-ACKs Received"
		self.kHTTP2ProtocolError = "HTTP2 Protocol Error"
		self.kSSLCertificateSelfSigned = "SSL Certificate Self Signed"
		self.kSSLAlertsSentillegal_parameter = "SSL Alerts Sent (illegal_parameter)"
		self.kHTTP2HTTP11RequiredError = "HTTP2 HTTP1.1 Required Error"
		self.kSSLAlertsReceivedunknown_ca = "SSL Alerts Received (unknown_ca)"
		self.kHTTP2EnhanceCalmError = "HTTP2 Enhance Calm Error"
		self.kSSLAlertsReceivedillegal_parameter = "SSL Alerts Received (illegal_parameter)"
		self.kSSLCertificateCASigned = "SSL Certificate CA Signed"
		self.kTCPRetries = "TCP Retries"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kFINsReceived = "FINs Received"
		self.kHTTPRequestsReceived = "HTTP Requests Received"
		self.kSSLAlertsReceivedprotocol_version = "SSL Alerts Received (protocol_version)"
		self.kHelloRequestsReceived = "Hello Requests Received"
		self.kSSLSessionReuseSuccess = "SSL Session Reuse Success"
		self.kSSLAlertsReceivedcertificate_expired = "SSL Alerts Received (certificate_expired)"
		self.kResponsesSent4xx = "Responses Sent (4xx)"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kHelloRequestsSent = "Hello Requests Sent"
		self.kRequestsReceived = "Requests Received"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kHTTP2WINDOWUPDATEFramesSent = "HTTP2 WINDOWUPDATE Frames Sent"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kSSLAlertsSenthandshake_failure = "SSL Alerts Sent (handshake_failure)"
		self.kHTTPRequestsFailedAborted = "HTTP Requests Failed (Aborted)"
		self.kHTTPCookiesReceived = "HTTP Cookies Received"
		self.kHTTP2DNSTotalQueriesFailedOther = "HTTP2 DNS Total Queries Failed (Other)"
		self.kSSLAlertsReceivedrecord_overflow = "SSL Alerts Received (record_overflow)"
		self.kHTTP2DNSTypeAAAAQueriesReceived = "HTTP2 DNS (Type AAAA) Queries Received"
		self.kHTTP2DNSTotalQueriesFailedRefused = "HTTP2 DNS Total Queries Failed (Refused)"
		self.kSSLearlydatasuccess = "SSL early data success"
		self.kHTTP2PUSHPROMISEFramesSent = "HTTP2 PUSHPROMISE Frames Sent"
		self.kHTTP2GOAWAYFramesSent = "HTTP2 GOAWAY Frames Sent"
		self.kHTTP2StreamsInitiatedbyClient = "HTTP2 Streams Initiated by Client"
		self.kHTTP2PRIORITYFramesSent = "HTTP2 PRIORITY Frames Sent"
		self.kSSLNegotiationFinishedSuccessfully = "SSL Negotiation Finished Successfully"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kHTTPRequestsFailed = "HTTP Requests Failed"
		self.kSSLSNIextensionsentsuccessfully = "SSL SNI extension sent successfully"
		self.kHTTP2DNSTotalQueriesFailedFormatError = "HTTP2 DNS Total Queries Failed (Format Error)"
		self.kSSLearlydatasent = "SSL early data sent"
		self.kSSLsessionticketreusefailure = "SSL session ticket reuse failure"
		self.kSSLAlertsSentclose_notify = "SSL Alerts Sent (close_notify)"
		self.kHTTP2DNSTypeNSQueriesReceived = "HTTP2 DNS (Type NS) Queries Received"
		self.kHTTPTotalChunksSent = "HTTP Total Chunks Sent"
		self.kSSLThroughputBytes = "SSL Throughput Bytes"
		self.kHTTP2SettingsTimeoutError = "HTTP2 Settings Timeout Error"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kFINACKsSent = "FIN-ACKs Sent"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kSSLErrorsReceivedundefinederror = "SSL Errors Received (undefined error)"
		self.kHTTPContentBytesReceived = "HTTP Content Bytes Received"
		self.kHTTPContentMD5CheckSuccessful = "HTTP Content-MD5 Check Successful"
		self.kClientHelloSent = "Client Hello Sent"
		self.kSSLAlertsSentunknown_ca = "SSL Alerts Sent (unknown_ca)"
		self.kHTTPBytesReceived = "HTTP Bytes Received"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kSSLErrorsReceivedunsupportedcertificate = "SSL Errors Received (unsupported certificate)"
		self.kSSLAlertsReceivedinternal_error = "SSL Alerts Received (internal_error)"
		self.kSSLAlertsSentrecord_overflow = "SSL Alerts Sent (record_overflow)"
		self.kSSLAlertsSentaccess_denied = "SSL Alerts Sent (access_denied)"
		self.kHTTP2ConnectionUpgradeFailed = "HTTP2 Connection Upgrade Failed"
		self.kSSLAlertsReceivedunsupported_certificate = "SSL Alerts Received (unsupported_certificate)"
		self.kResponsesSent3xx = "Responses Sent (3xx)"
		self.kHTTP2PINGFramesSent = "HTTP2 PING Frames Sent"
		self.kSSLBytesSent = "SSL Bytes Sent"
		self.kHTTP2DNSTypeTXTQueriesReceived = "HTTP2 DNS (Type TXT) Queries Received"
		self.kHTTPChunkedEncodedResponsesSent = "HTTP Chunked Encoded Responses Sent"
		self.kSSLAlertsSentbad_record_mac = "SSL Alerts Sent (bad_record_mac)"
		self.kHTTP2RESETSTREAMFramesSent = "HTTP2 RESETSTREAM Frames Sent"
		self.kHTTP2ConnectError = "HTTP2 Connect Error"
		self.kSSLErrorsSentunsupportedcertificate = "SSL Errors Sent (unsupported certificate)"
		self.kResponsesSent1xx = "Responses Sent (1xx)"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kSSLsessionticketreusesuccess = "SSL session ticket reuse success"
		self.kHTTPContentMD5CheckFailed = "HTTP Content-MD5 Check Failed"
		self.kHTTP2StreamClosedError = "HTTP2 Stream Closed Error"
		self.kSSLNegotiationFinishedSuccessfuly = "SSL Negotiation Finished Successfuly"
		self.kSSLAlertsReceivedunexpected_message = "SSL Alerts Received (unexpected_message)"
		self.kSSLSessionReuseFailed = "SSL Session Reuse Failed"
		self.kHTTP2FlowControlError = "HTTP2 Flow Control Error"
		self.kSSLErrorsSentnocertificate = "SSL Errors Sent (no certificate)"
		self.kHTTP2DNSTotalQueriesFailedNameError = "HTTP2 DNS Total Queries Failed (Name Error)"
		self.kSSLAlertsSentbad_certificate = "SSL Alerts Sent (bad_certificate)"
		self.kRetries = "Retries"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kHTTPOPTIONSRequestReceived = "HTTP OPTIONS Request Received"
		self.kAborted = "Aborted"
		self.kRequestsFaileds = "Requests Failed/s"
		self.kHTTP2DATAFramesReceived = "HTTP2 DATA Frames Received"
		self.kSSLAlertsReceivedexport_restriction = "SSL Alerts Received (export_restriction)"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kHTTP2FrameSizeError = "HTTP2 Frame Size Error"
		self.kSSLAlertsReceivedaccess_denied = "SSL Alerts Received (access_denied)"
		self.kSSLAlertsReceivedclose_notify = "SSL Alerts Received (close_notify)"
		self.kSSLAlertsReceivedinsufficient_security = "SSL Alerts Received (insufficient_security)"
		self.kHTTPOPTIONSResponseSent = "HTTP OPTIONS Response Sent"
		self.kSSLAlertsSentuser_canceled = "SSL Alerts Sent (user_canceled)"
		self.kSSLAlertsReceivedunrecognizedname = "SSL Alerts Received (unrecognized name)"
		self.kSSLAlertsSentno_renegotiation = "SSL Alerts Sent (no_renegotiation)"
		self.kSSLErrorsReceivednocipher = "SSL Errors Received (no cipher)"
		self.kHTTP2DNSTypeAQueriesReceived = "HTTP2 DNS (Type A) Queries Received"
		self.kSSLErrorsReceivednocertificate = "SSL Errors Received (no certificate)"
		self.kHTTPRequestsFailedWriteError = "HTTP Requests Failed (Write Error)"
		self.kSSLErrorsReceivedbadcertificate = "SSL Errors Received (bad certificate)"
		self.kSSLAlertsSentdecryption_failed = "SSL Alerts Sent (decryption_failed)"
		self.kSSLErrorsReceived = "SSL Errors Received"
		self.kHTTPTotalChunksReceived = "HTTP Total Chunks Received"
		self.kSSLAlertsReceivedcertificate_unknown = "SSL Alerts Received (certificate_unknown)"
		self.kHTTP2SETTINGSFramesSent = "HTTP2 SETTINGS Frames Sent"
		self.kResponsesSent5xx = "Responses Sent (5xx)"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kSSLAlertsSentdecompression_failure = "SSL Alerts Sent (decompression_failure)"
		self.kHTTP2StreamsFailedServertoClient = "HTTP2 Streams Failed Server to Client"
		self.kSSLAlertsSentdecrypt_error = "SSL Alerts Sent (decrypt_error)"
		self.kSSLearlydatafailed = "SSL early data failed"
		self.kSSLConcurrentSessions = "SSL Concurrent Sessions"
		self.kSSLCertificateValidationFailure = "SSL Certificate Validation Failure"
		self.kSSLAlertsReceivedno_renegotiation = "SSL Alerts Received (no_renegotiation)"
		self.kHTTPContentMD5RequestsReceived = "HTTP Content-MD5 Requests Received"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kHTTPResponsesSent5xx = "HTTP Responses Sent (5xx)"
		self.kHTTPContentBytesSent = "HTTP Content Bytes Sent"
		self.kHTTP2DNSTotalQueriesFailedNotImplemented = "HTTP2 DNS Total Queries Failed (Not Implemented)"
		self.kHTTP2RefusedStreamError = "HTTP2 Refused Stream Error"
		self.kHTTP2HEADERFramesReceived = "HTTP2 HEADER Frames Received"
		self.kSSLAlertsReceivedhandshake_failure = "SSL Alerts Received (handshake_failure)"
		self.kSSLAlertsReceivedno_certificate = "SSL Alerts Received (no_certificate)"
		self.kSSLAlertsSentinternal_error = "SSL Alerts Sent (internal_error)"
		self.kHTTPRequestsFailed50x = "HTTP Requests Failed (50x)"
		self.kSSLAlertsSentunexpected_message = "SSL Alerts Sent (unexpected_message)"
		self.kHTTP2InadequateSecurityError = "HTTP2 Inadequate Security Error"
		self.kSSLErrorsSentundefinederror = "SSL Errors Sent (undefined error)"
		self.kTCPFINReceived = "TCP FIN Received"
		self.kHTTPResponsesSent3xx = "HTTP Responses Sent (3xx)"
		self.kAcceptQueueEntries = "Accept Queue Entries"
		self.kHTTP2DNSTotalQueriesFailed = "HTTP2 DNS Total Queries Failed"
		self.kSSLAlertsSentexport_restriction = "SSL Alerts Sent (export_restriction)"
		self.kSSLAlertsReceiveddecode_error = "SSL Alerts Received (decode_error)"
		self.kResetsReceived = "Resets Received"
		self.kResponsesSentOther = "Responses Sent (Other)"
		self.kServerHelloSent = "Server Hello Sent"
		self.kHTTP2StreamCancelledError = "HTTP2 Stream Cancelled Error"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kSSLAlertsSentprotocol_version = "SSL Alerts Sent (protocol_version)"
		self.kRequestsReceiveds = "Requests Received/s"
		self.kHTTP2ConnectionUpgradeSucceeded = "HTTP2 Connection Upgrade Succeeded"
		self.kSSLearlydatareceived = "SSL early data received"
		self.kHTTPResponsesSent4xx = "HTTP Responses Sent (4xx)"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kTimeouts = "Timeouts"
		self.kHTTP2SETTINGSFramesReceived = "HTTP2 SETTINGS Frames Received"
		self.kRequestsSuccessful = "Requests Successful"
		self.kSSLAlertsSentinsufficient_security = "SSL Alerts Sent (insufficient_security)"
		self.kSSLAlertsReceiveddecompression_failure = "SSL Alerts Received (decompression_failure)"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kHTTP2HEADERFramesSent = "HTTP2 HEADER Frames Sent"
		self.kHTTP2PUSHPROMISEFramesReceived = "HTTP2 PUSHPROMISE Frames Received"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kHTTP2InternalError = "HTTP2 Internal Error"
		self.kHTTP2DATAFramesSent = "HTTP2 DATA Frames Sent"
		self.kHTTPCookiesReceivedWithNonmatchingServerID = "HTTP Cookies Received With Non-matching ServerID"
		self.kHTTP2DNSTotalQueriesReceived = "HTTP2 DNS Total Queries Received"
		self.kHTTPChunkedTransferEncodedRequestsReceived = "HTTP Chunked Transfer-Encoded Requests Received"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kHTTP2RESETSTREAMFramesReceived = "HTTP2 RESETSTREAM Frames Received"
		self.kSSLAlertsSentcertificate_unknown = "SSL Alerts Sent (certificate_unknown)"
		self.kHTTP2StreamsFailedClienttoServer = "HTTP2 Streams Failed Client to Server"
		self.kSSLApplicationDataBytes = "SSL Application Data Bytes"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kHTTPBytesSent = "HTTP Bytes Sent"
		self.kListenQueueDrops = "Listen Queue Drops"
		self.kHTTPSessionTimeouts408 = "HTTP Session Timeouts (408)"
		self.kRequestsSuccessfuls = "Requests Successful/s"
		self.kReceivedDataRateKbps = "Received Data Rate (Kbps)"
		self.kFINsSent = "FINs Sent"
		self.kSSLAlertsReceiveddecrypt_error = "SSL Alerts Received (decrypt_error)"
		self.kSSLsessionpskreusefailure = "SSL session psk reuse failure"
		self.kSSLAlertsReceived = "SSL Alerts Received"


class StatsNameHTTPClient(object):
	def __init__(self):
		self.kSSLAlertsSentunsupported_certificate = "SSL Alerts Sent (unsupported_certificate)"
		self.kHTTPClientHTTP20ContinuationFramesReceived = "HTTP Client HTTP2.0 Continuation Frames Received"
		self.kSSLAlertsReceivedillegal_parameter = "SSL Alerts Received (illegal_parameter)"
		self.kHelloRequestsSent = "Hello Requests Sent"
		self.kHTTPClientHTTP20ConnectionUpgradeSucceeded = "HTTP Client HTTP2.0 Connection Upgrade Succeeded"
		self.kTimeout = "Timeout"
		self.kSSLAlertsReceiveddecryption_failed = "SSL Alerts Received (decryption_failed)"
		self.kHTTPCookiesRejectedPathMatchFailed = "HTTP Cookies Rejected - (Path Match Failed)"
		self.kHTTPClientHTTP20DNSTypeTXTQueriesSent = "HTTP Client HTTP2.0 DNS (Type TXT) Queries Sent"
		self.kServerHelloReceived = "Server Hello Received"
		self.kSSLAlertsReceivedbad_record_mac = "SSL Alerts Received (bad_record_mac)"
		self.kDeflateContentEncodingDecodeFailedDecodingError = "Deflate Content-Encoding Decode Failed - Decoding Error"
		self.kClientHelloReceived = "Client Hello Received"
		self.kSSLAlertsReceivedunrecognizedname = "SSL Alerts Received (unrecognized name)"
		self.kHTTPRequestsFailed404 = "HTTP Requests Failed (404)"
		self.kTCPRetries = "TCP Retries"
		self.kHTTPRequestsFailedRead = "HTTP Requests Failed (Read)"
		self.kSSLBytesReceived = "SSL Bytes Received"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kHTTPRequestsFailed4xxother = "HTTP Requests Failed (4xx other)"
		self.kHTTPConcurrentConnections = "HTTP Concurrent Connections"
		self.kHTTPCookiesSent = "HTTP Cookies Sent"
		self.kHTTPClientHTTP20DNSTypeNSQueriesSent = "HTTP Client HTTP2.0 DNS (Type NS) Queries Sent"
		self.kTransactionRate = "Transaction Rate"
		self.kGzipContentEncodingDecodeFailedDecodingError = "Gzip Content-Encoding Decode Failed - Decoding Error"
		self.kHTTPClientHTTP20DNSTypeAQueriesSent = "HTTP Client HTTP2.0 DNS (Type A) Queries Sent"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kContentMD5ResponsesReceived = "Content-MD5 Responses Received"
		self.kHTTPClientHTTP20FlowControlError = "HTTP Client HTTP2.0 Flow Control Error"
		self.kHTTPConnectionAttempts = "HTTP Connection Attempts"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kHTTPClientHTTP20RefusedStreamError = "HTTP Client HTTP2.0 Refused Stream Error"
		self.kSSLAlertsReceivedcertificate_revoked = "SSL Alerts Received (certificate_revoked)"
		self.kHTTPClientHTTP20PushPromiseFramesSent = "HTTP Client HTTP2.0 Push Promise Frames Sent"
		self.kHTTPClientHTTP20DNSTypeAAAAQueriesSent = "HTTP Client HTTP2.0 DNS (Type AAAA) Queries Sent"
		self.k5xxotherthan503 = "5xx (other than 503)"
		self.kHTTPReceived408 = "HTTP Received 408"
		self.kAborted = "Aborted"
		self.kSSLAlertsSentcertificate_revoked = "SSL Alerts Sent (certificate_revoked)"
		self.kChunkedTransferEncodingHeadersSent = "Chunked Transfer-Encoding Headers Sent"
		self.kHTTPClientHTTP20PushPromiseFramesReceived = "HTTP Client HTTP2.0 Push Promise Frames Received"
		self.kHTTPSessionsRejected503 = "HTTP Sessions Rejected (503)"
		self.kResetsSent = "Resets Sent"
		self.kCustomMD5CheckFailed = "Custom-MD5 Check Failed"
		self.kSSLearlydatareceived = "SSL early data received"
		self.kSSLAlertsReceiveduser_canceled = "SSL Alerts Received (user_canceled)"
		self.kHTTPReceived503 = "HTTP Received 503"
		self.kTimeouts = "Timeouts"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kSSLErrorsSentnocipher = "SSL Errors Sent (no cipher)"
		self.kDeflateContentEncodingReceived = "Deflate Content-Encoding Received"
		self.kThroughputKbps = "Throughput (Kbps)"
		self.kSSLErrorsReceived = "SSL Errors Received"
		self.kSSLAlertsSentcertificate_expired = "SSL Alerts Sent (certificate_expired)"
		self.kHTTPSimulatedUsers = "HTTP Simulated Users"
		self.kHTTPRequestsFailed403 = "HTTP Requests Failed (403)"
		self.kHTTPClientHTTP20ResetStreamFramesSent = "HTTP Client HTTP2.0 Reset Stream Frames Sent"
		self.kDeflateContentEncodingDecodeFailedDataError = "Deflate Content-Encoding Decode Failed - Data Error"
		self.kHTTPRequestsSuccessful303 = "HTTP Requests Successful (303)"
		self.kHTTPRequestsSuccessful = "HTTP Requests Successful"
		self.kSSLErrorsSentbadcertificate = "SSL Errors Sent (bad certificate)"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kHTTPClientHTTP20DNSTotalQueriesFailed = "HTTP Client HTTP2.0 DNS Total Queries Failed"
		self.kHTTPClientHTTP20PingFramesReceived = "HTTP Client HTTP2.0 Ping Frames Received"
		self.kHTTPClientHTTP20DNSTotalQueriesFailedServerFailure = "HTTP Client HTTP2.0 DNS Total Queries Failed (Server Failure)"
		self.kHTTPConnectTimeus = "HTTP Connect Time (us)"
		self.kHTTPClientHTTP20ContinuationFramesSent = "HTTP Client HTTP2.0 Continuation Frames Sent"
		self.kHTTPClientHTTP20DNSTotalQueriesFailedNotImplemented = "HTTP Client HTTP2.0 DNS Total Queries Failed (Not Implemented)"
		self.kRequestsSuccessful = "Requests Successful"
		self.kOldSessionAbortDelayMinimumus = "Old Session Abort Delay - Minimum (us)"
		self.kFINsReceived = "FINs Received"
		self.kHTTPOldSessionAbortDelayAverageus = "HTTP Old Session Abort Delay - Average (us)"
		self.kConcurrentConnections = "Concurrent Connections"
		self.kSSLErrorsSent = "SSL Errors Sent"
		self.kHTTPConnectionAborts = "HTTP Connection Aborts"
		self.kRequestsSents = "Requests Sent/s"
		self.kHTTPRequestPreconditionFailed412 = "HTTP Request Precondition Failed (412)"
		self.kTotalChunksSent = "Total Chunks Sent"
		self.kSSLCertificateSelfSigned = "SSL Certificate Self Signed"
		self.kSSLAlertsSentillegal_parameter = "SSL Alerts Sent (illegal_parameter)"
		self.kSSLSessionReuseFailed = "SSL Session Reuse Failed"
		self.kSSLAlertsReceivedunknown_ca = "SSL Alerts Received (unknown_ca)"
		self.kHTTPClientHTTP20PriorityFramesReceived = "HTTP Client HTTP2.0 Priority Frames Received"
		self.kHTTPClientHTTP20StreamsInitiatedbyServer = "HTTP Client HTTP2.0 Streams Initiated by Server"
		self.kSSLCertificateCASigned = "SSL Certificate CA Signed"
		self.kHTTPUsersActive = "HTTP Users Active"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kHTTPRequestsFailed5xx = "HTTP Requests Failed (5xx)"
		self.kGzipContentEncodingDecodeFailed = "Gzip Content-Encoding Decode Failed"
		self.kSSLAlertsReceivedprotocol_version = "SSL Alerts Received (protocol_version)"
		self.kHTTPClientHTTP20StreamsSucceededServertoClient = "HTTP Client HTTP2.0 Streams Succeeded (Server to Client)"
		self.kHTTPRequestsSuccessful302 = "HTTP Requests Successful (302)"
		self.kHTTPClientHTTP20StreamCancelledError = "HTTP Client HTTP2.0 Stream Cancelled Error"
		self.kCustomMD5ResponsesReceived = "Custom-MD5 Responses Received"
		self.kHTTPTimeToFirstByteus = "HTTP Time To First Byte (us)"
		self.kHTTPCookiesRejected = "HTTP Cookies Rejected"
		self.kHTTPDecompressedContentBytesReceived = "HTTP Decompressed Content Bytes Received"
		self.kSSLBytesSent = "SSL Bytes Sent"
		self.kHTTPBytes = "HTTP Bytes"
		self.kHTTPClientHTTP20DataFramesSent = "HTTP Client HTTP2.0 Data Frames Sent"
		self.kHTTPClientHTTP20StreamsFailedServertoClient = "HTTP Client HTTP2.0 Streams Failed (Server to Client)"
		self.kHTTPClientHTTP20ConnectionUpgradeFailed = "HTTP Client HTTP2.0 Connection Upgrade Failed"
		self.kHTTPClientHTTP20DNSTotalQueriesSent = "HTTP Client HTTP2.0 DNS Total Queries Sent"
		self.kServerHelloSent = "Server Hello Sent"
		self.kSimulatedUsers = "Simulated Users"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kHTTPClientHTTP20StreamsInitiatedbyClient = "HTTP Client HTTP2.0 Streams Initiated by Client"
		self.kHTTPRequestsFailedBadHeader = "HTTP Requests Failed (Bad Header)"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kHTTPClientHTTP20HeaderFramesSent = "HTTP Client HTTP2.0 Header Frames Sent"
		self.kHTTPTimeToLastByteus = "HTTP Time To Last Byte (us)"
		self.kHTTPRequestsFailedAborted = "HTTP Requests Failed (Aborted)"
		self.kConnectTimeus = "Connect Time (us)"
		self.kHTTPCookiesReceived = "HTTP Cookies Received"
		self.kSSLSNIextensionmismatch = "SSL SNI extension mismatch"
		self.kTimeToFirstByteTTFBus = "Time To First Byte (TTFB) (us)"
		self.kChunkedTransferEncodedHeadersReceived = "Chunked Transfer-Encoded Headers Received"
		self.kIntermediateResponsesReceived1xx = "Intermediate Responses Received (1xx)"
		self.kTimeToLastByteTTLBus = "Time To Last Byte (TTLB) (us)"
		self.kHTTPClientHTTP20WindowUpdateFramesSent = "HTTP Client HTTP2.0 Window Update Frames Sent"
		self.kSSLAlertsReceivedrecord_overflow = "SSL Alerts Received (record_overflow)"
		self.kSSLAlertsReceivedcertificate_expired = "SSL Alerts Received (certificate_expired)"
		self.kSSLAlertsSenthandshake_failure = "SSL Alerts Sent (handshake_failure)"
		self.kSSLearlydatasuccess = "SSL early data success"
		self.kHTTPClientHTTP20InternalError = "HTTP Client HTTP2.0 Internal Error"
		self.kHTTPClientTotalDataIntegrityCheckFailed = "HTTP Client Total Data Integrity Check Failed"
		self.kHTTPIntermediateResponsesReceived1xx = "HTTP Intermediate Responses Received (1xx)"
		self.kSSLNegotiationFinishedSuccessfully = "SSL Negotiation Finished Successfully"
		self.kGzipContentEncodingReceived = "Gzip Content-Encoding Received"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kHTTPRequestsFailed = "HTTP Requests Failed"
		self.kHTTPRequestsSuccessful3xx = "HTTP Requests Successful (3xx)"
		self.kSSLSNIextensionsentsuccessfully = "SSL SNI extension sent successfully"
		self.kGzipContentEncodingDecodeSuccessful = "Gzip Content-Encoding Decode Successful"
		self.kHTTPRequestsFailed401 = "HTTP Requests Failed (401)"
		self.kOldSessionAbortDelayMaximumus = "Old Session Abort Delay - Maximum (us)"
		self.kSSLAlertsSentdecompression_failure = "SSL Alerts Sent (decompression_failure)"
		self.kFINsSent = "FINs Sent"
		self.kSSLearlydatasent = "SSL early data sent"
		self.kSSLsessionticketreusefailure = "SSL session ticket reuse failure"
		self.kSSLAlertsReceivedaccess_denied = "SSL Alerts Received (access_denied)"
		self.kSYNSYNACKsReceived = "SYN/SYN-ACKs Received"
		self.kSSLAlertsSentno_renegotiation = "SSL Alerts Sent (no_renegotiation)"
		self.kSSLThroughputBytes = "SSL Throughput Bytes"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kHTTPRequestsFailedTimeout = "HTTP Requests Failed (Timeout)"
		self.kContentMD5CheckSuccessful = "Content-MD5 Check Successful"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kSSLErrorsReceivedundefinederror = "SSL Errors Received (undefined error)"
		self.kHTTPClientHTTP20GoAwayFramesReceived = "HTTP Client HTTP2.0 Go Away Frames Received"
		self.kRequestsSuccessful2xx = "Requests Successful (2xx)"
		self.kHTTPContentBytesReceived = "HTTP Content Bytes Received"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kClientHelloSent = "Client Hello Sent"
		self.kHTTPClientHTTP20DNSTotalQueriesFailedNameError = "HTTP Client HTTP2.0 DNS Total Queries Failed (Name Error)"
		self.kSSLAlertsSentno_certificate = "SSL Alerts Sent (no_certificate)"
		self.kHTTPClientHTTP20DataFramesReceived = "HTTP Client HTTP2.0 Data Frames Received"
		self.kHTTPBytesReceived = "HTTP Bytes Received"
		self.kHTTPRequestsFailedWrite = "HTTP Requests Failed (Write)"
		self.kSSLErrorsReceivedunsupportedcertificate = "SSL Errors Received (unsupported certificate)"
		self.kSSLAlertsReceivedinternal_error = "SSL Alerts Received (internal_error)"
		self.kSSLErrorsReceivednocertificate = "SSL Errors Received (no certificate)"
		self.kSSLAlertsSentrecord_overflow = "SSL Alerts Sent (record_overflow)"
		self.kSSLAlertsSentaccess_denied = "SSL Alerts Sent (access_denied)"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kFINACKsReceived = "FIN-ACKs Received"
		self.kSSLAlertsSent = "SSL Alerts Sent"
		self.kHTTPRequestsSuccessful2xx = "HTTP Requests Successful (2xx)"
		self.kHTTPClientHTTP20DNSTotalQueriesFailedRefused = "HTTP Client HTTP2.0 DNS Total Queries Failed (Refused)"
		self.kChunkedTransferEncodingDecodeFailed = "Chunked Transfer-Encoding Decode Failed"
		self.kHTTPClientHTTP20StreamClosedError = "HTTP Client HTTP2.0 Stream Closed Error"
		self.kHTTPRequestsSuccessful301 = "HTTP Requests Successful (301)"
		self.kSYNsSent = "SYNs Sent"
		self.kHTTPTransactions = "HTTP Transactions"
		self.kSSLAlertsSentbad_record_mac = "SSL Alerts Sent (bad_record_mac)"
		self.kHTTPRequestsFailed400 = "HTTP Requests Failed (400)"
		self.kHTTPClientHTTP20HeaderFramesReceived = "HTTP Client HTTP2.0 Header Frames Received"
		self.kSSLErrorsSentunsupportedcertificate = "SSL Errors Sent (unsupported certificate)"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kHTTPRequestsFailed408 = "HTTP Requests Failed (408)"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kRequestsSuccessful3xx = "Requests Successful (3xx)"
		self.kCustomMD5CheckSuccessful = "Custom-MD5 Check Successful"
		self.kSSLsessionticketreusesuccess = "SSL session ticket reuse success"
		self.kHTTPRequestsFailed5xxother = "HTTP Requests Failed (5xx other)"
		self.kHTTPClientHTTP20DNSTotalQueriesFailedOther = "HTTP Client HTTP2.0 DNS Total Queries Failed (Other)"
		self.kHTTPClientHTTP20InadequateSecurityError = "HTTP Client HTTP2.0 Inadequate Security Error"
		self.kSSLAlertsReceiveddecode_error = "SSL Alerts Received (decode_error)"
		self.kFINACKsSent = "FIN-ACKs Sent"
		self.kSSLNegotiationFinishedSuccessfuly = "SSL Negotiation Finished Successfuly"
		self.kSSLAlertsReceivedunexpected_message = "SSL Alerts Received (unexpected_message)"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kHTTPClientHTTP20FrameSizeError = "HTTP Client HTTP2.0 Frame Size Error"
		self.kUnrecognizedContentEncodingReceived = "Unrecognized Content-Encoding Received"
		self.kSSLErrorsSentnocertificate = "SSL Errors Sent (no certificate)"
		self.kRequestsSent = "Requests Sent"
		self.kTxRateKbps = "Tx Rate (Kbps)"
		self.kSSLAlertsSentbad_certificate = "SSL Alerts Sent (bad_certificate)"
		self.kRetries = "Retries"
		self.kHTTPRequestsSent = "HTTP Requests Sent"
		self.kHTTPRequestsSuccessful307 = "HTTP Requests Successful (307)"
		self.kRequestsFaileds = "Requests Failed/s"
		self.kGzipContentEncodingDecodeFailedDataError = "Gzip Content-Encoding Decode Failed - Data Error"
		self.kHTTPClientHTTP20CompressionError = "HTTP Client HTTP2.0 Compression Error"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kHTTPConnections = "HTTP Connections"
		self.kSSLAlertsReceivedexport_restriction = "SSL Alerts Received (export_restriction)"
		self.kSSLAlertsReceivedclose_notify = "SSL Alerts Received (close_notify)"
		self.kSSLAlertsReceivedinsufficient_security = "SSL Alerts Received (insufficient_security)"
		self.kTotalChunksReceived = "Total Chunks Received"
		self.kSSLAlertsSentuser_canceled = "SSL Alerts Sent (user_canceled)"
		self.kHTTPClientHTTP20EnhanceCalmError = "HTTP Client HTTP2.0 Enhance Calm Error"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kSSLAlertsReceivedbad_certificate = "SSL Alerts Received (bad_certificate)"
		self.kOldSessionAbortRate = "Old Session Abort Rate"
		self.kHTTPCookieheadersRejectedMemoryOverflow = "HTTP Cookie headers Rejected - (Memory Overflow)"
		self.kHTTPClientHTTP20SettingsFramesReceived = "HTTP Client HTTP2.0 Settings Frames Received"
		self.kSSLErrorsReceivedbadcertificate = "SSL Errors Received (bad certificate)"
		self.kSSLAlertsSentdecryption_failed = "SSL Alerts Sent (decryption_failed)"
		self.kHTTPOldSessionAborts = "HTTP Old Session Aborts"
		self.kSSLAlertsReceivedcertificate_unknown = "SSL Alerts Received (certificate_unknown)"
		self.kConnectionAttemptRate = "Connection Attempt Rate"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kHTTPRequestsFailed407 = "HTTP Requests Failed (407)"
		self.kWriteFailed = "Write Failed"
		self.k4xx = "4xx"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kSSLAlertsSentdecrypt_error = "SSL Alerts Sent (decrypt_error)"
		self.kSSLearlydatafailed = "SSL early data failed"
		self.kSSLConcurrentSessions = "SSL Concurrent Sessions"
		self.kSSLCertificateValidationFailure = "SSL Certificate Validation Failure"
		self.kSSLAlertsReceivedno_renegotiation = "SSL Alerts Received (no_renegotiation)"
		self.kChunkedTransferEncodingDecodeSuccessful = "Chunked Transfer-Encoding Decode Successful"
		self.kRxRateKbps = "Rx Rate (Kbps)"
		self.kHTTPRequestsSuccessfulProvisional = "HTTP Requests Successful (Provisional)"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kHTTPAbortedBeforeRequest = "HTTP Aborted Before Request"
		self.kHTTPOldSessionAbortDelayMinimumus = "HTTP Old Session Abort Delay - Minimum (us)"
		self.kSSLAlertsSentdecode_error = "SSL Alerts Sent (decode_error)"
		self.kHTTPRequestsFailedother = "HTTP Requests Failed (other)"
		self.kHTTPContentBytesSent = "HTTP Content Bytes Sent"
		self.kSSLErrorsReceivednocipher = "SSL Errors Received (no cipher)"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kHTTPClientHTTP20GoAwayFramesSent = "HTTP Client HTTP2.0 Go Away Frames Sent"
		self.kConnectionRate = "Connection Rate"
		self.kSSLAlertsReceivedhandshake_failure = "SSL Alerts Received (handshake_failure)"
		self.kHTTPClientHTTP20ResetStreamFramesReceived = "HTTP Client HTTP2.0 Reset Stream Frames Received"
		self.kOthers = "Others"
		self.kSSLAlertsReceivedno_certificate = "SSL Alerts Received (no_certificate)"
		self.kSSLAlertsSentinternal_error = "SSL Alerts Sent (internal_error)"
		self.kHTTPClientHTTP20SettingsTimeoutError = "HTTP Client HTTP2.0 Settings Timeout Error"
		self.kChunkedTransferEncodedHeadersReceived2 = "Chunked Transfer-Encoded Headers Received2"
		self.kSSLAlertsSentunexpected_message = "SSL Alerts Sent (unexpected_message)"
		self.kSSLErrorsSentundefinederror = "SSL Errors Sent (undefined error)"
		self.kTCPFINReceived = "TCP FIN Received"
		self.kHTTPClientHTTP20ProtocolError = "HTTP Client HTTP2.0 Protocol Error"
		self.kContentEncodedResponsesDecodeFailed = "Content-Encoded Responses Decode Failed"
		self.kHTTPClientHTTP20PingFramesSent = "HTTP Client HTTP2.0 Ping Frames Sent"
		self.kHTTPClientHTTP20SettingsFramesSent = "HTTP Client HTTP2.0 Settings Frames Sent"
		self.kHelloRequestsReceived = "Hello Requests Received"
		self.kResetsReceived = "Resets Received"
		self.kHTTPClientHTTP20DNSTotalQueriesSuccessful = "HTTP Client HTTP2.0 DNS Total Queries Successful"
		self.kSSLAlertsSentclose_notify = "SSL Alerts Sent (close_notify)"
		self.kRequestsFailed = "Requests Failed"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kSSLAlertsSentprotocol_version = "SSL Alerts Sent (protocol_version)"
		self.kSSLSessionReuseSuccess = "SSL Session Reuse Success"
		self.kHTTPClientHTTP20DNSTotalQueriesFailedFormatError = "HTTP Client HTTP2.0 DNS Total Queries Failed (Format Error)"
		self.kHTTPRequestsFailed505 = "HTTP Requests Failed (505)"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kHTTPCookiesRejectedProbabilisticReject = "HTTP Cookies Rejected - (Probabilistic Reject)"
		self.kSSLsessionpskreusesuccess = "SSL session psk reuse success"
		self.kHTTPClientHTTP20StreamsFailedClienttoServer = "HTTP Client HTTP2.0 Streams Failed (Client to Server)"
		self.kHTTPAbortedAfterRequest = "HTTP Aborted After Request"
		self.kContentMD5CheckFailed = "Content-MD5 Check Failed"
		self.kSSLApplicationDataBytes = "SSL Application Data Bytes"
		self.kSSLAlertsSentinsufficient_security = "SSL Alerts Sent (insufficient_security)"
		self.kSSLAlertsReceiveddecompression_failure = "SSL Alerts Received (decompression_failure)"
		self.kHTTPClientHTTP20WindowUpdateFramesReceived = "HTTP Client HTTP2.0 Window Update Frames Received"
		self.kHTTPClientHTTP20PriorityFramesSent = "HTTP Client HTTP2.0 Priority Frames Sent"
		self.kOldSessionAbortDelayAverageus = "Old Session Abort Delay - Average (us)"
		self.kChunkedTransferEncodedResponsesReceived = "Chunked Transfer-Encoded Responses Received"
		self.kHTTPClientHTTP20HTTP1_1RequiredError = "HTTP Client HTTP2.0 HTTP1_1 Required Error"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kHTTPClientTotalDataIntegrityCheckSucceeded = "HTTP Client Total Data Integrity Check Succeeded"
		self.kSSLAlertsReceivedunsupported_certificate = "SSL Alerts Received (unsupported_certificate)"
		self.kHTTPClientHTTP20ConnectError = "HTTP Client HTTP2.0 Connect Error"
		self.kDeflateContentEncodingDecodeSuccessful = "Deflate Content-Encoding Decode Successful"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kBadHeader = "Bad Header"
		self.kSSLAlertsSentunknown_ca = "SSL Alerts Sent (unknown_ca)"
		self.kSSLAlertsSentcertificate_unknown = "SSL Alerts Sent (certificate_unknown)"
		self.kHTTPTransactionsActive = "HTTP Transactions Active"
		self.kContentEncodedResponsesReceived = "Content-Encoded Responses Received"
		self.kSSLAlertsSentexport_restriction = "SSL Alerts Sent (export_restriction)"
		self.kContentEncodedResponsesDecodeSuccessful = "Content-Encoded Responses Decode Successful"
		self.kHTTPBytesSent = "HTTP Bytes Sent"
		self.kDeflateContentEncodingDecodeFailed = "Deflate Content-Encoding Decode Failed"
		self.kReadFailed = "Read Failed"
		self.kHTTPClientHTTP20StreamsSucceededClienttoServer = "HTTP Client HTTP2.0 Streams Succeeded (Client to Server)"
		self.kHTTPSessionTimeouts408 = "HTTP Session Timeouts (408)"
		self.kRequestsSuccessfuls = "Requests Successful/s"
		self.kHTTPRequestsFailed4xx = "HTTP Requests Failed (4xx)"
		self.kHTTPCookiesRejectedCookiejarOverflow = "HTTP Cookies Rejected - (Cookiejar Overflow)"
		self.kHTTPOldSessionAbortDelayMaximumus = "HTTP Old Session Abort Delay - Maximum (us)"
		self.kSSLAlertsReceiveddecrypt_error = "SSL Alerts Received (decrypt_error)"
		self.kSSLsessionpskreusefailure = "SSL session psk reuse failure"
		self.kSSLearlydatafailure = "SSL early data failure"
		self.kHTTPCookiesRejectedDomainMatchFailed = "HTTP Cookies Rejected - (Domain Match Failed)"
		self.kSSLAlertsReceived = "SSL Alerts Received"


class IxActivityHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityHTTPClientWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.secondaryEnableConstraint = ixActivity.secondaryEnableConstraint
		self.protocol = ixActivity.protocol
		self.userIpMapping = ixActivity.userIpMapping
		self.enableConstraint = ixActivity.enableConstraint
		self.agent = PluginHTTPClientWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.timerGranularity = ixActivity.timerGranularity
		self.constraintValue = ixActivity.constraintValue
		self.customParameters = ixActivity.customParameters
		self.timelineId = ixActivity.timelineId
		self.role = ixActivity.role
		self.timeline = IxTimelineProxyHTTPClientWrapper(ixActivity.timeline)
		self.activeRole = ixActivity.activeRole
		self.type = ixActivity.type
		self.secondaryConstraintValue = ixActivity.secondaryConstraintValue
		self.enable = ixActivity.enable
		self.protocolAndType = ixActivity.protocolAndType
		self.userObjectiveType = ixActivity.userObjectiveType
		self.destinationIpMapping = ixActivity.destinationIpMapping
		self.name = ixActivity.name
		self.secondaryConstraintType = ixActivity.secondaryConstraintType
		self.userObjectiveValue = ixActivity.userObjectiveValue
		self.constraintType = ixActivity.constraintType
		self.cpsObjectiveBehavior = ixActivity.cpsObjectiveBehavior


	properties = ['secondaryEnableConstraint', 'protocol', 'userIpMapping', 'enableConstraint', 'objectivePercent', 'timerGranularity', 'constraintValue', 'customParameters', 'timelineId', 'role', 'activeRole', 'type', 'secondaryConstraintValue', 'enable', 'protocolAndType', 'userObjectiveType', 'destinationIpMapping', 'name', 'cpsObjectiveBehavior', 'secondaryConstraintType', 'userObjectiveValue', 'constraintType']

	

	def __getattribute__(self, name):
		if name in IxActivityHTTPClientWrapper.properties and super(IxActivityHTTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityHTTPClientWrapper, self).__getattribute__("_IxActivityHTTPClientWrapper__ixActivity"), name)
		else:
			return super(IxActivityHTTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityHTTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityHTTPClientWrapper, self).__getattribute__("_IxActivityHTTPClientWrapper__ixActivity"), name, value)
			super(IxActivityHTTPClientWrapper, self).__setattr__(name, value)


class IxActivityHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityHTTPServerWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.customParameters = ixActivity.customParameters
		self.enable = ixActivity.enable
		self.protocol = ixActivity.protocol
		self.name = ixActivity.name
		self.role = ixActivity.role
		self.agent = PluginHTTPServerWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.protocolAndType = ixActivity.protocolAndType
		self.timeline = IxTimelineProxyHTTPServerWrapper(ixActivity.timeline)
		self.timelineId = ixActivity.timelineId
		self.type = ixActivity.type
		self.activeRole = ixActivity.activeRole

	properties = ["customParameters", "enable", "protocol", "name", "role", "objectivePercent", "protocolAndType", "timelineId", "type", "activeRole", ]

	def __getattribute__(self, name):
		if name in IxActivityHTTPServerWrapper.properties and super(IxActivityHTTPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityHTTPServerWrapper, self).__getattribute__("_IxActivityHTTPServerWrapper__ixActivity"), name)
		else:
			return super(IxActivityHTTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityHTTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityHTTPServerWrapper, self).__getattribute__("_IxActivityHTTPServerWrapper__ixActivity"), name, value)
			super(IxActivityHTTPServerWrapper, self).__setattr__(name, value)


class IxActivityFilterListWrapper(RestObjectBaseClass):

	def __init__(self, filterList):
		self.__filterList = filterList

	def getItem(self, objectID):
		itemList = self.__filterList.activityFilters
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixRestFilter":
				return IxRestFilterWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, value=None):
		kwargs = {}
		kwargs.update({"value": value})
		return IxRestFilterWrapper(self.__filterList.activityFilters.appendItem(**kwargs))

	def getList(self):
		return self.__filterList.activityFilters

	def clear(self):
		return self.__filterList.activityFilters.clear()


class PluginHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginHTTPClientWrapper, self).__init__(agent)
		self.__agent = agent
		self.validateCertificate = agent.validateCertificate
		self.enableHttpsProxy = agent.enableHttpsProxy
		self.enableAuth = agent.enableAuth
		self.browserEmulationName = agent.browserEmulationName
		self.pfcClass = agent.pfcClass
		self.dontUseUpgrade = agent.dontUseUpgrade
		self.signPrivateKey = agent.signPrivateKey
		self.disableDnsResolutionCache = agent.disableDnsResolutionCache
		self.precedenceTOS = agent.precedenceTOS
		self.enableMiddleboxCompatMode = agent.enableMiddleboxCompatMode
		self.disablePfc = agent.disablePfc
		self.headerList = IxwebHttpHeaderListHTTPClientWrapper(agent)
		self.enableIntegrityCheckSupport = agent.enableIntegrityCheckSupport
		self.ctlsVersion = agent.ctlsVersion
		self.tcpCloseOption = agent.tcpCloseOption
		self.esm = agent.esm
		self.httpVersion = agent.httpVersion
		self.enableCookieSupport = agent.enableCookieSupport
		self.enableAchieveCCFirst = agent.enableAchieveCCFirst
		self.httpsProxy = agent.httpsProxy
		self.ecCurve = agent.ecCurve
		self.httpProxy = agent.httpProxy
		self.enableIetfTls = agent.enableIetfTls
		self.maxSessions = agent.maxSessions
		self.sslCertPerUser = agent.sslCertPerUser
		self.ipPreference = agent.ipPreference
		self.maxStreams = agent.maxStreams
		self.reliabilityTOS = agent.reliabilityTOS
		self.commandTimeout = agent.commandTimeout
		self.commandTimeout_ms = agent.commandTimeout_ms
		self.privateKeyPassword = agent.privateKeyPassword
		self.urlStatsCount = agent.urlStatsCount
		self.followHttpRedirects = agent.followHttpRedirects
		self.enableVlanPriority = agent.enableVlanPriority
		self.enablesslRecordSize = agent.enablesslRecordSize
		self.enableCtls = agent.enableCtls
		self.piggybackAck = agent.piggybackAck
		self.enableHttpsTunnel = agent.enableHttpsTunnel
		self.cmdListLoops = agent.cmdListLoops
		self.vlanPriority = agent.vlanPriority
		self.enableDecompressSupport = agent.enableDecompressSupport
		self.enablePerConnCookieSupport = agent.enablePerConnCookieSupport
		self.enableUnidirectionalClose = agent.enableUnidirectionalClose
		self.enableMasterSecret = agent.enableMasterSecret
		self.ttlValue = agent.ttlValue
		self.maxPersistentRequests = agent.maxPersistentRequests
		self.cmdPercentagePool = IxCommandPercentagePoolHTTPClientWrapper(agent.cmdPercentagePool)
		self.certificate = agent.certificate
		self.tos = agent.tos
		self.maxPipeline = agent.maxPipeline
		self.maxHeaderLen = agent.maxHeaderLen
		self.enableTrafficDistributionForCC = agent.enableTrafficDistributionForCC
		self.flowPercentage = agent.flowPercentage
		self.cookieJarSize = agent.cookieJarSize
		self.sslRecordSize = agent.sslRecordSize
		self.privateKey = agent.privateKey
		self.sslReuseMethod = agent.sslReuseMethod
		self.enableEarlyData = agent.enableEarlyData
		self.enableConsecutiveIpsPerSession = agent.enableConsecutiveIpsPerSession
		self.tcpFastOpen = agent.tcpFastOpen
		self.signCertificate = agent.signCertificate
		self.enableLargeHeader = agent.enableLargeHeader
		self.highPerfWithSU = agent.highPerfWithSU
		self.perHeaderPercentDist = agent.perHeaderPercentDist
		self.enableCRCCheckSupport = agent.enableCRCCheckSupport
		self.actionList = IxHttpCommandListHTTPClientWrapper(agent)
		self.encPrivateKey = agent.encPrivateKey
		self.exactTransactions = agent.exactTransactions
		self.enableSsl = agent.enableSsl
		self.cookieRejectProbability = agent.cookieRejectProbability
		self.disableMacValidation = agent.disableMacValidation
		self.httpsTunnel = agent.httpsTunnel
		self.enableEsm = agent.enableEsm
		self.sequentialSessionReuse = agent.sequentialSessionReuse
		self.enableSslSendCloseNotify = agent.enableSslSendCloseNotify
		self.contentLengthDeviationTolerance = agent.contentLengthDeviationTolerance
		self.caCert = agent.caCert
		self.enableHttpProxy = agent.enableHttpProxy
		self.enableTos = agent.enableTos
		self.enablemetaRedirectSupport = agent.enablemetaRedirectSupport
		self.delayTOS = agent.delayTOS
		self.encCertificate = agent.encCertificate
		self.sslVersion = agent.sslVersion
		self.throughputTOS = agent.throughputTOS
		self.enableECcurve = agent.enableECcurve
		self.clientCiphers = agent.clientCiphers
		self.constraintConcurrencyMode = agent.constraintConcurrencyMode
		self.keepAlive = agent.keepAlive

	properties = ["validateCertificate", "enableHttpsProxy", "enableAuth", "browserEmulationName", "pfcClass", "dontUseUpgrade", "signPrivateKey", "disableDnsResolutionCache", "precedenceTOS", "enableMiddleboxCompatMode", "disablePfc", "enableIntegrityCheckSupport", "ctlsVersion", "tcpCloseOption", "esm", "httpVersion", "enableCookieSupport", "enableAchieveCCFirst", "httpsProxy", "ecCurve", "httpProxy", "enableIetfTls", "maxSessions", "sslCertPerUser", "ipPreference", "maxStreams", "reliabilityTOS", "commandTimeout", "commandTimeout_ms", "privateKeyPassword", "urlStatsCount", "followHttpRedirects", "enableVlanPriority", "enablesslRecordSize", "enableCtls", "piggybackAck", "enableHttpsTunnel", "cmdListLoops", "vlanPriority", "enableDecompressSupport", "enablePerConnCookieSupport", "enableUnidirectionalClose", "enableMasterSecret", "ttlValue", "maxPersistentRequests", "certificate", "tos", "maxPipeline", "maxHeaderLen", "enableTrafficDistributionForCC", "flowPercentage", "cookieJarSize", "sslRecordSize", "privateKey", "sslReuseMethod", "enableEarlyData", "enableConsecutiveIpsPerSession", "tcpFastOpen", "signCertificate", "enableLargeHeader", "highPerfWithSU", "perHeaderPercentDist", "enableCRCCheckSupport", "encPrivateKey", "exactTransactions", "enableSsl", "cookieRejectProbability", "disableMacValidation", "httpsTunnel", "enableEsm", "sequentialSessionReuse", "enableSslSendCloseNotify", "contentLengthDeviationTolerance", "caCert", "enableHttpProxy", "enableTos", "enablemetaRedirectSupport", "delayTOS", "encCertificate", "sslVersion", "throughputTOS", "enableECcurve", "clientCiphers", "constraintConcurrencyMode", "keepAlive", ]

	def __getattribute__(self, name):
		if name in PluginHTTPClientWrapper.properties and super(PluginHTTPClientWrapper, self).__getattribute__(name):
			return getattr(super(PluginHTTPClientWrapper, self).__getattribute__("_PluginHTTPClientWrapper__agent"), name)
		else:
			return super(PluginHTTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginHTTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginHTTPClientWrapper, self).__getattribute__("_PluginHTTPClientWrapper__agent"), name, value)
			super(PluginHTTPClientWrapper, self).__setattr__(name, value)


class IxTimelineProxyHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyHTTPClientWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.iterations = timeline.iterations
		self.rampUpType = timeline.rampUpType
		self.rampUpValue = timeline.rampUpValue
		self.rampUpTime = timeline.rampUpTime
		self.rampDownTime = timeline.rampDownTime
		self.standbyTime = timeline.standbyTime
		self.rampDownValue = timeline.rampDownValue
		self.rampUpInterval = timeline.rampUpInterval
		self.offlineTime = timeline.offlineTime
		self.sustainTime = timeline.sustainTime
		self.name = timeline.name
		self.timelineType = timeline.timelineType


	properties = ['rampUpValue', 'rampUpTime', 'offlineTime', 'rampDownTime', 'standbyTime', 'rampDownValue', 'iterations', 'rampUpInterval', 'sustainTime', 'name', 'timelineType', 'rampUpType']

	

	def __getattribute__(self, name):
		if name in IxTimelineProxyHTTPClientWrapper.properties and super(IxTimelineProxyHTTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyHTTPClientWrapper, self).__getattribute__("_IxTimelineProxyHTTPClientWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyHTTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyHTTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyHTTPClientWrapper, self).__getattribute__("_IxTimelineProxyHTTPClientWrapper__timeline"), name, value)
			super(IxTimelineProxyHTTPClientWrapper, self).__setattr__(name, value)


class PluginHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginHTTPServerWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.signCertificate = agent.signCertificate
		self.responseHeaderList = IxResponseHeaderListHTTPServerWrapper(agent)
		self.privateKey = agent.privateKey
		self.vlanPriority = agent.vlanPriority
		self.validateCertificate = agent.validateCertificate
		self.encPrivateKey = agent.encPrivateKey
		self.maxResponseDelay = agent.maxResponseDelay
		self.ecdheCertDir = agent.ecdheCertDir
		self.docrootChunkSize = agent.docrootChunkSize
		self.enableTls13Support = agent.enableTls13Support
		self.disableMacValidation = agent.disableMacValidation
		self.ServerCiphers = agent.ServerCiphers
		self.webPageList = IxWebPageListHTTPServerWrapper(agent)
		self.rstTimeout = agent.rstTimeout
		self.ttlValue = agent.ttlValue
		self.ecdhCertDir = agent.ecdhCertDir
		self.enableChunkedRequest = agent.enableChunkedRequest
		self.enableEsm = agent.enableEsm
		self.enableHTTP2 = agent.enableHTTP2
		self.certificate = agent.certificate
		self.enableNewSslSupport = agent.enableNewSslSupport
		self.tos = agent.tos
		self.enableSslSendCloseNotify = agent.enableSslSendCloseNotify
		self.enableMD5Checksum = agent.enableMD5Checksum
		self.pfcClass = agent.pfcClass
		self.httpPort = agent.httpPort
		self.enableMiddleboxCompatMode = agent.enableMiddleboxCompatMode
		self.signPrivateKey = agent.signPrivateKey
		self.httpsPort = agent.httpsPort
		self.caCert = agent.caCert
		self.esm = agent.esm
		self.enableTos = agent.enableTos
		self.customPayloadList = IxCustomPayloadListHTTPServerWrapper(agent)
		self.sslCertPerUser = agent.sslCertPerUser
		self.precedenceTOS = agent.precedenceTOS
		self.integrityCheckOption = agent.integrityCheckOption
		self.flowPercentage = agent.flowPercentage
		self.enableChunkEncoding = agent.enableChunkEncoding
		self.enableCtlsSupport = agent.enableCtlsSupport
		self.sslRecordSize = agent.sslRecordSize
		self.reliabilityTOS = agent.reliabilityTOS
		self.disablePfc = agent.disablePfc
		self.delayTOS = agent.delayTOS
		self.rsaCertDir = agent.rsaCertDir
		self.privateKeyPassword = agent.privateKeyPassword
		self.urlStatsCount = agent.urlStatsCount
		self.tcpCloseOption = agent.tcpCloseOption
		self.enableVlanPriority = agent.enableVlanPriority
		self.enableIntegrityCheck = agent.enableIntegrityCheck
		self.docrootfile = agent.docrootfile
		self.enablesslRecordSize = agent.enablesslRecordSize
		self.encCertificate = agent.encCertificate
		self.dhParams = agent.dhParams
		self.throughputTOS = agent.throughputTOS
		self.requestTimeout = agent.requestTimeout
		self.dontExpectUpgrade = agent.dontExpectUpgrade
		self.enableGlobalPool = agent.enableGlobalPool
		self.enableDHsupport = agent.enableDHsupport
		self.enablePerServerPerURLstat = agent.enablePerServerPerURLstat
		self.urlPageSize = agent.urlPageSize
		self.cookieList = IxCookieListHTTPServerWrapper(agent)
		self.highPerfWithSU = agent.highPerfWithSU
		self.acceptSslConnections = agent.acceptSslConnections
		self.minResponseDelay = agent.minResponseDelay

	properties = ["cmdListLoops", "signCertificate", "privateKey", "vlanPriority", "validateCertificate", "encPrivateKey", "maxResponseDelay", "ecdheCertDir", "docrootChunkSize", "enableTls13Support", "disableMacValidation", "ServerCiphers", "rstTimeout", "ttlValue", "ecdhCertDir", "enableChunkedRequest", "enableEsm", "enableHTTP2", "certificate", "enableNewSslSupport", "tos", "enableSslSendCloseNotify", "enableMD5Checksum", "pfcClass", "httpPort", "enableMiddleboxCompatMode", "signPrivateKey", "httpsPort", "caCert", "esm", "enableTos", "sslCertPerUser", "precedenceTOS", "integrityCheckOption", "flowPercentage", "enableChunkEncoding", "enableCtlsSupport", "sslRecordSize", "reliabilityTOS", "disablePfc", "delayTOS", "rsaCertDir", "privateKeyPassword", "urlStatsCount", "tcpCloseOption", "enableVlanPriority", "enableIntegrityCheck", "docrootfile", "enablesslRecordSize", "encCertificate", "dhParams", "throughputTOS", "requestTimeout", "dontExpectUpgrade", "enableGlobalPool", "enableDHsupport", "enablePerServerPerURLstat", "urlPageSize", "highPerfWithSU", "acceptSslConnections", "minResponseDelay", ]

	def __getattribute__(self, name):
		if name in PluginHTTPServerWrapper.properties and super(PluginHTTPServerWrapper, self).__getattribute__(name):
			return getattr(super(PluginHTTPServerWrapper, self).__getattribute__("_PluginHTTPServerWrapper__agent"), name)
		else:
			return super(PluginHTTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginHTTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginHTTPServerWrapper, self).__getattribute__("_PluginHTTPServerWrapper__agent"), name, value)
			super(PluginHTTPServerWrapper, self).__setattr__(name, value)


class IxTimelineProxyHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyHTTPServerWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.name = timeline.name
		self.standbyTime = timeline.standbyTime
		self.iterations = timeline.iterations
		self.sustainTime = timeline.sustainTime

	properties = ["name", "standbyTime", "iterations", "sustainTime", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyHTTPServerWrapper.properties and super(IxTimelineProxyHTTPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyHTTPServerWrapper, self).__getattribute__("_IxTimelineProxyHTTPServerWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyHTTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyHTTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyHTTPServerWrapper, self).__getattribute__("_IxTimelineProxyHTTPServerWrapper__timeline"), name, value)
			super(IxTimelineProxyHTTPServerWrapper, self).__setattr__(name, value)


class IxwebHttpHeaderListHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent

	def getItem(self, objectID):
		itemList = self.__agent.headerList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "_httpHeaderString":
				return _httpHeaderStringHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return _httpHeaderStringHTTPClientWrapper(self.__agent.headerList.appendItem(**kwargs))

	def getList(self):
		return self.__agent.headerList

	def clear(self):
		return self.__agent.headerList.clear()


class _httpHeaderStringHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, _httpHeaderString):
		super(_httpHeaderStringHTTPClientWrapper, self).__init__(_httpHeaderString)
		self.___httpHeaderString = _httpHeaderString
		self.data = _httpHeaderString.data

	properties = ["data", ]

	def __getattribute__(self, name):
		if name in _httpHeaderStringHTTPClientWrapper.properties and super(_httpHeaderStringHTTPClientWrapper, self).__getattribute__(name):
			return getattr(super(_httpHeaderStringHTTPClientWrapper, self).__getattribute__("__httpHeaderStringHTTPClientWrapper___httpHeaderString"), name)
		else:
			return super(_httpHeaderStringHTTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(_httpHeaderStringHTTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(_httpHeaderStringHTTPClientWrapper, self).__getattribute__("__httpHeaderStringHTTPClientWrapper___httpHeaderString"), name, value)
			super(_httpHeaderStringHTTPClientWrapper, self).__setattr__(name, value)


class IxCommandPercentagePoolHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, cmdPercentagePool):
		super(IxCommandPercentagePoolHTTPClientWrapper, self).__init__(cmdPercentagePool)
		self.__cmdPercentagePool = cmdPercentagePool

	properties = []

	def __getattribute__(self, name):
		if name in IxCommandPercentagePoolHTTPClientWrapper.properties and super(IxCommandPercentagePoolHTTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxCommandPercentagePoolHTTPClientWrapper, self).__getattribute__("_IxCommandPercentagePoolHTTPClientWrapper__cmdPercentagePool"), name)
		else:
			return super(IxCommandPercentagePoolHTTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxCommandPercentagePoolHTTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxCommandPercentagePoolHTTPClientWrapper, self).__getattribute__("_IxCommandPercentagePoolHTTPClientWrapper__cmdPercentagePool"), name, value)
			super(IxCommandPercentagePoolHTTPClientWrapper, self).__setattr__(name, value)


class IxHttpCommandListHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent
		self.optionsDict = {
			('GET',): "IxHttpCommandHTTPClient",
			('START',): "IxStartCommandHTTPClient",
			('STOP',): "IxStopCommandHTTPClient",
			('HEAD',): "IxHttpCommandHTTPClient",
			('POST',): "IxHttpCommandHTTPClient",
			('DELETE',): "IxHttpCommandHTTPClient",
			('PUT',): "IxHttpCommandHTTPClient",
			('LoopBeginCommand',): "IxLoopBeginCommandHTTPClient",
			('THINK',): "IxThinkCommandHTTPClient",
			('UseCmdFromPool',): "IxUseCmdFromPoolHTTPClient",
			('LoopEndCommand',): "IxLoopEndCommandHTTPClient",
		}

	def getItemIxGetCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixHttpCommand":
				return IxHttpCommandHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxGetCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "GET"})
		return IxHttpCommandHTTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxStartCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixStartCommand":
				return IxStartCommandHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStartCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "START"})
		return IxStartCommandHTTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxStopCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixStopCommand":
				return IxStopCommandHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STOP"})
		return IxStopCommandHTTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, commandType=None):
		kwargs = {}
		kwargs.update({"commandType": commandType})
		return self.__agent.actionList.appendItem(**kwargs)

	def getList(self):
		return self.__agent.actionList

	def clear(self):
		return self.__agent.actionList.clear()

	def getItemIxHeadCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixHttpCommand":
				return IxHttpCommandHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxHeadCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "HEAD"})
		return IxHttpCommandHTTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxPostCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixHttpCommand":
				return IxHttpCommandHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxPostCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "POST"})
		return IxHttpCommandHTTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxDeleteCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixHttpCommand":
				return IxHttpCommandHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxDeleteCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "DELETE"})
		return IxHttpCommandHTTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxPutCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixHttpCommand":
				return IxHttpCommandHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxPutCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "PUT"})
		return IxHttpCommandHTTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxLoopbegincommandCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixLoopBeginCommand":
				return IxLoopBeginCommandHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopbegincommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopBeginCommand"})
		return IxLoopBeginCommandHTTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxThinkCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixThinkCommand":
				return IxThinkCommandHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxThinkCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "THINK"})
		return IxThinkCommandHTTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxUsecmdfrompoolCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixUseCmdFromPool":
				return IxUseCmdFromPoolHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxUsecmdfrompoolCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "UseCmdFromPool"})
		return IxUseCmdFromPoolHTTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxLoopendcommandCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixLoopEndCommand":
				return IxLoopEndCommandHTTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopendcommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopEndCommand"})
		return IxLoopEndCommandHTTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))


class IxStartCommandHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixStartCommand):
		super(IxStartCommandHTTPClientWrapper, self).__init__(ixStartCommand)
		self.__ixStartCommand = ixStartCommand
		self.commandType = ixStartCommand.commandType
		self.cmdName = ixStartCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxStartCommandHTTPClientWrapper.properties and super(IxStartCommandHTTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxStartCommandHTTPClientWrapper, self).__getattribute__("_IxStartCommandHTTPClientWrapper__ixStartCommand"), name)
		else:
			return super(IxStartCommandHTTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxStartCommandHTTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxStartCommandHTTPClientWrapper, self).__getattribute__("_IxStartCommandHTTPClientWrapper__ixStartCommand"), name, value)
			super(IxStartCommandHTTPClientWrapper, self).__setattr__(name, value)


class IxHttpCommandHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixHttpCommand):
		super(IxHttpCommandHTTPClientWrapper, self).__init__(ixHttpCommand)
		self.__ixHttpCommand = ixHttpCommand
		self.profile = ixHttpCommand.profile
		self.enableDi = ixHttpCommand.enableDi
		self.namevalueargs = ixHttpCommand.namevalueargs
		self.useSsl = ixHttpCommand.useSsl
		self.sendMD5ChkSumHeader = ixHttpCommand.sendMD5ChkSumHeader
		self.destination = ixHttpCommand.destination
		self.streamIden = ixHttpCommand.streamIden
		self.windowSize = ixHttpCommand.windowSize
		self.pingFreq = ixHttpCommand.pingFreq
		self.method = ixHttpCommand.method
		self.commandType = ixHttpCommand.commandType
		self.abort = ixHttpCommand.abort
		self.cmdName = ixHttpCommand.cmdName
		self.sslProfile = ixHttpCommand.sslProfile
		self.pageObject = ixHttpCommand.pageObject
		self.sendingChunkSize = ixHttpCommand.sendingChunkSize
		self.arguments = ixHttpCommand.arguments

	properties = ["profile", "enableDi", "namevalueargs", "useSsl", "sendMD5ChkSumHeader", "destination", "streamIden", "windowSize", "pingFreq", "method", "commandType", "abort", "cmdName", "sslProfile", "pageObject", "sendingChunkSize", "arguments", ]

	def __getattribute__(self, name):
		if name in IxHttpCommandHTTPClientWrapper.properties and super(IxHttpCommandHTTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxHttpCommandHTTPClientWrapper, self).__getattribute__("_IxHttpCommandHTTPClientWrapper__ixHttpCommand"), name)
		else:
			return super(IxHttpCommandHTTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxHttpCommandHTTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxHttpCommandHTTPClientWrapper, self).__getattribute__("_IxHttpCommandHTTPClientWrapper__ixHttpCommand"), name, value)
			super(IxHttpCommandHTTPClientWrapper, self).__setattr__(name, value)


class IxStopCommandHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixStopCommand):
		super(IxStopCommandHTTPClientWrapper, self).__init__(ixStopCommand)
		self.__ixStopCommand = ixStopCommand
		self.commandType = ixStopCommand.commandType
		self.cmdName = ixStopCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxStopCommandHTTPClientWrapper.properties and super(IxStopCommandHTTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxStopCommandHTTPClientWrapper, self).__getattribute__("_IxStopCommandHTTPClientWrapper__ixStopCommand"), name)
		else:
			return super(IxStopCommandHTTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxStopCommandHTTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxStopCommandHTTPClientWrapper, self).__getattribute__("_IxStopCommandHTTPClientWrapper__ixStopCommand"), name, value)
			super(IxStopCommandHTTPClientWrapper, self).__setattr__(name, value)


class IxResponseHeaderListHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent

	def getItem(self, objectID):
		itemList = self.__agent.responseHeaderList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixResponseHeader":
				return IxResponseHeaderHTTPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxResponseHeaderHTTPServerWrapper(self.__agent.responseHeaderList.appendItem(**kwargs))

	def getList(self):
		return self.__agent.responseHeaderList

	def clear(self):
		return self.__agent.responseHeaderList.clear()


class IxResponseHeaderHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixResponseHeader):
		super(IxResponseHeaderHTTPServerWrapper, self).__init__(ixResponseHeader)
		self.__ixResponseHeader = ixResponseHeader
		self.mimeType = ixResponseHeader.mimeType
		self.code = ixResponseHeader.code
		self.lastModifiedMode = ixResponseHeader.lastModifiedMode
		self.dateTimeValue = ixResponseHeader.dateTimeValue
		self.expirationAfterRequestValue = ixResponseHeader.expirationAfterRequestValue
		self.description = ixResponseHeader.description
		self.enableCustomPutResponse = ixResponseHeader.enableCustomPutResponse
		self.expirationDateTimeValue = ixResponseHeader.expirationDateTimeValue
		self.expirationAfterLastModifiedValue = ixResponseHeader.expirationAfterLastModifiedValue
		self.dateIncrementFor = ixResponseHeader.dateIncrementFor
		self.dateIncrementEnable = ixResponseHeader.dateIncrementEnable
		self.lastModifiedIncrementEnable = ixResponseHeader.lastModifiedIncrementEnable
		self.dateZone = ixResponseHeader.dateZone
		self.lastModifiedDateTimeValue = ixResponseHeader.lastModifiedDateTimeValue
		self.readOnly = ixResponseHeader.readOnly
		self.lastModifiedIncrementBy = ixResponseHeader.lastModifiedIncrementBy
		self.expirationMode = ixResponseHeader.expirationMode
		self.name = ixResponseHeader.name
		self.lastModifiedIncrementFor = ixResponseHeader.lastModifiedIncrementFor
		self.dateMode = ixResponseHeader.dateMode
		self.dateIncrementBy = ixResponseHeader.dateIncrementBy

	properties = ["mimeType", "code", "lastModifiedMode", "dateTimeValue", "expirationAfterRequestValue", "description", "enableCustomPutResponse", "expirationDateTimeValue", "expirationAfterLastModifiedValue", "dateIncrementFor", "dateIncrementEnable", "lastModifiedIncrementEnable", "dateZone", "lastModifiedDateTimeValue", "readOnly", "lastModifiedIncrementBy", "expirationMode", "name", "lastModifiedIncrementFor", "dateMode", "dateIncrementBy", ]

	def __getattribute__(self, name):
		if name in IxResponseHeaderHTTPServerWrapper.properties and super(IxResponseHeaderHTTPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxResponseHeaderHTTPServerWrapper, self).__getattribute__("_IxResponseHeaderHTTPServerWrapper__ixResponseHeader"), name)
		else:
			return super(IxResponseHeaderHTTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxResponseHeaderHTTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxResponseHeaderHTTPServerWrapper, self).__getattribute__("_IxResponseHeaderHTTPServerWrapper__ixResponseHeader"), name, value)
			super(IxResponseHeaderHTTPServerWrapper, self).__setattr__(name, value)


class IxWebPageListHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent

	def getItem(self, objectID):
		itemList = self.__agent.webPageList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixWebPageObject":
				return IxWebPageObjectHTTPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxWebPageObjectHTTPServerWrapper(self.__agent.webPageList.appendItem(**kwargs))

	def getList(self):
		return self.__agent.webPageList

	def clear(self):
		return self.__agent.webPageList.clear()


class IxWebPageObjectHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixWebPageObject):
		super(IxWebPageObjectHTTPServerWrapper, self).__init__(ixWebPageObject)
		self.__ixWebPageObject = ixWebPageObject
		self.chunkSize = ixWebPageObject.chunkSize
		self.Md5Option = ixWebPageObject.Md5Option
		self.cookieId = ixWebPageObject.cookieId
		self.payloadSize = ixWebPageObject.payloadSize
		self.customPayloadId = ixWebPageObject.customPayloadId
		self.payloadType = ixWebPageObject.payloadType
		self.payloadFile = ixWebPageObject.payloadFile
		self.response = IxResponseHeaderHTTPServerWrapper(ixWebPageObject.response)
		self.page = ixWebPageObject.page

	properties = ["chunkSize", "Md5Option", "cookieId", "payloadSize", "customPayloadId", "payloadType", "payloadFile", "page", ]

	def __getattribute__(self, name):
		if name in IxWebPageObjectHTTPServerWrapper.properties and super(IxWebPageObjectHTTPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxWebPageObjectHTTPServerWrapper, self).__getattribute__("_IxWebPageObjectHTTPServerWrapper__ixWebPageObject"), name)
		else:
			return super(IxWebPageObjectHTTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxWebPageObjectHTTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxWebPageObjectHTTPServerWrapper, self).__getattribute__("_IxWebPageObjectHTTPServerWrapper__ixWebPageObject"), name, value)
			super(IxWebPageObjectHTTPServerWrapper, self).__setattr__(name, value)


class IxCustomPayloadListHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent

	def getItem(self, objectID):
		itemList = self.__agent.customPayloadList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixCustomPayloadObject":
				return IxCustomPayloadObjectHTTPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxCustomPayloadObjectHTTPServerWrapper(self.__agent.customPayloadList.appendItem(**kwargs))

	def getList(self):
		return self.__agent.customPayloadList

	def clear(self):
		return self.__agent.customPayloadList.clear()


class IxCustomPayloadObjectHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixCustomPayloadObject):
		super(IxCustomPayloadObjectHTTPServerWrapper, self).__init__(ixCustomPayloadObject)
		self.__ixCustomPayloadObject = ixCustomPayloadObject
		self.asciiPayloadValue = ixCustomPayloadObject.asciiPayloadValue
		self.repeat = ixCustomPayloadObject.repeat
		self.name = ixCustomPayloadObject.name
		self.payloadmode = ixCustomPayloadObject.payloadmode
		self.readOnly = ixCustomPayloadObject.readOnly
		self.offset = ixCustomPayloadObject.offset
		self.hexPayloadValue = ixCustomPayloadObject.hexPayloadValue
		self.payloadPosition = ixCustomPayloadObject.payloadPosition
		self.id = ixCustomPayloadObject.id

	properties = ["asciiPayloadValue", "repeat", "name", "payloadmode", "readOnly", "offset", "hexPayloadValue", "payloadPosition", "id", ]

	def __getattribute__(self, name):
		if name in IxCustomPayloadObjectHTTPServerWrapper.properties and super(IxCustomPayloadObjectHTTPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxCustomPayloadObjectHTTPServerWrapper, self).__getattribute__("_IxCustomPayloadObjectHTTPServerWrapper__ixCustomPayloadObject"), name)
		else:
			return super(IxCustomPayloadObjectHTTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxCustomPayloadObjectHTTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxCustomPayloadObjectHTTPServerWrapper, self).__getattribute__("_IxCustomPayloadObjectHTTPServerWrapper__ixCustomPayloadObject"), name, value)
			super(IxCustomPayloadObjectHTTPServerWrapper, self).__setattr__(name, value)


class IxCookieListHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent

	def getItem(self, objectID):
		itemList = self.__agent.cookieList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixCookieObject":
				return IxCookieObjectHTTPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxCookieObjectHTTPServerWrapper(self.__agent.cookieList.appendItem(**kwargs))

	def getList(self):
		return self.__agent.cookieList

	def clear(self):
		return self.__agent.cookieList.clear()


class IxCookieObjectHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixCookieObject):
		super(IxCookieObjectHTTPServerWrapper, self).__init__(ixCookieObject)
		self.__ixCookieObject = ixCookieObject
		self.name = ixCookieObject.name
		self.readOnly = ixCookieObject.readOnly
		self.cookieContentList = IxCookieContentListHTTPServerWrapper(ixCookieObject)
		self.mode = ixCookieObject.mode
		self.type = ixCookieObject.type
		self.description = ixCookieObject.description

	properties = ["name", "readOnly", "mode", "type", "description", ]

	def __getattribute__(self, name):
		if name in IxCookieObjectHTTPServerWrapper.properties and super(IxCookieObjectHTTPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxCookieObjectHTTPServerWrapper, self).__getattribute__("_IxCookieObjectHTTPServerWrapper__ixCookieObject"), name)
		else:
			return super(IxCookieObjectHTTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxCookieObjectHTTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxCookieObjectHTTPServerWrapper, self).__getattribute__("_IxCookieObjectHTTPServerWrapper__ixCookieObject"), name, value)
			super(IxCookieObjectHTTPServerWrapper, self).__setattr__(name, value)


class IxCookieContentListHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixCookieObject):
		self.__ixCookieObject = ixCookieObject

	def getItem(self, objectID):
		itemList = self.__ixCookieObject.cookieContentList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixCookieContent":
				return IxCookieContentHTTPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxCookieContentHTTPServerWrapper(self.__ixCookieObject.cookieContentList.appendItem(**kwargs))

	def getList(self):
		return self.__ixCookieObject.cookieContentList

	def clear(self):
		return self.__ixCookieObject.cookieContentList.clear()


class IxCookieContentHTTPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixCookieContent):
		super(IxCookieContentHTTPServerWrapper, self).__init__(ixCookieContent)
		self.__ixCookieContent = ixCookieContent
		self.domain = ixCookieContent.domain
		self.name = ixCookieContent.name
		self.maxAge = ixCookieContent.maxAge
		self.value = ixCookieContent.value
		self.other = ixCookieContent.other
		self.path = ixCookieContent.path

	properties = ["domain", "name", "maxAge", "value", "other", "path", ]

	def __getattribute__(self, name):
		if name in IxCookieContentHTTPServerWrapper.properties and super(IxCookieContentHTTPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxCookieContentHTTPServerWrapper, self).__getattribute__("_IxCookieContentHTTPServerWrapper__ixCookieContent"), name)
		else:
			return super(IxCookieContentHTTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxCookieContentHTTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxCookieContentHTTPServerWrapper, self).__getattribute__("_IxCookieContentHTTPServerWrapper__ixCookieContent"), name, value)
			super(IxCookieContentHTTPServerWrapper, self).__setattr__(name, value)


class IxUseCmdFromPoolHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixUseCmdFromPool):
		super(IxUseCmdFromPoolHTTPClientWrapper, self).__init__(ixUseCmdFromPool)
		self.__ixUseCmdFromPool = ixUseCmdFromPool
		self.commandType = ixUseCmdFromPool.commandType

	properties = ["commandType", ]

	def __getattribute__(self, name):
		if name in IxUseCmdFromPoolHTTPClientWrapper.properties and super(IxUseCmdFromPoolHTTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxUseCmdFromPoolHTTPClientWrapper, self).__getattribute__("_IxUseCmdFromPoolHTTPClientWrapper__ixUseCmdFromPool"), name)
		else:
			return super(IxUseCmdFromPoolHTTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxUseCmdFromPoolHTTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxUseCmdFromPoolHTTPClientWrapper, self).__getattribute__("_IxUseCmdFromPoolHTTPClientWrapper__ixUseCmdFromPool"), name, value)
			super(IxUseCmdFromPoolHTTPClientWrapper, self).__setattr__(name, value)


class IxLoopBeginCommandHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixLoopBeginCommand):
		super(IxLoopBeginCommandHTTPClientWrapper, self).__init__(ixLoopBeginCommand)
		self.__ixLoopBeginCommand = ixLoopBeginCommand
		self.commandType = ixLoopBeginCommand.commandType
		self.cmdName = ixLoopBeginCommand.cmdName
		self.LoopCount = ixLoopBeginCommand.LoopCount

	properties = ["commandType", "cmdName", "LoopCount", ]

	def __getattribute__(self, name):
		if name in IxLoopBeginCommandHTTPClientWrapper.properties and super(IxLoopBeginCommandHTTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxLoopBeginCommandHTTPClientWrapper, self).__getattribute__("_IxLoopBeginCommandHTTPClientWrapper__ixLoopBeginCommand"), name)
		else:
			return super(IxLoopBeginCommandHTTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxLoopBeginCommandHTTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxLoopBeginCommandHTTPClientWrapper, self).__getattribute__("_IxLoopBeginCommandHTTPClientWrapper__ixLoopBeginCommand"), name, value)
			super(IxLoopBeginCommandHTTPClientWrapper, self).__setattr__(name, value)


class IxLoopEndCommandHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixLoopEndCommand):
		super(IxLoopEndCommandHTTPClientWrapper, self).__init__(ixLoopEndCommand)
		self.__ixLoopEndCommand = ixLoopEndCommand
		self.commandType = ixLoopEndCommand.commandType
		self.cmdName = ixLoopEndCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxLoopEndCommandHTTPClientWrapper.properties and super(IxLoopEndCommandHTTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxLoopEndCommandHTTPClientWrapper, self).__getattribute__("_IxLoopEndCommandHTTPClientWrapper__ixLoopEndCommand"), name)
		else:
			return super(IxLoopEndCommandHTTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxLoopEndCommandHTTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxLoopEndCommandHTTPClientWrapper, self).__getattribute__("_IxLoopEndCommandHTTPClientWrapper__ixLoopEndCommand"), name, value)
			super(IxLoopEndCommandHTTPClientWrapper, self).__setattr__(name, value)


class IxThinkCommandHTTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixThinkCommand):
		super(IxThinkCommandHTTPClientWrapper, self).__init__(ixThinkCommand)
		self.__ixThinkCommand = ixThinkCommand
		self.minimumInterval = ixThinkCommand.minimumInterval
		self.cmdName = ixThinkCommand.cmdName
		self.commandType = ixThinkCommand.commandType
		self.maximumInterval = ixThinkCommand.maximumInterval

	properties = ["minimumInterval", "cmdName", "commandType", "maximumInterval", ]

	def __getattribute__(self, name):
		if name in IxThinkCommandHTTPClientWrapper.properties and super(IxThinkCommandHTTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxThinkCommandHTTPClientWrapper, self).__getattribute__("_IxThinkCommandHTTPClientWrapper__ixThinkCommand"), name)
		else:
			return super(IxThinkCommandHTTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxThinkCommandHTTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxThinkCommandHTTPClientWrapper, self).__getattribute__("_IxThinkCommandHTTPClientWrapper__ixThinkCommand"), name, value)
			super(IxThinkCommandHTTPClientWrapper, self).__setattr__(name, value)


class StatsNameStatelessPeer(object):
	def __init__(self):
		self.kRxLatencyBucket50100ms = "Rx Latency Bucket 50-100 ms"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kLatencyBucket25ms = "Latency Bucket 2-5 ms"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kPostfragmentsSent = "Postfragments Sent"
		self.kPostfragmentsReceived = "Postfragments Received"
		self.kESPPacketsReceived = "ESP Packets Received"
		self.kRxLatencyBucket1025ms = "Rx Latency Bucket 10-25 ms"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kOutOfOrderPacketsRxSide = "Out Of Order Packets (Rx Side)"
		self.kFragmentsSent = "Fragments Sent"
		self.kRxOutOfOrderPackets = "Rx Out Of Order Packets"
		self.kTotalPacketsReceived = "Total Packets Received"
		self.kActiveStreamsTransmitting = "Active Streams Transmitting"
		self.kLatencyBucket200500ms = "Latency Bucket 200-500 ms"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kCleartextPacketsReceived = "Cleartext Packets Received"
		self.kRxLatencyBucket25ms = "Rx Latency Bucket 2-5 ms"
		self.kLatencyBucket100200ms = "Latency Bucket 100-200 ms"
		self.kLostPacketsRxSide = "Lost Packets (Rx Side)"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kLatencyBucketUndefined = "Latency Bucket Undefined"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kRxLatencyMax = "Rx Latency Max"
		self.kESPBytesReceived = "ESP Bytes Received"
		self.kRxAvgJitterns = "Rx Avg Jitter (ns)"
		self.kRxLatencyBucketUndefined = "Rx Latency Bucket Undefined"
		self.kRxLatencyMin = "Rx Latency Min"
		self.kRxLatencyBucket02ms = "Rx Latency Bucket 0-2 ms"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kRxLatencyBucket2550ms = "Rx Latency Bucket 25-50 ms"
		self.kPacketsDroppedTxSide = "Packets Dropped (Tx Side)"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kRxMinJitterns = "Rx Min Jitter (ns)"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kLatencyBucket50100ms = "Latency Bucket 50-100 ms"
		self.kESPPacketsSent = "ESP Packets Sent"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kRxLatencyBucket510ms = "Rx Latency Bucket 5-10 ms"
		self.kPacketsSentSecond = "Packets Sent/Second"
		self.kCleartextBytesSent = "Cleartext Bytes Sent"
		self.kInitiatorPeerCount = "Initiator Peer Count"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kRxIntegrityCheckSucceeded = "Rx Integrity Check Succeeded"
		self.kTCPRetries = "TCP Retries"
		self.kRxLatencyBucket200500ms = "Rx Latency Bucket 200-500 ms"
		self.kRxMaxJitterns = "Rx Max Jitter (ns)"
		self.kPrefragmentsError = "Prefragments Error"
		self.kPrefragmentsReceived = "Prefragments Received"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kTotalBytesSent = "Total Bytes Sent"
		self.kPostfragmentsError = "Postfragments Error"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kTxJitterns = "Tx Jitter (ns)"
		self.kFragmentsError = "Fragments Error"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kFragmentsReceived = "Fragments Received"
		self.kLatencyBucket500msandAbove = "Latency Bucket 500 ms and Above"
		self.kTotalTriggersReceived = "Total Triggers Received"
		self.kPacketsReceivedSecond = "Packets Received/Second"
		self.kLatencyMinus = "Latency Min (us)"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kFragmentsRXErrors = "Fragments RX Errors"
		self.kLatencyBucket2550ms = "Latency Bucket 25-50 ms"
		self.kCleartextPacketsSent = "Cleartext Packets Sent"
		self.kRxLatencyBucket500andAbove = "Rx Latency Bucket 500 and Above"
		self.kCleartextBytesReceived = "Cleartext Bytes Received"
		self.kRxLatencyAverage = "Rx Latency Average"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kRxLatencyBucket100200ms = "Rx Latency Bucket 100-200 ms"
		self.kTxPacketsDropped = "Tx Packets Dropped"
		self.kLatencyAverageus = "Latency Average (us)"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kRxIntegrityCheckFailed = "Rx Integrity Check Failed"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kPrefragmentsSent = "Prefragments Sent"
		self.kLatencyBucket510ms = "Latency Bucket 5-10 ms"
		self.kTotalTriggersSent = "Total Triggers Sent"
		self.kTxBitRateKbps = "Tx Bit Rate (Kbps)"
		self.kRxBitRateKbps = "Rx Bit Rate (Kbps)"
		self.kESPBytesSent = "ESP Bytes Sent"
		self.kRxInterPacketGapns = "Rx Inter Packet Gap (ns)"
		self.kResponderPeerCount = "Responder Peer Count"
		self.kRxLostPackets = "Rx Lost Packets"
		self.kLatencyMaxus = "Latency Max (us)"
		self.kLatencyBucket1025ms = "Latency Bucket 10-25 ms"
		self.kTotalPacketsSent = "Total Packets Sent"
		self.kTotalBytesReceived = "Total Bytes Received"
		self.kLatencyBucket02ms = "Latency Bucket 0-2 ms"
		self.kTCPFINReceived = "TCP FIN Received"


class IxActivitystatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivitystatelessPeerWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.secondaryEnableConstraint = ixActivity.secondaryEnableConstraint
		self.protocol = ixActivity.protocol
		self.userIpMapping = ixActivity.userIpMapping
		self.enableConstraint = ixActivity.enableConstraint
		self.agent = PluginstatelessPeerWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.constraintValue = ixActivity.constraintValue
		self.customParameters = IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper(ixActivity.customParameters)
		self.timelineId = ixActivity.timelineId
		self.role = ixActivity.role
		self.timeline = IxTimelineProxystatelessPeerWrapper(ixActivity.timeline)
		self.activeRole = ixActivity.activeRole
		self.type = ixActivity.type
		self.secondaryConstraintValue = ixActivity.secondaryConstraintValue
		self.enable = ixActivity.enable
		self.protocolAndType = ixActivity.protocolAndType
		self.userObjectiveType = ixActivity.userObjectiveType
		self.destinationIpMapping = ixActivity.destinationIpMapping
		self.name = ixActivity.name
		self.secondaryConstraintType = ixActivity.secondaryConstraintType
		self.userObjectiveValue = ixActivity.userObjectiveValue
		self.constraintType = ixActivity.constraintType

	properties = ["secondaryEnableConstraint", "protocol", "userIpMapping", "enableConstraint", "objectivePercent", "constraintValue", "timelineId", "role", "activeRole", "type", "secondaryConstraintValue", "enable", "protocolAndType", "userObjectiveType", "destinationIpMapping", "name", "secondaryConstraintType", "userObjectiveValue", "constraintType", ]

	def __getattribute__(self, name):
		if name in IxActivitystatelessPeerWrapper.properties and super(IxActivitystatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxActivitystatelessPeerWrapper, self).__getattribute__("_IxActivitystatelessPeerWrapper__ixActivity"), name)
		else:
			return super(IxActivitystatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivitystatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivitystatelessPeerWrapper, self).__getattribute__("_IxActivitystatelessPeerWrapper__ixActivity"), name, value)
			super(IxActivitystatelessPeerWrapper, self).__setattr__(name, value)


class PluginstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginstatelessPeerWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.pm = IxPropertyMap_statelessstatelessPeerWrapper(agent.pm)
		self.flowPercentage = agent.flowPercentage

	properties = ["cmdListLoops", "flowPercentage", ]

	def __getattribute__(self, name):
		if name in PluginstatelessPeerWrapper.properties and super(PluginstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(PluginstatelessPeerWrapper, self).__getattribute__("_PluginstatelessPeerWrapper__agent"), name)
		else:
			return super(PluginstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginstatelessPeerWrapper, self).__getattribute__("_PluginstatelessPeerWrapper__agent"), name, value)
			super(PluginstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, customParameters):
		super(IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper, self).__init__(customParameters)
		self.__customParameters = customParameters
		self.throughputUnit = customParameters.throughputUnit

	properties = ["throughputUnit", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper.properties and super(IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper__customParameters"), name)
		else:
			return super(IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper__customParameters"), name, value)
			super(IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper, self).__setattr__(name, value)


class IxTimelineProxystatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxystatelessPeerWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.iterations = timeline.iterations
		self.rampUpType = timeline.rampUpType
		self.rampUpValue = timeline.rampUpValue
		self.rampUpTime = timeline.rampUpTime
		self.rampDownTime = timeline.rampDownTime
		self.standbyTime = timeline.standbyTime
		self.rampDownValue = timeline.rampDownValue
		self.rampUpInterval = timeline.rampUpInterval
		self.offlineTime = timeline.offlineTime
		self.sustainTime = timeline.sustainTime
		self.name = timeline.name
		self.timelineType = timeline.timelineType

	properties = ["iterations", "rampUpType", "rampUpValue", "rampUpTime", "rampDownTime", "standbyTime", "rampDownValue", "rampUpInterval", "offlineTime", "sustainTime", "name", "timelineType", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxystatelessPeerWrapper.properties and super(IxTimelineProxystatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxystatelessPeerWrapper, self).__getattribute__("_IxTimelineProxystatelessPeerWrapper__timeline"), name)
		else:
			return super(IxTimelineProxystatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxystatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxystatelessPeerWrapper, self).__getattribute__("_IxTimelineProxystatelessPeerWrapper__timeline"), name, value)
			super(IxTimelineProxystatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyMap_statelessstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		super(IxPropertyMap_statelessstatelessPeerWrapper, self).__init__(pm)
		self.__pm = pm
		self.customActivityParams = IxPropertyClass_ixCustomActivityParametersstatelessPeerWrapper(pm.customActivityParams)
		self.availableTosList = IxPropertyGroupSequence_stateless_availableTosListstatelessPeerWrapper(pm)
		self.advOptions = IxPropertyClass_AdvancedOptionsstatelessPeerWrapper(pm.advOptions)
		self.protocolFlows = IxPropertyGroupSequence_stateless_protocolFlowsstatelessPeerWrapper(pm)
		self.lossCommunicationParameters = IxPropertyClass_BackplaneCommunicationstatelessPeerWrapper(pm.lossCommunicationParameters)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyMap_statelessstatelessPeerWrapper.properties and super(IxPropertyMap_statelessstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyMap_statelessstatelessPeerWrapper, self).__getattribute__("_IxPropertyMap_statelessstatelessPeerWrapper__pm"), name)
		else:
			return super(IxPropertyMap_statelessstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyMap_statelessstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyMap_statelessstatelessPeerWrapper, self).__getattribute__("_IxPropertyMap_statelessstatelessPeerWrapper__pm"), name, value)
			super(IxPropertyMap_statelessstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_stateless_availableTosListstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm

	def getItem(self, objectID):
		itemList = self.__pm.availableTosList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_AvailableTypeOfService":
				return IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper(self.__pm.availableTosList.appendItem(**kwargs))

	def getList(self):
		return self.__pm.availableTosList

	def clear(self):
		return self.__pm.availableTosList.clear()


class IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_AvailableTypeOfService):
		super(IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper, self).__init__(ixPropertyClass_AvailableTypeOfService)
		self.__ixPropertyClass_AvailableTypeOfService = ixPropertyClass_AvailableTypeOfService
		self.tos_value = ixPropertyClass_AvailableTypeOfService.tos_value

	properties = ["tos_value", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper.properties and super(IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper__ixPropertyClass_AvailableTypeOfService"), name)
		else:
			return super(IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper__ixPropertyClass_AvailableTypeOfService"), name, value)
			super(IxPropertyClass_AvailableTypeOfServicestatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_AdvancedOptionsstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, advOptions):
		super(IxPropertyClass_AdvancedOptionsstatelessPeerWrapper, self).__init__(advOptions)
		self.__advOptions = advOptions
		self.enableTOS = advOptions.enableTOS
		self.enableHeaderCacheHack = advOptions.enableHeaderCacheHack
		self.enablePerStreamStats = advOptions.enablePerStreamStats
		self.ipPreference = advOptions.ipPreference
		self.enableOutOfOrderStats = advOptions.enableOutOfOrderStats
		self.cycleThroughInterfaces = advOptions.cycleThroughInterfaces
		self.cycleThroughPercentage = advOptions.cycleThroughPercentage
		self.disablePromotion = advOptions.disablePromotion
		self.enableTimestamp = advOptions.enableTimestamp
		self.typeOfService = advOptions.typeOfService
		self.parallelCmdCnt = advOptions.parallelCmdCnt
		self.trafficGenerator = advOptions.trafficGenerator
		self.seedRandom = advOptions.seedRandom
		self.cycleThroughDuration = advOptions.cycleThroughDuration
		self.enableIntegrityCheck = advOptions.enableIntegrityCheck
		self.ttlValue = advOptions.ttlValue

	properties = ["enableTOS", "enableHeaderCacheHack", "enablePerStreamStats", "ipPreference", "enableOutOfOrderStats", "cycleThroughInterfaces", "cycleThroughPercentage", "disablePromotion", "enableTimestamp", "typeOfService", "parallelCmdCnt", "trafficGenerator", "seedRandom", "cycleThroughDuration", "enableIntegrityCheck", "ttlValue", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AdvancedOptionsstatelessPeerWrapper.properties and super(IxPropertyClass_AdvancedOptionsstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AdvancedOptionsstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_AdvancedOptionsstatelessPeerWrapper__advOptions"), name)
		else:
			return super(IxPropertyClass_AdvancedOptionsstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AdvancedOptionsstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AdvancedOptionsstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_AdvancedOptionsstatelessPeerWrapper__advOptions"), name, value)
			super(IxPropertyClass_AdvancedOptionsstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_stateless_protocolFlowsstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm
		self.optionsDict = {
			('GenerateIPStream',): "IxPropertyClass_GenerateIPStreamstatelessPeer",
			('STOP',): "IxPropertyCommandStopstatelessPeer",
			('START',): "IxPropertyCommandStartstatelessPeer",
			('GenerateTrigger',): "IxPropertyClass_GenerateTriggerstatelessPeer",
			('LoopBeginCommand',): "IxPropertyClass_LoopBeginCommandstatelessPeer",
			('GenerateStream',): "IxPropertyClass_GenerateStreamstatelessPeer",
			('LoopEndCommand',): "IxPropertyClass_LoopEndCommandstatelessPeer",
			('THINK',): "IxPropertyCommandThinkstatelessPeer",
			('WaitForFirstTrigger',): "IxPropertyClass_WaitForFirstTriggerstatelessPeer",
			('WaitForTrigger',): "IxPropertyClass_WaitForTriggerstatelessPeer",
		}

	def getItemIxGenerateipstreamCommand(self, objectID):
		itemList = self.__pm.protocolFlows
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_GenerateIPStream":
				return IxPropertyClass_GenerateIPStreamstatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxGenerateipstreamCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "GenerateIPStream"})
		return IxPropertyClass_GenerateIPStreamstatelessPeerWrapper(self.__pm.protocolFlows.appendItem(**kwargs))

	def getItemIxStopCommand(self, objectID):
		itemList = self.__pm.protocolFlows
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandStop":
				return IxPropertyCommandStopstatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STOP"})
		return IxPropertyCommandStopstatelessPeerWrapper(self.__pm.protocolFlows.appendItem(**kwargs))

	def getItemIxStartCommand(self, objectID):
		itemList = self.__pm.protocolFlows
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandStart":
				return IxPropertyCommandStartstatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStartCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "START"})
		return IxPropertyCommandStartstatelessPeerWrapper(self.__pm.protocolFlows.appendItem(**kwargs))

	def getItemIxGeneratetriggerCommand(self, objectID):
		itemList = self.__pm.protocolFlows
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_GenerateTrigger":
				return IxPropertyClass_GenerateTriggerstatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxGeneratetriggerCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "GenerateTrigger"})
		return IxPropertyClass_GenerateTriggerstatelessPeerWrapper(self.__pm.protocolFlows.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__pm.protocolFlows
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, commandType=None):
		kwargs = {}
		kwargs.update({"commandType": commandType})
		return self.__pm.protocolFlows.appendItem(**kwargs)

	def getList(self):
		return self.__pm.protocolFlows

	def clear(self):
		return self.__pm.protocolFlows.clear()

	def getItemIxLoopbegincommandCommand(self, objectID):
		itemList = self.__pm.protocolFlows
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_LoopBeginCommand":
				return IxPropertyClass_LoopBeginCommandstatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopbegincommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopBeginCommand"})
		return IxPropertyClass_LoopBeginCommandstatelessPeerWrapper(self.__pm.protocolFlows.appendItem(**kwargs))

	def getItemIxGeneratestreamCommand(self, objectID):
		itemList = self.__pm.protocolFlows
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_GenerateStream":
				return IxPropertyClass_GenerateStreamstatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxGeneratestreamCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "GenerateStream"})
		return IxPropertyClass_GenerateStreamstatelessPeerWrapper(self.__pm.protocolFlows.appendItem(**kwargs))

	def getItemIxLoopendcommandCommand(self, objectID):
		itemList = self.__pm.protocolFlows
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_LoopEndCommand":
				return IxPropertyClass_LoopEndCommandstatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopendcommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopEndCommand"})
		return IxPropertyClass_LoopEndCommandstatelessPeerWrapper(self.__pm.protocolFlows.appendItem(**kwargs))

	def getItemIxThinkCommand(self, objectID):
		itemList = self.__pm.protocolFlows
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandThink":
				return IxPropertyCommandThinkstatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxThinkCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "THINK"})
		return IxPropertyCommandThinkstatelessPeerWrapper(self.__pm.protocolFlows.appendItem(**kwargs))

	def getItemIxWaitforfirsttriggerCommand(self, objectID):
		itemList = self.__pm.protocolFlows
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_WaitForFirstTrigger":
				return IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxWaitforfirsttriggerCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "WaitForFirstTrigger"})
		return IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper(self.__pm.protocolFlows.appendItem(**kwargs))

	def getItemIxWaitfortriggerCommand(self, objectID):
		itemList = self.__pm.protocolFlows
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_WaitForTrigger":
				return IxPropertyClass_WaitForTriggerstatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxWaitfortriggerCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "WaitForTrigger"})
		return IxPropertyClass_WaitForTriggerstatelessPeerWrapper(self.__pm.protocolFlows.appendItem(**kwargs))


class IxPropertyCommandStartstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStart):
		super(IxPropertyCommandStartstatelessPeerWrapper, self).__init__(ixPropertyCommandStart)
		self.__ixPropertyCommandStart = ixPropertyCommandStart
		self.commandType = ixPropertyCommandStart.commandType
		self.cmdName = ixPropertyCommandStart.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandStartstatelessPeerWrapper.properties and super(IxPropertyCommandStartstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandStartstatelessPeerWrapper, self).__getattribute__("_IxPropertyCommandStartstatelessPeerWrapper__ixPropertyCommandStart"), name)
		else:
			return super(IxPropertyCommandStartstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandStartstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandStartstatelessPeerWrapper, self).__getattribute__("_IxPropertyCommandStartstatelessPeerWrapper__ixPropertyCommandStart"), name, value)
			super(IxPropertyCommandStartstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_GenerateIPStreamstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_GenerateIPStream):
		super(IxPropertyClass_GenerateIPStreamstatelessPeerWrapper, self).__init__(ixPropertyClass_GenerateIPStream)
		self.__ixPropertyClass_GenerateIPStream = ixPropertyClass_GenerateIPStream
		self.streamDur = ixPropertyClass_GenerateIPStream.streamDur
		self.minPacketFreq = ixPropertyClass_GenerateIPStream.minPacketFreq
		self.remotePeer = ixPropertyClass_GenerateIPStream.remotePeer
		self.rangeImixOption = ixPropertyClass_GenerateIPStream.rangeImixOption
		self.proto = ixPropertyClass_GenerateIPStream.proto
		self.cmdName = ixPropertyClass_GenerateIPStream.cmdName
		self.commandType = ixPropertyClass_GenerateIPStream.commandType
		self.maxPacketFreq = ixPropertyClass_GenerateIPStream.maxPacketFreq
		self.minContentSize = ixPropertyClass_GenerateIPStream.minContentSize
		self.longerThanTimeline = ixPropertyClass_GenerateIPStream.longerThanTimeline
		self.maxContentSize = ixPropertyClass_GenerateIPStream.maxContentSize

	properties = ["streamDur", "minPacketFreq", "remotePeer", "rangeImixOption", "proto", "cmdName", "commandType", "maxPacketFreq", "minContentSize", "longerThanTimeline", "maxContentSize", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_GenerateIPStreamstatelessPeerWrapper.properties and super(IxPropertyClass_GenerateIPStreamstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_GenerateIPStreamstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_GenerateIPStreamstatelessPeerWrapper__ixPropertyClass_GenerateIPStream"), name)
		else:
			return super(IxPropertyClass_GenerateIPStreamstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_GenerateIPStreamstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_GenerateIPStreamstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_GenerateIPStreamstatelessPeerWrapper__ixPropertyClass_GenerateIPStream"), name, value)
			super(IxPropertyClass_GenerateIPStreamstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_GenerateTriggerstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_GenerateTrigger):
		super(IxPropertyClass_GenerateTriggerstatelessPeerWrapper, self).__init__(ixPropertyClass_GenerateTrigger)
		self.__ixPropertyClass_GenerateTrigger = ixPropertyClass_GenerateTrigger
		self.remotePeer = ixPropertyClass_GenerateTrigger.remotePeer
		self.destination = ixPropertyClass_GenerateTrigger.destination
		self.cmdName = ixPropertyClass_GenerateTrigger.cmdName
		self.initiatorPortRanges = IxPropertyGroupSequence_GenerateTrigger_initiatorPortRangesstatelessPeerWrapper(ixPropertyClass_GenerateTrigger)
		self.commandType = ixPropertyClass_GenerateTrigger.commandType
		self.enableTriggerDestPortRand = ixPropertyClass_GenerateTrigger.enableTriggerDestPortRand
		self.enableTriggerSourcePortRand = ixPropertyClass_GenerateTrigger.enableTriggerSourcePortRand
		self.responderPortRanges = IxPropertyGroupSequence_GenerateTrigger_responderPortRangesstatelessPeerWrapper(ixPropertyClass_GenerateTrigger)
		self.destinationPort = ixPropertyClass_GenerateTrigger.destinationPort
		self.sourcePort = ixPropertyClass_GenerateTrigger.sourcePort
		self.contentSize = ixPropertyClass_GenerateTrigger.contentSize

	properties = ["remotePeer", "destination", "cmdName", "commandType", "enableTriggerDestPortRand", "enableTriggerSourcePortRand", "destinationPort", "sourcePort", "contentSize", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_GenerateTriggerstatelessPeerWrapper.properties and super(IxPropertyClass_GenerateTriggerstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_GenerateTriggerstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_GenerateTriggerstatelessPeerWrapper__ixPropertyClass_GenerateTrigger"), name)
		else:
			return super(IxPropertyClass_GenerateTriggerstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_GenerateTriggerstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_GenerateTriggerstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_GenerateTriggerstatelessPeerWrapper__ixPropertyClass_GenerateTrigger"), name, value)
			super(IxPropertyClass_GenerateTriggerstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyCommandStopstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStop):
		super(IxPropertyCommandStopstatelessPeerWrapper, self).__init__(ixPropertyCommandStop)
		self.__ixPropertyCommandStop = ixPropertyCommandStop
		self.commandType = ixPropertyCommandStop.commandType
		self.cmdName = ixPropertyCommandStop.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandStopstatelessPeerWrapper.properties and super(IxPropertyCommandStopstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandStopstatelessPeerWrapper, self).__getattribute__("_IxPropertyCommandStopstatelessPeerWrapper__ixPropertyCommandStop"), name)
		else:
			return super(IxPropertyCommandStopstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandStopstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandStopstatelessPeerWrapper, self).__getattribute__("_IxPropertyCommandStopstatelessPeerWrapper__ixPropertyCommandStop"), name, value)
			super(IxPropertyCommandStopstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_BackplaneCommunicationstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, lossCommunicationParameters):
		super(IxPropertyClass_BackplaneCommunicationstatelessPeerWrapper, self).__init__(lossCommunicationParameters)
		self.__lossCommunicationParameters = lossCommunicationParameters
		self.BackplaneInfo = IxPropertyGroupSequence_BackplaneCommunication_BackplaneInfostatelessPeerWrapper(lossCommunicationParameters)
		self.useBackplaneCommunication = lossCommunicationParameters.useBackplaneCommunication

	properties = ["useBackplaneCommunication", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_BackplaneCommunicationstatelessPeerWrapper.properties and super(IxPropertyClass_BackplaneCommunicationstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_BackplaneCommunicationstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_BackplaneCommunicationstatelessPeerWrapper__lossCommunicationParameters"), name)
		else:
			return super(IxPropertyClass_BackplaneCommunicationstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_BackplaneCommunicationstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_BackplaneCommunicationstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_BackplaneCommunicationstatelessPeerWrapper__lossCommunicationParameters"), name, value)
			super(IxPropertyClass_BackplaneCommunicationstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_GenerateTrigger_initiatorPortRangesstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_GenerateTrigger):
		self.__ixPropertyClass_GenerateTrigger = ixPropertyClass_GenerateTrigger

	def getItem(self, objectID):
		itemList = self.__ixPropertyClass_GenerateTrigger.initiatorPortRanges
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_PortRange":
				return IxPropertyClass_PortRangestatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_PortRangestatelessPeerWrapper(self.__ixPropertyClass_GenerateTrigger.initiatorPortRanges.appendItem(**kwargs))

	def getList(self):
		return self.__ixPropertyClass_GenerateTrigger.initiatorPortRanges

	def clear(self):
		return self.__ixPropertyClass_GenerateTrigger.initiatorPortRanges.clear()


class IxPropertyClass_PortRangestatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_PortRange):
		super(IxPropertyClass_PortRangestatelessPeerWrapper, self).__init__(ixPropertyClass_PortRange)
		self.__ixPropertyClass_PortRange = ixPropertyClass_PortRange
		self.lastPort = ixPropertyClass_PortRange.lastPort
		self.firstPort = ixPropertyClass_PortRange.firstPort

	properties = ["lastPort", "firstPort", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_PortRangestatelessPeerWrapper.properties and super(IxPropertyClass_PortRangestatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_PortRangestatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_PortRangestatelessPeerWrapper__ixPropertyClass_PortRange"), name)
		else:
			return super(IxPropertyClass_PortRangestatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_PortRangestatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_PortRangestatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_PortRangestatelessPeerWrapper__ixPropertyClass_PortRange"), name, value)
			super(IxPropertyClass_PortRangestatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_GenerateTrigger_responderPortRangesstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_GenerateTrigger):
		self.__ixPropertyClass_GenerateTrigger = ixPropertyClass_GenerateTrigger

	def getItem(self, objectID):
		itemList = self.__ixPropertyClass_GenerateTrigger.responderPortRanges
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_PortRange":
				return IxPropertyClass_PortRangestatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_PortRangestatelessPeerWrapper(self.__ixPropertyClass_GenerateTrigger.responderPortRanges.appendItem(**kwargs))

	def getList(self):
		return self.__ixPropertyClass_GenerateTrigger.responderPortRanges

	def clear(self):
		return self.__ixPropertyClass_GenerateTrigger.responderPortRanges.clear()


class IxPropertyGroupSequence_BackplaneCommunication_BackplaneInfostatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, lossCommunicationParameters):
		self.__lossCommunicationParameters = lossCommunicationParameters

	def getItem(self, objectID):
		itemList = self.__lossCommunicationParameters.BackplaneInfo
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_NodeCommunication":
				return IxPropertyClass_NodeCommunicationstatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_NodeCommunicationstatelessPeerWrapper(self.__lossCommunicationParameters.BackplaneInfo.appendItem(**kwargs))

	def getList(self):
		return self.__lossCommunicationParameters.BackplaneInfo

	def clear(self):
		return self.__lossCommunicationParameters.BackplaneInfo.clear()


class IxPropertyClass_NodeCommunicationstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_NodeCommunication):
		super(IxPropertyClass_NodeCommunicationstatelessPeerWrapper, self).__init__(ixPropertyClass_NodeCommunication)
		self.__ixPropertyClass_NodeCommunication = ixPropertyClass_NodeCommunication
		self.PortId = ixPropertyClass_NodeCommunication.PortId
		self.ChassisIP = ixPropertyClass_NodeCommunication.ChassisIP
		self.PortIP = ixPropertyClass_NodeCommunication.PortIP
		self.SendToIP = ixPropertyClass_NodeCommunication.SendToIP
		self.RxPortCount = ixPropertyClass_NodeCommunication.RxPortCount
		self.ToChassisIP = ixPropertyClass_NodeCommunication.ToChassisIP

	properties = ["PortId", "ChassisIP", "PortIP", "SendToIP", "RxPortCount", "ToChassisIP", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_NodeCommunicationstatelessPeerWrapper.properties and super(IxPropertyClass_NodeCommunicationstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_NodeCommunicationstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_NodeCommunicationstatelessPeerWrapper__ixPropertyClass_NodeCommunication"), name)
		else:
			return super(IxPropertyClass_NodeCommunicationstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_NodeCommunicationstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_NodeCommunicationstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_NodeCommunicationstatelessPeerWrapper__ixPropertyClass_NodeCommunication"), name, value)
			super(IxPropertyClass_NodeCommunicationstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_GenerateStreamstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_GenerateStream):
		super(IxPropertyClass_GenerateStreamstatelessPeerWrapper, self).__init__(ixPropertyClass_GenerateStream)
		self.__ixPropertyClass_GenerateStream = ixPropertyClass_GenerateStream
		self.cmdName = ixPropertyClass_GenerateStream.cmdName
		self.initiatorPortRanges = IxPropertyGroupSequence_GenerateStream_initiatorPortRangesstatelessPeerWrapper(ixPropertyClass_GenerateStream)
		self.streamDur = ixPropertyClass_GenerateStream.streamDur
		self.enableSourcePortRand = ixPropertyClass_GenerateStream.enableSourcePortRand
		self.rangeImixOption = ixPropertyClass_GenerateStream.rangeImixOption
		self.destination = ixPropertyClass_GenerateStream.destination
		self.packetFreq = ixPropertyClass_GenerateStream.packetFreq
		self.maxPacketFreq = ixPropertyClass_GenerateStream.maxPacketFreq
		self.enableDestinationPortRand = ixPropertyClass_GenerateStream.enableDestinationPortRand
		self.maxContentSize = ixPropertyClass_GenerateStream.maxContentSize
		self.contentSize = ixPropertyClass_GenerateStream.contentSize
		self.responderPortRanges = IxPropertyGroupSequence_GenerateStream_responderPortRangesstatelessPeerWrapper(ixPropertyClass_GenerateStream)
		self.commandType = ixPropertyClass_GenerateStream.commandType
		self.destinationPort = ixPropertyClass_GenerateStream.destinationPort
		self.sourcePort = ixPropertyClass_GenerateStream.sourcePort
		self.remotePeer = ixPropertyClass_GenerateStream.remotePeer
		self.longerThanTimeline = ixPropertyClass_GenerateStream.longerThanTimeline

	properties = ["cmdName", "streamDur", "enableSourcePortRand", "rangeImixOption", "destination", "packetFreq", "maxPacketFreq", "enableDestinationPortRand", "maxContentSize", "contentSize", "commandType", "destinationPort", "sourcePort", "remotePeer", "longerThanTimeline", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_GenerateStreamstatelessPeerWrapper.properties and super(IxPropertyClass_GenerateStreamstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_GenerateStreamstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_GenerateStreamstatelessPeerWrapper__ixPropertyClass_GenerateStream"), name)
		else:
			return super(IxPropertyClass_GenerateStreamstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_GenerateStreamstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_GenerateStreamstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_GenerateStreamstatelessPeerWrapper__ixPropertyClass_GenerateStream"), name, value)
			super(IxPropertyClass_GenerateStreamstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_LoopBeginCommandstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_LoopBeginCommand):
		super(IxPropertyClass_LoopBeginCommandstatelessPeerWrapper, self).__init__(ixPropertyClass_LoopBeginCommand)
		self.__ixPropertyClass_LoopBeginCommand = ixPropertyClass_LoopBeginCommand
		self.commandType = ixPropertyClass_LoopBeginCommand.commandType
		self.cmdName = ixPropertyClass_LoopBeginCommand.cmdName
		self.LoopCount = ixPropertyClass_LoopBeginCommand.LoopCount

	properties = ["commandType", "cmdName", "LoopCount", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_LoopBeginCommandstatelessPeerWrapper.properties and super(IxPropertyClass_LoopBeginCommandstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_LoopBeginCommandstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_LoopBeginCommandstatelessPeerWrapper__ixPropertyClass_LoopBeginCommand"), name)
		else:
			return super(IxPropertyClass_LoopBeginCommandstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_LoopBeginCommandstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_LoopBeginCommandstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_LoopBeginCommandstatelessPeerWrapper__ixPropertyClass_LoopBeginCommand"), name, value)
			super(IxPropertyClass_LoopBeginCommandstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyCommandThinkstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandThink):
		super(IxPropertyCommandThinkstatelessPeerWrapper, self).__init__(ixPropertyCommandThink)
		self.__ixPropertyCommandThink = ixPropertyCommandThink
		self.minimumInterval = ixPropertyCommandThink.minimumInterval
		self.cmdName = ixPropertyCommandThink.cmdName
		self.commandType = ixPropertyCommandThink.commandType
		self.maximumInterval = ixPropertyCommandThink.maximumInterval

	properties = ["minimumInterval", "cmdName", "commandType", "maximumInterval", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandThinkstatelessPeerWrapper.properties and super(IxPropertyCommandThinkstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandThinkstatelessPeerWrapper, self).__getattribute__("_IxPropertyCommandThinkstatelessPeerWrapper__ixPropertyCommandThink"), name)
		else:
			return super(IxPropertyCommandThinkstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandThinkstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandThinkstatelessPeerWrapper, self).__getattribute__("_IxPropertyCommandThinkstatelessPeerWrapper__ixPropertyCommandThink"), name, value)
			super(IxPropertyCommandThinkstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_LoopEndCommandstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_LoopEndCommand):
		super(IxPropertyClass_LoopEndCommandstatelessPeerWrapper, self).__init__(ixPropertyClass_LoopEndCommand)
		self.__ixPropertyClass_LoopEndCommand = ixPropertyClass_LoopEndCommand
		self.commandType = ixPropertyClass_LoopEndCommand.commandType
		self.cmdName = ixPropertyClass_LoopEndCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_LoopEndCommandstatelessPeerWrapper.properties and super(IxPropertyClass_LoopEndCommandstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_LoopEndCommandstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_LoopEndCommandstatelessPeerWrapper__ixPropertyClass_LoopEndCommand"), name)
		else:
			return super(IxPropertyClass_LoopEndCommandstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_LoopEndCommandstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_LoopEndCommandstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_LoopEndCommandstatelessPeerWrapper__ixPropertyClass_LoopEndCommand"), name, value)
			super(IxPropertyClass_LoopEndCommandstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_WaitForTriggerstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_WaitForTrigger):
		super(IxPropertyClass_WaitForTriggerstatelessPeerWrapper, self).__init__(ixPropertyClass_WaitForTrigger)
		self.__ixPropertyClass_WaitForTrigger = ixPropertyClass_WaitForTrigger
		self.commandType = ixPropertyClass_WaitForTrigger.commandType
		self.waitTimer = ixPropertyClass_WaitForTrigger.waitTimer
		self.cmdName = ixPropertyClass_WaitForTrigger.cmdName

	properties = ["commandType", "waitTimer", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_WaitForTriggerstatelessPeerWrapper.properties and super(IxPropertyClass_WaitForTriggerstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_WaitForTriggerstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_WaitForTriggerstatelessPeerWrapper__ixPropertyClass_WaitForTrigger"), name)
		else:
			return super(IxPropertyClass_WaitForTriggerstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_WaitForTriggerstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_WaitForTriggerstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_WaitForTriggerstatelessPeerWrapper__ixPropertyClass_WaitForTrigger"), name, value)
			super(IxPropertyClass_WaitForTriggerstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_WaitForFirstTrigger):
		super(IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper, self).__init__(ixPropertyClass_WaitForFirstTrigger)
		self.__ixPropertyClass_WaitForFirstTrigger = ixPropertyClass_WaitForFirstTrigger
		self.commandType = ixPropertyClass_WaitForFirstTrigger.commandType
		self.waitTimer = ixPropertyClass_WaitForFirstTrigger.waitTimer
		self.cmdName = ixPropertyClass_WaitForFirstTrigger.cmdName

	properties = ["commandType", "waitTimer", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper.properties and super(IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper__ixPropertyClass_WaitForFirstTrigger"), name)
		else:
			return super(IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper, self).__getattribute__("_IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper__ixPropertyClass_WaitForFirstTrigger"), name, value)
			super(IxPropertyClass_WaitForFirstTriggerstatelessPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_GenerateStream_initiatorPortRangesstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_GenerateStream):
		self.__ixPropertyClass_GenerateStream = ixPropertyClass_GenerateStream

	def getItem(self, objectID):
		itemList = self.__ixPropertyClass_GenerateStream.initiatorPortRanges
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_PortRange":
				return IxPropertyClass_PortRangestatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_PortRangestatelessPeerWrapper(self.__ixPropertyClass_GenerateStream.initiatorPortRanges.appendItem(**kwargs))

	def getList(self):
		return self.__ixPropertyClass_GenerateStream.initiatorPortRanges

	def clear(self):
		return self.__ixPropertyClass_GenerateStream.initiatorPortRanges.clear()


class IxPropertyGroupSequence_GenerateStream_responderPortRangesstatelessPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_GenerateStream):
		self.__ixPropertyClass_GenerateStream = ixPropertyClass_GenerateStream

	def getItem(self, objectID):
		itemList = self.__ixPropertyClass_GenerateStream.responderPortRanges
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_PortRange":
				return IxPropertyClass_PortRangestatelessPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_PortRangestatelessPeerWrapper(self.__ixPropertyClass_GenerateStream.responderPortRanges.appendItem(**kwargs))

	def getList(self):
		return self.__ixPropertyClass_GenerateStream.responderPortRanges

	def clear(self):
		return self.__ixPropertyClass_GenerateStream.responderPortRanges.clear()


class IxNetSixRdPluginWrapper(RestObjectBaseClass):

	def __init__(self, ixNetSixRdPlugin):
		super(IxNetSixRdPluginWrapper, self).__init__(ixNetSixRdPlugin)
		self.__ixNetSixRdPlugin = ixNetSixRdPlugin
		self.itemType = ixNetSixRdPlugin.itemType
		self.rangeList = IxNetSixRdRangeListWrapper(ixNetSixRdPlugin)
		self.name = ixNetSixRdPlugin.name

	properties = ["itemType", "name", ]

	def __getattribute__(self, name):
		if name in IxNetSixRdPluginWrapper.properties and super(IxNetSixRdPluginWrapper, self).__getattribute__(name):
			return getattr(super(IxNetSixRdPluginWrapper, self).__getattribute__("_IxNetSixRdPluginWrapper__ixNetSixRdPlugin"), name)
		else:
			return super(IxNetSixRdPluginWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetSixRdPluginWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetSixRdPluginWrapper, self).__getattribute__("_IxNetSixRdPluginWrapper__ixNetSixRdPlugin"), name, value)
			super(IxNetSixRdPluginWrapper, self).__setattr__(name, value)

	def insertParentPlugin(self, pluginType):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__ixNetSixRdPlugin.insertParentPlugin(**kwargs)


class IxNetSixRdRangeListWrapper(RestObjectBaseClass):

	def __init__(self, ixNetSixRdPlugin):
		self.__ixNetSixRdPlugin = ixNetSixRdPlugin

	def getItem(self, objectID):
		itemList = self.__ixNetSixRdPlugin.rangeList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixNetSixRdRange":
				return IxNetSixRdRangeWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxNetSixRdRangeWrapper(self.__ixNetSixRdPlugin.rangeList.appendItem(**kwargs))

	def getList(self):
		return self.__ixNetSixRdPlugin.rangeList

	def clear(self):
		return self.__ixNetSixRdPlugin.rangeList.clear()


class IxNetSixRdRangeWrapper(RestObjectBaseClass):

	def __init__(self, ixNetSixRdRange):
		super(IxNetSixRdRangeWrapper, self).__init__(ixNetSixRdRange)
		self.__ixNetSixRdRange = ixNetSixRdRange
		self.tunnelCount = ixNetSixRdRange.tunnelCount
		self.sixRdPrefixMask = ixNetSixRdRange.sixRdPrefixMask
		self.itemType = ixNetSixRdRange.itemType
		self.mss = ixNetSixRdRange.mss
		self.hostCount = ixNetSixRdRange.hostCount
		self.enabled = ixNetSixRdRange.enabled
		self.publishStats = ixNetSixRdRange.publishStats
		self.sixRdPrefix = ixNetSixRdRange.sixRdPrefix
		self.tunnelDstIncrementBy = ixNetSixRdRange.tunnelDstIncrementBy
		self.sixRdIPv4PrefixLen = ixNetSixRdRange.sixRdIPv4PrefixLen
		self.useGatewayAsTunnelDst = ixNetSixRdRange.useGatewayAsTunnelDst
		self.tunnelDst = ixNetSixRdRange.tunnelDst
		self.sixRdDelegatedPrefixMask = ixNetSixRdRange.sixRdDelegatedPrefixMask
		self.hostsPerTunnel = ixNetSixRdRange.hostsPerTunnel
		self.ipType = ixNetSixRdRange.ipType
		self.sixRdDelegatedPrefixIncrement = ixNetSixRdRange.sixRdDelegatedPrefixIncrement
		self.sixRdDelegatedPrefix = ixNetSixRdRange.sixRdDelegatedPrefix
		self.name = ixNetSixRdRange.name

	properties = ["tunnelCount", "sixRdPrefixMask", "itemType", "mss", "hostCount", "enabled", "publishStats", "sixRdPrefix", "tunnelDstIncrementBy", "sixRdIPv4PrefixLen", "useGatewayAsTunnelDst", "tunnelDst", "sixRdDelegatedPrefixMask", "hostsPerTunnel", "ipType", "sixRdDelegatedPrefixIncrement", "sixRdDelegatedPrefix", "name", ]

	def __getattribute__(self, name):
		if name in IxNetSixRdRangeWrapper.properties and super(IxNetSixRdRangeWrapper, self).__getattribute__(name):
			return getattr(super(IxNetSixRdRangeWrapper, self).__getattribute__("_IxNetSixRdRangeWrapper__ixNetSixRdRange"), name)
		else:
			return super(IxNetSixRdRangeWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxNetSixRdRangeWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxNetSixRdRangeWrapper, self).__getattribute__("_IxNetSixRdRangeWrapper__ixNetSixRdRange"), name, value)
			super(IxNetSixRdRangeWrapper, self).__setattr__(name, value)


class StatsNameFTPServer(object):
	def __init__(self):
		self.kControlBytesSents = "Control Bytes Sent/s"
		self.kControlTCPConnectionsinFINWAIT1State = "Control TCP Connections in FIN-WAIT-1 State"
		self.kControlConnReceived = "Control Conn Received"
		self.kDataTCPSYNACKSent = "Data TCP SYN-ACK Sent"
		self.kDataSYNsSent = "Data SYNs Sent"
		self.kControlSYNSYNACKsReceived = "Control SYN/SYN-ACKs Received"
		self.kControlSYNACKsSent = "Control SYN-ACKs Sent"
		self.kDataConnFailedActiveMode = "Data Conn Failed (Active Mode)"
		self.kDataConnectionLatencyActiveModems = "Data Connection Latency (Active Mode) (ms)"
		self.kDownloadsFaileds = "Downloads Failed/s"
		self.kControlConnRejecteds = "Control Conn Rejected/s"
		self.kFTPFileUploadsSuccessful = "FTP File Uploads Successful"
		self.kDataTCPSYNSent = "Data TCP SYN Sent"
		self.kDataBytesReceiveds = "Data Bytes Received/s"
		self.kControlTCPListenQueueDrops = "Control TCP Listen Queue Drops"
		self.kUploadsFaileds = "Uploads Failed/s"
		self.kControlTCPConnectionsinCLOSEWAITState = "Control TCP Connections in CLOSE-WAIT State"
		self.kDataTCPFINReceived = "Data TCP FIN Received"
		self.kDataTCPListenQueueDrops = "Data TCP Listen Queue Drops"
		self.kDataListenQueueDrops = "Data Listen Queue Drops"
		self.kControlTCPConnectionsinFINWAIT2State = "Control TCP Connections in FIN-WAIT-2 State"
		self.kControlTCPConnectionsinSYNSENTState = "Control TCP Connections in SYN-SENT State"
		self.kControlConnEstablisheds = "Control Conn Established/s"
		self.kControlResetsReceived = "Control Resets Received"
		self.kDataConnFailedsActiveMode = "Data Conn Failed/s (Active Mode)"
		self.kControlListenQueueDrops = "Control Listen Queue Drops"
		self.kDataTCPFINACKReceived = "Data TCP FIN-ACK Received"
		self.kControlTCPConnectionsinLISTENINGState = "Control TCP Connections in LISTENING State"
		self.kControlFINACKsReceived = "Control FIN-ACKs Received"
		self.kFTPControlConnActive = "FTP Control Conn Active"
		self.kControlTCPConnectionsinESTABLISHEDState = "Control TCP Connections in ESTABLISHED State"
		self.kDataFINsReceived = "Data FINs Received"
		self.kDownloadsSuccessfuls = "Downloads Successful/s"
		self.kDataResetsReceived = "Data Resets Received"
		self.kControlFINACKsSent = "Control FIN-ACKs Sent"
		self.kControlTCPSYNFailed = "Control TCP SYN Failed"
		self.kDataConnectionRequestsFailed = "Data Connection Requests Failed"
		self.kDataTCPRetries = "Data TCP Retries"
		self.kDataTCPSYN_SYNACKReceived = "Data TCP SYN_SYN-ACK Received"
		self.kDataTCPTimeouts = "Data TCP Timeouts"
		self.kDataTCPConnectionsinSYNRECEIVEDState = "Data TCP Connections in SYN-RECEIVED State"
		self.kControlTCPFINACKSent = "Control TCP FIN-ACK Sent"
		self.kUploadSuccessfuls = "Upload Successful/s"
		self.kFTPControlConnEstablished = "FTP Control Conn Established"
		self.kControlTCPSYNACKSent = "Control TCP SYN-ACK Sent"
		self.kDataTCPResetsSent = "Data TCP Resets Sent"
		self.kDownloadsRequesteds = "Downloads Requested/s"
		self.kDataFINACKsSent = "Data FIN-ACKs Sent"
		self.kDataTCPResetsReceived = "Data TCP Resets Received"
		self.kControlTCPConnectionsinSYNRECEIVEDState = "Control TCP Connections in SYN-RECEIVED State"
		self.kDataBytesSents = "Data Bytes Sent/s"
		self.kControlTCPRetries = "Control TCP Retries"
		self.kFTPControlConnRejected = "FTP Control Conn Rejected"
		self.kControlConnRejected = "Control Conn Rejected"
		self.kDataTCPConnectionsinCLOSINGState = "Data TCP Connections in CLOSING State"
		self.kControlBytesReceiveds = "Control Bytes Received/s"
		self.kControlTCPSYNSent = "Control TCP SYN Sent"
		self.kControlSYNsSent = "Control SYNs Sent"
		self.kDataConnEstablished = "Data Conn Established"
		self.kFTPDataConnActive = "FTP Data Conn Active"
		self.kDataTCPConnectionsinLASTACKState = "Data TCP Connections in LAST-ACK State"
		self.kDataTCPFINACKSent = "Data TCP FIN-ACK Sent"
		self.kControlTCPConnectionsinTIMEWAITState = "Control TCP Connections in TIME-WAIT State"
		self.kDataTCPConnectionsinSYNSENTState = "Data TCP Connections in SYN-SENT State"
		self.kFTPDataConnEstablishedActiveMode = "FTP Data Conn Established (Active Mode)"
		self.kDataTCPAcceptQueueEntries = "Data TCP Accept Queue Entries"
		self.kDataTCPConnectionsEstablished = "Data TCP Connections Established"
		self.kControlTCPConnectionsinCLOSINGState = "Control TCP Connections in CLOSING State"
		self.kDataSYNACKsSent = "Data SYN-ACKs Sent"
		self.kControlTCPFINReceived = "Control TCP FIN Received"
		self.kDataTCPConnectionsinFINWAIT1State = "Data TCP Connections in FIN-WAIT-1 State"
		self.kFTPControlBytesSent = "FTP Control Bytes Sent"
		self.kDataTCPInternallyAbortedConnections = "Data TCP Internally Aborted Connections"
		self.kDataTCPConnectionRequestsFailed = "Data TCP Connection Requests Failed"
		self.kFTPFileDownloadsSuccessful = "FTP File Downloads Successful"
		self.kControlTCPResetsReceived = "Control TCP Resets Received"
		self.kFTPFileUploadsFailed = "FTP File Uploads Failed"
		self.kControlTCPConnectionsinCLOSESTATE = "Control TCP Connections in CLOSE STATE"
		self.kDataTCPSYNFailed = "Data TCP SYN Failed"
		self.kFTPControlBytesReceived = "FTP Control Bytes Received"
		self.kControlConnReceiveds = "Control Conn Received/s"
		self.kControlFINsSent = "Control FINs Sent"
		self.kFTPFileDownloadsRequested = "FTP File Downloads Requested"
		self.kControlTCPResetsSent = "Control TCP Resets Sent"
		self.kControlFINsReceived = "Control FINs Received"
		self.kControlRetries = "Control Retries"
		self.kDataTCPFINSent = "Data TCP FIN Sent"
		self.kControlTCPConnectionsEstablished = "Control TCP Connections Established"
		self.kControlAcceptQueueEntries = "Control Accept Queue Entries"
		self.kFTPFileDownloadsFailed = "FTP File Downloads Failed"
		self.kDataConnEstablisheds = "Data Conn Established/s"
		self.kDataTCPConnectionsinCLOSESTATE = "Data TCP Connections in CLOSE STATE"
		self.kControlTCPFINACKReceived = "Control TCP FIN-ACK Received"
		self.kDataAcceptQueueEntries = "Data Accept Queue Entries"
		self.kDataRetries = "Data Retries"
		self.kDataTCPConnectionsinCLOSEWAITState = "Data TCP Connections in CLOSE-WAIT State"
		self.kDataSYNSYNACKsReceived = "Data SYN/SYN-ACKs Received"
		self.kFTPDataConnectionLatencyActiveModems = "FTP Data Connection Latency (Active Mode) (ms)"
		self.kDataTCPConnectionsinTIMEWAITState = "Data TCP Connections in TIME-WAIT State"
		self.kControlTCPTimeouts = "Control TCP Timeouts"
		self.kControlTCPAcceptQueueEntries = "Control TCP Accept Queue Entries"
		self.kFTPDataBytesSent = "FTP Data Bytes Sent"
		self.kUploadsRequesteds = "Uploads Requested/s"
		self.kControlTCPConnectionRequestsFailed = "Control TCP Connection Requests Failed"
		self.kControlConnectionRequestsFailed = "Control Connection Requests Failed"
		self.kFTPFileUploadsRequested = "FTP File Uploads Requested"
		self.kDataFINACKsReceived = "Data FIN-ACKs Received"
		self.kControlTCPSYN_SYNACKReceived = "Control TCP SYN_SYN-ACK Received"
		self.kDataTCPConnectionsinESTABLISHEDState = "Data TCP Connections in ESTABLISHED State"
		self.kFTPDataConnFailedActiveMode = "FTP Data Conn Failed (Active Mode)"
		self.kDataTCPConnectionsinLISTENINGState = "Data TCP Connections in LISTENING State"
		self.kDataFINsSent = "Data FINs Sent"
		self.kFTPDataConnEstablished = "FTP Data Conn Established"
		self.kControlTimeouts = "Control Timeouts"
		self.kDataTCPConnectionsinFINWAIT2State = "Data TCP Connections in FIN-WAIT-2 State"
		self.kControlTCPConnectionsinLASTACKState = "Control TCP Connections in LAST-ACK State"
		self.kControlTCPFINSent = "Control TCP FIN Sent"
		self.kDataTimeouts = "Data Timeouts"
		self.kControlResetsSent = "Control Resets Sent"
		self.kControlConnEstablished = "Control Conn Established"
		self.kControlTCPInternallyAbortedConnections = "Control TCP Internally Aborted Connections"
		self.kFTPDataConnEstablishedPassiveMode = "FTP Data Conn Established (Passive Mode)"
		self.kDataResetsSent = "Data Resets Sent"
		self.kFTPControlConnReceived = "FTP Control Conn Received"
		self.kFTPDataConnRequestedActiveMode = "FTP Data Conn Requested (Active Mode)"
		self.kFTPDataBytesReceived = "FTP Data Bytes Received"


class StatsNameFTPClient(object):
	def __init__(self):
		self.kControlTCPConnectionsinFINWAIT1State = "Control TCP Connections in FIN-WAIT-1 State"
		self.kDataTCPSYNACKSent = "Data TCP SYN-ACK Sent"
		self.kDataSYNsSent = "Data SYNs Sent"
		self.kFTPControlConnFailed = "FTP Control Conn Failed"
		self.kDataTxRateKbps = "Data Tx Rate (Kbps)"
		self.kControlTxRateKbps = "Control Tx Rate (Kbps)"
		self.kDownloadsFaileds = "Downloads Failed/s"
		self.kFTPFileUploadsSuccessful = "FTP File Uploads Successful"
		self.kDataTCPSYNSent = "Data TCP SYN Sent"
		self.kControlTCPListenQueueDrops = "Control TCP Listen Queue Drops"
		self.kUploadsFaileds = "Uploads Failed/s"
		self.kControlTCPConnectionsinCLOSEWAITState = "Control TCP Connections in CLOSE-WAIT State"
		self.kThroughputKbps = "Throughput (Kbps)"
		self.kFTPControlConnectionLatencyms = "FTP Control Connection Latency (ms)"
		self.kDataTCPFINReceived = "Data TCP FIN Received"
		self.kDataTCPListenQueueDrops = "Data TCP Listen Queue Drops"
		self.kControlTCPConnectionsinFINWAIT2State = "Control TCP Connections in FIN-WAIT-2 State"
		self.kControlTCPConnectionsinSYNSENTState = "Control TCP Connections in SYN-SENT State"
		self.kControlConnEstablisheds = "Control Conn Established/s"
		self.kDataConnFailed = "Data Conn Failed"
		self.kDataTCPFINACKReceived = "Data TCP FIN-ACK Received"
		self.kControlTCPConnectionsinLISTENINGState = "Control TCP Connections in LISTENING State"
		self.kControlFINACKsReceived = "Control FIN-ACKs Received"
		self.kFTPControlConnActive = "FTP Control Conn Active"
		self.kControlTCPConnectionsinESTABLISHEDState = "Control TCP Connections in ESTABLISHED State"
		self.kDataFINsReceived = "Data FINs Received"
		self.kDownloadsSuccessfuls = "Downloads Successful/s"
		self.kDataResetsReceived = "Data Resets Received"
		self.kControlFINACKsSent = "Control FIN-ACKs Sent"
		self.kControlConnectionLatencyms = "Control Connection Latency (ms)"
		self.kControlTCPSYNFailed = "Control TCP SYN Failed"
		self.kDataTCPRetries = "Data TCP Retries"
		self.kDataTCPSYN_SYNACKReceived = "Data TCP SYN_SYN-ACK Received"
		self.kDataTCPTimeouts = "Data TCP Timeouts"
		self.kFTPConcurrentSessions = "FTP Concurrent Sessions"
		self.kDataTCPConnectionsinSYNRECEIVEDState = "Data TCP Connections in SYN-RECEIVED State"
		self.kControlResetsReceived = "Control Resets Received"
		self.kControlSYNSYNACKsReceived = "Control SYN/SYN-ACKs Received"
		self.kControlTCPFINACKSent = "Control TCP FIN-ACK Sent"
		self.kUploadSuccessfuls = "Upload Successful/s"
		self.kFTPControlConnEstablished = "FTP Control Conn Established"
		self.kSimulatedUsers = "Simulated Users"
		self.kControlTCPSYNACKSent = "Control TCP SYN-ACK Sent"
		self.kDataTCPResetsSent = "Data TCP Resets Sent"
		self.kDownloadsRequesteds = "Downloads Requested/s"
		self.kDataFINACKsSent = "Data FIN-ACKs Sent"
		self.kFTPDataConnRequestedPassiveMode = "FTP Data Conn Requested (Passive Mode)"
		self.kTransactionRate = "Transaction Rate"
		self.kDataTCPResetsReceived = "Data TCP Resets Received"
		self.kFTPTransactions = "FTP Transactions"
		self.kControlTCPConnectionsinSYNRECEIVEDState = "Control TCP Connections in SYN-RECEIVED State"
		self.kFTPDataConnFailedPassiveMode = "FTP Data Conn Failed (Passive Mode)"
		self.kFTPDataConnectionLatencyPassiveModems = "FTP Data Connection Latency (Passive Mode) (ms)"
		self.kFTPConnections = "FTP Connections"
		self.kDataTCPConnectionsinCLOSESTATE = "Data TCP Connections in CLOSE STATE"
		self.kSYNsdroppedfromListenQueue = "SYNs dropped from Listen Queue"
		self.kFTPControlConnFailedRejected = "FTP Control Conn Failed (Rejected)"
		self.kControlRxRateKbps = "Control Rx Rate (Kbps)"
		self.kDataTCPConnectionsinCLOSINGState = "Data TCP Connections in CLOSING State"
		self.kControlTCPSYNSent = "Control TCP SYN Sent"
		self.kControlSYNsSent = "Control SYNs Sent"
		self.kDataConnEstablished = "Data Conn Established"
		self.kFTPDataConnActive = "FTP Data Conn Active"
		self.kDataTCPConnectionsinLASTACKState = "Data TCP Connections in LAST-ACK State"
		self.kDataTCPFINACKSent = "Data TCP FIN-ACK Sent"
		self.kControlConnFaileds = "Control Conn Failed/s"
		self.kControlTCPConnectionsinTIMEWAITState = "Control TCP Connections in TIME-WAIT State"
		self.kControlConnEstablished = "Control Conn Established"
		self.kFTPDataConnEstablishedActiveMode = "FTP Data Conn Established (Active Mode)"
		self.kDataTCPAcceptQueueEntries = "Data TCP Accept Queue Entries"
		self.kDataTCPConnectionsEstablished = "Data TCP Connections Established"
		self.kControlTCPConnectionsinCLOSINGState = "Control TCP Connections in CLOSING State"
		self.kControlTCPFINReceived = "Control TCP FIN Received"
		self.kDataTCPConnectionsinFINWAIT1State = "Data TCP Connections in FIN-WAIT-1 State"
		self.kDataConnectionLatencyPassiveModems = "Data Connection Latency (Passive Mode) (ms)"
		self.kFTPControlBytesSent = "FTP Control Bytes Sent"
		self.kDataTCPInternallyAbortedConnections = "Data TCP Internally Aborted Connections"
		self.kDataTCPConnectionRequestsFailed = "Data TCP Connection Requests Failed"
		self.kFTPFileDownloadsSuccessful = "FTP File Downloads Successful"
		self.kControlTCPResetsReceived = "Control TCP Resets Received"
		self.kFTPFileUploadsFailed = "FTP File Uploads Failed"
		self.kControlTCPConnectionsinCLOSESTATE = "Control TCP Connections in CLOSE STATE"
		self.kDataTCPSYNFailed = "Data TCP SYN Failed"
		self.kFTPControlBytesReceived = "FTP Control Bytes Received"
		self.kControlFINsSent = "Control FINs Sent"
		self.kFTPFileDownloadsRequested = "FTP File Downloads Requested"
		self.kControlTCPResetsSent = "Control TCP Resets Sent"
		self.kControlFINsReceived = "Control FINs Received"
		self.kControlRetries = "Control Retries"
		self.kFTPControlConnRequested = "FTP Control Conn Requested"
		self.kDataTCPFINSent = "Data TCP FIN Sent"
		self.kControlConnRequested = "Control Conn Requested"
		self.kControlTCPConnectionsEstablished = "Control TCP Connections Established"
		self.kFTPFileDownloadsFailed = "FTP File Downloads Failed"
		self.kDataConnEstablisheds = "Data Conn Established/s"
		self.kControlTCPRetries = "Control TCP Retries"
		self.kControlTCPFINACKReceived = "Control TCP FIN-ACK Received"
		self.kFTPControlConnFailedOther = "FTP Control Conn Failed (Other)"
		self.kDataRetries = "Data Retries"
		self.kDataTCPConnectionsinCLOSEWAITState = "Data TCP Connections in CLOSE-WAIT State"
		self.kControlConnRequesteds = "Control Conn Requested/s"
		self.kDataSYNSYNACKsReceived = "Data SYN/SYN-ACKs Received"
		self.kDataRxRateKbps = "Data Rx Rate (Kbps)"
		self.kConnectionRate = "Connection Rate"
		self.kDataTCPConnectionsinTIMEWAITState = "Data TCP Connections in TIME-WAIT State"
		self.kControlTCPTimeouts = "Control TCP Timeouts"
		self.kControlTCPAcceptQueueEntries = "Control TCP Accept Queue Entries"
		self.kFTPDataBytesSent = "FTP Data Bytes Sent"
		self.kConcurrentSessions = "Concurrent Sessions"
		self.kControlConnFailed = "Control Conn Failed"
		self.kFTPBytes = "FTP Bytes"
		self.kUploadsRequesteds = "Uploads Requested/s"
		self.kControlTCPConnectionRequestsFailed = "Control TCP Connection Requests Failed"
		self.kFTPFileUploadsRequested = "FTP File Uploads Requested"
		self.kDataFINACKsReceived = "Data FIN-ACKs Received"
		self.kControlTCPSYN_SYNACKReceived = "Control TCP SYN_SYN-ACK Received"
		self.kDataTCPConnectionsinESTABLISHEDState = "Data TCP Connections in ESTABLISHED State"
		self.kDataTCPConnectionsinLISTENINGState = "Data TCP Connections in LISTENING State"
		self.kDataFINsSent = "Data FINs Sent"
		self.kFTPDataConnEstablished = "FTP Data Conn Established"
		self.kControlTimeouts = "Control Timeouts"
		self.kDataTCPConnectionsinFINWAIT2State = "Data TCP Connections in FIN-WAIT-2 State"
		self.kControlTCPConnectionsinLASTACKState = "Control TCP Connections in LAST-ACK State"
		self.kControlTCPFINSent = "Control TCP FIN Sent"
		self.kDataTimeouts = "Data Timeouts"
		self.kControlResetsSent = "Control Resets Sent"
		self.kDataTCPConnectionsinSYNSENTState = "Data TCP Connections in SYN-SENT State"
		self.kControlTCPInternallyAbortedConnections = "Control TCP Internally Aborted Connections"
		self.kFTPDataConnEstablishedPassiveMode = "FTP Data Conn Established (Passive Mode)"
		self.kDataResetsSent = "Data Resets Sent"
		self.kDataConnFailedsPassiveMode = "Data Conn Failed/s (Passive Mode)"
		self.kFTPSimulatedUsers = "FTP Simulated Users"
		self.kFTPDataBytesReceived = "FTP Data Bytes Received"


class IxActivityFTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityFTPClientWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.secondaryEnableConstraint = ixActivity.secondaryEnableConstraint
		self.protocol = ixActivity.protocol
		self.userIpMapping = ixActivity.userIpMapping
		self.enableConstraint = ixActivity.enableConstraint
		self.agent = PluginFTPClientWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.constraintValue = ixActivity.constraintValue
		self.customParameters = ixActivity.customParameters
		self.timelineId = ixActivity.timelineId
		self.role = ixActivity.role
		self.timeline = IxTimelineProxyFTPClientWrapper(ixActivity.timeline)
		self.activeRole = ixActivity.activeRole
		self.type = ixActivity.type
		self.secondaryConstraintValue = ixActivity.secondaryConstraintValue
		self.enable = ixActivity.enable
		self.protocolAndType = ixActivity.protocolAndType
		self.userObjectiveType = ixActivity.userObjectiveType
		self.destinationIpMapping = ixActivity.destinationIpMapping
		self.name = ixActivity.name
		self.secondaryConstraintType = ixActivity.secondaryConstraintType
		self.userObjectiveValue = ixActivity.userObjectiveValue
		self.constraintType = ixActivity.constraintType

	properties = ["secondaryEnableConstraint", "protocol", "userIpMapping", "enableConstraint", "objectivePercent", "constraintValue", "customParameters", "timelineId", "role", "activeRole", "type", "secondaryConstraintValue", "enable", "protocolAndType", "userObjectiveType", "destinationIpMapping", "name", "secondaryConstraintType", "userObjectiveValue", "constraintType", ]

	def __getattribute__(self, name):
		if name in IxActivityFTPClientWrapper.properties and super(IxActivityFTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityFTPClientWrapper, self).__getattribute__("_IxActivityFTPClientWrapper__ixActivity"), name)
		else:
			return super(IxActivityFTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityFTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityFTPClientWrapper, self).__getattribute__("_IxActivityFTPClientWrapper__ixActivity"), name, value)
			super(IxActivityFTPClientWrapper, self).__setattr__(name, value)


class IxActivityFTPServerWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityFTPServerWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.customParameters = ixActivity.customParameters
		self.enable = ixActivity.enable
		self.protocol = ixActivity.protocol
		self.name = ixActivity.name
		self.role = ixActivity.role
		self.agent = PluginFTPServerWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.protocolAndType = ixActivity.protocolAndType
		self.timeline = IxTimelineProxyFTPServerWrapper(ixActivity.timeline)
		self.timelineId = ixActivity.timelineId
		self.type = ixActivity.type
		self.activeRole = ixActivity.activeRole

	properties = ["customParameters", "enable", "protocol", "name", "role", "objectivePercent", "protocolAndType", "timelineId", "type", "activeRole", ]

	def __getattribute__(self, name):
		if name in IxActivityFTPServerWrapper.properties and super(IxActivityFTPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityFTPServerWrapper, self).__getattribute__("_IxActivityFTPServerWrapper__ixActivity"), name)
		else:
			return super(IxActivityFTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityFTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityFTPServerWrapper, self).__getattribute__("_IxActivityFTPServerWrapper__ixActivity"), name, value)
			super(IxActivityFTPServerWrapper, self).__setattr__(name, value)


class PluginFTPClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginFTPClientWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.vlanPriority = agent.vlanPriority
		self.actionList = IxFtpCommandListFTPClientWrapper(agent)
		self.realFileList = RealFileListFTPClientWrapper(agent)
		self.commandTimeout = agent.commandTimeout
		self.enableEsm = agent.enableEsm
		self.tos = agent.tos
		self.esm = agent.esm
		self.enableTos = agent.enableTos
		self.precedenceTOS = agent.precedenceTOS
		self.ipPreference = agent.ipPreference
		self.flowPercentage = agent.flowPercentage
		self.reliabilityTOS = agent.reliabilityTOS
		self.delayTOS = agent.delayTOS
		self.fileList = agent.fileList
		self.password = agent.password
		self.enableVlanPriority = agent.enableVlanPriority
		self.userName = agent.userName
		self.throughputTOS = agent.throughputTOS
		self.mode = agent.mode

	properties = ["cmdListLoops", "vlanPriority", "commandTimeout", "enableEsm", "tos", "esm", "enableTos", "precedenceTOS", "ipPreference", "flowPercentage", "reliabilityTOS", "delayTOS", "password", "enableVlanPriority", "userName", "throughputTOS", "mode", ]

	def __getattribute__(self, name):
		if name in PluginFTPClientWrapper.properties and super(PluginFTPClientWrapper, self).__getattribute__(name):
			return getattr(super(PluginFTPClientWrapper, self).__getattribute__("_PluginFTPClientWrapper__agent"), name)
		else:
			return super(PluginFTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginFTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginFTPClientWrapper, self).__getattribute__("_PluginFTPClientWrapper__agent"), name, value)
			super(PluginFTPClientWrapper, self).__setattr__(name, value)


class IxTimelineProxyFTPClientWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyFTPClientWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.iterations = timeline.iterations
		self.rampUpType = timeline.rampUpType
		self.rampUpValue = timeline.rampUpValue
		self.rampUpTime = timeline.rampUpTime
		self.rampDownTime = timeline.rampDownTime
		self.standbyTime = timeline.standbyTime
		self.rampDownValue = timeline.rampDownValue
		self.rampUpInterval = timeline.rampUpInterval
		self.offlineTime = timeline.offlineTime
		self.sustainTime = timeline.sustainTime
		self.name = timeline.name
		self.timelineType = timeline.timelineType

	properties = ["iterations", "rampUpType", "rampUpValue", "rampUpTime", "rampDownTime", "standbyTime", "rampDownValue", "rampUpInterval", "offlineTime", "sustainTime", "name", "timelineType", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyFTPClientWrapper.properties and super(IxTimelineProxyFTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyFTPClientWrapper, self).__getattribute__("_IxTimelineProxyFTPClientWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyFTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyFTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyFTPClientWrapper, self).__getattribute__("_IxTimelineProxyFTPClientWrapper__timeline"), name, value)
			super(IxTimelineProxyFTPClientWrapper, self).__setattr__(name, value)


class PluginFTPServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginFTPServerWrapper, self).__init__(agent)
		self.__agent = agent
		self.enableTos = agent.enableTos
		self.cmdListLoops = agent.cmdListLoops
		self.enableEsm = agent.enableEsm
		self.flowPercentage = agent.flowPercentage
		self.vlanPriority = agent.vlanPriority
		self.tos = agent.tos
		self.reliabilityTOS = agent.reliabilityTOS
		self.realFileList = RealFileListFTPServerWrapper(agent)
		self.ftpPort = agent.ftpPort
		self.delayTOS = agent.delayTOS
		self.precedenceTOS = agent.precedenceTOS
		self.throughputTOS = agent.throughputTOS
		self.esm = agent.esm
		self.enableVlanPriority = agent.enableVlanPriority

	properties = ["enableTos", "cmdListLoops", "enableEsm", "flowPercentage", "vlanPriority", "tos", "reliabilityTOS", "ftpPort", "delayTOS", "precedenceTOS", "throughputTOS", "esm", "enableVlanPriority", ]

	def __getattribute__(self, name):
		if name in PluginFTPServerWrapper.properties and super(PluginFTPServerWrapper, self).__getattribute__(name):
			return getattr(super(PluginFTPServerWrapper, self).__getattribute__("_PluginFTPServerWrapper__agent"), name)
		else:
			return super(PluginFTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginFTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginFTPServerWrapper, self).__getattribute__("_PluginFTPServerWrapper__agent"), name, value)
			super(PluginFTPServerWrapper, self).__setattr__(name, value)


class IxTimelineProxyFTPServerWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyFTPServerWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.name = timeline.name
		self.standbyTime = timeline.standbyTime
		self.iterations = timeline.iterations
		self.sustainTime = timeline.sustainTime

	properties = ["name", "standbyTime", "iterations", "sustainTime", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyFTPServerWrapper.properties and super(IxTimelineProxyFTPServerWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyFTPServerWrapper, self).__getattribute__("_IxTimelineProxyFTPServerWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyFTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyFTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyFTPServerWrapper, self).__getattribute__("_IxTimelineProxyFTPServerWrapper__timeline"), name, value)
			super(IxTimelineProxyFTPServerWrapper, self).__setattr__(name, value)


class IxFtpCommandListFTPClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent
		self.optionsDict = {
			('CD',): "IxFtpCommandFTPClient",
			('{Put}',): "IxFtpCommandFTPClient",
			('{Get}',): "IxFtpCommandFTPClient",
			('START',): "IxStartCommandFTPClient",
			('STOP',): "IxStopCommandFTPClient",
			('LoopBeginCommand',): "IxLoopBeginCommandFTPClient",
			('QUIT',): "IxFtpCommandFTPClient",
			('LOGIN',): "IxFtpCommandFTPClient",
			('THINK',): "IxThinkCommandFTPClient",
			('MKD',): "IxFtpCommandFTPClient",
			('STORE',): "IxFtpCommandFTPClient",
			('RETRIEVE',): "IxFtpCommandFTPClient",
			('LoopEndCommand',): "IxLoopEndCommandFTPClient",
		}

	def getItemIxCdCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixFtpCommand":
				return IxFtpCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxCdCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "CD"})
		return IxFtpCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxPutCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixFtpCommand":
				return IxFtpCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxPutCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "{Put}"})
		return IxFtpCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxGetCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixFtpCommand":
				return IxFtpCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxGetCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "{Get}"})
		return IxFtpCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxStartCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixStartCommand":
				return IxStartCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStartCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "START"})
		return IxStartCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxStopCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixStopCommand":
				return IxStopCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STOP"})
		return IxStopCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, commandType=None):
		kwargs = {}
		kwargs.update({"commandType": commandType})
		return self.__agent.actionList.appendItem(**kwargs)

	def getList(self):
		return self.__agent.actionList

	def clear(self):
		return self.__agent.actionList.clear()

	def getItemIxLoopbegincommandCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixLoopBeginCommand":
				return IxLoopBeginCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopbegincommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopBeginCommand"})
		return IxLoopBeginCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxQuitCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixFtpCommand":
				return IxFtpCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxQuitCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "QUIT"})
		return IxFtpCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxLoginCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixFtpCommand":
				return IxFtpCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoginCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LOGIN"})
		return IxFtpCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxThinkCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixThinkCommand":
				return IxThinkCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxThinkCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "THINK"})
		return IxThinkCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxMkdCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixFtpCommand":
				return IxFtpCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxMkdCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "MKD"})
		return IxFtpCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxStoreCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixFtpCommand":
				return IxFtpCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStoreCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STORE"})
		return IxFtpCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxRetrieveCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixFtpCommand":
				return IxFtpCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxRetrieveCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "RETRIEVE"})
		return IxFtpCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))

	def getItemIxLoopendcommandCommand(self, objectID):
		itemList = self.__agent.actionList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixLoopEndCommand":
				return IxLoopEndCommandFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxLoopendcommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "LoopEndCommand"})
		return IxLoopEndCommandFTPClientWrapper(self.__agent.actionList.appendItem(**kwargs))


class IxStartCommandFTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixStartCommand):
		super(IxStartCommandFTPClientWrapper, self).__init__(ixStartCommand)
		self.__ixStartCommand = ixStartCommand
		self.commandType = ixStartCommand.commandType
		self.cmdName = ixStartCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxStartCommandFTPClientWrapper.properties and super(IxStartCommandFTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxStartCommandFTPClientWrapper, self).__getattribute__("_IxStartCommandFTPClientWrapper__ixStartCommand"), name)
		else:
			return super(IxStartCommandFTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxStartCommandFTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxStartCommandFTPClientWrapper, self).__getattribute__("_IxStartCommandFTPClientWrapper__ixStartCommand"), name, value)
			super(IxStartCommandFTPClientWrapper, self).__setattr__(name, value)


class IxFtpCommandFTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixFtpCommand):
		super(IxFtpCommandFTPClientWrapper, self).__init__(ixFtpCommand)
		self.__ixFtpCommand = ixFtpCommand
		self.userName = ixFtpCommand.userName
		self.destination = ixFtpCommand.destination
		self.cmdName = ixFtpCommand.cmdName
		self.commandType = ixFtpCommand.commandType
		self.sessionId = ixFtpCommand.sessionId
		self.arguments = ixFtpCommand.arguments
		self.password = ixFtpCommand.password

	properties = ["userName", "destination", "cmdName", "commandType", "sessionId", "arguments", "password", ]

	def __getattribute__(self, name):
		if name in IxFtpCommandFTPClientWrapper.properties and super(IxFtpCommandFTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxFtpCommandFTPClientWrapper, self).__getattribute__("_IxFtpCommandFTPClientWrapper__ixFtpCommand"), name)
		else:
			return super(IxFtpCommandFTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxFtpCommandFTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxFtpCommandFTPClientWrapper, self).__getattribute__("_IxFtpCommandFTPClientWrapper__ixFtpCommand"), name, value)
			super(IxFtpCommandFTPClientWrapper, self).__setattr__(name, value)


class IxStopCommandFTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixStopCommand):
		super(IxStopCommandFTPClientWrapper, self).__init__(ixStopCommand)
		self.__ixStopCommand = ixStopCommand
		self.commandType = ixStopCommand.commandType
		self.cmdName = ixStopCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxStopCommandFTPClientWrapper.properties and super(IxStopCommandFTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxStopCommandFTPClientWrapper, self).__getattribute__("_IxStopCommandFTPClientWrapper__ixStopCommand"), name)
		else:
			return super(IxStopCommandFTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxStopCommandFTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxStopCommandFTPClientWrapper, self).__getattribute__("_IxStopCommandFTPClientWrapper__ixStopCommand"), name, value)
			super(IxStopCommandFTPClientWrapper, self).__setattr__(name, value)


class RealFileListFTPClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent

	def getItem(self, objectID):
		itemList = self.__agent.realFileList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "RealFileObject":
				return RealFileObjectFTPClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return RealFileObjectFTPClientWrapper(self.__agent.realFileList.appendItem(**kwargs))

	def getList(self):
		return self.__agent.realFileList

	def clear(self):
		return self.__agent.realFileList.clear()


class RealFileObjectFTPClientWrapper(RestObjectBaseClass):

	def __init__(self, RealFileObject):
		super(RealFileObjectFTPClientWrapper, self).__init__(RealFileObject)
		self.__RealFileObject = RealFileObject
		self.payloadFile = RealFileObject.payloadFile
		self.page = RealFileObject.page

	properties = ["payloadFile", "page", ]

	def __getattribute__(self, name):
		if name in RealFileObjectFTPClientWrapper.properties and super(RealFileObjectFTPClientWrapper, self).__getattribute__(name):
			return getattr(super(RealFileObjectFTPClientWrapper, self).__getattribute__("_RealFileObjectFTPClientWrapper__RealFileObject"), name)
		else:
			return super(RealFileObjectFTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(RealFileObjectFTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(RealFileObjectFTPClientWrapper, self).__getattribute__("_RealFileObjectFTPClientWrapper__RealFileObject"), name, value)
			super(RealFileObjectFTPClientWrapper, self).__setattr__(name, value)


class RealFileListFTPServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		self.__agent = agent

	def getItem(self, objectID):
		itemList = self.__agent.realFileList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "RealFileObject":
				return RealFileObjectFTPServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return RealFileObjectFTPServerWrapper(self.__agent.realFileList.appendItem(**kwargs))

	def getList(self):
		return self.__agent.realFileList

	def clear(self):
		return self.__agent.realFileList.clear()


class RealFileObjectFTPServerWrapper(RestObjectBaseClass):

	def __init__(self, RealFileObject):
		super(RealFileObjectFTPServerWrapper, self).__init__(RealFileObject)
		self.__RealFileObject = RealFileObject
		self.payloadFile = RealFileObject.payloadFile
		self.page = RealFileObject.page

	properties = ["payloadFile", "page", ]

	def __getattribute__(self, name):
		if name in RealFileObjectFTPServerWrapper.properties and super(RealFileObjectFTPServerWrapper, self).__getattribute__(name):
			return getattr(super(RealFileObjectFTPServerWrapper, self).__getattribute__("_RealFileObjectFTPServerWrapper__RealFileObject"), name)
		else:
			return super(RealFileObjectFTPServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(RealFileObjectFTPServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(RealFileObjectFTPServerWrapper, self).__getattribute__("_RealFileObjectFTPServerWrapper__RealFileObject"), name, value)
			super(RealFileObjectFTPServerWrapper, self).__setattr__(name, value)


class IxLoopBeginCommandFTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixLoopBeginCommand):
		super(IxLoopBeginCommandFTPClientWrapper, self).__init__(ixLoopBeginCommand)
		self.__ixLoopBeginCommand = ixLoopBeginCommand
		self.commandType = ixLoopBeginCommand.commandType
		self.cmdName = ixLoopBeginCommand.cmdName
		self.LoopCount = ixLoopBeginCommand.LoopCount

	properties = ["commandType", "cmdName", "LoopCount", ]

	def __getattribute__(self, name):
		if name in IxLoopBeginCommandFTPClientWrapper.properties and super(IxLoopBeginCommandFTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxLoopBeginCommandFTPClientWrapper, self).__getattribute__("_IxLoopBeginCommandFTPClientWrapper__ixLoopBeginCommand"), name)
		else:
			return super(IxLoopBeginCommandFTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxLoopBeginCommandFTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxLoopBeginCommandFTPClientWrapper, self).__getattribute__("_IxLoopBeginCommandFTPClientWrapper__ixLoopBeginCommand"), name, value)
			super(IxLoopBeginCommandFTPClientWrapper, self).__setattr__(name, value)


class IxLoopEndCommandFTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixLoopEndCommand):
		super(IxLoopEndCommandFTPClientWrapper, self).__init__(ixLoopEndCommand)
		self.__ixLoopEndCommand = ixLoopEndCommand
		self.commandType = ixLoopEndCommand.commandType
		self.cmdName = ixLoopEndCommand.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxLoopEndCommandFTPClientWrapper.properties and super(IxLoopEndCommandFTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxLoopEndCommandFTPClientWrapper, self).__getattribute__("_IxLoopEndCommandFTPClientWrapper__ixLoopEndCommand"), name)
		else:
			return super(IxLoopEndCommandFTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxLoopEndCommandFTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxLoopEndCommandFTPClientWrapper, self).__getattribute__("_IxLoopEndCommandFTPClientWrapper__ixLoopEndCommand"), name, value)
			super(IxLoopEndCommandFTPClientWrapper, self).__setattr__(name, value)


class IxThinkCommandFTPClientWrapper(RestObjectBaseClass):

	def __init__(self, ixThinkCommand):
		super(IxThinkCommandFTPClientWrapper, self).__init__(ixThinkCommand)
		self.__ixThinkCommand = ixThinkCommand
		self.minimumInterval = ixThinkCommand.minimumInterval
		self.cmdName = ixThinkCommand.cmdName
		self.commandType = ixThinkCommand.commandType
		self.maximumInterval = ixThinkCommand.maximumInterval

	properties = ["minimumInterval", "cmdName", "commandType", "maximumInterval", ]

	def __getattribute__(self, name):
		if name in IxThinkCommandFTPClientWrapper.properties and super(IxThinkCommandFTPClientWrapper, self).__getattribute__(name):
			return getattr(super(IxThinkCommandFTPClientWrapper, self).__getattribute__("_IxThinkCommandFTPClientWrapper__ixThinkCommand"), name)
		else:
			return super(IxThinkCommandFTPClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxThinkCommandFTPClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxThinkCommandFTPClientWrapper, self).__getattribute__("_IxThinkCommandFTPClientWrapper__ixThinkCommand"), name, value)
			super(IxThinkCommandFTPClientWrapper, self).__setattr__(name, value)


class StatsNameSilverlightClient(object):
	def __init__(self):
		self.kSilverlightStreamsVoDPlayedWithError = "Silverlight Streams VoD Played With Error"
		self.kSilverlightManifestFailed = "Silverlight Manifest Failed"
		self.kSilverlightStreamsInBitrate0to400 = "Silverlight Streams In Bitrate 0 to 400"
		self.kSilverlightStreamsInBitrate900to1500 = "Silverlight Streams In Bitrate 900 to 1500"
		self.kSilverlightUpshiftsDueto4xxAttempted = "Silverlight Upshifts Due to 4xx Attempted"
		self.kSilverlightStreamsLiveAttempted = "Silverlight Streams Live Attempted"
		self.kSilverlightInvalidManifestURL = "Silverlight Invalid Manifest URL"
		self.kSilverlightMonitorUserCurrentBitrate = "Silverlight Monitor User Current Bitrate"
		self.kSilverlightTotalMediaBytesReceived = "Silverlight Total Media Bytes Received"
		self.kSilverlightDownshiftsDueto4xxAttempted = "Silverlight Downshifts Due to 4xx Attempted"
		self.kSilverlightManifestRequest = "Silverlight Manifest Request"
		self.kSilverlightVideoFragmentsFailed = "Silverlight Video Fragments Failed"
		self.kSilverlightAudioFragmentsRequested = "Silverlight Audio Fragments Requested"
		self.kSilverlightActiveVoDStreams = "Silverlight Active VoD Streams"
		self.kSilverlightTotalAudioBytesReceived = "Silverlight Total Audio Bytes Received"
		self.kSilverlightDownshiftsDueto4xxSucceeded = "Silverlight Downshifts Due to 4xx Succeeded"
		self.kSilverlightStreamsInBitrate400to900 = "Silverlight Streams In Bitrate 400 to 900"
		self.kSilverlightDownshiftsAttempted = "Silverlight Downshifts Attempted"
		self.kSilverlightActiveLiveStreams = "Silverlight Active Live Streams"
		self.kSilverlightTotalVideoBytesReceived = "Silverlight Total Video Bytes Received"
		self.kSilverlightStreamsInBitrate5000to6000 = "Silverlight Streams In Bitrate 5000 to 6000"
		self.kSilverlightStreamsVoDAttempted = "Silverlight Streams VoD Attempted"
		self.kSilverlightUpshiftsDueto4xxSucceeded = "Silverlight Upshifts Due to 4xx Succeeded"
		self.kSilverlightStreamsInBitrate2000to3000 = "Silverlight Streams In Bitrate 2000 to 3000"
		self.kSilverlightVideoFragmentsSuccessful = "Silverlight Video Fragments Successful"
		self.kSilverlightStreamsInBitrategreaterthan7000 = "Silverlight Streams In Bitrate greater than 7000"
		self.kSilverlightStreamsInBitrate4000to5000 = "Silverlight Streams In Bitrate 4000 to 5000"
		self.kSilverlightInvalidFragmentURL = "Silverlight Invalid Fragment URL"
		self.kSilverlightStreamsInBitrate1500to2000 = "Silverlight Streams In Bitrate 1500 to 2000"
		self.kSilverlightStreamsLivePlayedSuccessful = "Silverlight Streams Live Played Successful"
		self.kSilverlightStreamsVoDPlayedSuccessful = "Silverlight Streams VoD Played Successful"
		self.kSilverlightDownshiftsDueto4xxFailed = "Silverlight Downshifts Due to 4xx Failed"
		self.kSilverlightManifestSuccessful = "Silverlight Manifest Successful"
		self.kSilverlightStreamsLivePlayedWithError = "Silverlight Streams Live Played With Error"
		self.kSilverlightAudioFragmentsFailed = "Silverlight Audio Fragments Failed"
		self.kSilverlightStreamsInBitrate3000to4000 = "Silverlight Streams In Bitrate 3000 to 4000"
		self.kSilverlightVideoFragmentsRequested = "Silverlight Video Fragments Requested"
		self.kSilverlightStreamsInBitrate6000to7000 = "Silverlight Streams In Bitrate 6000 to 7000"
		self.kSilverlightUpshiftsDueto4xxFailed = "Silverlight Upshifts Due to 4xx Failed"
		self.kSilverlightAudioFragmentsSuccessful = "Silverlight Audio Fragments Successful"
		self.kSilverlightUpshiftsAttempted = "Silverlight Upshifts Attempted"


class StatsNameHTTPHTTPStreamingClient(object):
	def __init__(self):
		self.kHTTPBytesReceived = "HTTP Bytes Received"
		self.kHTTPRequestPreconditionFailed412 = "HTTP Request Precondition Failed (412)"
		self.kHTTPRequestsFailedWrite = "HTTP Requests Failed (Write)"
		self.kHTTPConnectTimems = "HTTP Connect Time (ms)"
		self.kHTTPRequestsFailedother = "HTTP Requests Failed (other)"
		self.kHTTPContentBytesSent = "HTTP Content Bytes Sent"
		self.kHTTPRequestsSuccessful2xx = "HTTP Requests Successful (2xx)"
		self.kHTTPRequestsFailed404 = "HTTP Requests Failed (404)"
		self.kHTTPThroughputRxKbps = "HTTP Throughput - Rx (Kbps)"
		self.kHTTPRequestsFailedRead = "HTTP Requests Failed (Read)"
		self.kHTTPRequestsSuccessful301 = "HTTP Requests Successful (301)"
		self.kHTTPTransactions = "HTTP Transactions"
		self.kHTTPRequestsSuccessful302 = "HTTP Requests Successful (302)"
		self.kHTTPRequestsFailed4xxother = "HTTP Requests Failed (4xx other)"
		self.kHTTPRequestsFailed400 = "HTTP Requests Failed (400)"
		self.kHTTPTimeToFirstByteus = "HTTP Time To First Byte (us)"
		self.kHTTPBytes = "HTTP Bytes"
		self.kHTTPRequestsFailed408 = "HTTP Requests Failed (408)"
		self.kHTTPConnectionAttempts = "HTTP Connection Attempts"
		self.kHTTPRequestsFailed5xxother = "HTTP Requests Failed (5xx other)"
		self.kHTTPTimeToLastBytems = "HTTP Time To Last Byte (ms)"
		self.kHTTPRequestsFailedBadHeader = "HTTP Requests Failed (Bad Header)"
		self.kHTTPTimeToLastByteus = "HTTP Time To Last Byte (us)"
		self.kHTTPRequestsFailedAborted = "HTTP Requests Failed (Aborted)"
		self.kHTTPRequestsFailed505 = "HTTP Requests Failed (505)"
		self.kHTTPSessionsRejected503 = "HTTP Sessions Rejected (503)"
		self.kHTTPRequestsSent = "HTTP Requests Sent"
		self.kHTTPRequestsSuccessful307 = "HTTP Requests Successful (307)"
		self.kHTTPConnections = "HTTP Connections"
		self.kHTTPIntermediateResponsesReceived1xx = "HTTP Intermediate Responses Received (1xx)"
		self.kHTTPTransactionsActive = "HTTP Transactions Active"
		self.kHTTPRequestsFailed = "HTTP Requests Failed"
		self.kHTTPRequestsSuccessful3xx = "HTTP Requests Successful (3xx)"
		self.kHTTPRequestsFailed403 = "HTTP Requests Failed (403)"
		self.kHTTPRequestsFailed401 = "HTTP Requests Failed (401)"
		self.kHTTPRequestsSuccessful303 = "HTTP Requests Successful (303)"
		self.kHTTPRequestsSuccessful = "HTTP Requests Successful"
		self.kHTTPRequestsFailed5xx = "HTTP Requests Failed (5xx)"
		self.kHTTPRequestsFailedTimeout = "HTTP Requests Failed (Timeout)"
		self.kHTTPRequestsFailed407 = "HTTP Requests Failed (407)"
		self.kHTTPConnectTimeus = "HTTP Connect Time (us)"
		self.kHTTPBytesSent = "HTTP Bytes Sent"
		self.kHTTPSessionTimeouts408 = "HTTP Session Timeouts (408)"
		self.kHTTPTimeToFirstBytems = "HTTP Time To First Byte (ms)"
		self.kHTTPContentBytesReceived = "HTTP Content Bytes Received"
		self.kHTTPThroughputKbps = "HTTP Throughput (Kbps)"
		self.kHTTPRequestsFailed4xx = "HTTP Requests Failed (4xx)"
		self.kHTTPThroughputTxKbps = "HTTP Throughput - Tx (Kbps)"


class StatsNameHLSClient(object):
	def __init__(self):
		self.kActiveStreamsInBitrate3000to4000Kbps = "Active Streams In Bitrate 3000 to 4000 Kbps"
		self.kHLSKeyRequestsFailed = "HLS Key Requests Failed"
		self.kHLSStreamsLiveAttempted = "HLS Streams Live Attempted"
		self.kSecondaryPlaylistRequestSuccessful = "Secondary Playlist Request Successful"
		self.kActiveStreamsInBitrate0to400Kbps = "Active Streams In Bitrate 0 to 400 Kbps"
		self.kHLSStreamsInBitrate3000to4000 = "HLS Streams In Bitrate 3000 to 4000"
		self.kKeyRequestsSuccessful = "Key Requests Successful"
		self.kMonitorUserCurrentBitrateKbps = "Monitor User Current Bitrate (Kbps)"
		self.kSecondaryPlaylistsRequested = "Secondary Playlists Requested"
		self.kUpshiftPlaylistRequestsSuccessful = "Upshift Playlist Requests Successful"
		self.kStalePlaylist = "Stale Playlist"
		self.kEmptyPlaylist = "Empty Playlist"
		self.kHLSStreamsInBitrate0to400 = "HLS Streams In Bitrate 0 to 400"
		self.kHLSPrimaryPlaylistRequested = "HLS Primary Playlist Requested"
		self.kHLSInvalidPlaylistURL = "HLS Invalid Playlist URL"
		self.kHLSPlaylistReloadFailed = "HLS Playlist Reload Failed"
		self.kHLSStreamsInBitrate1500to2000 = "HLS Streams In Bitrate 1500 to 2000"
		self.kActiveStreamsInBitrate5000to6000Kbps = "Active Streams In Bitrate 5000 to 6000 Kbps"
		self.kPrimaryPlaylistRequestsSuccessful = "Primary Playlist Requests Successful"
		self.kPrimaryPlaylistRequestsFailed = "Primary Playlist Requests Failed"
		self.kHLSStreamsVoDPlayedSuccessful = "HLS Streams VoD Played Successful"
		self.kHLSInvalidKeyURL = "HLS Invalid Key URL"
		self.kHLSStreamsInBitrate400to900 = "HLS Streams In Bitrate 400 to 900"
		self.kHLSStreamsInBitrate2000to3000 = "HLS Streams In Bitrate 2000 to 3000"
		self.kHLSStreamsInBitrate5000to6000 = "HLS Streams In Bitrate 5000 to 6000"
		self.kUpshiftsAttempted = "Upshifts Attempted"
		self.kActiveStreamsInBitrate6000to7000Kbps = "Active Streams In Bitrate 6000 to 7000 Kbps"
		self.kHLSUpshiftsAttempted = "HLS Upshifts Attempted"
		self.kActiveVoDStreams = "Active VoD Streams"
		self.kSecondaryPlaylistRequestsFailed = "Secondary Playlist Requests Failed"
		self.kHLSActiveLiveStreams = "HLS Active Live Streams"
		self.kMediaSegmentRequestsSuccessful = "Media Segment Requests Successful"
		self.kStreamsVoDPlayedSuccessful = "Streams VoD Played Successful"
		self.kHLSMediaSegmentRequestsFailed = "HLS Media Segment Requests Failed"
		self.kStreamsVoDAttempted = "Streams VoD Attempted"
		self.kDynamicPlaylistReloadsFailed = "Dynamic Playlist Reloads Failed"
		self.kActiveStreamsInBitrate1500to2000Kbps = "Active Streams In Bitrate 1500 to 2000 Kbps"
		self.kInvalidMediaURL = "Invalid Media URL"
		self.kMediaSegmentsRequested = "Media Segments Requested"
		self.kActiveStreamsInBitrate4000to5000Kbps = "Active Streams In Bitrate 4000 to 5000 Kbps"
		self.kHLSDownshiftsAttempted = "HLS Downshifts Attempted"
		self.kHLSStreamsLivePlayedSuccessful = "HLS Streams Live Played Successful"
		self.kActiveStreamsInBitrate900to1500Kbps = "Active Streams In Bitrate 900 to 1500 Kbps"
		self.kHLSStreamsVoDAttempted = "HLS Streams VoD Attempted"
		self.kHLSUpshiftPlaylistRequestsSuccessful = "HLS Upshift Playlist Requests Successful"
		self.kHLSSecondaryPlaylistRequestsFailed = "HLS Secondary Playlist Requests Failed"
		self.kInvalidPlaylistURL = "Invalid Playlist URL"
		self.kDownshiftPlaylistRequestsSuccessful = "Downshift Playlist Requests Successful"
		self.kHLSStreamsVoDPlayedWithError = "HLS Streams VoD Played With Error"
		self.kHLSInvalidMediaURL = "HLS Invalid Media URL"
		self.kHLSKeyRequestsAttempted = "HLS Key Requests Attempted"
		self.kHLSActiveVoDStreams = "HLS Active VoD Streams"
		self.kHLSMediaSegmentsRequested = "HLS Media Segments Requested"
		self.kHLSStalePlaylist = "HLS Stale Playlist"
		self.kActiveLiveStreams = "Active Live Streams"
		self.kMediaSegmentRequestsFailed = "Media Segment Requests Failed"
		self.kHLSMediaSegmentRequestsSuccessful = "HLS Media Segment Requests Successful"
		self.kHLSPlaylistReloadSuccessful = "HLS Playlist Reload Successful"
		self.kHLSStreamsInBitrategreaterthan7000 = "HLS Streams In Bitrate greater than 7000"
		self.kHLSDownshiftPlaylistRequestsSuccessful = "HLS Downshift Playlist Requests Successful"
		self.kDynamicPlaylistReloadsRequested = "Dynamic Playlist Reloads Requested"
		self.kStreamsVoDPlayedWithError = "Streams VoD Played With Error"
		self.kHLSMonitorUserCurrentBitrate = "HLS Monitor User Current Bitrate"
		self.kHLSPrimaryPlaylistRequestsFailed = "HLS Primary Playlist Requests Failed"
		self.kHLSEmptyPlaylist = "HLS Empty Playlist"
		self.kHLSPrimaryPlaylistRequestsSuccessful = "HLS Primary Playlist Requests Successful"
		self.kUpshiftPlaylistRequestsFailed = "Upshift Playlist Requests Failed"
		self.kHLSSecondaryPlaylistsRequested = "HLS Secondary Playlists Requested"
		self.kStreamsLivePlayedSuccessful = "Streams Live Played Successful"
		self.kInvalidKeyURL = "Invalid Key URL"
		self.kKeyRequestsFailed = "Key Requests Failed"
		self.kHLSStreamsInBitrate900to1500 = "HLS Streams In Bitrate 900 to 1500"
		self.kDynamicPlaylistReloadSuccessful = "Dynamic Playlist Reload Successful"
		self.kHLSUpshiftPlaylistRequestsFailed = "HLS Upshift Playlist Requests Failed"
		self.kHLSMediaBytesReceived = "HLS Media Bytes Received"
		self.kMediaDataRateKbps = "Media Data Rate (Kbps)"
		self.kHLSStreamsInBitrate6000to7000 = "HLS Streams In Bitrate 6000 to 7000"
		self.kHLSDownshiftPlaylistRequestsFailed = "HLS Downshift Playlist Requests Failed"
		self.kActiveStreamsInBitrate2000to3000Kbps = "Active Streams In Bitrate 2000 to 3000 Kbps"
		self.kHLSKeyRequestsSuccessful = "HLS Key Requests Successful"
		self.kHLSStreamsLivePlayedWithError = "HLS Streams Live Played With Error"
		self.kDownshiftsAttempted = "Downshifts Attempted"
		self.kHLSPlaylistReloadsRequested = "HLS Playlist Reloads Requested"
		self.kHLSSecondaryPlaylistRequestSuccessful = "HLS Secondary Playlist Request Successful"
		self.kPrimaryPlaylistRequested = "Primary Playlist Requested"
		self.kActiveStreamsInBitrategreaterthan7000Kbps = "Active Streams In Bitrate greater than 7000 Kbps"
		self.kDownshiftPlaylistRequestsFailed = "Downshift Playlist Requests Failed"
		self.kHLSStreamsInBitrate4000to5000 = "HLS Streams In Bitrate 4000 to 5000"
		self.kStreamsLivePlayedWithError = "Streams Live Played With Error"
		self.kStreamsLiveAttempted = "Streams Live Attempted"
		self.kActiveStreamsInBitrate400to900Kbps = "Active Streams In Bitrate 400 to 900 Kbps"
		self.kKeyRequestsAttempted = "Key Requests Attempted"


class StatsNameHLSHTTPSSL(object):
	def __init__(self):
		self.kSSLAlertsSentunsupported_certificate = "SSL Alerts Sent (unsupported_certificate)"
		self.kSSLAlertsReceiveddecryption_failed = "SSL Alerts Received (decryption_failed)"
		self.kSSLAlertsReceivedillegal_parameter = "SSL Alerts Received (illegal_parameter)"
		self.kHelloRequestsSent = "Hello Requests Sent"
		self.kSSLErrorsReceivedunsupportedcertificate = "SSL Errors Received (unsupported certificate)"
		self.kSSLAlertsReceivedinternal_error = "SSL Alerts Received (internal_error)"
		self.kSSLSessionReuseFailed = "SSL Session Reuse Failed"
		self.kSSLAlertsSentrecord_overflow = "SSL Alerts Sent (record_overflow)"
		self.kSSLAlertsSentcertificate_revoked = "SSL Alerts Sent (certificate_revoked)"
		self.kSSLAlertsReceivedunknown_ca = "SSL Alerts Received (unknown_ca)"
		self.kSSLErrorsReceived = "SSL Errors Received"
		self.kSSLAlertsReceivedbad_record_mac = "SSL Alerts Received (bad_record_mac)"
		self.kSSLAlertsSentcertificate_expired = "SSL Alerts Sent (certificate_expired)"
		self.kClientHelloReceived = "Client Hello Received"
		self.kSSLAlertsSent = "SSL Alerts Sent"
		self.kSSLAlertsSentinternal_error = "SSL Alerts Sent (internal_error)"
		self.kSSLAlertsReceivedhandshake_failure = "SSL Alerts Received (handshake_failure)"
		self.kSSLErrorsReceivedundefinederror = "SSL Errors Received (undefined error)"
		self.kSSLBytesReceived = "SSL Bytes Received"
		self.kSSLAlertsReceivedprotocol_version = "SSL Alerts Received (protocol_version)"
		self.kHelloRequestsReceived = "Hello Requests Received"
		self.kSSLAlertsSentbad_record_mac = "SSL Alerts Sent (bad_record_mac)"
		self.kSSLSessionReuseSuccess = "SSL Session Reuse Success"
		self.kSSLAlertsSentunexpected_message = "SSL Alerts Sent (unexpected_message)"
		self.kSSLErrorsSentundefinederror = "SSL Errors Sent (undefined error)"
		self.kSSLErrorsSentunsupportedcertificate = "SSL Errors Sent (unsupported certificate)"
		self.kSSLAlertsReceivedexport_restriction = "SSL Alerts Received (export_restriction)"
		self.kSSLAlertsSentexport_restriction = "SSL Alerts Sent (export_restriction)"
		self.kSSLAlertsReceiveddecode_error = "SSL Alerts Received (decode_error)"
		self.kSSLAlertsSentillegal_parameter = "SSL Alerts Sent (illegal_parameter)"
		self.kServerHelloSent = "Server Hello Sent"
		self.kSSLAlertsSentprotocol_version = "SSL Alerts Sent (protocol_version)"
		self.kSSLAlertsReceivedunexpected_message = "SSL Alerts Received (unexpected_message)"
		self.kSSLAlertsSentaccess_denied = "SSL Alerts Sent (access_denied)"
		self.kSSLAlertsReceivedcertificate_revoked = "SSL Alerts Received (certificate_revoked)"
		self.kSSLApplicationDataBytes = "SSL Application Data Bytes"
		self.kSSLErrorsSentnocertificate = "SSL Errors Sent (no certificate)"
		self.kSSLAlertsSentbad_certificate = "SSL Alerts Sent (bad_certificate)"
		self.kSSLAlertsReceiveduser_canceled = "SSL Alerts Received (user_canceled)"
		self.kServerHelloReceived = "Server Hello Received"
		self.kSSLAlertsReceivedrecord_overflow = "SSL Alerts Received (record_overflow)"
		self.kSSLAlertsReceivedcertificate_expired = "SSL Alerts Received (certificate_expired)"
		self.kSSLAlertsSentinsufficient_security = "SSL Alerts Sent (insufficient_security)"
		self.kSSLAlertsReceiveddecompression_failure = "SSL Alerts Received (decompression_failure)"
		self.kSSLAlertsSenthandshake_failure = "SSL Alerts Sent (handshake_failure)"
		self.kSSLErrorsSentnocipher = "SSL Errors Sent (no cipher)"
		self.kSSLAlertsSentdecode_error = "SSL Alerts Sent (decode_error)"
		self.kSSLAlertsReceivedaccess_denied = "SSL Alerts Received (access_denied)"
		self.kSSLAlertsReceivedclose_notify = "SSL Alerts Received (close_notify)"
		self.kSSLAlertsReceivedinsufficient_security = "SSL Alerts Received (insufficient_security)"
		self.kSSLNegotiationFinishedSuccessfully = "SSL Negotiation Finished Successfully"
		self.kSSLErrorsSentbadcertificate = "SSL Errors Sent (bad certificate)"
		self.kSSLAlertsSentuser_canceled = "SSL Alerts Sent (user_canceled)"
		self.kSSLAlertsReceivedunsupported_certificate = "SSL Alerts Received (unsupported_certificate)"
		self.kSSLBytesSent = "SSL Bytes Sent"
		self.kSSLErrorsReceivednocipher = "SSL Errors Received (no cipher)"
		self.kSSLAlertsReceivedbad_certificate = "SSL Alerts Received (bad_certificate)"
		self.kSSLErrorsReceivednocertificate = "SSL Errors Received (no certificate)"
		self.kSSLThroughputBytes = "SSL Throughput Bytes"
		self.kSSLErrorsReceivedbadcertificate = "SSL Errors Received (bad certificate)"
		self.kSSLAlertsSentdecryption_failed = "SSL Alerts Sent (decryption_failed)"
		self.kSSLAlertsSentunknown_ca = "SSL Alerts Sent (unknown_ca)"
		self.kSSLAlertsSentno_renegotiation = "SSL Alerts Sent (no_renegotiation)"
		self.kSSLAlertsSentcertificate_unknown = "SSL Alerts Sent (certificate_unknown)"
		self.kSSLAlertsReceivedcertificate_unknown = "SSL Alerts Received (certificate_unknown)"
		self.kSSLAlertsSentdecompression_failure = "SSL Alerts Sent (decompression_failure)"
		self.kSSLAlertsReceivedno_certificate = "SSL Alerts Received (no_certificate)"
		self.kSSLAlertsSentdecrypt_error = "SSL Alerts Sent (decrypt_error)"
		self.kSSLAlertsSentclose_notify = "SSL Alerts Sent (close_notify)"
		self.kSSLConcurrentSessions = "SSL Concurrent Sessions"
		self.kSSLAlertsReceivedno_renegotiation = "SSL Alerts Received (no_renegotiation)"
		self.kClientHelloSent = "Client Hello Sent"
		self.kSSLAlertsReceiveddecrypt_error = "SSL Alerts Received (decrypt_error)"
		self.kSSLAlertsReceived = "SSL Alerts Received"
		self.kSSLErrorsSent = "SSL Errors Sent"
		self.kSSLAlertsSentno_certificate = "SSL Alerts Sent (no_certificate)"


class StatsNameHTTPStreamingClient(object):
	def __init__(self):
		self.kQUICBLOCKEDframeTx = "QUIC BLOCKED frame (Tx)"
		self.kQUICduplicatedframesRx = "QUIC duplicated frames (Rx)"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kQUICpacketerrors = "QUIC packet errors"
		self.kQUICHTTPRequestsFailed = "QUIC HTTP Requests Failed"
		self.kConnectTimeMin = "Connect Time (Min)"
		self.kQUICnewconnections = "QUIC new connections"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kQUIChandshake0rtt = "QUIC handshake 0rtt"
		self.kBufferEmptyRatekbps = "Buffer Empty Rate (kbps)"
		self.kMOS_AAvg = "MOS_A (Avg)"
		self.kBufferLowWatermark = "Buffer Low Watermark"
		self.kQUICframeerrors = "QUIC frame errors"
		self.kQUICGOAWAYframeTx = "QUIC GOAWAY frame (Tx)"
		self.kQUICstreamsclosed = "QUIC streams closed"
		self.kActiveStreamsUnshifted = "Active Streams Unshifted"
		self.kTCPRetries = "TCP Retries"
		self.kQUICinternalerrors = "QUIC internal errors"
		self.kQUICpacketssent = "QUIC packets sent"
		self.kQUICretxpacketswithdata = "QUIC retx packets with data"
		self.kQUIChandshakesdone = "QUIC handshakes done"
		self.kBufferEmptyDuration = "Buffer Empty Duration"
		self.kMOS_AMax = "MOS_A (Max)"
		self.kPoorQuality = "Poor Quality"
		self.kQUICconnectionclosed = "QUIC connection closed"
		self.kConnectTimeMinms = "Connect Time (Min) ms"
		self.kQUICHTTPRequestsFailed5xx = "QUIC HTTP Requests Failed (5xx)"
		self.kMOS_AMin = "MOS_A (Min)"
		self.kAbsoluteMOS_VAvg = "Absolute MOS_V (Avg)"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kQUICRST_STREAMframeRx = "QUIC RST_STREAM frame (Rx)"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kBufferLowWatermarkms = "Buffer Low Watermark (ms)"
		self.kRebufferDurationms = "Rebuffer Duration (ms)"
		self.kTotalPlaybackTimeMaxms = "Total Playback Time (Max) ms"
		self.kPlaybackStartTimeAvg = "Playback Start Time (Avg)"
		self.kVideoDelayDegradationLevel = "Video Delay Degradation Level"
		self.kQUICPINGframeRx = "QUIC PING frame (Rx)"
		self.kQUICHTTPIntermediateResponsesReceived1xx = "QUIC HTTP Intermediate Responses Received (1xx)"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kPlaybackStartTimeMinms = "Playback Start Time (Min) ms"
		self.kQUICstreamerrors = "QUIC stream errors"
		self.kAbsoluteMOS_VMin = "Absolute MOS_V (Min)"
		self.kQUICnewstreams = "QUIC new streams"
		self.kVideoFrameRateDegradationLevel = "Video Frame Rate Degradation Level"
		self.kTotalPlaybackTimeAvgms = "Total Playback Time (Avg) ms"
		self.kActiveStreamsshiftedmorethan1800s = "Active Streams shifted more than 1800 s"
		self.kQUICACKframeRx = "QUIC ACK frame (Rx)"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kPlaybackStartTimeAvgms = "Playback Start Time (Avg) ms"
		self.kActiveStreamsshiftedbetween1and30s = "Active Streams shifted between 1 and 30 s"
		self.kQUICwindowerrors = "QUIC window errors"
		self.kQUICPADDINGframeRx = "QUIC PADDING frame (Rx)"
		self.kQUICconnectionswitherrors = "QUIC connections with errors"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kQUIChandshaketimeout = "QUIC handshake timeout"
		self.kQUICretxpacketsnodata = "QUIC retx packets no data"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kQUIChandshakesfailed = "QUIC handshakes failed"
		self.kHTTPrequestsoverQUIC = "HTTP requests over QUIC"
		self.kVideoDiscardDegradationLevel = "Video Discard Degradation Level"
		self.kQUICbytessent = "QUIC bytes sent"
		self.kVideoGOPLengthDegradationLevel = "Video GOP Length Degradation Level"
		self.kMOS_AVAvg = "MOS_AV (Avg)"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kRebufferProportion = "Rebuffer Proportion (%)"
		self.kConnectTimeMaxms = "Connect Time (Max) ms"
		self.kInitialBufferTimeMin = "Initial Buffer Time (Min)"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kTotalPlaybackTimeMinms = "Total Playback Time (Min) ms"
		self.kConnectTimeMax = "Connect Time (Max)"
		self.kInitialBufferTimeMaxms = "Initial Buffer Time (Max) ms"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kConnectTimeAvg = "Connect Time (Avg)"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kQUICBLOCKEDframeRx = "QUIC BLOCKED frame (Rx)"
		self.kQUICHTTPRequestsSuccessful = "QUIC HTTP Requests Successful"
		self.kVideoAvailNetBWDegradationLevel = "Video Avail Net BW Degradation Level"
		self.kQUICSTREAMframeRx = "QUIC STREAM frame (Rx)"
		self.kBufferEmptyProportion = "Buffer Empty Proportion"
		self.kExcellentQuality = "Excellent Quality"
		self.kPlaybackStartTimeMaxms = "Playback Start Time (Max) ms"
		self.kRelativeMOS_VMax = "Relative MOS_V (Max)"
		self.kQUICWINDOW_UPDATEframeRx = "QUIC WINDOW_UPDATE frame (Rx)"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kQUICbytesreceived = "QUIC bytes received"
		self.kInitialBufferTimeMax = "Initial Buffer Time (Max)"
		self.kQUICHTTPRequestsSuccessful2xx = "QUIC HTTP Requests Successful (2xx)"
		self.kQUICdecryptionerrors = "QUIC decryption errors"
		self.kBufferEmptyCount = "Buffer Empty Count"
		self.kVideoAVSyncDegradationLevel = "Video AV Sync Degradation Level"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kQUICinvalidframeTx = "QUIC invalid frame (Tx)"
		self.kQUICHTTPRequestsSent = "QUIC HTTP Requests Sent"
		self.kQUICSTOP_WAITINGframeTx = "QUIC STOP_WAITING frame (Tx)"
		self.kQUICHTTPRequestsSuccessful3xx = "QUIC HTTP Requests Successful (3xx)"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kQUICCONNECTION_CLOSEframeTx = "QUIC CONNECTION_CLOSE frame (Tx)"
		self.kConnectTimeAvgms = "Connect Time (Avg) ms"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kBufferLevelms = "Buffer Level (ms)"
		self.kQUICSTOP_WAITINGframeRx = "QUIC STOP_WAITING frame (Rx)"
		self.kQUICGOAWAYframeRx = "QUIC GOAWAY frame (Rx)"
		self.kActiveStreamsshiftedbetween300and600s = "Active Streams shifted between 300 and 600 s"
		self.kQUICPINGframeTx = "QUIC PING frame (Tx)"
		self.kStreamAvailabilityAverage = "Stream Availability Average"
		self.kPlaybackStartTimeMax = "Playback Start Time (Max)"
		self.kActiveStreamsshiftedbetween600and1800s = "Active Streams shifted between 600 and 1800 s"
		self.kQUICCONNECTION_CLOSEframeRx = "QUIC CONNECTION_CLOSE frame (Rx)"
		self.kRebufferDuration = "Rebuffer Duration"
		self.kQUICPADDINGframeTx = "QUIC PADDING frame (Tx)"
		self.kInitialBufferTimeAvgms = "Initial Buffer Time (Avg) ms"
		self.kBufferFillRateKbps = "Buffer Fill Rate (Kbps)"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kMOS_AVMin = "MOS_AV (Min)"
		self.kQUICsenderrors = "QUIC send errors"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kVideoLossDegradationLevel = "Video Loss Degradation Level"
		self.kMOS_AVMax = "MOS_AV (Max)"
		self.kQUIChandshaketimems = "QUIC handshake time (ms)"
		self.kQUICoverlappedframesRx = "QUIC overlapped frames (Rx)"
		self.kActiveStreamsshiftedbetween30and90s = "Active Streams shifted between 30 and 90 s"
		self.kRelativeMOS_VMin = "Relative MOS_V (Min)"
		self.kQUICpacketsreceived = "QUIC packets received"
		self.kQUIChandshake1rtt = "QUIC handshake 1rtt"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kAbsoluteMOS_VMax = "Absolute MOS_V (Max)"
		self.kInitialBufferTimeMinms = "Initial Buffer Time (Min) ms"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kRelativeMOS_VAvg = "Relative MOS_V (Avg)"
		self.kStreamAvailabilityGood = "Stream Availability Good"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kStreamAvailabilityPoor = "Stream Availability Poor"
		self.kPlaybackStartTimeMin = "Playback Start Time (Min)"
		self.kVideoCODECQuantDegradationLevel = "Video CODEC Quant Degradation Level"
		self.kBufferEmptyDurationms = "Buffer Empty Duration (ms)"
		self.kMediumQuality = "Medium Quality"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kTotalPlaybackTimeMax = "Total Playback Time (Max)"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kGoodQuality = "Good Quality"
		self.kStreamingSimulatedUsers = "Streaming Simulated Users"
		self.kRebufferProportion = "Rebuffer Proportion"
		self.kTotalPlaybackTimeAvg = "Total Playback Time (Avg)"
		self.kVideoCODECBWRestrictDegradationLevel = "Video CODEC BW Restrict Degradation Level"
		self.kBufferEmptyProportion = "Buffer Empty Proportion (%)"
		self.kQUICRST_STREAMframeTx = "QUIC RST_STREAM frame (Tx)"
		self.kRedirectLoopErrors = "Redirect Loop Errors"
		self.kBufferHighWatermark = "Buffer High Watermark"
		self.kBufferHighWatermarkms = "Buffer High Watermark (ms)"
		self.kQUICversionerrors = "QUIC version errors"
		self.kQUICHTTPRequestsFailed4xx = "QUIC HTTP Requests Failed (4xx)"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kActiveStreamsshiftedbetween90and300s = "Active Streams shifted between 90 and 300 s"
		self.kStreamAvailabilityExcellent = "Stream Availability Excellent"
		self.kInitialBufferTimeAvg = "Initial Buffer Time (Avg)"
		self.kBufferBytesReceived = "Buffer Bytes Received"
		self.kQUICinvalidframeRx = "QUIC invalid frame (Rx)"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kQUICSTREAMframeTx = "QUIC STREAM frame (Tx)"
		self.kBufferLevel = "Buffer Level"
		self.kVideoRecencyDegradationLevel = "Video Recency Degradation Level"
		self.kQUICACKframeTx = "QUIC ACK frame (Tx)"
		self.kQUICWINDOW_UPDATEframeTx = "QUIC WINDOW_UPDATE frame (Tx)"
		self.kBufferEmptyRate = "Buffer Empty Rate"
		self.kQUICerrorsonheadersstream = "QUIC errors on headers stream"
		self.kVideoFrameResolutionDegradationLevel = "Video Frame Resolution Degradation Level"
		self.kTotalPlaybackTimeMin = "Total Playback Time (Min)"
		self.kTCPFINReceived = "TCP FIN Received"


class IxTestWrapper(RestObjectBaseClass):

	def __init__(self, activeTest):
		super(IxTestWrapper, self).__init__(activeTest)
		self.__activeTest = activeTest
		self.comment = activeTest.comment
		self.networkFailureThreshold = activeTest.networkFailureThreshold
		self.timelineList = IxTimelineListWrapper(activeTest)
		self.statViewThroughputUnits = activeTest.statViewThroughputUnits
		self.showNetworkDiagnosticsFromApplyConfig = activeTest.showNetworkDiagnosticsFromApplyConfig
		self.csvThroughputScalingFactor = activeTest.csvThroughputScalingFactor
		self.activitiesGroupedByObjective = activeTest.activitiesGroupedByObjective
		self.sessionSpecificDataList = IxNetSessionSpecificDataListWrapper(activeTest)
		self.resetNetworkDiagnosticsAtStartRun = activeTest.resetNetworkDiagnosticsAtStartRun
		self.testRunError = activeTest.testRunError
		self.enableForceNetworkUpdateCloud = activeTest.enableForceNetworkUpdateCloud
		self.enableFrameSizeDistributionStats = activeTest.enableFrameSizeDistributionStats
		self.enableTcpAdvancedStats = activeTest.enableTcpAdvancedStats
		self.communityList = _communityListSequenceContainerWrapper(activeTest)
		self.showNetworkDiagnosticsAfterRunStops = activeTest.showNetworkDiagnosticsAfterRunStops
		self.enableResetPorts = activeTest.enableResetPorts
		self.enableNetworkDiagnosticsLogging = activeTest.enableNetworkDiagnosticsLogging
		self.eventHandlerSettings = IxEventHandlerSettingsWrapper(activeTest.eventHandlerSettings)
		self.csvInterval = activeTest.csvInterval
		self.name = activeTest.name
		self.downgradeAppLibFlowsToLatestValidVersion = activeTest.downgradeAppLibFlowsToLatestValidVersion
		self.statsRequired = activeTest.statsRequired
		self.captureViewOptions = IxViewOptionsWrapper(activeTest.captureViewOptions)
		self.isFrameSizeDistributionViewSupported = activeTest.isFrameSizeDistributionViewSupported
		self.enableForceOwnership = activeTest.enableForceOwnership
		self.enableNetworkDiagnostics = activeTest.enableNetworkDiagnostics
		self.allowMixedObjectiveTypes = activeTest.allowMixedObjectiveTypes
		self.currentState = activeTest.currentState

	properties = ["comment", "networkFailureThreshold", "statViewThroughputUnits", "showNetworkDiagnosticsFromApplyConfig", "csvThroughputScalingFactor", "activitiesGroupedByObjective", "resetNetworkDiagnosticsAtStartRun", "testRunError", "enableForceNetworkUpdateCloud", "enableFrameSizeDistributionStats", "enableTcpAdvancedStats", "showNetworkDiagnosticsAfterRunStops", "enableResetPorts", "enableNetworkDiagnosticsLogging", "csvInterval", "name", "downgradeAppLibFlowsToLatestValidVersion", "statsRequired", "isFrameSizeDistributionViewSupported", "enableForceOwnership", "enableNetworkDiagnostics", "allowMixedObjectiveTypes", "currentState", ]

	def __getattribute__(self, name):
		if name in IxTestWrapper.properties and super(IxTestWrapper, self).__getattribute__(name):
			return getattr(super(IxTestWrapper, self).__getattribute__("_IxTestWrapper__activeTest"), name)
		else:
			return super(IxTestWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTestWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTestWrapper, self).__getattribute__("_IxTestWrapper__activeTest"), name, value)
			super(IxTestWrapper, self).__setattr__(name, value)

	def collectDiagnostics(self, zipFileLocation, clientOnly=False):
		frame = inspect.currentframe()
		keys, _, _, values = inspect.getargvalues(frame)
		kwargs = {}
		for key in keys:
			if key != 'self':
				kwargs[key] = values[key]
		self.__activeTest.collectDiagnostics(**kwargs)


class IxActivityStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityStreamingClientWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.secondaryEnableConstraint = ixActivity.secondaryEnableConstraint
		self.protocol = ixActivity.protocol
		self.userIpMapping = ixActivity.userIpMapping
		self.enableConstraint = ixActivity.enableConstraint
		self.agent = PluginStreamingClientWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.constraintValue = ixActivity.constraintValue
		self.customParameters = IxPropertyClass_ixCustomActivityParametersStreamingClientWrapper(ixActivity.customParameters)
		self.timelineId = ixActivity.timelineId
		self.role = ixActivity.role
		self.timeline = IxTimelineProxyStreamingClientWrapper(ixActivity.timeline)
		self.activeRole = ixActivity.activeRole
		self.type = ixActivity.type
		self.secondaryConstraintValue = ixActivity.secondaryConstraintValue
		self.enable = ixActivity.enable
		self.protocolAndType = ixActivity.protocolAndType
		self.userObjectiveType = ixActivity.userObjectiveType
		self.destinationIpMapping = ixActivity.destinationIpMapping
		self.name = ixActivity.name
		self.secondaryConstraintType = ixActivity.secondaryConstraintType
		self.userObjectiveValue = ixActivity.userObjectiveValue
		self.constraintType = ixActivity.constraintType

	properties = ["secondaryEnableConstraint", "protocol", "userIpMapping", "enableConstraint", "objectivePercent", "constraintValue", "timelineId", "role", "activeRole", "type", "secondaryConstraintValue", "enable", "protocolAndType", "userObjectiveType", "destinationIpMapping", "name", "secondaryConstraintType", "userObjectiveValue", "constraintType", ]

	def __getattribute__(self, name):
		if name in IxActivityStreamingClientWrapper.properties and super(IxActivityStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityStreamingClientWrapper, self).__getattribute__("_IxActivityStreamingClientWrapper__ixActivity"), name)
		else:
			return super(IxActivityStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityStreamingClientWrapper, self).__getattribute__("_IxActivityStreamingClientWrapper__ixActivity"), name, value)
			super(IxActivityStreamingClientWrapper, self).__setattr__(name, value)


class PluginStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginStreamingClientWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.pm = IxPropertyMap_StreamingStreamingClientWrapper(agent.pm)
		self.flowPercentage = agent.flowPercentage

	properties = ["cmdListLoops", "flowPercentage", ]

	def __getattribute__(self, name):
		if name in PluginStreamingClientWrapper.properties and super(PluginStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(PluginStreamingClientWrapper, self).__getattribute__("_PluginStreamingClientWrapper__agent"), name)
		else:
			return super(PluginStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginStreamingClientWrapper, self).__getattribute__("_PluginStreamingClientWrapper__agent"), name, value)
			super(PluginStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_ixCustomActivityParametersStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, customParameters):
		super(IxPropertyClass_ixCustomActivityParametersStreamingClientWrapper, self).__init__(customParameters)
		self.__customParameters = customParameters

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_ixCustomActivityParametersStreamingClientWrapper.properties and super(IxPropertyClass_ixCustomActivityParametersStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ixCustomActivityParametersStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersStreamingClientWrapper__customParameters"), name)
		else:
			return super(IxPropertyClass_ixCustomActivityParametersStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ixCustomActivityParametersStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ixCustomActivityParametersStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersStreamingClientWrapper__customParameters"), name, value)
			super(IxPropertyClass_ixCustomActivityParametersStreamingClientWrapper, self).__setattr__(name, value)


class IxTimelineProxyStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyStreamingClientWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.iterations = timeline.iterations
		self.rampUpType = timeline.rampUpType
		self.rampUpValue = timeline.rampUpValue
		self.rampUpTime = timeline.rampUpTime
		self.rampDownTime = timeline.rampDownTime
		self.standbyTime = timeline.standbyTime
		self.rampDownValue = timeline.rampDownValue
		self.rampUpInterval = timeline.rampUpInterval
		self.offlineTime = timeline.offlineTime
		self.sustainTime = timeline.sustainTime
		self.name = timeline.name
		self.timelineType = timeline.timelineType

	properties = ["iterations", "rampUpType", "rampUpValue", "rampUpTime", "rampDownTime", "standbyTime", "rampDownValue", "rampUpInterval", "offlineTime", "sustainTime", "name", "timelineType", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyStreamingClientWrapper.properties and super(IxTimelineProxyStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyStreamingClientWrapper, self).__getattribute__("_IxTimelineProxyStreamingClientWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyStreamingClientWrapper, self).__getattribute__("_IxTimelineProxyStreamingClientWrapper__timeline"), name, value)
			super(IxTimelineProxyStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyMap_StreamingStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		super(IxPropertyMap_StreamingStreamingClientWrapper, self).__init__(pm)
		self.__pm = pm
		self.httpSettings = IxPropertyClass_HTTPSettingsStreamingClientWrapper(pm.httpSettings)
		self.viewingProfileList = IxPropertyClass_ViewingProfileListStreamingClientWrapper(pm.viewingProfileList)
		self.quicSettings = IxPropertyClass_QUICSettingsStreamingClientWrapper(pm.quicSettings)
		self.predefinedTos = IxPropertyGroupSequence_Streaming_predefinedTosStreamingClientWrapper(pm)
		self.advancedSettings = IxPropertyClass_AdvancedSettingsStreamingClientWrapper(pm.advancedSettings)
		self.signedURLSettings = IxPropertyClass_SignedURLSettingsStreamingClientWrapper(pm.signedURLSettings)
		self.cmdList = IxPropertyGroupSequence_Streaming_cmdListStreamingClientWrapper(pm)
		self.qualitySettings = IxPropertyClass_QualitySettingsStreamingClientWrapper(pm.qualitySettings)
		self.globalOptions = IxPropertyClass_GlobalOptionsStreamingClientWrapper(pm.globalOptions)
		self.sslSettings = IxPropertyClass_SSLStreamingClientWrapper(pm.sslSettings)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyMap_StreamingStreamingClientWrapper.properties and super(IxPropertyMap_StreamingStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyMap_StreamingStreamingClientWrapper, self).__getattribute__("_IxPropertyMap_StreamingStreamingClientWrapper__pm"), name)
		else:
			return super(IxPropertyMap_StreamingStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyMap_StreamingStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyMap_StreamingStreamingClientWrapper, self).__getattribute__("_IxPropertyMap_StreamingStreamingClientWrapper__pm"), name, value)
			super(IxPropertyMap_StreamingStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_HTTPSettingsStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, httpSettings):
		super(IxPropertyClass_HTTPSettingsStreamingClientWrapper, self).__init__(httpSettings)
		self.__httpSettings = httpSettings
		self.httpProtocol = httpSettings.httpProtocol
		self.commandTimeout = httpSettings.commandTimeout
		self.enableProxy = httpSettings.enableProxy
		self.proxyTCPPort = httpSettings.proxyTCPPort
		self.enableCookies = httpSettings.enableCookies
		self.customHdr = httpSettings.customHdr
		self.signingURL = httpSettings.signingURL
		self.httpTransactionsPerConnection = httpSettings.httpTransactionsPerConnection
		self.streamingTransportProto = httpSettings.streamingTransportProto
		self.forwardCookies = httpSettings.forwardCookies
		self.httpKeepalive = httpSettings.httpKeepalive
		self.proxyIP = httpSettings.proxyIP
		self.playerEmulation = httpSettings.playerEmulation
		self.enableTransactionsPerConnection = httpSettings.enableTransactionsPerConnection
		self.httpVersion = httpSettings.httpVersion

	properties = ["httpProtocol", "commandTimeout", "enableProxy", "proxyTCPPort", "enableCookies", "customHdr", "signingURL", "httpTransactionsPerConnection", "streamingTransportProto", "forwardCookies", "httpKeepalive", "proxyIP", "playerEmulation", "enableTransactionsPerConnection", "httpVersion", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_HTTPSettingsStreamingClientWrapper.properties and super(IxPropertyClass_HTTPSettingsStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_HTTPSettingsStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_HTTPSettingsStreamingClientWrapper__httpSettings"), name)
		else:
			return super(IxPropertyClass_HTTPSettingsStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_HTTPSettingsStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_HTTPSettingsStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_HTTPSettingsStreamingClientWrapper__httpSettings"), name, value)
			super(IxPropertyClass_HTTPSettingsStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_ViewingProfileListStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, viewingProfileList):
		super(IxPropertyClass_ViewingProfileListStreamingClientWrapper, self).__init__(viewingProfileList)
		self.__viewingProfileList = viewingProfileList
		self.viewingProfile = IxPropertyGroupSequence_ViewingProfileList_viewingProfileStreamingClientWrapper(viewingProfileList)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_ViewingProfileListStreamingClientWrapper.properties and super(IxPropertyClass_ViewingProfileListStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ViewingProfileListStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_ViewingProfileListStreamingClientWrapper__viewingProfileList"), name)
		else:
			return super(IxPropertyClass_ViewingProfileListStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ViewingProfileListStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ViewingProfileListStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_ViewingProfileListStreamingClientWrapper__viewingProfileList"), name, value)
			super(IxPropertyClass_ViewingProfileListStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_QUICSettingsStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, quicSettings):
		super(IxPropertyClass_QUICSettingsStreamingClientWrapper, self).__init__(quicSettings)
		self.__quicSettings = quicSettings
		self.explicitShutdown = quicSettings.explicitShutdown
		self.quicVersion = quicSettings.quicVersion
		self.CFCW = quicSettings.CFCW
		self.SFCW = quicSettings.SFCW
		self.streamingDisableQEncryption = quicSettings.streamingDisableQEncryption

	properties = ["explicitShutdown", "quicVersion", "CFCW", "SFCW", "streamingDisableQEncryption", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_QUICSettingsStreamingClientWrapper.properties and super(IxPropertyClass_QUICSettingsStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_QUICSettingsStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_QUICSettingsStreamingClientWrapper__quicSettings"), name)
		else:
			return super(IxPropertyClass_QUICSettingsStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_QUICSettingsStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_QUICSettingsStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_QUICSettingsStreamingClientWrapper__quicSettings"), name, value)
			super(IxPropertyClass_QUICSettingsStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_Streaming_predefinedTosStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm

	def getItem(self, objectID):
		itemList = self.__pm.predefinedTos
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_TypeOfService":
				return IxPropertyClass_TypeOfServiceStreamingClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_TypeOfServiceStreamingClientWrapper(self.__pm.predefinedTos.appendItem(**kwargs))

	def getList(self):
		return self.__pm.predefinedTos

	def clear(self):
		return self.__pm.predefinedTos.clear()


class IxPropertyClass_TypeOfServiceStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_TypeOfService):
		super(IxPropertyClass_TypeOfServiceStreamingClientWrapper, self).__init__(ixPropertyClass_TypeOfService)
		self.__ixPropertyClass_TypeOfService = ixPropertyClass_TypeOfService
		self.tosVal = ixPropertyClass_TypeOfService.tosVal

	properties = ["tosVal", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_TypeOfServiceStreamingClientWrapper.properties and super(IxPropertyClass_TypeOfServiceStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_TypeOfServiceStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_TypeOfServiceStreamingClientWrapper__ixPropertyClass_TypeOfService"), name)
		else:
			return super(IxPropertyClass_TypeOfServiceStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_TypeOfServiceStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_TypeOfServiceStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_TypeOfServiceStreamingClientWrapper__ixPropertyClass_TypeOfService"), name, value)
			super(IxPropertyClass_TypeOfServiceStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_AdvancedSettingsStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, advancedSettings):
		super(IxPropertyClass_AdvancedSettingsStreamingClientWrapper, self).__init__(advancedSettings)
		self.__advancedSettings = advancedSettings
		self.enableTimeshift = advancedSettings.enableTimeshift
		self.ipPreference2 = advancedSettings.ipPreference2

	properties = ["enableTimeshift", "ipPreference2", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AdvancedSettingsStreamingClientWrapper.properties and super(IxPropertyClass_AdvancedSettingsStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AdvancedSettingsStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_AdvancedSettingsStreamingClientWrapper__advancedSettings"), name)
		else:
			return super(IxPropertyClass_AdvancedSettingsStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AdvancedSettingsStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AdvancedSettingsStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_AdvancedSettingsStreamingClientWrapper__advancedSettings"), name, value)
			super(IxPropertyClass_AdvancedSettingsStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_SignedURLSettingsStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, signedURLSettings):
		super(IxPropertyClass_SignedURLSettingsStreamingClientWrapper, self).__init__(signedURLSettings)
		self.__signedURLSettings = signedURLSettings
		self.keyIdNumber_Name = signedURLSettings.keyIdNumber_Name
		self.keyIdOwner_Enabled = signedURLSettings.keyIdOwner_Enabled
		self.signatureName = signedURLSettings.signatureName
		self.expireTimeout_Enabled = signedURLSettings.expireTimeout_Enabled
		self.keyIdNumber_Enabled = signedURLSettings.keyIdNumber_Enabled
		self.keyIdNumber_Value = signedURLSettings.keyIdNumber_Value
		self.keyIdOwner_Value = signedURLSettings.keyIdOwner_Value
		self.expireTimeout_Name = signedURLSettings.expireTimeout_Name
		self.secretKey = signedURLSettings.secretKey
		self.includeClientIP = signedURLSettings.includeClientIP
		self.changeKey = signedURLSettings.changeKey
		self.expireTimeout_Value = signedURLSettings.expireTimeout_Value
		self.keyIdOwner_Name = signedURLSettings.keyIdOwner_Name
		self.changeFreq = signedURLSettings.changeFreq

	properties = ["keyIdNumber_Name", "keyIdOwner_Enabled", "signatureName", "expireTimeout_Enabled", "keyIdNumber_Enabled", "keyIdNumber_Value", "keyIdOwner_Value", "expireTimeout_Name", "secretKey", "includeClientIP", "changeKey", "expireTimeout_Value", "keyIdOwner_Name", "changeFreq", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_SignedURLSettingsStreamingClientWrapper.properties and super(IxPropertyClass_SignedURLSettingsStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_SignedURLSettingsStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_SignedURLSettingsStreamingClientWrapper__signedURLSettings"), name)
		else:
			return super(IxPropertyClass_SignedURLSettingsStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_SignedURLSettingsStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_SignedURLSettingsStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_SignedURLSettingsStreamingClientWrapper__signedURLSettings"), name, value)
			super(IxPropertyClass_SignedURLSettingsStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_Streaming_cmdListStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm
		self.optionsDict = {
			('Play',): "IxPropertyClass_PlayStreamingClient",
			('START',): "IxPropertyCommandStartStreamingClient",
			('STOP',): "IxPropertyCommandStopStreamingClient",
		}

	def getItemIxPlayCommand(self, objectID):
		itemList = self.__pm.cmdList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_Play":
				return IxPropertyClass_PlayStreamingClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxPlayCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "Play"})
		return IxPropertyClass_PlayStreamingClientWrapper(self.__pm.cmdList.appendItem(**kwargs))

	def getItemIxStartCommand(self, objectID):
		itemList = self.__pm.cmdList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandStart":
				return IxPropertyCommandStartStreamingClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStartCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "START"})
		return IxPropertyCommandStartStreamingClientWrapper(self.__pm.cmdList.appendItem(**kwargs))

	def getItemIxStopCommand(self, objectID):
		itemList = self.__pm.cmdList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandStop":
				return IxPropertyCommandStopStreamingClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STOP"})
		return IxPropertyCommandStopStreamingClientWrapper(self.__pm.cmdList.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__pm.cmdList
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, commandType=None):
		kwargs = {}
		kwargs.update({"commandType": commandType})
		return self.__pm.cmdList.appendItem(**kwargs)

	def getList(self):
		return self.__pm.cmdList

	def clear(self):
		return self.__pm.cmdList.clear()


class IxPropertyCommandStartStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStart):
		super(IxPropertyCommandStartStreamingClientWrapper, self).__init__(ixPropertyCommandStart)
		self.__ixPropertyCommandStart = ixPropertyCommandStart
		self.commandType = ixPropertyCommandStart.commandType
		self.cmdName = ixPropertyCommandStart.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandStartStreamingClientWrapper.properties and super(IxPropertyCommandStartStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandStartStreamingClientWrapper, self).__getattribute__("_IxPropertyCommandStartStreamingClientWrapper__ixPropertyCommandStart"), name)
		else:
			return super(IxPropertyCommandStartStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandStartStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandStartStreamingClientWrapper, self).__getattribute__("_IxPropertyCommandStartStreamingClientWrapper__ixPropertyCommandStart"), name, value)
			super(IxPropertyCommandStartStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_PlayStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Play):
		super(IxPropertyClass_PlayStreamingClientWrapper, self).__init__(ixPropertyClass_Play)
		self.__ixPropertyClass_Play = ixPropertyClass_Play
		self.minimumInterval = ixPropertyClass_Play.minimumInterval
		self.durationType = ixPropertyClass_Play.durationType
		self.maximumInterval = ixPropertyClass_Play.maximumInterval
		self.mediaUrl = ixPropertyClass_Play.mediaUrl
		self.cmdName = ixPropertyClass_Play.cmdName
		self.commandType = ixPropertyClass_Play.commandType
		self.serverAddr = ixPropertyClass_Play.serverAddr

	properties = ["minimumInterval", "durationType", "maximumInterval", "mediaUrl", "cmdName", "commandType", "serverAddr", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_PlayStreamingClientWrapper.properties and super(IxPropertyClass_PlayStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_PlayStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_PlayStreamingClientWrapper__ixPropertyClass_Play"), name)
		else:
			return super(IxPropertyClass_PlayStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_PlayStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_PlayStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_PlayStreamingClientWrapper__ixPropertyClass_Play"), name, value)
			super(IxPropertyClass_PlayStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyCommandStopStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStop):
		super(IxPropertyCommandStopStreamingClientWrapper, self).__init__(ixPropertyCommandStop)
		self.__ixPropertyCommandStop = ixPropertyCommandStop
		self.commandType = ixPropertyCommandStop.commandType
		self.cmdName = ixPropertyCommandStop.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandStopStreamingClientWrapper.properties and super(IxPropertyCommandStopStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandStopStreamingClientWrapper, self).__getattribute__("_IxPropertyCommandStopStreamingClientWrapper__ixPropertyCommandStop"), name)
		else:
			return super(IxPropertyCommandStopStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandStopStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandStopStreamingClientWrapper, self).__getattribute__("_IxPropertyCommandStopStreamingClientWrapper__ixPropertyCommandStop"), name, value)
			super(IxPropertyCommandStopStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_QualitySettingsStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, qualitySettings):
		super(IxPropertyClass_QualitySettingsStreamingClientWrapper, self).__init__(qualitySettings)
		self.__qualitySettings = qualitySettings
		self.maxBitRate = qualitySettings.maxBitRate
		self.enableDynamicAdaption = qualitySettings.enableDynamicAdaption
		self.numFragments = qualitySettings.numFragments
		self.enableVQStatistics = qualitySettings.enableVQStatistics
		self.globalProfileTable = IxPropertyGroupSequence_QualitySettings_globalProfileTableStreamingClientWrapper(qualitySettings)
		self.threshold = qualitySettings.threshold
		self.bufferSize = qualitySettings.bufferSize
		self.playoutNominalDelay = qualitySettings.playoutNominalDelay

	properties = ["maxBitRate", "enableDynamicAdaption", "numFragments", "enableVQStatistics", "threshold", "bufferSize", "playoutNominalDelay", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_QualitySettingsStreamingClientWrapper.properties and super(IxPropertyClass_QualitySettingsStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_QualitySettingsStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_QualitySettingsStreamingClientWrapper__qualitySettings"), name)
		else:
			return super(IxPropertyClass_QualitySettingsStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_QualitySettingsStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_QualitySettingsStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_QualitySettingsStreamingClientWrapper__qualitySettings"), name, value)
			super(IxPropertyClass_QualitySettingsStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_GlobalOptionsStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, globalOptions):
		super(IxPropertyClass_GlobalOptionsStreamingClientWrapper, self).__init__(globalOptions)
		self.__globalOptions = globalOptions
		self.enableTos = globalOptions.enableTos
		self.enableEsm = globalOptions.enableEsm
		self.protocol = globalOptions.protocol
		self.vlanPriority = globalOptions.vlanPriority
		self.monitorUserId = globalOptions.monitorUserId
		self.tosValue = globalOptions.tosValue
		self.enableUserMonitoring = globalOptions.enableUserMonitoring
		self.disableDNSCache = globalOptions.disableDNSCache
		self.esm = globalOptions.esm
		self.enableVlanPriority = globalOptions.enableVlanPriority
		self.ttlValue = globalOptions.ttlValue

	properties = ["enableTos", "enableEsm", "protocol", "vlanPriority", "monitorUserId", "tosValue", "enableUserMonitoring", "disableDNSCache", "esm", "enableVlanPriority", "ttlValue", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_GlobalOptionsStreamingClientWrapper.properties and super(IxPropertyClass_GlobalOptionsStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_GlobalOptionsStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_GlobalOptionsStreamingClientWrapper__globalOptions"), name)
		else:
			return super(IxPropertyClass_GlobalOptionsStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_GlobalOptionsStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_GlobalOptionsStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_GlobalOptionsStreamingClientWrapper__globalOptions"), name, value)
			super(IxPropertyClass_GlobalOptionsStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_SSLStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, sslSettings):
		super(IxPropertyClass_SSLStreamingClientWrapper, self).__init__(sslSettings)
		self.__sslSettings = sslSettings
		self.tlsPublicKeyCertificate = sslSettings.tlsPublicKeyCertificate
		self.tlsKeyType = sslSettings.tlsKeyType
		self.tlsPassword = sslSettings.tlsPassword
		self.tlsCertType = sslSettings.tlsCertType
		self.enableSSL = sslSettings.enableSSL
		self.tlsCertificatesPath = sslSettings.tlsCertificatesPath
		self.tlsPrivateKeyCertificate = sslSettings.tlsPrivateKeyCertificate

	properties = ["tlsPublicKeyCertificate", "tlsKeyType", "tlsPassword", "tlsCertType", "enableSSL", "tlsCertificatesPath", "tlsPrivateKeyCertificate", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_SSLStreamingClientWrapper.properties and super(IxPropertyClass_SSLStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_SSLStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_SSLStreamingClientWrapper__sslSettings"), name)
		else:
			return super(IxPropertyClass_SSLStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_SSLStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_SSLStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_SSLStreamingClientWrapper__sslSettings"), name, value)
			super(IxPropertyClass_SSLStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_ViewingProfileList_viewingProfileStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, viewingProfileList):
		self.__viewingProfileList = viewingProfileList

	def getItem(self, objectID):
		itemList = self.__viewingProfileList.viewingProfile
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_ViewingProfile":
				return IxPropertyClass_ViewingProfileStreamingClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_ViewingProfileStreamingClientWrapper(self.__viewingProfileList.viewingProfile.appendItem(**kwargs))

	def getList(self):
		return self.__viewingProfileList.viewingProfile

	def clear(self):
		return self.__viewingProfileList.viewingProfile.clear()


class IxPropertyClass_ViewingProfileStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_ViewingProfile):
		super(IxPropertyClass_ViewingProfileStreamingClientWrapper, self).__init__(ixPropertyClass_ViewingProfile)
		self.__ixPropertyClass_ViewingProfile = ixPropertyClass_ViewingProfile
		self.profileName = ixPropertyClass_ViewingProfile.profileName
		self.bitrateShiftTable = IxPropertyGroupSequence_ViewingProfile_bitrateShiftTableStreamingClientWrapper(ixPropertyClass_ViewingProfile)

	properties = ["profileName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_ViewingProfileStreamingClientWrapper.properties and super(IxPropertyClass_ViewingProfileStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ViewingProfileStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_ViewingProfileStreamingClientWrapper__ixPropertyClass_ViewingProfile"), name)
		else:
			return super(IxPropertyClass_ViewingProfileStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ViewingProfileStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ViewingProfileStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_ViewingProfileStreamingClientWrapper__ixPropertyClass_ViewingProfile"), name, value)
			super(IxPropertyClass_ViewingProfileStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_QualitySettings_globalProfileTableStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, qualitySettings):
		self.__qualitySettings = qualitySettings

	def getItem(self, objectID):
		itemList = self.__qualitySettings.globalProfileTable
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_GlobalProfileTable":
				return IxPropertyClass_GlobalProfileTableStreamingClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_GlobalProfileTableStreamingClientWrapper(self.__qualitySettings.globalProfileTable.appendItem(**kwargs))

	def getList(self):
		return self.__qualitySettings.globalProfileTable

	def clear(self):
		return self.__qualitySettings.globalProfileTable.clear()


class IxPropertyClass_GlobalProfileTableStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_GlobalProfileTable):
		super(IxPropertyClass_GlobalProfileTableStreamingClientWrapper, self).__init__(ixPropertyClass_GlobalProfileTable)
		self.__ixPropertyClass_GlobalProfileTable = ixPropertyClass_GlobalProfileTable
		self.profileName = ixPropertyClass_GlobalProfileTable.profileName
		self.percentage = ixPropertyClass_GlobalProfileTable.percentage

	properties = ["profileName", "percentage", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_GlobalProfileTableStreamingClientWrapper.properties and super(IxPropertyClass_GlobalProfileTableStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_GlobalProfileTableStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_GlobalProfileTableStreamingClientWrapper__ixPropertyClass_GlobalProfileTable"), name)
		else:
			return super(IxPropertyClass_GlobalProfileTableStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_GlobalProfileTableStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_GlobalProfileTableStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_GlobalProfileTableStreamingClientWrapper__ixPropertyClass_GlobalProfileTable"), name, value)
			super(IxPropertyClass_GlobalProfileTableStreamingClientWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_ViewingProfile_bitrateShiftTableStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_ViewingProfile):
		self.__ixPropertyClass_ViewingProfile = ixPropertyClass_ViewingProfile

	def getItem(self, objectID):
		itemList = self.__ixPropertyClass_ViewingProfile.bitrateShiftTable
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_BitRateShiftTable":
				return IxPropertyClass_BitRateShiftTableStreamingClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_BitRateShiftTableStreamingClientWrapper(self.__ixPropertyClass_ViewingProfile.bitrateShiftTable.appendItem(**kwargs))

	def getList(self):
		return self.__ixPropertyClass_ViewingProfile.bitrateShiftTable

	def clear(self):
		return self.__ixPropertyClass_ViewingProfile.bitrateShiftTable.clear()


class IxPropertyClass_BitRateShiftTableStreamingClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_BitRateShiftTable):
		super(IxPropertyClass_BitRateShiftTableStreamingClientWrapper, self).__init__(ixPropertyClass_BitRateShiftTable)
		self.__ixPropertyClass_BitRateShiftTable = ixPropertyClass_BitRateShiftTable
		self.numLevels = ixPropertyClass_BitRateShiftTable.numLevels
		self.shiftType = ixPropertyClass_BitRateShiftTable.shiftType
		self.playDuration = ixPropertyClass_BitRateShiftTable.playDuration

	properties = ["numLevels", "shiftType", "playDuration", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_BitRateShiftTableStreamingClientWrapper.properties and super(IxPropertyClass_BitRateShiftTableStreamingClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_BitRateShiftTableStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_BitRateShiftTableStreamingClientWrapper__ixPropertyClass_BitRateShiftTable"), name)
		else:
			return super(IxPropertyClass_BitRateShiftTableStreamingClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_BitRateShiftTableStreamingClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_BitRateShiftTableStreamingClientWrapper, self).__getattribute__("_IxPropertyClass_BitRateShiftTableStreamingClientWrapper__ixPropertyClass_BitRateShiftTable"), name, value)
			super(IxPropertyClass_BitRateShiftTableStreamingClientWrapper, self).__setattr__(name, value)


class StatsNameVideoServer(object):
	def __init__(self):
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kNoofMulticastStreamsPlaying = "No of Multicast Streams Playing"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kMulticastStreamsBitRate = "Multicast Streams Bit Rate"
		self.kRTSPTEARDOWNReceived = "RTSP TEARDOWN Received"
		self.kPauseRequestsReceived = "Pause Requests Received"
		self.kNoofIPTVVServerRequestsSuccessful = "No of IPTV V Server Requests Successful"
		self.kTCPRetries = "TCP Retries"
		self.kRTSPResponseCodesSent6xx1xxx = "RTSP Response Codes Sent (6xx-1xxx)"
		self.kNoofIPTVDServerRequestsFailedforBandwidth = "No of IPTV D Server Requests Failed for Bandwidth"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kNoofIPTVVServerRequestsFailedforPortOverload = "No of IPTV V Server Requests Failed for Port Overload"
		self.kNoofIPTVDServerRequestsReceived = "No of IPTV D Server Requests Received"
		self.kNoofIPTVActiveAServerStreamsPlaying = "No of IPTV Active A Server Streams Playing"
		self.kRTSPResponseCodesSent4xx = "RTSP Response Codes Sent (4xx)"
		self.kNoofIPTVActiveVServerStreams = "No of IPTV Active V Server Streams"
		self.kRTSPOPTIONSReceived = "RTSP OPTIONS Received"
		self.kRTSPGETPARAMETERReceived = "RTSP GET PARAMETER Received"
		self.kRTSPPresentationsReceived = "RTSP Presentations Received"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kNoofVoDStreamsActive = "No of VoD Streams Active"
		self.kNoofIPTVActiveVServerStreamsPaused = "No of IPTV Active V Server Streams Paused"
		self.kSetupRequestsReceived = "Setup Requests Received"
		self.kActiveVoDStreams = "Active VoD Streams"
		self.kNoofVoDStreamsPlaying = "No of VoD Streams Playing"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kDServerStreamsBitRate = "D Server Streams Bit Rate"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kRTSPSETPARAMETERReceived = "RTSP SET PARAMETER Received"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kRTSPResponseCodesSent2xx = "RTSP Response Codes Sent (2xx)"
		self.kActiveMulticastStreams = "Active Multicast Streams"
		self.kActiveVoDStreamsPlaying = "Active VoD Streams - Playing"
		self.kNoofVoDStreamsPaused = "No of VoD Streams Paused"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kNoofVoDStreamsPlayed = "No of VoD Streams Played"
		self.kNoofIPTVActiveDServerStreamsPlaying = "No of IPTV Active D Server Streams Playing"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kActiveVoDStreamsPaused = "Active VoD Streams - Paused"
		self.kNoofIPTVDServerRequestsFailedforPortOverload = "No of IPTV D Server Requests Failed for Port Overload"
		self.kRTSPBytesReceived = "RTSP Bytes Received"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kNoofIPTVVServerRequestsFailed = "No of IPTV V Server Requests Failed"
		self.kTotalStreamsPlaying = "Total Streams Playing"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kNoofIPTVDServerRequestsFailed = "No of IPTV D Server Requests Failed"
		self.kRTSPPAUSEReceived = "RTSP PAUSE Received"
		self.kRTSPPacketsSent = "RTSP Packets Sent"
		self.kNoofIPTVActiveVServerStreamsPlaying = "No of IPTV Active V Server Streams Playing"
		self.kActiveUnicastStreams = "Active Unicast Streams"
		self.kTotalStreamingBitRateKbps = "Total Streaming Bit Rate (Kbps)"
		self.kRTSPBytesSent = "RTSP Bytes Sent"
		self.kRTSPPlayLatencyms = "RTSP Play Latency (ms)"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kTotalBytesSent = "Total Bytes Sent"
		self.kNoofIPTVDServerRequestsSuccessful = "No of IPTV D Server Requests Successful"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kTxJitterns = "Tx Jitter (ns)"
		self.kVServerStreamsBitRate = "V Server Streams Bit Rate"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kAServerStreamsBitRate = "A Server Streams Bit Rate"
		self.kVoDStreamsBitRate = "VoD Streams Bit Rate"
		self.kRTSPDESCRIBEReceived = "RTSP DESCRIBE Received"
		self.kRTSPSETUPReceived = "RTSP SETUP Received"
		self.kNoofIPTVVServerRequestsReceived = "No of IPTV V Server Requests Received"
		self.kTransmitThroughputKbps = "Transmit Throughput (Kbps)"
		self.kRTSPPacketsReceived = "RTSP Packets Received"
		self.kRTSPResponseCodesSent5xx = "RTSP Response Codes Sent (5xx)"
		self.kNoofMulticastStreamsPlayed = "No of Multicast Streams Played"
		self.kRTSPResponseCodesSent3xx = "RTSP Response Codes Sent (3xx)"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kRTSPPresentationsSuccessful = "RTSP Presentations Successful"
		self.kUnicastStreamsBitRate = "Unicast Streams Bit Rate"
		self.kTotalMulticastStreamsBitRateKbps = "Total Multicast Streams Bit Rate (Kbps)"
		self.kRTSPPLAYReceived = "RTSP PLAY Received"
		self.kRTSPPresentationsFailed = "RTSP Presentations Failed"
		self.kNoofIPTVDServerRequestsFailedforOtherReasons = "No of IPTV D Server Requests Failed for Other Reasons"
		self.kNoofUnicastStreamsPlaying = "No of Unicast Streams Playing"
		self.kTxPacketsDropped = "Tx Packets Dropped"
		self.kIPTVTotalStreamingBitRate = "IPTV Total Streaming Bit Rate"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kNoofIPTVVServerRequestsFailedforOtherReasons = "No of IPTV V Server Requests Failed for Other Reasons"
		self.kTotalStreamingBitRate = "Total Streaming Bit Rate"
		self.kPlayRequestsReceived = "Play Requests Received"
		self.kTotalVoDStreamsBitRateKbps = "Total VoD Streams Bit Rate (Kbps)"
		self.kNoofIPTVVServerRequestsFailedforBandwidth = "No of IPTV V Server Requests Failed for Bandwidth"
		self.kTotalUnicastStreamsBitRateKbps = "Total Unicast Streams Bit Rate (Kbps)"
		self.kRTSPCommandsReceived = "RTSP Commands Received"
		self.kTotalPacketsSent = "Total Packets Sent"
		self.kTCPFINReceived = "TCP FIN Received"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"


class StatsNameVideoClientPerStream(object):
	def __init__(self):
		self.kTVQMFrameRate = "TVQM Frame Rate"
		self.kBFramesRcvd = "B Frames Rcvd"
		self.kJBPacketsEarly = "JB Packets Early"
		self.kAvgIntervalAbsMOSV = "Avg Interval Abs MOSV"
		self.kCurrentVideoServiceQuality = "Current Video Service Quality"
		self.kBurstCount = "Burst Count"
		self.kMAXMDIDF = "MAX MDI-DF"
		self.kIFramesRcvd2 = "I Frames Rcvd2"
		self.kAvgIntervalRelMOSV = "Avg Interval Rel MOSV"
		self.kChannelSwitchLatencyms = "Channel Switch Latency (ms)"
		self.kJBPacketsOutOfSeq = "JB Packets Out Of Seq"
		self.kMaxInterPktArrivalTime = "Max Inter Pkt Arrival Time"
		self.kJoinLatencyms = "Join Latency (ms)"
		self.kCurrentJBPacketsDiscarded = "Current JB Packets Discarded"
		self.kVSPQ = "VSPQ"
		self.kTVQMAvgAbsMOSV = "TVQM Avg Abs MOSV"
		self.kPFramesRcvd = "P Frames Rcvd"
		self.kMinInterPktArrivalTime = "Min Inter Pkt Arrival Time"
		self.kBytes = "Bytes"
		self.kJBPacketsDiscarded = "JB Packets Discarded"
		self.kTVQMPPDV = "TVQM PPDV"
		self.kMaxPacketLatencyns = "Max Packet Latency (ns)"
		self.kMaxMDIDFms = "Max MDI-DF (ms)"
		self.kControlSent = "Control Sent"
		self.kTVQMDetailLevel = "TVQM Detail Level"
		self.kFrameRate = "Frame Rate"
		self.kPPDVus = "PPDV (us)"
		self.kJBMaxEnvNegDelta = "JB Max Env Neg Delta"
		self.kAvgPacketLatencyns = "Avg Packet Latency (ns)"
		self.kJBPacketsDiscarded2 = "JB Packets Discarded2"
		self.kCurrentVSTQ = "Current VSTQ"
		self.kCurrentJBPacketsAccepted = "Current JB Packets Accepted"
		self.kTVQMBFramesRcvd = "TVQM B Frames Rcvd"
		self.kTransport = "Transport"
		self.kAvgVideoBandwidthKbps = "Avg Video Bandwidth (Kbps)"
		self.kLeaveLatencyms = "Leave Latency (ms)"
		self.kIJoinLatencyms = "I Join Latency (ms)"
		self.kTVQMIntAvgAbsMOSV = "TVQM Int Avg Abs MOSV"
		self.kPeakVideoBandwidthKbps = "Peak Video Bandwidth (Kbps) "
		self.kTVQMAvgMOSAV = "TVQM Avg MOSAV"
		self.kPFramesRcvd2 = "P Frames Rcvd2"
		self.kAvgRelativeMOSV = "Avg Relative MOSV"
		self.kRTCPAvgTransmittedPacketSize = "RTCP Avg Transmitted Packet Size"
		self.kMDIDF = "MDI-DF"
		self.kAvgGapLenPkts = "Avg Gap Len (Pkts)"
		self.kTVQMPanningLevel = "TVQM Panning Level"
		self.kJBPacketsAccepted = "JB Packets Accepted"
		self.kLostRTPPackets = "Lost RTP Packets"
		self.kTVQMPFramesImpaired = "TVQM P Frames Impaired"
		self.kStreamBitRate = "Stream Bit Rate"
		self.kIFramesImpaired = "I Frames Impaired"
		self.kGapVideoServiceQuality = "Gap Video Service Quality"
		self.kAvgMDIDFms = "Avg MDI-DF (ms)"
		self.kPackets = "Packets"
		self.kJBPacketsDiscardedUnderrun = "JB Packets Discarded (Underrun)"
		self.kTVQMIFramesRcvd = "TVQM I Frames Rcvd"
		self.kJBAvgEnvNegDelta = "JB Avg Env Neg Delta"
		self.kPacketLatencyns = "Packet Latency (ns)"
		self.kTVQMPacketsDiscarded = "TVQM Packets Discarded"
		self.kChannelGapDurationms = "Channel Gap Duration (ms)"
		self.kJBDuplicatePackets = "JB Duplicate Packets"
		self.kMPEG2TSLoss = "MPEG2 TS Loss"
		self.kChannelGapDuration = "Channel Gap Duration"
		self.kStreamBitRateKbps = "Stream Bit Rate (Kbps)"
		self.kJitterns = "Jitter (ns)"
		self.kBurstVSPQ = "Burst VSPQ"
		self.kMaxInterPktArrivalTimens = "Max Inter Pkt Arrival Time (ns)"
		self.kAVGMDIDF = "AVG-MDI-DF"
		self.kMaximumLostSequence = "Maximum Lost Sequence"
		self.kMDIMLR = "MDI-MLR"
		self.kTVQMInterIFrameGap = "TVQM Inter I Frame Gap"
		self.kAvgMOSAV = "Avg MOSAV"
		self.kPlayLatencyms = "Play Latency (ms)"
		self.kChannelOverlapDuration = "Channel Overlap Duration"
		self.kTVQMIFramesImpaired = "TVQM I Frames Impaired"
		self.kMINMDIDF = "MIN MDI-DF"
		self.kChannelOverlapDurationms = "Channel Overlap Duration (ms)"
		self.kDataRcvd = "Data Rcvd"
		self.kTVQMIntAvgRelMOSV = "TVQM Int Avg Rel MOSV"
		self.kScenePanningLevel = "Scene Panning Level"
		self.kActive = "Active"
		self.kAvgInterIFrameGapFrames = "Avg Inter I Frame Gap (Frames)"
		self.kSceneMotionLevel = "Scene Motion Level"
		self.kMOS_V = "MOS_V"
		self.kStreamName = "Stream Name"
		self.kTVQMBFramesImpaired = "TVQM B Frames Impaired"
		self.kRTPPacketsOutofOrder = "RTP Packets Out of Order"
		self.kVideoCodec = "Video Codec"
		self.kJBPacketsAccepted2 = "JB Packets Accepted2"
		self.kRTCPPacketsSent = "RTCP Packets Sent"
		self.kDegradationDiscard = "Degradation (Discard)"
		self.kPFramesImpaired = "P Frames Impaired"
		self.kFlowID = "Flow ID"
		self.kJitter = "Jitter"
		self.kJBAvgEnvPosDelta = "JB Avg Env Pos Delta"
		self.kIFramesRcvd = "I Frames Rcvd"
		self.kBurstVideoServiceQuality = "Burst Video Service Quality"
		self.kMinPacketLatencyns = "Min Packet Latency (ns)"
		self.kTVQMPacketsReceived = "TVQM Packets Received"
		self.kSceneDetailLevel = "Scene Detail Level"
		self.kTVQMPeakVideoBw = "TVQM Peak Video Bw"
		self.kPFramesImpaired2 = "P Frames Impaired2"
		self.kAveragePeakSNR = "Average Peak SNR"
		self.kAvgAbsoluteMOSV = "Avg Absolute MOSV"
		self.kRTCPAvgTransmissionInterval = "RTCP Avg Transmission Interval"
		self.kTVQMAvgVideoBw = "TVQM Avg Video Bw"
		self.kInterPktArrivalTime = "Inter Pkt Arrival Time"
		self.kBFramesImpaired2 = "B Frames Impaired2"
		self.kRTPPacketsDuplicated = "RTP Packets Duplicated"
		self.kTVQMAvgMOSA = "TVQM Avg MOSA"
		self.kAvgBurstLenPkts = "Avg Burst Len (Pkts)"
		self.kGapVSPQ = "Gap VSPQ"
		self.kReorderedRTPPackets = "Reordered RTP Packets"
		self.kCurrentJBPacketsLost = "Current JB Packets Lost"
		self.kJBMaxEnvPosDelta = "JB Max Env Pos Delta"
		self.kPPDV = "PPDV"
		self.kTVQMPFramesRcvd = "TVQM P Frames Rcvd"
		self.kAvgMOSA = "Avg MOSA"
		self.kLoss = "Loss"
		self.kTVQMAvgRelMOSV = "TVQM Avg Rel MOSV"
		self.kDegradationLoss = "Degradation (Loss)"
		self.kBFramesImpaired = "B Frames Impaired"
		self.kBFramesRcvd2 = "B Frames Rcvd2"
		self.kInterPktArrivalTimens = "Inter Pkt Arrival Time (ns)"
		self.kVideoServiceQuality = "Video Service Quality"
		self.kMDIDFms = "MDI-DF (ms)"
		self.kRTPPacketsLost = "RTP Packets Lost"
		self.kDuplicateRTPPackets = "Duplicate RTP Packets"
		self.kMinMDIDFms = "Min MDI-DF (ms)"
		self.kTVQMMotionLevel = "TVQM Motion Level"
		self.kIFramesImpaired2 = "I Frames Impaired2"
		self.kJBPacketsDiscardedOverrun = "JB Packets Discarded (Overrun)"
		self.kMinInterPktArrivalTimens = "Min Inter Pkt Arrival Time (ns)"
		self.kDegradationVideoCodec = "Degradation (Video Codec)"


class StatsNameVideoClient(object):
	def __init__(self):
		self.kDServerRequestsSuccessful = "D Server Requests Successful"
		self.kRTSPPlayLatency0ms10ms = "RTSP Play Latency (0 ms - 10 ms)"
		self.kAvgCompMOSAV = "Avg Comp MOS AV"
		self.kBFrameAvgVideoBw = "B Frame Avg Video Bw"
		self.kMPEG2PacketsLost = "MPEG2 Packets Lost"
		self.kPacketLatencybetween100200ms = "Packet Latency between 100 - 200 ms"
		self.kBFramesRcvd = "B Frames Rcvd"
		self.kDServerRequestsFailedControl = "D Server Requests Failed (Control)"
		self.kPlayRequestsSuccessful = "Play Requests Successful"
		self.kPMT2Errors = "PMT2 Errors"
		self.kRTSPTeardownSuccessful = "RTSP Teardown Successful"
		self.kInterPacketArrivalTimebetween510ms = "Inter Packet Arrival Time between 5 - 10 ms"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kPCRAccuracyErrors = "PCR Accuracy Errors"
		self.kRTPLostSequenceSixtoTenPackets = "RTP Lost Sequence: Six to Ten Packets"
		self.kVServerRequestsSuccessful = "V Server Requests Successful"
		self.kChannelSwitchLatencyms = "Channel Switch Latency (ms)"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kPauselatencyms = "Pause latency (ms)"
		self.kRTSPPacketsReceived = "RTSP Packets Received"
		self.kTotalBytesRcvd = "Total Bytes Rcvd"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kTCPRetries = "TCP Retries"
		self.kJitterlessthan50us = "Jitter less than 50 us"
		self.kJitterbetween100500us = "Jitter between 100 - 500 us"
		self.kReportsTx = "Reports Tx"
		self.kAvgCompRelMOSV = "Avg Comp Rel MOS V"
		self.kRTSPTEARDOWNSuccessful = "RTSP TEARDOWN Successful"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kJoinLatencyms = "Join Latency (ms)"
		self.kPIDErrors = "PID Errors"
		self.kRTPLostSequenceOnePacket = "RTP Lost Sequence: One Packet "
		self.kRTSPSETUPSuccessful = "RTSP SETUP Successful"
		self.kPFramesRcvd = "P Frames Rcvd"
		self.kAvgIntervalAbsMOSV = "Avg Interval Abs MOS V"
		self.kVideoSimulatedUsers = "Video Simulated Users"
		self.kRTSPOPTIONSFailed = "RTSP OPTIONS Failed"
		self.kAvgCurrMOSA = "Avg Curr MOS A"
		self.kRTSPDESCRIBESents = "RTSP DESCRIBE Sent/s"
		self.kJitterbetween25ms = "Jitter between 2 - 5 ms"
		self.kPCRRepetitionErrors = "PCR Repetition Errors"
		self.kRTSPTEARDOWNSent = "RTSP TEARDOWN Sent"
		self.kIGMPReportsSent = "IGMP Reports Sent"
		self.kRTSPSETUPSent = "RTSP SETUP Sent"
		self.kPauseRequestsSent = "Pause Requests Sent"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kGlobalJitterns = "Global Jitter (ns)"
		self.kMaxPacketLatencyns = "Max Packet Latency (ns)"
		self.kPlayRequestsFailed = "Play Requests Failed"
		self.kPauseRequestsFailed = "Pause Requests Failed"
		self.kRTSPDESCRIBESent = "RTSP DESCRIBE Sent"
		self.kPacketLatencybetween200500ms = "Packet Latency between 200 - 500 ms"
		self.kInterPacketArrivalTimebetween50100ms = "Inter Packet Arrival Time between 50 - 100 ms"
		self.kPacketLatencybetween25ms = "Packet Latency between 2 - 5 ms"
		self.kRTSPSETPARAMETERSuccessful = "RTSP SET PARAMETER Successful"
		self.kRTSPGetParameterSent = "RTSP Get Parameter Sent"
		self.kRTSPDescribeSuccessful = "RTSP Describe Successful"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kIGMPQueriesRcvd = "IGMP Queries Rcvd"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kRTSPGETPARAMETERSuccessful = "RTSP GET PARAMETER Successful"
		self.kRTSPSetupSuccessful = "RTSP Setup Successful"
		self.kActiveDServerChannels = "Active D Server Channels"
		self.kRTSPSETUPFailed = "RTSP SETUP Failed"
		self.kActiveVoDStreams = "Active VoD Streams"
		self.kAveragePlaylatencyms = "Average Play latency (ms)"
		self.kPacketLatencygreaterthan500ms = "Packet Latency greater than 500 ms"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kSetupRequestsFailed = "Setup Requests Failed"
		self.kRTCPAvgPacketSize = "RTCP Avg Packet Size"
		self.kVoDStreamsWithErrors = "VoD Streams With Errors"
		self.kMulticastRequestsSuccessful = "Multicast Requests Successful"
		self.kRTSPDESCRIBESuccessful = "RTSP DESCRIBE Successful"
		self.kRTSPPLAYSent = "RTSP PLAY Sent"
		self.kLeaveLatencyms = "Leave Latency (ms)"
		self.kCompletedstreamswithTR101290Errors = "Completed streams with TR 101 290 Errors"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kRTSPPresentationRequestsFailed = "RTSP Presentation Requests Failed"
		self.kMLDQueriesRx = "MLD Queries Rx"
		self.kPacketLatencybetween1025ms = "Packet Latency between 10 - 25 ms"
		self.kInterPacketArrivalTimebetween1025ms = "Inter Packet Arrival Time between 10 - 25 ms"
		self.kQueriesRx = "Queries Rx"
		self.kPFrameAvgVideoBw = "P Frame Avg Video Bw"
		self.kInterPacketArrivalTimebetween200500ms = "Inter Packet Arrival Time between 200 - 500 ms"
		self.kRTSPPLAYFailed = "RTSP PLAY Failed"
		self.kAvgCurrAbsMOSV = "Avg Curr Abs MOS V"
		self.kCRCErrors = "CRC Errors"
		self.kTotalLoss = "Total Loss"
		self.kRTSPPresentationsActive = "RTSP Presentations Active"
		self.kPacketLatencybetween2550ms = "Packet Latency between 25 - 50 ms"
		self.kActiveVoDStreamsPlaying = "Active VoD Streams - Playing"
		self.kPacketSizebetween0100bytes = "Packet Size between 0 - 100 bytes"
		self.kSimulatedUsers = "Simulated Users"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kRTPMaximumLostSequence = "RTP Maximum Lost Sequence"
		self.kReceiveThroughputKbps = "Receive Throughput (Kbps)"
		self.kAvgPacketLatencyns = "Avg Packet Latency (ns)"
		self.kVServerRequestsFailedControl = "V Server Requests Failed (Control)"
		self.kSceneAvgDetailLevel = "Scene Avg Detail Level"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kMLDReportsSent = "MLD Reports Sent"
		self.kAvgCompAbsMOSV = "Avg Comp Abs MOS V"
		self.kTransportErrorBitSet = "Transport Error Bit Set"
		self.kIFramesImpaired = "I Frames Impaired"
		self.kSetupRequestsSent = "Setup Requests Sent"
		self.kActiveVServerChannels = "Active V Server Channels"
		self.kRTSPPAUSEFailed = "RTSP PAUSE Failed"
		self.kDServerRequestsFailedData = "D Server Requests Failed (Data)"
		self.kMaxJitterns = "Max Jitter (ns)"
		self.kMLDLeavesTx = "MLD Leaves Tx"
		self.kRTCPAvgPacketTransmissionTimems = "RTCP Avg Packet Transmission Time (ms)"
		self.kUnexpectedUDPPacketsReceived = "Unexpected UDP Packets Received"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kRTSPSETPARAMETERFailed = "RTSP SET PARAMETER Failed"
		self.kPacketLatencybetween02ms = "Packet Latency between 0 - 2 ms"
		self.kPacketSizegreaterthan1000bytes = "Packet Size greater than 1000 bytes"
		self.kPTSErrors = "PTS Errors"
		self.kRTSPTeardownLatencyms = "RTSP Teardown Latency (ms)"
		self.kRTSPBytesReceived = "RTSP Bytes Received"
		self.kTotalDuplicateRTPPackets = "Total Duplicate RTP Packets"
		self.kTSSyncLoss = "TS Sync Loss"
		self.kPacketSizebetween6001000bytes = "Packet Size between 600 - 1000 bytes"
		self.kRTSPGETPARAMETERSent = "RTSP GET PARAMETER Sent"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kRTSPPlayLatency50ms100ms = "RTSP Play Latency (50 ms - 100 ms)"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kRTSPPAUSESent = "RTSP PAUSE Sent"
		self.kRTSPPresentationRequestsSuccessful = "RTSP Presentation Requests Successful"
		self.kDServerRequestsFailed = "D Server Requests Failed"
		self.kInterPacketArrivalTimebetween02ms = "Inter Packet Arrival Time between 0 - 2 ms"
		self.kAvgCurrMOSAV = "Avg Curr MOS AV"
		self.kPacketSizebetween400600bytes = "Packet Size between 400 - 600 bytes"
		self.kRTSPPacketsSent = "RTSP Packets Sent"
		self.kMLDQueriesRcvd = "MLD Queries Rcvd"
		self.kTotalRTPPacketsLost = "Total RTP Packets Lost"
		self.kPacketLatencybetween50100ms = "Packet Latency between 50 - 100 ms"
		self.kActiveVoDStreamsPaused = "Active VoD Streams - Paused"
		self.kPCRErrors = "PCR Errors"
		self.kPacketSizebetween200400bytes = "Packet Size between 200 - 400 bytes"
		self.kJitterbetween510ms = "Jitter between 5 - 10 ms"
		self.kRTPLostSequenceTwoorThreePackets = "RTP Lost Sequence: Two or Three Packets"
		self.kRTSPBytesSent = "RTSP Bytes Sent"
		self.kVServerRequestsFailedData = "V Server Requests Failed (Data)"
		self.kJittergreaterthan10ms = "Jitter greater than 10 ms"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kAvgCurrRelMOSV = "Avg Curr Rel MOS V"
		self.kSetupRequestsSuccessful = "Setup Requests Successful"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kRTSPOPTIONSSent = "RTSP OPTIONS Sent"
		self.kMinJitterns = "Min Jitter (ns)"
		self.kRTSPPAUSESuccessful = "RTSP PAUSE Successful"
		self.kSceneAvgMotionLevel = "Scene Avg Motion Level"
		self.kRTSPDescribeSent = "RTSP Describe Sent"
		self.kInterPacketArrivalTimebetween2550ms = "Inter Packet Arrival Time between 25 - 50 ms"
		self.kTotalpacketsRcvd = "Total packets Rcvd"
		self.kInterPacketArrivalTimegreaterthan500ms = "Inter Packet Arrival Time greater than 500 ms"
		self.kRTSPSETPARAMETERSent = "RTSP SET PARAMETER Sent"
		self.kRTSPPresentationsRequested = "RTSP Presentations Requested"
		self.kRTSPTeardownSent = "RTSP Teardown Sent"
		self.kRTSPTransactions = "RTSP Transactions"
		self.kRTSPSetupSent = "RTSP Setup Sent"
		self.kRTSPPLAYSuccessful = "RTSP PLAY Successful"
		self.kRTSPSetupLatencyms = "RTSP Setup Latency (ms)"
		self.kLeavesTx = "Leaves Tx"
		self.kInterPacketArrivalTimebetween100200ms = "Inter Packet Arrival Time between 100 - 200 ms"
		self.kRTSPSETUPSents = "RTSP SETUP Sent/s"
		self.kMLDReportsTx = "MLD Reports Tx"
		self.kRTCPPacketsSent = "RTCP Packets Sent"
		self.kRTSPTEARDOWNFailed = "RTSP TEARDOWN Failed"
		self.kPFramesImpaired = "P Frames Impaired"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kRunningstreamswithTR101290Errors = "Running streams with TR 101 290 Errors"
		self.kIFramesRcvd = "I Frames Rcvd"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kRTSPConnections = "RTSP Connections"
		self.kIGMPLeavesSent = "IGMP Leaves Sent"
		self.kRTPLostSequenceOnePacket = "RTP Lost Sequence: One Packet"
		self.kVoDStreamsPlaybackFailed = "VoD Streams Playback Failed"
		self.kPauseRequestsSuccessful = "Pause Requests Successful"
		self.kRTSPPresentationsPlaying = "RTSP Presentations Playing"
		self.kTotalOutOfOrderRTPPacketsRcvd = "Total Out Of Order RTP Packets Rcvd"
		self.kActiveMulticastChannels = "Active Multicast Channels"
		self.kRTSPPlayLatency100ms300ms = "RTSP Play Latency (100 ms - 300 ms)"
		self.kOverloadPacketsDropped = "Overload Packets Dropped"
		self.kPacketLatencybetween510ms = "Packet Latency between 5 - 10 ms"
		self.kDServerChannelsRequested = "D Server Channels Requested"
		self.kMaxPacketLatencyns2 = "Max Packet Latency (ns)2"
		self.kRTSPPlayLatencyGreaterThan1s = "RTSP Play Latency (Greater Than 1s)"
		self.kSyncByteErrors = "Sync Byte Errors"
		self.kRTPLostSequenceFourorFivePackets = "RTP Lost Sequence: Four or Five Packets"
		self.kRTSPPLAYSents = "RTSP PLAY Sent/s"
		self.kRTSPOPTIONSSuccessful = "RTSP OPTIONS Successful"
		self.kRTSPGETPARAMETERFailed = "RTSP GET PARAMETER Failed"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kRTPLostSequenceElevenorMorePackets = "RTP Lost Sequence: Eleven or More Packets"
		self.kRTSPTransactionss = "RTSP Transactions/s"
		self.kAveragePauselatencyms = "Average Pause latency (ms)"
		self.kPAT2Errors = "PAT2 Errors"
		self.kInterPacketArrivalTimebetween25ms = "Inter Packet Arrival Time between 2 - 5 ms"
		self.kRTSPConcurrentSessions = "RTSP Concurrent Sessions"
		self.kPMTErrors = "PMT Errors"
		self.kRTSPPlayLatency300ms1s = "RTSP Play Latency (300 ms - 1s)"
		self.kRTPMaximumLostSequence2 = "RTP Maximum Lost Sequence2"
		self.kContinuityErrors = "Continuity Errors"
		self.kRTSPPlayLatency10ms50ms = "RTSP Play Latency (10 ms - 50 ms)"
		self.kPacketSizebetween100200bytes = "Packet Size between 100 - 200 bytes"
		self.kMLDLeavesSent = "MLD Leaves Sent"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kRTSPDESCRIBEFailed = "RTSP DESCRIBE Failed"
		self.kCATErrors = "CAT Errors"
		self.kActiveMulticastStreams = "Active Multicast Streams"
		self.kVServerChannelsRequested = "V Server Channels Requested"
		self.kIFrameAvgVideoBw = "I Frame Avg Video Bw"
		self.kJitterbetween50100us = "Jitter between 50 - 100 us"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kPCRDiscontinuityErrors = "PCR Discontinuity Errors"
		self.kRTSPTEARDOWNSents = "RTSP TEARDOWN Sent/s"
		self.kVoDStreamsPlaybackSuccessful = "VoD Streams Playback Successful"
		self.kPATErrors = "PAT Errors"
		self.kAvgIntervalRelMOSV = "Avg Interval Rel MOS V"
		self.kSceneAvgPanningLevel = "Scene Avg Panning Level"
		self.kAvgVideoBw = "Avg Video Bw"
		self.kBFramesImpaired = "B Frames Impaired"
		self.kVoDStreamsPlayed = "VoD Streams Played"
		self.kMulticastChannelsRequested = "Multicast Channels Requested"
		self.kRTSPConnectionss = "RTSP Connections/s"
		self.kMulticastRequestsFailed = "Multicast Requests Failed"
		self.kVServerRequestsFailed = "V Server Requests Failed"
		self.kPlayRequestsSent = "Play Requests Sent"
		self.kPlaylatencyms = "Play latency (ms)"
		self.kJitterbetween500us2ms = "Jitter between 500 us - 2 ms"
		self.kRTSPGetParameterSuccessful = "RTSP Get Parameter Successful"
		self.kAvgCompMOSA = "Avg Comp MOS A"
		self.kRTSPPresentationsPaused = "RTSP Presentations Paused"
		self.kTCPFINReceived = "TCP FIN Received"


class IxActivityVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityVideoClientWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.secondaryEnableConstraint = ixActivity.secondaryEnableConstraint
		self.protocol = ixActivity.protocol
		self.userIpMapping = ixActivity.userIpMapping
		self.enableConstraint = ixActivity.enableConstraint
		self.agent = PluginVideoClientWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.constraintValue = ixActivity.constraintValue
		self.customParameters = IxPropertyClass_ixCustomActivityParametersVideoClientWrapper(ixActivity.customParameters)
		self.timelineId = ixActivity.timelineId
		self.role = ixActivity.role
		self.timeline = IxTimelineProxyVideoClientWrapper(ixActivity.timeline)
		self.activeRole = ixActivity.activeRole
		self.type = ixActivity.type
		self.secondaryConstraintValue = ixActivity.secondaryConstraintValue
		self.enable = ixActivity.enable
		self.protocolAndType = ixActivity.protocolAndType
		self.userObjectiveType = ixActivity.userObjectiveType
		self.destinationIpMapping = ixActivity.destinationIpMapping
		self.name = ixActivity.name
		self.secondaryConstraintType = ixActivity.secondaryConstraintType
		self.userObjectiveValue = ixActivity.userObjectiveValue
		self.constraintType = ixActivity.constraintType

	properties = ["secondaryEnableConstraint", "protocol", "userIpMapping", "enableConstraint", "objectivePercent", "constraintValue", "timelineId", "role", "activeRole", "type", "secondaryConstraintValue", "enable", "protocolAndType", "userObjectiveType", "destinationIpMapping", "name", "secondaryConstraintType", "userObjectiveValue", "constraintType", ]

	def __getattribute__(self, name):
		if name in IxActivityVideoClientWrapper.properties and super(IxActivityVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityVideoClientWrapper, self).__getattribute__("_IxActivityVideoClientWrapper__ixActivity"), name)
		else:
			return super(IxActivityVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityVideoClientWrapper, self).__getattribute__("_IxActivityVideoClientWrapper__ixActivity"), name, value)
			super(IxActivityVideoClientWrapper, self).__setattr__(name, value)


class IxActivityVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityVideoServerWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.customParameters = IxPropertyClass_ixCustomActivityParametersVideoServerWrapper(ixActivity.customParameters)
		self.enable = ixActivity.enable
		self.protocol = ixActivity.protocol
		self.name = ixActivity.name
		self.role = ixActivity.role
		self.agent = PluginVideoServerWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.protocolAndType = ixActivity.protocolAndType
		self.timeline = IxTimelineProxyVideoServerWrapper(ixActivity.timeline)
		self.timelineId = ixActivity.timelineId
		self.type = ixActivity.type
		self.activeRole = ixActivity.activeRole

	properties = ["enable", "protocol", "name", "role", "objectivePercent", "protocolAndType", "timelineId", "type", "activeRole", ]

	def __getattribute__(self, name):
		if name in IxActivityVideoServerWrapper.properties and super(IxActivityVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityVideoServerWrapper, self).__getattribute__("_IxActivityVideoServerWrapper__ixActivity"), name)
		else:
			return super(IxActivityVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityVideoServerWrapper, self).__getattribute__("_IxActivityVideoServerWrapper__ixActivity"), name, value)
			super(IxActivityVideoServerWrapper, self).__setattr__(name, value)


class PluginVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginVideoClientWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.pm = IxPropertyMap_VideoVideoClientWrapper(agent.pm)
		self.flowPercentage = agent.flowPercentage

	properties = ["cmdListLoops", "flowPercentage", ]

	def __getattribute__(self, name):
		if name in PluginVideoClientWrapper.properties and super(PluginVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(PluginVideoClientWrapper, self).__getattribute__("_PluginVideoClientWrapper__agent"), name)
		else:
			return super(PluginVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginVideoClientWrapper, self).__getattribute__("_PluginVideoClientWrapper__agent"), name, value)
			super(PluginVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_ixCustomActivityParametersVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, customParameters):
		super(IxPropertyClass_ixCustomActivityParametersVideoClientWrapper, self).__init__(customParameters)
		self.__customParameters = customParameters

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_ixCustomActivityParametersVideoClientWrapper.properties and super(IxPropertyClass_ixCustomActivityParametersVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ixCustomActivityParametersVideoClientWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersVideoClientWrapper__customParameters"), name)
		else:
			return super(IxPropertyClass_ixCustomActivityParametersVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ixCustomActivityParametersVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ixCustomActivityParametersVideoClientWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersVideoClientWrapper__customParameters"), name, value)
			super(IxPropertyClass_ixCustomActivityParametersVideoClientWrapper, self).__setattr__(name, value)


class IxTimelineProxyVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyVideoClientWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.iterations = timeline.iterations
		self.rampUpType = timeline.rampUpType
		self.rampUpValue = timeline.rampUpValue
		self.rampUpTime = timeline.rampUpTime
		self.rampDownTime = timeline.rampDownTime
		self.standbyTime = timeline.standbyTime
		self.rampDownValue = timeline.rampDownValue
		self.rampUpInterval = timeline.rampUpInterval
		self.offlineTime = timeline.offlineTime
		self.sustainTime = timeline.sustainTime
		self.name = timeline.name
		self.timelineType = timeline.timelineType

	properties = ["iterations", "rampUpType", "rampUpValue", "rampUpTime", "rampDownTime", "standbyTime", "rampDownValue", "rampUpInterval", "offlineTime", "sustainTime", "name", "timelineType", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyVideoClientWrapper.properties and super(IxTimelineProxyVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyVideoClientWrapper, self).__getattribute__("_IxTimelineProxyVideoClientWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyVideoClientWrapper, self).__getattribute__("_IxTimelineProxyVideoClientWrapper__timeline"), name, value)
			super(IxTimelineProxyVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_ixCustomActivityParametersVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, customParameters):
		super(IxPropertyClass_ixCustomActivityParametersVideoServerWrapper, self).__init__(customParameters)
		self.__customParameters = customParameters

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_ixCustomActivityParametersVideoServerWrapper.properties and super(IxPropertyClass_ixCustomActivityParametersVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ixCustomActivityParametersVideoServerWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersVideoServerWrapper__customParameters"), name)
		else:
			return super(IxPropertyClass_ixCustomActivityParametersVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ixCustomActivityParametersVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ixCustomActivityParametersVideoServerWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersVideoServerWrapper__customParameters"), name, value)
			super(IxPropertyClass_ixCustomActivityParametersVideoServerWrapper, self).__setattr__(name, value)


class PluginVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginVideoServerWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.pm = IxPropertyMap_VideoVideoServerWrapper(agent.pm)
		self.flowPercentage = agent.flowPercentage

	properties = ["cmdListLoops", "flowPercentage", ]

	def __getattribute__(self, name):
		if name in PluginVideoServerWrapper.properties and super(PluginVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(PluginVideoServerWrapper, self).__getattribute__("_PluginVideoServerWrapper__agent"), name)
		else:
			return super(PluginVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginVideoServerWrapper, self).__getattribute__("_PluginVideoServerWrapper__agent"), name, value)
			super(PluginVideoServerWrapper, self).__setattr__(name, value)


class IxTimelineProxyVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyVideoServerWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.name = timeline.name
		self.standbyTime = timeline.standbyTime
		self.iterations = timeline.iterations
		self.sustainTime = timeline.sustainTime

	properties = ["name", "standbyTime", "iterations", "sustainTime", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyVideoServerWrapper.properties and super(IxTimelineProxyVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyVideoServerWrapper, self).__getattribute__("_IxTimelineProxyVideoServerWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyVideoServerWrapper, self).__getattribute__("_IxTimelineProxyVideoServerWrapper__timeline"), name, value)
			super(IxTimelineProxyVideoServerWrapper, self).__setattr__(name, value)


class IxPropertyMap_VideoVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		super(IxPropertyMap_VideoVideoClientWrapper, self).__init__(pm)
		self.__pm = pm
		self.channelSrcHistory = IxPropertyGroupSequence_Video_channelSrcHistoryVideoClientWrapper(pm)
		self.predefined_tos = IxPropertyGroupSequence_Video_predefined_tosVideoClientWrapper(pm)
		self.stats = IxPropertyClass_StatsVideoClientWrapper(pm.stats)
		self.channelList = IxPropertyClass_ChannelListVideoClientWrapper(pm.channelList)
		self.commands = IxPropertyGroupSequence_Video_commandsVideoClientWrapper(pm)
		self.synchronizing = IxPropertyClass_SynchronizingVideoClientWrapper(pm.synchronizing)
		self.transport = IxPropertyClass_TransportVideoClientWrapper(pm.transport)
		self.iptv_options = IxPropertyClass_IPTVOptionsVideoClientWrapper(pm.iptv_options)
		self.signalling = IxPropertyClass_SignallingVideoClientWrapper(pm.signalling)
		self.advanced = IxPropertyClass_AdvancedVideoClientWrapper(pm.advanced)
		self.ipHistory = IxPropertyGroupSequence_Video_ipHistoryVideoClientWrapper(pm)
		self.UrlHistory = IxPropertyGroupSequence_Video_UrlHistoryVideoClientWrapper(pm)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyMap_VideoVideoClientWrapper.properties and super(IxPropertyMap_VideoVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyMap_VideoVideoClientWrapper, self).__getattribute__("_IxPropertyMap_VideoVideoClientWrapper__pm"), name)
		else:
			return super(IxPropertyMap_VideoVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyMap_VideoVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyMap_VideoVideoClientWrapper, self).__getattribute__("_IxPropertyMap_VideoVideoClientWrapper__pm"), name, value)
			super(IxPropertyMap_VideoVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyMap_VideoVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		super(IxPropertyMap_VideoVideoServerWrapper, self).__init__(pm)
		self.__pm = pm
		self.predefined_tos_for_rtsp = IxPropertyGroupSequence_Video_predefined_tos_for_rtspVideoServerWrapper(pm)
		self.videoProp = IxPropertyClass_VideoPropVideoServerWrapper(pm.videoProp)
		self.videoConfig = IxPropertyClass_VideoConfigVideoServerWrapper(pm.videoConfig)
		self.predefined_tos_for_data = IxPropertyGroupSequence_Video_predefined_tos_for_dataVideoServerWrapper(pm)
		self.advancedOptions = IxPropertyClass_AdvancedOptionsVideoServerWrapper(pm.advancedOptions)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyMap_VideoVideoServerWrapper.properties and super(IxPropertyMap_VideoVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyMap_VideoVideoServerWrapper, self).__getattribute__("_IxPropertyMap_VideoVideoServerWrapper__pm"), name)
		else:
			return super(IxPropertyMap_VideoVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyMap_VideoVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyMap_VideoVideoServerWrapper, self).__getattribute__("_IxPropertyMap_VideoVideoServerWrapper__pm"), name, value)
			super(IxPropertyMap_VideoVideoServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_Video_channelSrcHistoryVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm

	def getItem(self, objectID):
		itemList = self.__pm.channelSrcHistory
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_channelSrc":
				return IxPropertyClass_channelSrcVideoClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_channelSrcVideoClientWrapper(self.__pm.channelSrcHistory.appendItem(**kwargs))

	def getList(self):
		return self.__pm.channelSrcHistory

	def clear(self):
		return self.__pm.channelSrcHistory.clear()


class IxPropertyClass_channelSrcVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_channelSrc):
		super(IxPropertyClass_channelSrcVideoClientWrapper, self).__init__(ixPropertyClass_channelSrc)
		self.__ixPropertyClass_channelSrc = ixPropertyClass_channelSrc
		self.name = ixPropertyClass_channelSrc.name

	properties = ["name", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_channelSrcVideoClientWrapper.properties and super(IxPropertyClass_channelSrcVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_channelSrcVideoClientWrapper, self).__getattribute__("_IxPropertyClass_channelSrcVideoClientWrapper__ixPropertyClass_channelSrc"), name)
		else:
			return super(IxPropertyClass_channelSrcVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_channelSrcVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_channelSrcVideoClientWrapper, self).__getattribute__("_IxPropertyClass_channelSrcVideoClientWrapper__ixPropertyClass_channelSrc"), name, value)
			super(IxPropertyClass_channelSrcVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_Video_predefined_tosVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm

	def getItem(self, objectID):
		itemList = self.__pm.predefined_tos
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_TypeOfService":
				return IxPropertyClass_TypeOfServiceVideoClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_TypeOfServiceVideoClientWrapper(self.__pm.predefined_tos.appendItem(**kwargs))

	def getList(self):
		return self.__pm.predefined_tos

	def clear(self):
		return self.__pm.predefined_tos.clear()


class IxPropertyClass_TypeOfServiceVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_TypeOfService):
		super(IxPropertyClass_TypeOfServiceVideoClientWrapper, self).__init__(ixPropertyClass_TypeOfService)
		self.__ixPropertyClass_TypeOfService = ixPropertyClass_TypeOfService
		self.tos_val = ixPropertyClass_TypeOfService.tos_val

	properties = ["tos_val", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_TypeOfServiceVideoClientWrapper.properties and super(IxPropertyClass_TypeOfServiceVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_TypeOfServiceVideoClientWrapper, self).__getattribute__("_IxPropertyClass_TypeOfServiceVideoClientWrapper__ixPropertyClass_TypeOfService"), name)
		else:
			return super(IxPropertyClass_TypeOfServiceVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_TypeOfServiceVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_TypeOfServiceVideoClientWrapper, self).__getattribute__("_IxPropertyClass_TypeOfServiceVideoClientWrapper__ixPropertyClass_TypeOfService"), name, value)
			super(IxPropertyClass_TypeOfServiceVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_StatsVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, stats):
		super(IxPropertyClass_StatsVideoClientWrapper, self).__init__(stats)
		self.__stats = stats
		self.PerStreamEntriesPerUser = stats.PerStreamEntriesPerUser
		self.max_tracks_per_stream = stats.max_tracks_per_stream
		self.vuserId = stats.vuserId
		self.enableVuserMonitor = stats.enableVuserMonitor
		self.bufferSize = stats.bufferSize
		self.MinDelay = stats.MinDelay
		self.MaxDelay = stats.MaxDelay
		self.enableFrameStats = stats.enableFrameStats
		self.JBEMode = stats.JBEMode
		self.bitrateLimit = stats.bitrateLimit
		self.NomDelay = stats.NomDelay
		self.IgnoreLoss = stats.IgnoreLoss
		self.nominalDelay = stats.nominalDelay
		self.updateInterval = stats.updateInterval
		self.enableStreamStats = stats.enableStreamStats
		self.enableTR101290 = stats.enableTR101290
		self.frameLimit = stats.frameLimit
		self.totalLimit = stats.totalLimit
		self.qualityLimit = stats.qualityLimit
		self.enableVQmonStats = stats.enableVQmonStats

	properties = ["PerStreamEntriesPerUser", "max_tracks_per_stream", "vuserId", "enableVuserMonitor", "bufferSize", "MinDelay", "MaxDelay", "enableFrameStats", "JBEMode", "bitrateLimit", "NomDelay", "IgnoreLoss", "nominalDelay", "updateInterval", "enableStreamStats", "enableTR101290", "frameLimit", "totalLimit", "qualityLimit", "enableVQmonStats", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_StatsVideoClientWrapper.properties and super(IxPropertyClass_StatsVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_StatsVideoClientWrapper, self).__getattribute__("_IxPropertyClass_StatsVideoClientWrapper__stats"), name)
		else:
			return super(IxPropertyClass_StatsVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_StatsVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_StatsVideoClientWrapper, self).__getattribute__("_IxPropertyClass_StatsVideoClientWrapper__stats"), name, value)
			super(IxPropertyClass_StatsVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_ChannelListVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, channelList):
		super(IxPropertyClass_ChannelListVideoClientWrapper, self).__init__(channelList)
		self.__channelList = channelList

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_ChannelListVideoClientWrapper.properties and super(IxPropertyClass_ChannelListVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ChannelListVideoClientWrapper, self).__getattribute__("_IxPropertyClass_ChannelListVideoClientWrapper__channelList"), name)
		else:
			return super(IxPropertyClass_ChannelListVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ChannelListVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ChannelListVideoClientWrapper, self).__getattribute__("_IxPropertyClass_ChannelListVideoClientWrapper__channelList"), name, value)
			super(IxPropertyClass_ChannelListVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_Video_commandsVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm
		self.optionsDict = {
			('JoinCommand',): "IxPropertyClass_JoinCommandVideoClient",
			('START',): "IxPropertyCommandStartVideoClient",
			('STOP',): "IxPropertyCommandStopVideoClient",
			('PlayMediaCommand',): "IxPropertyClass_PlayMediaCommandVideoClient",
		}

	def getItemIxJoincommandCommand(self, objectID):
		itemList = self.__pm.commands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_JoinCommand":
				return IxPropertyClass_JoinCommandVideoClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxJoincommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "JoinCommand"})
		return IxPropertyClass_JoinCommandVideoClientWrapper(self.__pm.commands.appendItem(**kwargs))

	def getItemIxStartCommand(self, objectID):
		itemList = self.__pm.commands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandStart":
				return IxPropertyCommandStartVideoClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStartCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "START"})
		return IxPropertyCommandStartVideoClientWrapper(self.__pm.commands.appendItem(**kwargs))

	def getItemIxStopCommand(self, objectID):
		itemList = self.__pm.commands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandStop":
				return IxPropertyCommandStopVideoClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STOP"})
		return IxPropertyCommandStopVideoClientWrapper(self.__pm.commands.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__pm.commands
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, commandType=None):
		kwargs = {}
		kwargs.update({"commandType": commandType})
		return self.__pm.commands.appendItem(**kwargs)

	def getList(self):
		return self.__pm.commands

	def clear(self):
		return self.__pm.commands.clear()


	def getItemIxPlaymediacommandCommand(self, objectID):
		itemList = self.__pm.commands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_PlayMediaCommand":
				return IxPropertyClass_PlayMediaCommandVideoClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxPlaymediacommandCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "PlayMediaCommand"})
		return IxPropertyClass_PlayMediaCommandVideoClientWrapper(self.__pm.commands.appendItem(**kwargs))


class IxPropertyCommandStartVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStart):
		super(IxPropertyCommandStartVideoClientWrapper, self).__init__(ixPropertyCommandStart)
		self.__ixPropertyCommandStart = ixPropertyCommandStart
		self.commandType = ixPropertyCommandStart.commandType
		self.cmdName = ixPropertyCommandStart.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandStartVideoClientWrapper.properties and super(IxPropertyCommandStartVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandStartVideoClientWrapper, self).__getattribute__("_IxPropertyCommandStartVideoClientWrapper__ixPropertyCommandStart"), name)
		else:
			return super(IxPropertyCommandStartVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandStartVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandStartVideoClientWrapper, self).__getattribute__("_IxPropertyCommandStartVideoClientWrapper__ixPropertyCommandStart"), name, value)
			super(IxPropertyCommandStartVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_JoinCommandVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_JoinCommand):
		super(IxPropertyClass_JoinCommandVideoClientWrapper, self).__init__(ixPropertyClass_JoinCommand)
		self.__ixPropertyClass_JoinCommand = ixPropertyClass_JoinCommand
		self.channel_switch_mode = ixPropertyClass_JoinCommand.channel_switch_mode
		self.channel_switch_delay_max = ixPropertyClass_JoinCommand.channel_switch_delay_max
		self.cmdName = ixPropertyClass_JoinCommand.cmdName
		self.useFile = ixPropertyClass_JoinCommand.useFile
		self.group_address_count = ixPropertyClass_JoinCommand.group_address_count
		self.channel_switch_delay_min = ixPropertyClass_JoinCommand.channel_switch_delay_min
		self.filename = ixPropertyClass_JoinCommand.filename
		self.group_address_step = ixPropertyClass_JoinCommand.group_address_step
		self.source_address = ixPropertyClass_JoinCommand.source_address
		self.destination_server_activity = ixPropertyClass_JoinCommand.destination_server_activity
		self.commandType = ixPropertyClass_JoinCommand.commandType
		self.varLambda = ixPropertyClass_JoinCommand.varLambda
		self.start_group_address_sym = ixPropertyClass_JoinCommand.start_group_address_sym
		self.mu = ixPropertyClass_JoinCommand.mu
		self.duration_max = ixPropertyClass_JoinCommand.duration_max
		self.duration_min = ixPropertyClass_JoinCommand.duration_min
		self.watch_count = ixPropertyClass_JoinCommand.watch_count
		self.sigma = ixPropertyClass_JoinCommand.sigma
		self.concurrent_channels = ixPropertyClass_JoinCommand.concurrent_channels

	properties = ["channel_switch_mode", "channel_switch_delay_max", "cmdName", "useFile", "group_address_count", "channel_switch_delay_min", "filename", "group_address_step", "source_address", "destination_server_activity", "commandType", "varLambda", "start_group_address_sym", "mu", "duration_max", "duration_min", "watch_count", "sigma", "concurrent_channels", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_JoinCommandVideoClientWrapper.properties and super(IxPropertyClass_JoinCommandVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_JoinCommandVideoClientWrapper, self).__getattribute__("_IxPropertyClass_JoinCommandVideoClientWrapper__ixPropertyClass_JoinCommand"), name)
		else:
			return super(IxPropertyClass_JoinCommandVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_JoinCommandVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_JoinCommandVideoClientWrapper, self).__getattribute__("_IxPropertyClass_JoinCommandVideoClientWrapper__ixPropertyClass_JoinCommand"), name, value)
			super(IxPropertyClass_JoinCommandVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyCommandStopVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStop):
		super(IxPropertyCommandStopVideoClientWrapper, self).__init__(ixPropertyCommandStop)
		self.__ixPropertyCommandStop = ixPropertyCommandStop
		self.commandType = ixPropertyCommandStop.commandType
		self.cmdName = ixPropertyCommandStop.cmdName

	properties = ["commandType", "cmdName", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandStopVideoClientWrapper.properties and super(IxPropertyCommandStopVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandStopVideoClientWrapper, self).__getattribute__("_IxPropertyCommandStopVideoClientWrapper__ixPropertyCommandStop"), name)
		else:
			return super(IxPropertyCommandStopVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandStopVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandStopVideoClientWrapper, self).__getattribute__("_IxPropertyCommandStopVideoClientWrapper__ixPropertyCommandStop"), name, value)
			super(IxPropertyCommandStopVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_SynchronizingVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, synchronizing):
		super(IxPropertyClass_SynchronizingVideoClientWrapper, self).__init__(synchronizing)
		self.__synchronizing = synchronizing

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_SynchronizingVideoClientWrapper.properties and super(IxPropertyClass_SynchronizingVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_SynchronizingVideoClientWrapper, self).__getattribute__("_IxPropertyClass_SynchronizingVideoClientWrapper__synchronizing"), name)
		else:
			return super(IxPropertyClass_SynchronizingVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_SynchronizingVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_SynchronizingVideoClientWrapper, self).__getattribute__("_IxPropertyClass_SynchronizingVideoClientWrapper__synchronizing"), name, value)
			super(IxPropertyClass_SynchronizingVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_TransportVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, transport):
		super(IxPropertyClass_TransportVideoClientWrapper, self).__init__(transport)
		self.__transport = transport
		self.vlan_priority = transport.vlan_priority
		self.type_of_service_for_rtsp = transport.type_of_service_for_rtsp
		self.enableTosRTSP = transport.enableTosRTSP
		self.enableEsm = transport.enableEsm
		self.esm = transport.esm
		self.enableVlanPriority = transport.enableVlanPriority
		self.transport = transport.transport

	properties = ["vlan_priority", "type_of_service_for_rtsp", "enableTosRTSP", "enableEsm", "esm", "enableVlanPriority", "transport", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_TransportVideoClientWrapper.properties and super(IxPropertyClass_TransportVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_TransportVideoClientWrapper, self).__getattribute__("_IxPropertyClass_TransportVideoClientWrapper__transport"), name)
		else:
			return super(IxPropertyClass_TransportVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_TransportVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_TransportVideoClientWrapper, self).__getattribute__("_IxPropertyClass_TransportVideoClientWrapper__transport"), name, value)
			super(IxPropertyClass_TransportVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_IPTVOptionsVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, iptv_options):
		super(IxPropertyClass_IPTVOptionsVideoClientWrapper, self).__init__(iptv_options)
		self.__iptv_options = iptv_options
		self.seq_gen_mode = iptv_options.seq_gen_mode
		self.enable_hwacc = iptv_options.enable_hwacc
		self.parallel_multicast_vod = iptv_options.parallel_multicast_vod
		self.enable_custom = iptv_options.enable_custom
		self.iptv_switch_mode = iptv_options.iptv_switch_mode
		self.enable_graceful_rampdown = iptv_options.enable_graceful_rampdown
		self.iptv_switch_delay = iptv_options.iptv_switch_delay
		self.profile_table = IxPropertyGroupSequence_IPTVOptions_profile_tableVideoClientWrapper(iptv_options)

	properties = ["seq_gen_mode", "enable_hwacc", "parallel_multicast_vod", "enable_custom", "iptv_switch_mode", "enable_graceful_rampdown", "iptv_switch_delay", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_IPTVOptionsVideoClientWrapper.properties and super(IxPropertyClass_IPTVOptionsVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_IPTVOptionsVideoClientWrapper, self).__getattribute__("_IxPropertyClass_IPTVOptionsVideoClientWrapper__iptv_options"), name)
		else:
			return super(IxPropertyClass_IPTVOptionsVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_IPTVOptionsVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_IPTVOptionsVideoClientWrapper, self).__getattribute__("_IxPropertyClass_IPTVOptionsVideoClientWrapper__iptv_options"), name, value)
			super(IxPropertyClass_IPTVOptionsVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_SignallingVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, signalling):
		super(IxPropertyClass_SignallingVideoClientWrapper, self).__init__(signalling)
		self.__signalling = signalling
		self.pppoe_fork = signalling.pppoe_fork
		self.ipPreference = signalling.ipPreference
		self.general_query_response_mode = signalling.general_query_response_mode
		self.enableCVReports = signalling.enableCVReports
		self.unsolicited_response_mode = signalling.unsolicited_response_mode
		self.report_frequency = signalling.report_frequency
		self.igmp_version = signalling.igmp_version
		self.mld_version = signalling.mld_version
		self.router_alert = signalling.router_alert
		self.group_specific_query_response_mode = signalling.group_specific_query_response_mode
		self.suppress_reports = signalling.suppress_reports
		self.ip_version = signalling.ip_version
		self.immediate_response = signalling.immediate_response
		self.client_mode = signalling.client_mode

	properties = ["pppoe_fork", "ipPreference", "general_query_response_mode", "enableCVReports", "unsolicited_response_mode", "report_frequency", "igmp_version", "mld_version", "router_alert", "group_specific_query_response_mode", "suppress_reports", "ip_version", "immediate_response", "client_mode", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_SignallingVideoClientWrapper.properties and super(IxPropertyClass_SignallingVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_SignallingVideoClientWrapper, self).__getattribute__("_IxPropertyClass_SignallingVideoClientWrapper__signalling"), name)
		else:
			return super(IxPropertyClass_SignallingVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_SignallingVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_SignallingVideoClientWrapper, self).__getattribute__("_IxPropertyClass_SignallingVideoClientWrapper__signalling"), name, value)
			super(IxPropertyClass_SignallingVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_AdvancedVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, advanced):
		super(IxPropertyClass_AdvancedVideoClientWrapper, self).__init__(advanced)
		self.__advanced = advanced
		self.typeOfTest = advanced.typeOfTest
		self.rtspProxyEnable = advanced.rtspProxyEnable
		self.CustomSetup = advanced.CustomSetup
		self.rtspKeepaliveInterval = advanced.rtspKeepaliveInterval
		self.custom_protocol_name = advanced.custom_protocol_name
		self.followRtspRedirect = advanced.followRtspRedirect
		self.rtspKeepaliveMessageType = advanced.rtspKeepaliveMessageType
		self.async_teardown_hdr_val = advanced.async_teardown_hdr_val
		self.users_allowed = advanced.users_allowed
		self.rtspProxyIp = advanced.rtspProxyIp
		self.enable_async_teardown = advanced.enable_async_teardown
		self.rtspKeepaliveEnable = advanced.rtspKeepaliveEnable
		self.enable_custom_protocol = advanced.enable_custom_protocol
		self.header_values = IxPropertyGroupSequence_Advanced_header_valuesVideoClientWrapper(advanced)
		self.rtsp_header = advanced.rtsp_header
		self.rtcp_enable = advanced.rtcp_enable
		self.custom_profile_name = advanced.custom_profile_name
		self.enable_custom_profile = advanced.enable_custom_profile
		self.enableCustomSetup = advanced.enableCustomSetup
		self.rtspProxyPort = advanced.rtspProxyPort

	properties = ["typeOfTest", "rtspProxyEnable", "CustomSetup", "rtspKeepaliveInterval", "custom_protocol_name", "followRtspRedirect", "rtspKeepaliveMessageType", "async_teardown_hdr_val", "users_allowed", "rtspProxyIp", "enable_async_teardown", "rtspKeepaliveEnable", "enable_custom_protocol", "rtsp_header", "rtcp_enable", "custom_profile_name", "enable_custom_profile", "enableCustomSetup", "rtspProxyPort", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AdvancedVideoClientWrapper.properties and super(IxPropertyClass_AdvancedVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AdvancedVideoClientWrapper, self).__getattribute__("_IxPropertyClass_AdvancedVideoClientWrapper__advanced"), name)
		else:
			return super(IxPropertyClass_AdvancedVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AdvancedVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AdvancedVideoClientWrapper, self).__getattribute__("_IxPropertyClass_AdvancedVideoClientWrapper__advanced"), name, value)
			super(IxPropertyClass_AdvancedVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_Video_predefined_tos_for_rtspVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm

	def getItem(self, objectID):
		itemList = self.__pm.predefined_tos_for_rtsp
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_TypeOfServiceForRtsp":
				return IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper(self.__pm.predefined_tos_for_rtsp.appendItem(**kwargs))

	def getList(self):
		return self.__pm.predefined_tos_for_rtsp

	def clear(self):
		return self.__pm.predefined_tos_for_rtsp.clear()


class IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_TypeOfServiceForRtsp):
		super(IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper, self).__init__(ixPropertyClass_TypeOfServiceForRtsp)
		self.__ixPropertyClass_TypeOfServiceForRtsp = ixPropertyClass_TypeOfServiceForRtsp
		self.tos_val_for_rtsp = ixPropertyClass_TypeOfServiceForRtsp.tos_val_for_rtsp

	properties = ["tos_val_for_rtsp", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper.properties and super(IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper, self).__getattribute__("_IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper__ixPropertyClass_TypeOfServiceForRtsp"), name)
		else:
			return super(IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper, self).__getattribute__("_IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper__ixPropertyClass_TypeOfServiceForRtsp"), name, value)
			super(IxPropertyClass_TypeOfServiceForRtspVideoServerWrapper, self).__setattr__(name, value)


class IxPropertyClass_VideoPropVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, videoProp):
		super(IxPropertyClass_VideoPropVideoServerWrapper, self).__init__(videoProp)
		self.__videoProp = videoProp
		self.stream = IxPropertyGroupSequence_VideoProp_streamVideoServerWrapper(videoProp)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_VideoPropVideoServerWrapper.properties and super(IxPropertyClass_VideoPropVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_VideoPropVideoServerWrapper, self).__getattribute__("_IxPropertyClass_VideoPropVideoServerWrapper__videoProp"), name)
		else:
			return super(IxPropertyClass_VideoPropVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_VideoPropVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_VideoPropVideoServerWrapper, self).__getattribute__("_IxPropertyClass_VideoPropVideoServerWrapper__videoProp"), name, value)
			super(IxPropertyClass_VideoPropVideoServerWrapper, self).__setattr__(name, value)


class IxPropertyClass_VideoConfigVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, videoConfig):
		super(IxPropertyClass_VideoConfigVideoServerWrapper, self).__init__(videoConfig)
		self.__videoConfig = videoConfig
		self.serverMode = videoConfig.serverMode
		self.typeList = IxPropertyGroupSequence_VideoConfig_typeListVideoServerWrapper(videoConfig)
		self.iptv_multiport_enable = videoConfig.iptv_multiport_enable
		self.videoList = IxPropertyGroupSequence_VideoConfig_videoListVideoServerWrapper(videoConfig)
		self.a_server_ip = videoConfig.a_server_ip

	properties = ["serverMode", "iptv_multiport_enable", "a_server_ip", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_VideoConfigVideoServerWrapper.properties and super(IxPropertyClass_VideoConfigVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_VideoConfigVideoServerWrapper, self).__getattribute__("_IxPropertyClass_VideoConfigVideoServerWrapper__videoConfig"), name)
		else:
			return super(IxPropertyClass_VideoConfigVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_VideoConfigVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_VideoConfigVideoServerWrapper, self).__getattribute__("_IxPropertyClass_VideoConfigVideoServerWrapper__videoConfig"), name, value)
			super(IxPropertyClass_VideoConfigVideoServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_Video_predefined_tos_for_dataVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm

	def getItem(self, objectID):
		itemList = self.__pm.predefined_tos_for_data
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_TypeOfServiceForData":
				return IxPropertyClass_TypeOfServiceForDataVideoServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_TypeOfServiceForDataVideoServerWrapper(self.__pm.predefined_tos_for_data.appendItem(**kwargs))

	def getList(self):
		return self.__pm.predefined_tos_for_data

	def clear(self):
		return self.__pm.predefined_tos_for_data.clear()


class IxPropertyClass_TypeOfServiceForDataVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_TypeOfServiceForData):
		super(IxPropertyClass_TypeOfServiceForDataVideoServerWrapper, self).__init__(ixPropertyClass_TypeOfServiceForData)
		self.__ixPropertyClass_TypeOfServiceForData = ixPropertyClass_TypeOfServiceForData
		self.tos_val_for_data = ixPropertyClass_TypeOfServiceForData.tos_val_for_data

	properties = ["tos_val_for_data", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_TypeOfServiceForDataVideoServerWrapper.properties and super(IxPropertyClass_TypeOfServiceForDataVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_TypeOfServiceForDataVideoServerWrapper, self).__getattribute__("_IxPropertyClass_TypeOfServiceForDataVideoServerWrapper__ixPropertyClass_TypeOfServiceForData"), name)
		else:
			return super(IxPropertyClass_TypeOfServiceForDataVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_TypeOfServiceForDataVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_TypeOfServiceForDataVideoServerWrapper, self).__getattribute__("_IxPropertyClass_TypeOfServiceForDataVideoServerWrapper__ixPropertyClass_TypeOfServiceForData"), name, value)
			super(IxPropertyClass_TypeOfServiceForDataVideoServerWrapper, self).__setattr__(name, value)


class IxPropertyClass_AdvancedOptionsVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, advancedOptions):
		super(IxPropertyClass_AdvancedOptionsVideoServerWrapper, self).__init__(advancedOptions)
		self.__advancedOptions = advancedOptions
		self.enableEsm = advancedOptions.enableEsm
		self.type_of_service_for_rtsp = advancedOptions.type_of_service_for_rtsp
		self.enableVlanPriority_for_rtsp = advancedOptions.enableVlanPriority_for_rtsp
		self.listen_port = advancedOptions.listen_port
		self.enableTosRTSP = advancedOptions.enableTosRTSP
		self.udp_port_range = advancedOptions.udp_port_range
		self.enable_hwacc = advancedOptions.enable_hwacc
		self.dupMcastTraffic = advancedOptions.dupMcastTraffic
		self.spacing = advancedOptions.spacing
		self.enableTosData = advancedOptions.enableTosData
		self.link_speed = advancedOptions.link_speed
		self.type_of_service_for_data = advancedOptions.type_of_service_for_data
		self.esm = advancedOptions.esm
		self.vlan_priority_rtsp = advancedOptions.vlan_priority_rtsp
		self.enableSpacing = advancedOptions.enableSpacing

	properties = ["enableEsm", "type_of_service_for_rtsp", "enableVlanPriority_for_rtsp", "listen_port", "enableTosRTSP", "udp_port_range", "enable_hwacc", "dupMcastTraffic", "spacing", "enableTosData", "link_speed", "type_of_service_for_data", "esm", "vlan_priority_rtsp", "enableSpacing", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AdvancedOptionsVideoServerWrapper.properties and super(IxPropertyClass_AdvancedOptionsVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AdvancedOptionsVideoServerWrapper, self).__getattribute__("_IxPropertyClass_AdvancedOptionsVideoServerWrapper__advancedOptions"), name)
		else:
			return super(IxPropertyClass_AdvancedOptionsVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AdvancedOptionsVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AdvancedOptionsVideoServerWrapper, self).__getattribute__("_IxPropertyClass_AdvancedOptionsVideoServerWrapper__advancedOptions"), name, value)
			super(IxPropertyClass_AdvancedOptionsVideoServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_IPTVOptions_profile_tableVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, iptv_options):
		self.__iptv_options = iptv_options

	def getItem(self, objectID):
		itemList = self.__iptv_options.profile_table
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_ProfileTable":
				return IxPropertyClass_ProfileTableVideoClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_ProfileTableVideoClientWrapper(self.__iptv_options.profile_table.appendItem(**kwargs))

	def getList(self):
		return self.__iptv_options.profile_table

	def clear(self):
		return self.__iptv_options.profile_table.clear()


class IxPropertyClass_ProfileTableVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_ProfileTable):
		super(IxPropertyClass_ProfileTableVideoClientWrapper, self).__init__(ixPropertyClass_ProfileTable)
		self.__ixPropertyClass_ProfileTable = ixPropertyClass_ProfileTable
		self.duration_max = ixPropertyClass_ProfileTable.duration_max
		self.name = ixPropertyClass_ProfileTable.name
		self.num_profiles = ixPropertyClass_ProfileTable.num_profiles
		self.channel_switch_delay_max = ixPropertyClass_ProfileTable.channel_switch_delay_max
		self.duration_min = ixPropertyClass_ProfileTable.duration_min
		self.percentage = ixPropertyClass_ProfileTable.percentage
		self.channel_switch_delay_min = ixPropertyClass_ProfileTable.channel_switch_delay_min

	properties = ["duration_max", "name", "num_profiles", "channel_switch_delay_max", "duration_min", "percentage", "channel_switch_delay_min", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_ProfileTableVideoClientWrapper.properties and super(IxPropertyClass_ProfileTableVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ProfileTableVideoClientWrapper, self).__getattribute__("_IxPropertyClass_ProfileTableVideoClientWrapper__ixPropertyClass_ProfileTable"), name)
		else:
			return super(IxPropertyClass_ProfileTableVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ProfileTableVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ProfileTableVideoClientWrapper, self).__getattribute__("_IxPropertyClass_ProfileTableVideoClientWrapper__ixPropertyClass_ProfileTable"), name, value)
			super(IxPropertyClass_ProfileTableVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_Advanced_header_valuesVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, advanced):
		self.__advanced = advanced

	def getItem(self, objectID):
		itemList = self.__advanced.header_values
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_Header":
				return IxPropertyClass_HeaderVideoClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_HeaderVideoClientWrapper(self.__advanced.header_values.appendItem(**kwargs))

	def getList(self):
		return self.__advanced.header_values

	def clear(self):
		return self.__advanced.header_values.clear()


class IxPropertyClass_HeaderVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Header):
		super(IxPropertyClass_HeaderVideoClientWrapper, self).__init__(ixPropertyClass_Header)
		self.__ixPropertyClass_Header = ixPropertyClass_Header
		self.command_name = ixPropertyClass_Header.command_name
		self.name = ixPropertyClass_Header.name
		self.value = ixPropertyClass_Header.value

	properties = ["command_name", "name", "value", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_HeaderVideoClientWrapper.properties and super(IxPropertyClass_HeaderVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_HeaderVideoClientWrapper, self).__getattribute__("_IxPropertyClass_HeaderVideoClientWrapper__ixPropertyClass_Header"), name)
		else:
			return super(IxPropertyClass_HeaderVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_HeaderVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_HeaderVideoClientWrapper, self).__getattribute__("_IxPropertyClass_HeaderVideoClientWrapper__ixPropertyClass_Header"), name, value)
			super(IxPropertyClass_HeaderVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_VideoProp_streamVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, videoProp):
		self.__videoProp = videoProp

	def getItem(self, objectID):
		itemList = self.__videoProp.stream
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_Stream":
				return IxPropertyClass_StreamVideoServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_StreamVideoServerWrapper(self.__videoProp.stream.appendItem(**kwargs))

	def getList(self):
		return self.__videoProp.stream

	def clear(self):
		return self.__videoProp.stream.clear()


class IxPropertyClass_StreamVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Stream):
		super(IxPropertyClass_StreamVideoServerWrapper, self).__init__(ixPropertyClass_Stream)
		self.__ixPropertyClass_Stream = ixPropertyClass_Stream
		self.mpeg4_contains_hint_track = ixPropertyClass_Stream.mpeg4_contains_hint_track
		self.fileButton = ixPropertyClass_Stream.fileButton
		self.ip_bit_rate = ixPropertyClass_Stream.ip_bit_rate
		self.enable_tos = ixPropertyClass_Stream.enable_tos
		self.tsperudp = ixPropertyClass_Stream.tsperudp
		self.duration = ixPropertyClass_Stream.duration
		self.transport = ixPropertyClass_Stream.transport
		self.dest_port_incr = ixPropertyClass_Stream.dest_port_incr
		self.addr_incr = ixPropertyClass_Stream.addr_incr
		self.d_server_tos_or_dscp = ixPropertyClass_Stream.d_server_tos_or_dscp
		self.tos_or_dscp = ixPropertyClass_Stream.tos_or_dscp
		self.filename = ixPropertyClass_Stream.filename
		self.content = ixPropertyClass_Stream.content
		self.type = ixPropertyClass_Stream.type
		self.enable_d_server_tos = ixPropertyClass_Stream.enable_d_server_tos
		self.h264_contains_hint_track = ixPropertyClass_Stream.h264_contains_hint_track
		self.starting_dest_port = ixPropertyClass_Stream.starting_dest_port
		self.same_source_ip = ixPropertyClass_Stream.same_source_ip
		self.starting_multicast_group_addr = ixPropertyClass_Stream.starting_multicast_group_addr
		self.trackList = IxPropertyGroupSequence_Stream_trackListVideoServerWrapper(ixPropertyClass_Stream)
		self.h264_ignore_hint_track = ixPropertyClass_Stream.h264_ignore_hint_track
		self.d_server_bit_rate = ixPropertyClass_Stream.d_server_bit_rate
		self.name = ixPropertyClass_Stream.name
		self.stream_count = ixPropertyClass_Stream.stream_count
		self.mpeg4_ignore_hint_track = ixPropertyClass_Stream.mpeg4_ignore_hint_track
		self.max_allowed_requests_d_server = ixPropertyClass_Stream.max_allowed_requests_d_server

	properties = ["mpeg4_contains_hint_track", "fileButton", "ip_bit_rate", "enable_tos", "tsperudp", "duration", "transport", "dest_port_incr", "addr_incr", "d_server_tos_or_dscp", "tos_or_dscp", "filename", "content", "type", "enable_d_server_tos", "h264_contains_hint_track", "starting_dest_port", "same_source_ip", "starting_multicast_group_addr", "h264_ignore_hint_track", "d_server_bit_rate", "name", "stream_count", "mpeg4_ignore_hint_track", "max_allowed_requests_d_server", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_StreamVideoServerWrapper.properties and super(IxPropertyClass_StreamVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_StreamVideoServerWrapper, self).__getattribute__("_IxPropertyClass_StreamVideoServerWrapper__ixPropertyClass_Stream"), name)
		else:
			return super(IxPropertyClass_StreamVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_StreamVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_StreamVideoServerWrapper, self).__getattribute__("_IxPropertyClass_StreamVideoServerWrapper__ixPropertyClass_Stream"), name, value)
			super(IxPropertyClass_StreamVideoServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_VideoConfig_typeListVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, videoConfig):
		self.__videoConfig = videoConfig

	def getItem(self, objectID):
		itemList = self.__videoConfig.typeList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_serverType":
				return IxPropertyClass_serverTypeVideoServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_serverTypeVideoServerWrapper(self.__videoConfig.typeList.appendItem(**kwargs))

	def getList(self):
		return self.__videoConfig.typeList

	def clear(self):
		return self.__videoConfig.typeList.clear()


class IxPropertyClass_serverTypeVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_serverType):
		super(IxPropertyClass_serverTypeVideoServerWrapper, self).__init__(ixPropertyClass_serverType)
		self.__ixPropertyClass_serverType = ixPropertyClass_serverType
		self.name = ixPropertyClass_serverType.name

	properties = ["name", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_serverTypeVideoServerWrapper.properties and super(IxPropertyClass_serverTypeVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_serverTypeVideoServerWrapper, self).__getattribute__("_IxPropertyClass_serverTypeVideoServerWrapper__ixPropertyClass_serverType"), name)
		else:
			return super(IxPropertyClass_serverTypeVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_serverTypeVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_serverTypeVideoServerWrapper, self).__getattribute__("_IxPropertyClass_serverTypeVideoServerWrapper__ixPropertyClass_serverType"), name, value)
			super(IxPropertyClass_serverTypeVideoServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_VideoConfig_videoListVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, videoConfig):
		self.__videoConfig = videoConfig

	def getItem(self, objectID):
		itemList = self.__videoConfig.videoList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_Video":
				return IxPropertyClass_VideoVideoServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_VideoVideoServerWrapper(self.__videoConfig.videoList.appendItem(**kwargs))

	def getList(self):
		return self.__videoConfig.videoList

	def clear(self):
		return self.__videoConfig.videoList.clear()


class IxPropertyClass_VideoVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Video):
		super(IxPropertyClass_VideoVideoServerWrapper, self).__init__(ixPropertyClass_Video)
		self.__ixPropertyClass_Video = ixPropertyClass_Video
		self.dest_port_incr = ixPropertyClass_Video.dest_port_incr
		self.addr_incr = ixPropertyClass_Video.addr_incr
		self.name = ixPropertyClass_Video.name
		self.stream_count = ixPropertyClass_Video.stream_count
		self.starting_multicast_group_addr = ixPropertyClass_Video.starting_multicast_group_addr
		self.duration = ixPropertyClass_Video.duration
		self.IP_type = ixPropertyClass_Video.IP_type
		self.type = ixPropertyClass_Video.type
		self.starting_dest_port = ixPropertyClass_Video.starting_dest_port

	properties = ["dest_port_incr", "addr_incr", "name", "stream_count", "starting_multicast_group_addr", "duration", "IP_type", "type", "starting_dest_port", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_VideoVideoServerWrapper.properties and super(IxPropertyClass_VideoVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_VideoVideoServerWrapper, self).__getattribute__("_IxPropertyClass_VideoVideoServerWrapper__ixPropertyClass_Video"), name)
		else:
			return super(IxPropertyClass_VideoVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_VideoVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_VideoVideoServerWrapper, self).__getattribute__("_IxPropertyClass_VideoVideoServerWrapper__ixPropertyClass_Video"), name, value)
			super(IxPropertyClass_VideoVideoServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_Stream_trackListVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Stream):
		self.__ixPropertyClass_Stream = ixPropertyClass_Stream

	def getItem(self, objectID):
		itemList = self.__ixPropertyClass_Stream.trackList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_Track":
				return IxPropertyClass_TrackVideoServerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_TrackVideoServerWrapper(self.__ixPropertyClass_Stream.trackList.appendItem(**kwargs))

	def getList(self):
		return self.__ixPropertyClass_Stream.trackList

	def clear(self):
		return self.__ixPropertyClass_Stream.trackList.clear()


class IxPropertyClass_TrackVideoServerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Track):
		super(IxPropertyClass_TrackVideoServerWrapper, self).__init__(ixPropertyClass_Track)
		self.__ixPropertyClass_Track = ixPropertyClass_Track
		self.bitrate = ixPropertyClass_Track.bitrate
		self.numInstances = ixPropertyClass_Track.numInstances
		self.max_packet_size = ixPropertyClass_Track.max_packet_size

	properties = ["bitrate", "numInstances", "max_packet_size", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_TrackVideoServerWrapper.properties and super(IxPropertyClass_TrackVideoServerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_TrackVideoServerWrapper, self).__getattribute__("_IxPropertyClass_TrackVideoServerWrapper__ixPropertyClass_Track"), name)
		else:
			return super(IxPropertyClass_TrackVideoServerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_TrackVideoServerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_TrackVideoServerWrapper, self).__getattribute__("_IxPropertyClass_TrackVideoServerWrapper__ixPropertyClass_Track"), name, value)
			super(IxPropertyClass_TrackVideoServerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_Video_ipHistoryVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm

	def getItem(self, objectID):
		itemList = self.__pm.ipHistory
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_Ip":
				return IxPropertyClass_IpVideoClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_IpVideoClientWrapper(self.__pm.ipHistory.appendItem(**kwargs))

	def getList(self):
		return self.__pm.ipHistory

	def clear(self):
		return self.__pm.ipHistory.clear()


class IxPropertyClass_IpVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Ip):
		super(IxPropertyClass_IpVideoClientWrapper, self).__init__(ixPropertyClass_Ip)
		self.__ixPropertyClass_Ip = ixPropertyClass_Ip
		self.name = ixPropertyClass_Ip.name

	properties = ["name", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_IpVideoClientWrapper.properties and super(IxPropertyClass_IpVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_IpVideoClientWrapper, self).__getattribute__("_IxPropertyClass_IpVideoClientWrapper__ixPropertyClass_Ip"), name)
		else:
			return super(IxPropertyClass_IpVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_IpVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_IpVideoClientWrapper, self).__getattribute__("_IxPropertyClass_IpVideoClientWrapper__ixPropertyClass_Ip"), name, value)
			super(IxPropertyClass_IpVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_Video_UrlHistoryVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm

	def getItem(self, objectID):
		itemList = self.__pm.UrlHistory
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_Url":
				return IxPropertyClass_UrlVideoClientWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self):
		kwargs = {}
		return IxPropertyClass_UrlVideoClientWrapper(self.__pm.UrlHistory.appendItem(**kwargs))

	def getList(self):
		return self.__pm.UrlHistory

	def clear(self):
		return self.__pm.UrlHistory.clear()


class IxPropertyClass_UrlVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Url):
		super(IxPropertyClass_UrlVideoClientWrapper, self).__init__(ixPropertyClass_Url)
		self.__ixPropertyClass_Url = ixPropertyClass_Url
		self.name = ixPropertyClass_Url.name

	properties = ["name", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_UrlVideoClientWrapper.properties and super(IxPropertyClass_UrlVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_UrlVideoClientWrapper, self).__getattribute__("_IxPropertyClass_UrlVideoClientWrapper__ixPropertyClass_Url"), name)
		else:
			return super(IxPropertyClass_UrlVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_UrlVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_UrlVideoClientWrapper, self).__getattribute__("_IxPropertyClass_UrlVideoClientWrapper__ixPropertyClass_Url"), name, value)
			super(IxPropertyClass_UrlVideoClientWrapper, self).__setattr__(name, value)


class IxPropertyClass_PlayMediaCommandVideoClientWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_PlayMediaCommand):
		super(IxPropertyClass_PlayMediaCommandVideoClientWrapper, self).__init__(ixPropertyClass_PlayMediaCommand)
		self.__ixPropertyClass_PlayMediaCommand = ixPropertyClass_PlayMediaCommand
		self.media = ixPropertyClass_PlayMediaCommand.media
		self.cmdName = ixPropertyClass_PlayMediaCommand.cmdName
		self.commandType = ixPropertyClass_PlayMediaCommand.commandType
		self.symServerIP = ixPropertyClass_PlayMediaCommand.symServerIP

	properties = ["media", "cmdName", "commandType", "symServerIP", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_PlayMediaCommandVideoClientWrapper.properties and super(IxPropertyClass_PlayMediaCommandVideoClientWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_PlayMediaCommandVideoClientWrapper, self).__getattribute__("_IxPropertyClass_PlayMediaCommandVideoClientWrapper__ixPropertyClass_PlayMediaCommand"), name)
		else:
			return super(IxPropertyClass_PlayMediaCommandVideoClientWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_PlayMediaCommandVideoClientWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_PlayMediaCommandVideoClientWrapper, self).__getattribute__("_IxPropertyClass_PlayMediaCommandVideoClientWrapper__ixPropertyClass_PlayMediaCommand"), name, value)
			super(IxPropertyClass_PlayMediaCommandVideoClientWrapper, self).__setattr__(name, value)


class StatsNameSIPVoIPSip(object):
	def __init__(self):
		self.kINFORequestsSent2 = "INFO Requests Sent2"
		self.kREGISTERRequestsSent = "REGISTER Requests Sent"
		self.kACKRequestsSent2 = "ACK Requests Sent2"
		self.kRedirectedCalls = "Redirected Calls"
		self.k1xxResponsesMatched = "1xx Responses Matched"
		self.kINVITERequestsParsed = "INVITE Requests Parsed"
		self.kAutoNOTIFYRequestsProcessed = "Auto NOTIFY Requests Processed"
		self.kINVITERequestsMatched = "INVITE Requests Matched"
		self.kAuto3xxResponsesProcessed = "Auto 3xx Responses Processed"
		self.kACKRequestsRetransmitted = "ACK Requests Retransmitted"
		self.kAutoACKRequestsRetransmitted = "Auto ACK Requests Retransmitted"
		self.kINFORequestsProcessed = "INFO Requests Processed"
		self.kSUBSCRIBERequestsSent2 = "SUBSCRIBE Requests Sent2"
		self.k1xxResponsesSent = "1xx Responses Sent"
		self.kAutoNOTIFYRequestsSent = "Auto NOTIFY Requests Sent"
		self.k4xxResponsesRetransmited = "4xx Responses Retransmited"
		self.kAuto6xxResponsesProcessed = "Auto 6xx Responses Processed"
		self.kPRACKRequestsProcessed = "PRACK Requests Processed"
		self.kBYERequestsSent = "BYE Requests Sent"
		self.k6xxResponsesSent = "6xx Responses Sent"
		self.k4xxResponsesProcessed = "4xx Responses Processed"
		self.kUNKNOWNRequestsParsed = "UNKNOWN Requests Parsed"
		self.kSIPRetransmittedMsgs = "SIP Retransmitted Msgs"
		self.kTXSIPMessages = "TX SIP Messages"
		self.kAuto2xxResponsesProcessed = "Auto 2xx Responses Processed"
		self.kAutoREGISTERRequestsProcessed = "Auto REGISTER Requests Processed"
		self.kAutoREGISTERRequestsSent = "Auto REGISTER Requests Sent"
		self.kCANCELRequestsParsed = "CANCEL Requests Parsed"
		self.kUPDATERequestsProcessed = "UPDATE Requests Processed"
		self.kAutoCANCELRequestsProcessed = "Auto CANCEL Requests Processed"
		self.kAutoUPDATERequestsProcessed = "Auto UPDATE Requests Processed"
		self.kBYERequestsRetransmitted = "BYE Requests Retransmitted"
		self.kNOTIFYRequestsMatched = "NOTIFY Requests Matched"
		self.k3xxResponsesRetransmited = "3xx Responses Retransmited"
		self.kAuto6xxResponsesSent = "Auto 6xx Responses Sent"
		self.kSIPResponsesOrphans = "SIP Responses Orphans"
		self.k3xxResponsesMatched = "3xx Responses Matched"
		self.kREFERRequestsRetransmited = "REFER Requests Retransmited"
		self.k2xxResponsesRetransmited = "2xx Responses Retransmited"
		self.kCallsOverTLSsec = "Calls Over TLS /sec"
		self.kFailedTxProcedures = "Failed Tx Procedures"
		self.kUNKNOWNRequestsRetransmitted = "UNKNOWN Requests Retransmitted"
		self.kCANCELRequestsRetransmitted = "CANCEL Requests Retransmitted"
		self.kOPTIONSRequestsSent2 = "OPTIONS Requests Sent2"
		self.kMESSAGERequestsProcessed = "MESSAGE Requests Processed"
		self.kUPDATERequestsParsed = "UPDATE Requests Parsed"
		self.kREFERRequestsMatched = "REFER Requests Matched"
		self.k3xxResponsesSent = "3xx Responses Sent"
		self.kAutoOPTIONSRequestsRetransmitted = "Auto OPTIONS Requests Retransmitted"
		self.kAutoACKRequestsProcessed = "Auto ACK Requests Processed"
		self.kAutoBYERequestsRetransmitted = "Auto BYE Requests Retransmitted"
		self.kAutoPRACKRequestsSent = "Auto PRACK Requests Sent"
		self.kCallsOverUDPsec = "Calls Over UDP /sec"
		self.kAutoOPTIONSRequestsProcessed = "Auto OPTIONS Requests Processed"
		self.k4xxResponsesSent = "4xx Responses Sent"
		self.kAutoSUBSCRIBERequestsSent = "Auto SUBSCRIBE Requests Sent"
		self.kAutoSUBSCRIBERequestsRetransmitted = "Auto SUBSCRIBE Requests Retransmitted"
		self.kOPTIONSRequestsParsed = "OPTIONS Requests Parsed"
		self.k1xxResponsesProcessed = "1xx Responses Processed"
		self.kNOTIFYRequestsSent2 = "NOTIFY Requests Sent2"
		self.kACKRequestsProcessed = "ACK Requests Processed"
		self.kCallSetupTimeAvgms = "Call Setup Time (Avg) [ms]"
		self.kUPDATERequestsRetransmited = "UPDATE Requests Retransmited"
		self.kINFORequestsMatched = "INFO Requests Matched"
		self.kAutoMESSAGERequestsSent = "Auto MESSAGE Requests Sent"
		self.k6xxResponsesRetransmited = "6xx Responses Retransmited"
		self.kAutoMESSAGERequestsProcessed = "Auto MESSAGE Requests Processed"
		self.kBYERequestsRetransmited = "BYE Requests Retransmited"
		self.kAutoCANCELRequestsRetransmitted = "Auto CANCEL Requests Retransmitted"
		self.kCallsOverMixedTransportsec = "Calls Over Mixed Transport /sec"
		self.kAutoREFERRequestsSent = "Auto REFER Requests Sent"
		self.kBYERequestsSent2 = "BYE Requests Sent2"
		self.k6xxResponsesSent2 = "6xx Responses Sent2"
		self.k3xxResponsesSent2 = "3xx Responses Sent2"
		self.kOPTIONSRequestsRetransmited = "OPTIONS Requests Retransmited"
		self.kREGISTERRequestsRetransmited = "REGISTER Requests Retransmited"
		self.kREFERRequestsParsed = "REFER Requests Parsed"
		self.kCallsOverTCP = "Calls Over TCP"
		self.k5xxResponsesSent2 = "5xx Responses Sent2"
		self.kAuto4xxResponsesSent = "Auto 4xx Responses Sent"
		self.kNOTIFYRequestsSent = "NOTIFY Requests Sent"
		self.kOPTIONSRequestsSent = "OPTIONS Requests Sent"
		self.kACKRequestsParsed = "ACK Requests Parsed"
		self.kREFERRequestsRetransmitted = "REFER Requests Retransmitted"
		self.kSIPIgnoredRetransmissions = "SIP Ignored Retransmissions"
		self.kCallsOverIPSec = "Calls Over IPSec"
		self.kINFORequestsRetransmited = "INFO Requests Retransmited"
		self.kSUBSCRIBERequestsRetransmited = "SUBSCRIBE Requests Retransmited"
		self.kRedirectedCallssec = "Redirected Calls /sec"
		self.kSIPRequestsOrphans = "SIP Requests Orphans"
		self.kAuto1xxResponsesProcessed = "Auto 1xx Responses Processed"
		self.kCallsOverMixedTransport = "Calls Over Mixed Transport"
		self.kSIPResponsesSent = "SIP Responses Sent"
		self.kMESSAGERequestsMatched = "MESSAGE Requests Matched"
		self.kREGISTERRequestsMatched = "REGISTER Requests Matched"
		self.kSIPInternalErrors = "SIP Internal Errors"
		self.kSIPRequestsSent = "SIP Requests Sent"
		self.kTXSIPMsgLengthAvg = "TX SIP Msg Length (Avg)"
		self.kAutoUNKNOWNResponsesProcessed = "Auto UNKNOWN Responses Processed"
		self.kAutoCANCELRequestsSent = "Auto CANCEL Requests Sent"
		self.kAuto5xxResponsesSent = "Auto 5xx Responses Sent"
		self.kUNKNOWNResponsesParsed = "UNKNOWN Responses Parsed"
		self.k4xxResponsesMatched = "4xx Responses Matched"
		self.kRXSIPMsgLengthMin = "RX SIP Msg Length (Min)"
		self.kMESSAGERequestsParsed = "MESSAGE Requests Parsed"
		self.kCallsOverUDP = "Calls Over UDP"
		self.kAutoINFORequestsSent = "Auto INFO Requests Sent"
		self.kACKRequestsSent = "ACK Requests Sent"
		self.kOPTIONSRequestsRetransmitted = "OPTIONS Requests Retransmitted"
		self.kRejectedCalls = "Rejected Calls"
		self.kCANCELRequestsMatched = "CANCEL Requests Matched"
		self.kNOTIFYRequestsParsed = "NOTIFY Requests Parsed"
		self.kCANCELRequestsRetransmited = "CANCEL Requests Retransmited"
		self.kUPDATERequestsRetransmitted = "UPDATE Requests Retransmitted"
		self.kINVITERequestsSent = "INVITE Requests Sent"
		self.kAutoSUBSCRIBERequestsProcessed = "Auto SUBSCRIBE Requests Processed"
		self.k2xxResponsesProcessed = "2xx Responses Processed"
		self.kUNKNOWNRequestsSent = "UNKNOWN Requests Sent"
		self.kPRACKRequestsRetransmitted = "PRACK Requests Retransmitted"
		self.k2xxResponsesSent2 = "2xx Responses Sent2"
		self.kAuto1xxResponsesSent = "Auto 1xx Responses Sent"
		self.kSuccessfulTxProcedures = "Successful Tx Procedures"
		self.k1xxResponsesSent2 = "1xx Responses Sent2"
		self.kREGISTERRequestsParsed = "REGISTER Requests Parsed"
		self.kSUBSCRIBERequestsProcessed = "SUBSCRIBE Requests Processed"
		self.kNOTIFYRequestsProcessed = "NOTIFY Requests Processed"
		self.kAutoUNKNOWNRequestsSent = "Auto UNKNOWN Requests Sent"
		self.kAuto5xxResponsesProcessed = "Auto 5xx Responses Processed"
		self.kPRACKRequestsSent2 = "PRACK Requests Sent2"
		self.kNOTIFYRequestsRetransmited = "NOTIFY Requests Retransmited"
		self.kCANCELRequestsSent = "CANCEL Requests Sent"
		self.kResponsesParsed = "Responses Parsed"
		self.kSIPBytesReceived = "SIP Bytes Received"
		self.kSIPBytesTransmitted = "SIP Bytes Transmitted"
		self.kAutoACKRequestsSent = "Auto ACK Requests Sent"
		self.kSIPCallFlowErrors = "SIP Call Flow Errors"
		self.k1xxResponsesRetransmited = "1xx Responses Retransmited"
		self.kAutoNOTIFYRequestsRetransmitted = "Auto NOTIFY Requests Retransmitted"
		self.kBYERequestsInternallyMatched = "BYE Requests Internally Matched"
		self.kSUBSCRIBERequestsParsed = "SUBSCRIBE Requests Parsed"
		self.kSUBSCRIBERequestsRetransmitted = "SUBSCRIBE Requests Retransmitted"
		self.kSIPRequestsMatched = "SIP Requests Matched"
		self.kCallsOverTLS = "Calls Over TLS"
		self.kSUBSCRIBERequestsMatched = "SUBSCRIBE Requests Matched"
		self.k5xxResponsesSent = "5xx Responses Sent"
		self.kCANCELRequestsSent2 = "CANCEL Requests Sent2"
		self.kSIPResponsesParsed = "SIP Responses Parsed"
		self.k3xxResponsesProcessed = "3xx Responses Processed"
		self.k5xxResponsesRetransmited = "5xx Responses Retransmited"
		self.kSIPRequestsParsed = "SIP Requests Parsed"
		self.kCallsOverTCPsec = "Calls Over TCP /sec"
		self.kREGISTERRequestsSent2 = "REGISTER Requests Sent2"
		self.kFailedSessionRefreshes = "Failed Session Refreshes"
		self.kUPDATERequestsMatched = "UPDATE Requests Matched"
		self.kREGISTERRequestsRetransmitted = "REGISTER Requests Retransmitted"
		self.kSIPSDPErrors = "SIP SDP Errors"
		self.kAutoPRACKRequestsProcessed = "Auto PRACK Requests Processed"
		self.kCallsOverWSS = "Calls Over WSS"
		self.kCallsOverWS = "Calls Over WS"
		self.kSuccessfulSessionRefreshes = "Successful Session Refreshes"
		self.k3xxResponsesParsed = "3xx Responses Parsed"
		self.kUNKNOWNResponsesMatched = "UNKNOWN Responses Matched"
		self.kAutoUNKNOWNRequestsProcessed = "Auto UNKNOWN Requests Processed"
		self.kREGISTERRequestsProcessed = "REGISTER Requests Processed"
		self.kCallSetupTimeInstantAvgms = "Call Setup Time Instant (Avg) [ms]"
		self.kINFORequestsParsed = "INFO Requests Parsed"
		self.kREFERRequestsSent2 = "REFER Requests Sent2"
		self.k4xxResponsesParsed = "4xx Responses Parsed"
		self.kSIPResponsesMatched = "SIP Responses Matched"
		self.kAuto2xxResponsesSent = "Auto 2xx Responses Sent"
		self.k2xxResponsesSent = "2xx Responses Sent"
		self.kAuto4xxResponsesProcessed = "Auto 4xx Responses Processed"
		self.kPRACKRequestsRetransmited = "PRACK Requests Retransmited"
		self.k5xxResponsesParsed = "5xx Responses Parsed"
		self.kREFERRequestsSent = "REFER Requests Sent"
		self.kPRACKRequestsSent = "PRACK Requests Sent"
		self.kSIPParserErrors = "SIP Parser Errors"
		self.kAutoREFERRequestsProcessed = "Auto REFER Requests Processed"
		self.kBytesTransmitted = "Bytes Transmitted"
		self.kREFERRequestsProcessed = "REFER Requests Processed"
		self.kAutoPRACKRequestsRetransmitted = "Auto PRACK Requests Retransmitted"
		self.kAutoMESSAGERequestsRetransmitted = "Auto MESSAGE Requests Retransmitted"
		self.kINVITERequestsRetransmited = "INVITE Requests Retransmited"
		self.kACKRequestsMatched = "ACK Requests Matched"
		self.kAutoREGISTERRequestsRetransmitted = "Auto REGISTER Requests Retransmitted"
		self.kINFORequestsSent = "INFO Requests Sent"
		self.kAttemptedSessionRefreshes = "Attempted Session Refreshes"
		self.kBYERequestsMatched = "BYE Requests Matched"
		self.k6xxResponsesMatched = "6xx Responses Matched"
		self.kBytesReceived = "Bytes Received"
		self.kRejectedCallssec = "Rejected Calls /sec"
		self.kSIPExtractVariablesErrors = "SIP Extract Variables Errors"
		self.kRXSIPMessages = "RX SIP Messages"
		self.kAutoOPTIONSRequestsSent = "Auto OPTIONS Requests Sent"
		self.kUNKNOWNRequestsProcessed = "UNKNOWN Requests Processed"
		self.kAutoINFORequestsProcessed = "Auto INFO Requests Processed"
		self.kNOTIFYRequestsRetransmitted = "NOTIFY Requests Retransmitted"
		self.k2xxResponsesMatched = "2xx Responses Matched"
		self.kUNKNOWNResponsesProcessed = "UNKNOWN Responses Processed"
		self.kOPTIONSRequestsMatched = "OPTIONS Requests Matched"
		self.k5xxResponsesProcessed = "5xx Responses Processed"
		self.kMESSAGERequestsSent = "MESSAGE Requests Sent"
		self.kUPDATERequestsSent = "UPDATE Requests Sent"
		self.kAutoBYERequestsProcessed = "Auto BYE Requests Processed"
		self.kUPDATERequestsSent2 = "UPDATE Requests Sent2"
		self.kAutoUPDATERequestsRetransmitted = "Auto UPDATE Requests Retransmitted"
		self.k2xxResponsesParsed = "2xx Responses Parsed"
		self.kCallswithAuthenticationRequiredsec = "Calls with Authentication Required /sec"
		self.kAutoUNKNOWNRequestsRetransmitted = "Auto UNKNOWN Requests Retransmitted"
		self.kReceivedSessionRefreshes = "Received Session Refreshes"
		self.kTXSIPMsgLengthMin = "TX SIP Msg Length (Min)"
		self.kACKRequestsRetransmited = "ACK Requests Retransmited"
		self.kExtractVariablesErrors = "Extract Variables Errors"
		self.kPRACKRequestsMatched = "PRACK Requests Matched"
		self.kAutoUPDATERequestsSent = "Auto UPDATE Requests Sent"
		self.k1xxResponsesParsed = "1xx Responses Parsed"
		self.kRXSIPMsgLengthAvg = "RX SIP Msg Length (Avg)"
		self.k6xxResponsesProcessed = "6xx Responses Processed"
		self.kTXSIPMsgLengthMax = "TX SIP Msg Length (Max)"
		self.kCallswithAuthenticationRequired = "Calls with Authentication Required"
		self.kMESSAGERequestsRetransmitted = "MESSAGE Requests Retransmitted"
		self.k4xxResponsesSent2 = "4xx Responses Sent2"
		self.kAutoBYERequestsSent = "Auto BYE Requests Sent"
		self.kBYERequestsProcessed = "BYE Requests Processed"
		self.kCANCELRequestsProcessed = "CANCEL Requests Processed"
		self.kOPTIONSRequestsProcessed = "OPTIONS Requests Processed"
		self.kAutoREFERRequestsRetransmitted = "Auto REFER Requests Retransmitted"
		self.kSIPSDPGlareConditions = "SIP SDP Glare Conditions"
		self.kAuto3xxResponsesSent = "Auto 3xx Responses Sent"
		self.kSUBSCRIBERequestsSent = "SUBSCRIBE Requests Sent"
		self.kRXSIPMsgLengthMax = "RX SIP Msg Length (Max)"
		self.kUNKNOWNRequestsMatched = "UNKNOWN Requests Matched"
		self.kINFORequestsRetransmitted = "INFO Requests Retransmitted"
		self.k5xxResponsesMatched = "5xx Responses Matched"
		self.kMESSAGERequestsRetransmited = "MESSAGE Requests Retransmited"
		self.kCallsOverIPSecsec = "Calls Over IPSec /sec"
		self.kPRACKRequestsParsed = "PRACK Requests Parsed"
		self.kAutoINFORequestsRetransmitted = "Auto INFO Requests Retransmitted"
		self.kBYERequestsParsed = "BYE Requests Parsed"
		self.kMESSAGERequestsSent2 = "MESSAGE Requests Sent2"
		self.k6xxResponsesParsed = "6xx Responses Parsed"


class StatsNameMediaFlowsVoIPSip(object):
	def __init__(self):
		self.kT38Flows = "T.38 Flows"
		self.kExpectedMediaFlows = "Expected Media Flows"
		self.kExpectedTextFlows = "Expected Text Flows"
		self.kMediaFlows = "Media Flows"
		self.kExpectedT38Flows = "Expected T.38 Flows"
		self.kTextFlows = "Text Flows"
		self.kVideoFlows = "Video Flows"
		self.kAudioFlows = "Audio Flows"
		self.kExpectedAudioFlows = "Expected Audio Flows"
		self.kExpectedVideoFlows = "Expected Video Flows"


class StatsNameVideoRTPVoIPSip(object):
	def __init__(self):
		self.kVideoSuccessfulRecords = "Video Successful Records"
		self.kVideoFailedRecords = "Video Failed Records"
		self.kVideoConferenceVqmonEnabledPorts = "Video Conference Vqmon Enabled Ports"
		self.kVideoConferenceVqmonDisabledPorts = "Video Conference Vqmon Disabled Ports"
		self.kVideoSuccessfulPlaybacks = "Video Successful Playbacks"
		self.kVideoFailedPlaybacks = "Video Failed Playbacks"


class StatsNameRTPVoIPSip(object):
	def __init__(self):
		self.kAMRRateChangeRecv = "AMR Rate Change Recv"
		self.kMFsMatched = "MFs Matched"
		self.kTotalintervalswithMOSbetween1and2 = "Total intervals with MOS between 1 and 2"
		self.kInterarrivalJitterMaxus = "Interarrival Jitter (Max) [us]"
		self.kG729AnnexAwithAnnexB = "G.729 Annex A with Annex B"
		self.kConsecutiveLostofSixtoTenPacketsSequences = "Consecutive Lost of Six to Ten Packets Sequences"
		self.kCallswithfairMOS335 = "Calls with fair MOS (3 - 3.5)"
		self.k10ms = "10 ms"
		self.kCustomTonesDetected = "Custom Tones Detected"
		self.kTXjittergreaterthen1ms = "TX jitter greater then 1ms"
		self.kEVRCFrame18 = "EVRC Frame 1/8"
		self.kMDIDFAvgus = "MDI DF (Avg) [us]"
		self.kFailedPlaybacks = "Failed Playbacks"
		self.kCustomToneDetectionTimeout = "Custom Tone Detection Timeout"
		self.kCallswithexcellentMOS445 = "Calls with excellent MOS (4 - 4.5)"
		self.kG729 = "G.729"
		self.kIntervalswithMOSbetween3and35 = "Intervals with MOS between 3 and 3.5"
		self.kSuccessfulPlaybacks = "Successful Playbacks"
		self.kEVRCFrameBlank = "EVRC Frame Blank"
		self.kRTPOneWayDelayMaxus = "RTP One Way Delay (Max) [us]"
		self.kRTPBytesSent = "RTP Bytes Sent"
		self.kMFsDetected = "MFs Detected"
		self.kAudioStreamswithptimegreaterthan40ms = "Audio Streams with ptime greater than 40 ms"
		self.kGoodDTMFSequencesDetected = "Good DTMF Sequences Detected"
		self.kG72624kbps = "G.726 24 kbps"
		self.kPoorcallswithMOSbetween2and3 = "Poor - calls with MOS between 2 and 3"
		self.kOneWayDelayMaxus = "One Way Delay (Max) [us]"
		self.kRFactorInstantWorst = "R-Factor Instant Worst"
		self.kGoodcallswithMOSbetween35and4 = "Good - calls with MOS between 3.5 and 4"
		self.k2833Tones = "2833 Tones"
		self.kRTCPPacketArrivalTimeAvgms = "RTCP Packet Arrival Time (Avg) [ms]"
		self.kIntervalswithMOSbetween4and45 = "Intervals with MOS between 4 and 4.5"
		self.kRTPPacketLossCorrelation = "RTP Packet Loss Correlation"
		self.kRTPConsecutiveLostofTwoorThreePacketsSequences = "RTP Consecutive Lost of Two or Three Packets Sequences"
		self.kTimeoutPathConfirmations = "Timeout Path Confirmations"
		self.kTotalintervalswithMOSbetween2and3 = "Total intervals with MOS between 2 and 3"
		self.kAMRFqiZero = "AMR Fqi Zero"
		self.kPacketswithDelayVariationJitterUpTo20ms = "Packets with Delay Variation Jitter Up To 20ms"
		self.kIntervalswithbadMOS12 = "Intervals with bad MOS (1 - 2)"
		self.kInterarrivalJitterAvgus = "Interarrival Jitter (Avg) [us]"
		self.kPacketsSent = "Packets Sent"
		self.kDelayVariationJitterMaxus = "Delay Variation Jitter (Max) [us]"
		self.kRTPDuplicatePacketsReceived = "RTP Duplicate Packets Received"
		self.kBadDTMFSequencesDetected = "Bad DTMF Sequences Detected"
		self.kEVRCFrame14 = "EVRC Frame 1/4"
		self.kG711uLaw = "G.711 u-Law"
		self.kRTPPacketDuplicatePercentage = "RTP Packet Duplicate Percentage [%]"
		self.kPacketswithDelayVariationJitterUpTo3ms = "Packets with Delay Variation Jitter Up To 3ms"
		self.kMOSWorst = "MOS Worst"
		self.kPacketsReceived = "Packets Received"
		self.kMOSPerCallbetween35and4 = "MOS Per Call between 3.5 and 4"
		self.kAMRNoChange = "AMR No Change"
		self.kPartialPathConfirmationChannels = "Partial Path Confirmation Channels"
		self.kRTCPPacketErrorsReceived = "RTCP Packet Errors Received"
		self.kRTPFatalErrors = "RTP Fatal Errors"
		self.kMDIMLRAvgpacketss = "MDI MLR (Avg) [packets/s]"
		self.kG729AnnexB = "G.729 Annex B"
		self.kAMRChangeAfter3 = "AMR Change After 3"
		self.kMaximumConsecutiveLostPackets = "Maximum Consecutive Lost Packets"
		self.kIntervalswithgoodMOS354 = "Intervals with good MOS (3.5 - 4)"
		self.kMOSPerCallbetween3and35 = "MOS Per Call between 3 and 3.5"
		self.kRTPPacketErrorsReceived = "RTP Packet Errors Received"
		self.kBadMFSequencesDetected = "Bad MF Sequences Detected"
		self.kG722 = "G.722"
		self.kDTMFsMatched = "DTMFs Matched"
		self.kPacketswithDelayVariationJitterUpTo5ms = "Packets with Delay Variation Jitter Up To 5ms"
		self.kILBC = "ILBC"
		self.kPathConfirmationTimeoutChannels = "Path Confirmation Timeout Channels"
		self.kDelayVariationJitterMaxus3 = "Delay Variation Jitter (Max) [us]3"
		self.kDelayVariationJitterMaxus2 = "Delay Variation Jitter (Max) [us]2"
		self.k2833Events = "2833 Events"
		self.kTotalcallswithMOSbetween35and4 = "Total calls with MOS between 3.5 and 4"
		self.kTotalintervalswithMOSbetween35and4 = "Total intervals with MOS between 3.5 and 4"
		self.kEVS = "EVS"
		self.kEVRCA = "EVRCA"
		self.kCallswithpoorMOS23 = "Calls with poor MOS (2 - 3)"
		self.kEVRCB = "EVRCB"
		self.kRTPConsecutiveLostofFourorFivePacketsSequences = "RTP Consecutive Lost of Four or Five Packets Sequences"
		self.kMFSequencesSent = "MF Sequences Sent"
		self.kSuccessfulRecords = "Successful Records"
		self.kTimeoutPathConfirmationChannels = "Timeout Path Confirmation Channels"
		self.kFunctionsDisconnected = "Functions Disconnected"
		self.kAudioStreamswithptime30ms = "Audio Streams with ptime 30 ms"
		self.kPacketSizeMismatched = "Packet Size Mismatched"
		self.kMDIDFMaxus = "MDI DF (Max) [us]"
		self.kExcellentcallswithMOSbetween4and45 = "Excellent - calls with MOS between 4 and 4.5"
		self.kConsecutiveLostofOnePacketSequences = "Consecutive Lost of One Packet Sequences"
		self.kTXJitterns = "TX Jitter [ns]"
		self.kThroughputOutboundKbps = "Throughput Outbound (Kbps)"
		self.kAMR = "AMR"
		self.kDTMFsDetected = "DTMFs Detected"
		self.kAMRChangeAfter2 = "AMR Change After 2"
		self.kRTPMaximumConsecutiveLostPackets = "RTP Maximum Consecutive Lost Packets"
		self.k30ms = "30 ms"
		self.kG723153kbps = "G.723.1 5.3 kbps"
		self.kTimeoutPathConfirmationSequences = "Timeout Path Confirmation Sequences"
		self.kMOSBest2 = "MOS Best2"
		self.kAMRSIDRx = "AMR SID Rx"
		self.kRTPPacketErrorsPercentage = "RTP Packet Errors Percentage [%]"
		self.kRTPBytesLostPercentage = "RTP Bytes Lost Percentage [%]"
		self.kPacketErrorsReceived = "Packet Errors Received"
		self.kSuccessfulPathConfirmations = "Successful Path Confirmations"
		self.kTotalintervalswithMOSbetween3and35 = "Total intervals with MOS between 3 and 3.5"
		self.kRTCPPacketsReceived = "RTCP Packets Received"
		self.kRTCPRxPacketsDropped = "RTCP Rx Packets Dropped"
		self.kFaircallswithMOSbetween3and35 = "Fair - calls with MOS between 3 and 3.5"
		self.kConsecutiveLostofTwoorThreePacketsSequences = "Consecutive Lost of Two or Three Packets Sequences"
		self.kRFactorInstantAvg = "R-Factor Instant (Avg)"
		self.kPacketswithDelayVariationJitterUpTo40ms = "Packets with Delay Variation Jitter Up To 40ms"
		self.kPacketswithDelayVariationJitterUpTo10ms = "Packets with Delay Variation Jitter Up To 10ms"
		self.kCustomTonesMatched = "Custom Tones Matched"
		self.kEVRCFrameHalfRate = "EVRC Frame Half Rate"
		self.kRTPMisorderedPacketsReceived = "RTP Misordered Packets Received"
		self.kAMRSIDTx = "AMR SID Tx"
		self.kAMRChangeAfter4Plus = "AMR Change After 4 Plus"
		self.kTotalcallswithMOSbetween2and3 = "Total calls with MOS between 2 and 3"
		self.kMOSInstantWorst = "MOS Instant Worst"
		self.kRTCPPacketSentSizeAvg = "RTCP Packet Sent Size (Avg)"
		self.kEVRCNW = "EVRCNW"
		self.kMDIMLRMaxpacketss = "MDI MLR (Max) [packets/s]"
		self.kG729AnnexA = "G.729 Annex A"
		self.kDTMFSequencesSent = "DTMF Sequences Sent"
		self.kFailedRecords = "Failed Records"
		self.kPacketLossPercentage = "Packet Loss Percentage [%]"
		self.kLatePacketsReceived = "Late Packets Received"
		self.kPacketMisorderPercentage = "Packet Misorder Percentage [%]"
		self.kAMRIllegalFrametype = "AMR Illegal Frametype"
		self.kCustomTonesNotMatched = "Custom Tones Not Matched"
		self.kIntervalswithMOSbetween35and4 = "Intervals with MOS between 3.5 and 4"
		self.kAudioStreamswithptime5ms = "Audio Streams with ptime 5 ms"
		self.kDelayDegradation = "Delay Degradation"
		self.kEVRCWB = "EVRCWB"
		self.k5ms = "5 ms"
		self.kMFDigitsSent = "MF Digits Sent"
		self.kTotalcallswithMOSbetween1and2 = "Total calls with MOS between 1 and 2"
		self.kRTPOneWayDelayAvgus = "RTP One Way Delay (Avg) [us]"
		self.kRTPPacketsSent = "RTP Packets Sent"
		self.kRTPPacketLossPercentage = "RTP Packet Loss Percentage [%]"
		self.kMOSInstantBest = "MOS Instant Best"
		self.kRTPConsecutiveLostofElevenorMorePacketsSequences = "RTP Consecutive Lost of Eleven or More Packets Sequences"
		self.kMOSPerCallbetween2and3 = "MOS Per Call between 2 and 3"
		self.kDTMFsNotMatched = "DTMFs Not Matched"
		self.k40ms = "40 ms"
		self.kSpeechVqmonDisabledPorts = "Speech Vqmon Disabled Ports"
		self.kRTPSkippedFunctions = "RTP Skipped Functions"
		self.kTotalcallswithMOSbetween3and35 = "Total calls with MOS between 3 and 3.5"
		self.kJitterDegradation = "Jitter Degradation"
		self.kMOSPerCallBest = "MOS Per Call Best"
		self.kSpeechVqmonEnabledPorts = "Speech Vqmon Enabled Ports"
		self.kBytesLostPercentage = "Bytes Lost Percentage [%]"
		self.kCustomTonesSent = "Custom Tones Sent"
		self.kPacketLossCorrelation = "Packet Loss Correlation"
		self.kG711ALaw = "G.711 A-Law"
		self.kAMRInvalidMode = "AMR Invalid Mode"
		self.kRTCPPacketReceivedSizeAvg = "RTCP Packet Received Size (Avg)"
		self.kPacketswithDelayVariationJitterUpTo1ms = "Packets with Delay Variation Jitter Up To 1ms"
		self.kDelayVariationJitterAvgus = "Delay Variation Jitter (Avg) [us]"
		self.kRTCPPacketsSent = "RTCP Packets Sent"
		self.kMOSPerCallbetween4and45 = "MOS Per Call between 4 and 4.5"
		self.kIntervalswithexcelentMOS445 = "Intervals with excelent MOS (4 - 4.5)"
		self.kEVRCFrameFullRate = "EVRC Frame Full Rate"
		self.kAMRWrongChange = "AMR Wrong Change"
		self.kMisorderedPacketsReceived = "Misordered Packets Received"
		self.kNoPathConfirmationChannels = "No Path Confirmation Channels"
		self.kG72616kbps = "G.726 16 kbps"
		self.kMismatchPathConfirmationSequences = "Mismatch Path Confirmation Sequences"
		self.kPacketswithDelayVariationJitterMoreThan40ms = "Packets with Delay Variation Jitter More Than 40ms"
		self.kConsecutiveLostofFourorFivePacketsSequences = "Consecutive Lost of Four or Five Packets Sequences"
		self.kOPUS = "OPUS"
		self.kMOSPerCallbetween1and2 = "MOS Per Call between 1 and 2"
		self.kTotalintervalswithMOSbetween4and45 = "Total intervals with MOS between 4 and 4.5"
		self.kPacketCodecMismatched = "Packet Codec Mismatched"
		self.kIntervalswithfairMOS335 = "Intervals with fair MOS (3 - 3.5)"
		self.kMOSInstantAvg = "MOS Instant (Avg)"
		self.kLossDegradation = "Loss Degradation"
		self.kBytesReceived = "Bytes Received"
		self.kCallswithbadMOS12 = "Calls with bad MOS (1 - 2)"
		self.kRTPLatePacketsReceived = "RTP Late Packets Received"
		self.kRTPPacketCodecMismatched = "RTP Packet Codec Mismatched"
		self.kGoodMFSequencesDetected = "Good MF Sequences Detected"
		self.kPacketDuplicatePercentage = "Packet Duplicate Percentage [%]"
		self.kTotalcallswithMOSbetween4and45 = "Total calls with MOS between 4 and 4.5"
		self.kRTPLostPackets = "RTP Lost Packets"
		self.kOther = "Other"
		self.kRTPPacketMisorderPercentage = "RTP Packet Misorder Percentage [%]"
		self.kLostPackets = "Lost Packets"
		self.kG72632kbps = "G.726 32 kbps"
		self.k20ms = "20 ms"
		self.kAMRRateChangeSent = "AMR Rate Change Sent"
		self.kG723163kbps = "G.723.1 6.3 kbps"
		self.kRTPBytesReceived = "RTP Bytes Received"
		self.kTxPacketsDropped = "Tx Packets Dropped"
		self.kAudioConcurrentFlows = "Audio Concurrent Flows"
		self.kMOSWorst2 = "MOS Worst2"
		self.kMOSBest = "MOS Best"
		self.kRTPConsecutiveLostofOnePacketSequences = "RTP Consecutive Lost of One Packet Sequences"
		self.kBadcallswithMOSbetween1and2 = "Bad - calls with MOS between 1 and 2"
		self.kCodecDegradation = "Codec Degradation"
		self.kAudioStreamswithptime40ms = "Audio Streams with ptime 40 ms"
		self.kAudioStreamswithptime10ms = "Audio Streams with ptime 10 ms"
		self.kRTPPayloadBytesReceived = "RTP Payload Bytes Received"
		self.kCustomTonesSequencesSent = "Custom Tones Sequences Sent"
		self.kDTMFDetectionTimeout = "DTMF Detection Timeout"
		self.kConsecutiveLostofElevenorMorePacketsSequences = "Consecutive Lost of Eleven or More Packets Sequences"
		self.kIntervalswithpoorMOS23 = "Intervals with poor MOS (2 - 3)"
		self.kAudioStreamswithptime20ms = "Audio Streams with ptime 20 ms"
		self.kRTPTxPacketsDropped = "RTP Tx Packets Dropped"
		self.kRTPRxPacketsDropped = "RTP Rx Packets Dropped"
		self.kPacketErrorsPercentage = "Packet Errors Percentage [%]"
		self.kIntervalswithMOSbetween1and2 = "Intervals with MOS between 1 and 2"
		self.k40ms = ">40 ms"
		self.kBytesSent = "Bytes Sent"
		self.kMFDetectionTimeout = "MF Detection Timeout"
		self.kRTPPacketSizeMismatched = "RTP Packet Size Mismatched"
		self.kOneWayDelayAvgus = "One Way Delay (Avg) [us]"
		self.kMOSPerCallWorst = "MOS Per Call Worst"
		self.kRFactorInstantBest = "R-Factor Instant Best"
		self.kRTPPacketsReceived = "RTP Packets Received"
		self.kMOSPerCallAvg = "MOS Per Call (Avg)"
		self.kSuccessfulPathConfirmationSequences = "Successful Path Confirmation Sequences"
		self.kMFsNotMatched = "MFs Not Matched"
		self.kDuplicatePacketsReceived = "Duplicate Packets Received"
		self.kCallswithgoodMOS354 = "Calls with good MOS (3.5 - 4)"
		self.kRTPConsecutiveLostofSixtoTenPacketsSequences = "RTP Consecutive Lost of Six to Ten Packets Sequences"
		self.kThroughputInboundKbps = "Throughput Inbound (Kbps)"
		self.kDTMFDigitsSent = "DTMF Digits Sent"
		self.kRTCPPacketTransmissionTimeAvgms = "RTCP Packet Transmission Time (Avg) [ms]"
		self.kInterarrivalJitterMaxus3 = "Interarrival Jitter (Max) [us]3"
		self.kInterarrivalJitterMaxus2 = "Interarrival Jitter (Max) [us]2"
		self.kG72640kbps = "G.726 40 kbps"
		self.kMismatchPathConfirmations = "Mismatch Path Confirmations"
		self.kIntervalswithMOSbetween2and3 = "Intervals with MOS between 2 and 3"
		self.kRecencyDegradation = "Recency Degradation"


class StatsNameBHCMVoIPSip(object):
	def __init__(self):
		self.kBHCC = "BHCC"
		self.kBHCA = "BHCA"


class StatsNameVoIPPeer(object):
	def __init__(self):
		self.kSSLAlertsSentunsupported_certificate = "SSL Alerts Sent (unsupported_certificate)"
		self.kSSLAlertsReceiveddecryption_failed = "SSL Alerts Received (decryption_failed)"
		self.kTCPConnectionsinFINWAIT1State = "TCP Connections in FIN-WAIT-1 State"
		self.kTCPConnectionsinLASTACKState = "TCP Connections in LAST-ACK State"
		self.kSSLAlertsSentcertificate_revoked = "SSL Alerts Sent (certificate_revoked)"
		self.kServerHelloReceived = "Server Hello Received"
		self.kSSLAlertsReceivedbad_record_mac = "SSL Alerts Received (bad_record_mac)"
		self.kSSLAlertsSentcertificate_expired = "SSL Alerts Sent (certificate_expired)"
		self.kClientHelloReceived = "Client Hello Received"
		self.kSSLBytesReceived = "SSL Bytes Received"
		self.kTCPRetries = "TCP Retries"
		self.kSSLAlertsSentdecode_error = "SSL Alerts Sent (decode_error)"
		self.kSSLAlertsReceiveduser_canceled = "SSL Alerts Received (user_canceled)"
		self.kSSLErrorsSentnocipher = "SSL Errors Sent (no cipher)"
		self.kTCPFINACKReceived = "TCP FIN-ACK Received"
		self.kTCPConnectionsinCLOSESTATE = "TCP Connections in CLOSE STATE"
		self.kTCPConnectionsinLISTENINGState = "TCP Connections in LISTENING State"
		self.kSSLErrorsSentbadcertificate = "SSL Errors Sent (bad certificate)"
		self.kTCPConnectionsinESTABLISHEDState = "TCP Connections in ESTABLISHED State"
		self.kSSLErrorsSent = "SSL Errors Sent"
		self.kSSLAlertsSentno_certificate = "SSL Alerts Sent (no_certificate)"
		self.kTCPConnectionsinSYNSENTState = "TCP Connections in SYN-SENT State"
		self.kSSLAlertsSentillegal_parameter = "SSL Alerts Sent (illegal_parameter)"
		self.kSSLSessionReuseFailed = "SSL Session Reuse Failed"
		self.kSSLAlertsReceivedunknown_ca = "SSL Alerts Received (unknown_ca)"
		self.kSSLAlertsReceivedillegal_parameter = "SSL Alerts Received (illegal_parameter)"
		self.kTCPFINSent = "TCP FIN Sent"
		self.kSSLAlertsReceivedprotocol_version = "SSL Alerts Received (protocol_version)"
		self.kHelloRequestsReceived = "Hello Requests Received"
		self.kSSLSessionReuseSuccess = "SSL Session Reuse Success"
		self.kTCPResetsReceived = "TCP Resets Received"
		self.kHelloRequestsSent = "Hello Requests Sent"
		self.kTCPConnectionsinCLOSINGState = "TCP Connections in CLOSING State"
		self.kSSLTxRateKbps = "SSL Tx Rate (Kbps)"
		self.kTCPFINACKSent = "TCP FIN-ACK Sent"
		self.kTCPInternallyAbortedConnections = "TCP Internally Aborted Connections"
		self.kSSLAlertsReceivedrecord_overflow = "SSL Alerts Received (record_overflow)"
		self.kSSLAlertsReceivedcertificate_expired = "SSL Alerts Received (certificate_expired)"
		self.kSSLAlertsSenthandshake_failure = "SSL Alerts Sent (handshake_failure)"
		self.kSSLNegotiationFinishedSuccessfully = "SSL Negotiation Finished Successfully"
		self.kTCPListenQueueDrops = "TCP Listen Queue Drops"
		self.kTCPSYNACKSent = "TCP SYN-ACK Sent"
		self.kSSLAlertsReceivedexport_restriction = "SSL Alerts Received (export_restriction)"
		self.kSSLAlertsSentno_renegotiation = "SSL Alerts Sent (no_renegotiation)"
		self.kSSLThroughputBytes = "SSL Throughput Bytes"
		self.kTCPConnectionsinFINWAIT2State = "TCP Connections in FIN-WAIT-2 State"
		self.kTCPSYN_SYNACKReceived = "TCP SYN_SYN-ACK Received"
		self.kSSLErrorsReceivedundefinederror = "SSL Errors Received (undefined error)"
		self.kTCPConnectionsinCLOSEWAITState = "TCP Connections in CLOSE-WAIT State"
		self.kTCPSYNFailed = "TCP SYN Failed"
		self.kSSLAlertsSentunknown_ca = "SSL Alerts Sent (unknown_ca)"
		self.kSSLRxRateKbps = "SSL Rx Rate (Kbps)"
		self.kSSLErrorsReceivedunsupportedcertificate = "SSL Errors Received (unsupported certificate)"
		self.kSSLAlertsReceivedinternal_error = "SSL Alerts Received (internal_error)"
		self.kSSLAlertsSentrecord_overflow = "SSL Alerts Sent (record_overflow)"
		self.kSSLAlertsSentaccess_denied = "SSL Alerts Sent (access_denied)"
		self.kSSLAlertsSent = "SSL Alerts Sent"
		self.kSSLAlertsSentbad_record_mac = "SSL Alerts Sent (bad_record_mac)"
		self.kSSLErrorsSentunsupportedcertificate = "SSL Errors Sent (unsupported certificate)"
		self.kTCPConnectionsinSYNRECEIVEDState = "TCP Connections in SYN-RECEIVED State"
		self.kSSLAlertsReceivedunexpected_message = "SSL Alerts Received (unexpected_message)"
		self.kTCPSYNSent = "TCP SYN Sent"
		self.kSSLApplicationDataBytes = "SSL Application Data Bytes"
		self.kSSLErrorsSentnocertificate = "SSL Errors Sent (no certificate)"
		self.kSSLAlertsSentbad_certificate = "SSL Alerts Sent (bad_certificate)"
		self.kTCPAcceptQueueEntries = "TCP Accept Queue Entries"
		self.kTCPTimeouts = "TCP Timeouts"
		self.kSSLAlertsReceivedaccess_denied = "SSL Alerts Received (access_denied)"
		self.kSSLAlertsReceivedclose_notify = "SSL Alerts Received (close_notify)"
		self.kSSLAlertsReceivedinsufficient_security = "SSL Alerts Received (insufficient_security)"
		self.kSSLAlertsSentuser_canceled = "SSL Alerts Sent (user_canceled)"
		self.kSSLThroughputKbps = "SSL Throughput (Kbps)"
		self.kSSLAlertsReceivedbad_certificate = "SSL Alerts Received (bad_certificate)"
		self.kSSLErrorsReceivednocertificate = "SSL Errors Received (no certificate)"
		self.kSSLErrorsReceivedbadcertificate = "SSL Errors Received (bad certificate)"
		self.kSSLAlertsSentdecryption_failed = "SSL Alerts Sent (decryption_failed)"
		self.kSSLErrorsReceived = "SSL Errors Received"
		self.kSSLAlertsReceivedcertificate_unknown = "SSL Alerts Received (certificate_unknown)"
		self.kTCPConnectionsinTIMEWAITState = "TCP Connections in TIME-WAIT State"
		self.kSSLAlertsSentdecompression_failure = "SSL Alerts Sent (decompression_failure)"
		self.kTCPConnectionRequestsFailed = "TCP Connection Requests Failed"
		self.kSSLAlertsSentdecrypt_error = "SSL Alerts Sent (decrypt_error)"
		self.kSSLConcurrentSessions = "SSL Concurrent Sessions"
		self.kSSLAlertsReceivedno_renegotiation = "SSL Alerts Received (no_renegotiation)"
		self.kSSLErrorsReceivednocipher = "SSL Errors Received (no cipher)"
		self.kSSLAlertsReceivedhandshake_failure = "SSL Alerts Received (handshake_failure)"
		self.kSSLAlertsSentinternal_error = "SSL Alerts Sent (internal_error)"
		self.kSSLAlertsSentunexpected_message = "SSL Alerts Sent (unexpected_message)"
		self.kSSLErrorsSentundefinederror = "SSL Errors Sent (undefined error)"
		self.kTCPConnectionsEstablished = "TCP Connections Established"
		self.kSSLAlertsSentexport_restriction = "SSL Alerts Sent (export_restriction)"
		self.kSSLAlertsReceiveddecode_error = "SSL Alerts Received (decode_error)"
		self.kServerHelloSent = "Server Hello Sent"
		self.kTCPResetsSent = "TCP Resets Sent"
		self.kSSLAlertsSentprotocol_version = "SSL Alerts Sent (protocol_version)"
		self.kSSLAlertsReceivedcertificate_revoked = "SSL Alerts Received (certificate_revoked)"
		self.kSSLAlertsSentinsufficient_security = "SSL Alerts Sent (insufficient_security)"
		self.kSSLAlertsReceiveddecompression_failure = "SSL Alerts Received (decompression_failure)"
		self.kClientHelloSent = "Client Hello Sent"
		self.kSSLAlertsReceivedunsupported_certificate = "SSL Alerts Received (unsupported_certificate)"
		self.kSSLBytesSent = "SSL Bytes Sent"
		self.kSSLAlertsSentcertificate_unknown = "SSL Alerts Sent (certificate_unknown)"
		self.kSSLAlertsReceivedno_certificate = "SSL Alerts Received (no_certificate)"
		self.kSSLAlertsSentclose_notify = "SSL Alerts Sent (close_notify)"
		self.kSSLAlertsReceiveddecrypt_error = "SSL Alerts Received (decrypt_error)"
		self.kSSLAlertsReceived = "SSL Alerts Received"
		self.kTCPFINReceived = "TCP FIN Received"


class StatsNameErrorsVoIPSip(object):
	def __init__(self):
		self.kTimeoutErrors = "Timeout Errors"
		self.kRTPErrors = "RTP Errors"
		self.kInternalErrors = "Internal Errors"
		self.kTransportErrors = "Transport Errors"
		self.kTriggerErrors = "Trigger Errors"


class StatsNameSignalingVoIPSip(object):
	def __init__(self):
		self.kPostPickupDelayAvgms = "Post-Pickup Delay (Avg) [ms]"
		self.kMediaDelayRXMaxms = "Media Delay RX (Max) [ms]"
		self.kInterruptedCalls = "Interrupted Calls"
		self.kAttemptedCalls = "Attempted Calls"
		self.kSuccessfulRegistrations = "Successful Registrations"
		self.kAttemptedRegistrations = "Attempted Registrations"
		self.kFailedReceivedCalls = "Failed Received Calls"
		self.kAttemptedCallssec = "Attempted Calls /sec"
		self.kAttemptedDeRegistrations = "Attempted DeRegistrations"
		self.kTalkTimeAvgms = "Talk Time (Avg) [ms]"
		self.kMediaDelayTXMaxms2 = "Media Delay TX (Max) [ms]2"
		self.kAttemptedRegistrationssec = "Attempted Registrations /sec"
		self.kRegistrationTimeAvgms = "Registration Time (Avg) [ms]"
		self.kSuccessfulDeRegistrationssec = "Successful DeRegistrations /sec"
		self.kMediaDelayRXMaxms2 = "Media Delay RX (Max) [ms]2"
		self.kMediaDelayRXInstantAvgms = "Media Delay RX Instant (Avg) [ms]"
		self.kFailedDeRegistrations = "Failed DeRegistrations"
		self.kPostDialDelayAvgms = "Post Dial Delay (Avg) [ms]"
		self.kAttemptedDeRegistrationssec = "Attempted DeRegistrations /sec"
		self.kAnsweredCalls = "Answered Calls"
		self.kAnsweredCallssec = "Answered Calls /sec"
		self.kMediaDelayTXMinms = "Media Delay TX (Min) [ms]"
		self.kActiveCalls = "Active Calls"
		self.kSuccessfulDeRegistrations = "Successful DeRegistrations"
		self.kDeRegistrationTimeAvgms = "DeRegistration Time (Avg) [ms]"
		self.kMediaDelayRXMinms = "Media Delay RX (Min) [ms]"
		self.kTransferredCalls = "Transferred Calls"
		self.kPostPickupDelayMaxms = "Post-Pickup Delay (Max) [ms]"
		self.kBusyCallssec = "Busy Calls /sec"
		self.kEndCallsInitiated = "End Calls Initiated"
		self.kMediaDelayTXMaxms = "Media Delay TX (Max) [ms]"
		self.kConnectedCallssec = "Connected Calls /sec"
		self.kPostPickupDelayMinms = "Post-Pickup Delay (Min) [ms]"
		self.kMediaDelayTXAvgms = "Media Delay TX (Avg) [ms]"
		self.kReceivedCalls = "Received Calls"
		self.kMediaDelayTXInstantAvgms = "Media Delay TX Instant (Avg) [ms]"
		self.kTransferredCallssec = "Transferred Calls /sec"
		self.kTotalCallDurationAvgms = "Total Call Duration (Avg) [ms]"
		self.kEndCallsCompleted = "End Calls Completed"
		self.kConnectedCalls = "Connected Calls"
		self.kBusyCalls = "Busy Calls"
		self.kEndCallsReceived = "End Calls Received"
		self.kReceivedCallssec = "Received Calls /sec"
		self.kEndCallTimeAvgms = "End Call Time (Avg) [ms]"
		self.kFailedRegistrations = "Failed Registrations"
		self.kPostDialDelayInstantAvgms = "Post Dial Delay Instant (Avg) [ms]"
		self.kRegisteredUsers = "Registered Users"
		self.kFailedAttemptedCalls = "Failed Attempted Calls"
		self.kMediaDelayRXAvgms = "Media Delay RX (Avg) [ms]"
		self.kSuccessfulRegistrationssec = "Successful Registrations /sec"
		self.kPostPickupDelayMaxms2 = "Post-Pickup Delay (Max) [ms]2"


class StatsNameCPSRateVoIPSip(object):
	def __init__(self):
		self.kCallssecRate = "Calls /sec Rate"


class StatsNameFlowVoIPSip(object):
	def __init__(self):
		self.kUserCounter2Sum = "User Counter 2 (Sum)"
		self.kUserCounter17Avg = "User Counter 17 (Avg)"
		self.kSuccessfulChannels = "Successful Channels"
		self.kUserCounter6Sum = "User Counter 6 (Sum)"
		self.kUserCounter4Sum = "User Counter 4 (Sum)"
		self.kUserCounter7Sum = "User Counter 7 (Sum)"
		self.kUserCounter11Avg = "User Counter 11 (Avg)"
		self.kUserCounter13Avg = "User Counter 13 (Avg)"
		self.kTriggersBytesReceived = "Triggers Bytes Received"
		self.kWarningChannels = "Warning Channels"
		self.kUserCounter11Min = "User Counter 11 (Min)"
		self.kUserCounter18Avg = "User Counter 18 (Avg)"
		self.kUserCounter10Sum = "User Counter 10 (Sum)"
		self.kUserCounter19Avg = "User Counter 19 (Avg)"
		self.kUserCounter11Max = "User Counter 11 (Max)"
		self.kUserCounter1Max = "User Counter 1 (Max)"
		self.kUserCounter12Avg = "User Counter 12 (Avg)"
		self.kUserCounter14Avg = "User Counter 14 (Avg)"
		self.kAbortedChannelLoops = "Aborted Channel Loops"
		self.kTriggersReceived = "Triggers Received"
		self.kUserCounter1Sum = "User Counter 1 (Sum)"
		self.kTriggersBytesSent = "Triggers Bytes Sent"
		self.kUserCounter9Sum = "User Counter 9 (Sum)"
		self.kUserCounter5Sum = "User Counter 5 (Sum)"
		self.kUserCounter8Sum = "User Counter 8 (Sum)"
		self.kUserCounter15Avg = "User Counter 15 (Avg)"
		self.kTotalChannels = "Total Channels"
		self.kUserCounter1Min = "User Counter 1 (Min)"
		self.kUserCounter16Avg = "User Counter 16 (Avg)"
		self.kTotalChannelLoops = "Total Channel Loops"
		self.kFailedChannelLoops = "Failed Channel Loops"
		self.kFailedChannels = "Failed Channels"
		self.kAbortedChannels = "Aborted Channels"
		self.kActiveChannels = "Active Channels"
		self.kActiveCallers = "Active Callers"
		self.kWarningChannelLoops = "Warning Channel Loops"
		self.kSuccessfulChannelLoops = "Successful Channel Loops"
		self.kUserCounter3Sum = "User Counter 3 (Sum)"
		self.kTriggersSent = "Triggers Sent"
		self.kUserCounter20Avg = "User Counter 20 (Avg)"
		self.kInterLoopDurationAvgms = "Inter Loop Duration (Avg) [ms]"


class StatsNameWSWSSConnectionsVoIPSip(object):
	def __init__(self):
		self.kWSWSSConnectionsEstablished = "WS/WSS Connections Established"
		self.kWSWSSConnectionsInitiated = "WS/WSS Connections Initiated"
		self.kWSWSSConnectionsFailed = "WS/WSS Connections Failed"
		self.kWSWSSConnectionsTimeout = "WS/WSS Connections Timeout"


class StatsNameVideoSignalingVoIPSip(object):
	def __init__(self):
		self.kVideoPostPickupDelayMinms = "Video Post-Pickup Delay (Min) [ms]"
		self.kVideoMediaDelayRXMinms = "Video Media Delay RX (Min) [ms]"
		self.kVideoMediaDelayRXMaxms = "Video Media Delay RX (Max) [ms]"
		self.kVideoPostPickupDelayMaxms2 = "Video Post-Pickup Delay (Max) [ms]2"
		self.kVideoPostPickupDelayMaxms = "Video Post-Pickup Delay (Max) [ms]"
		self.kVideoPostPickupDelayAvgms = "Video Post-Pickup Delay (Avg) [ms]"
		self.kVideoMediaDelayTXMaxms2 = "Video Media Delay TX (Max) [ms]2"
		self.kVideoMediaDelayRXMaxms2 = "Video Media Delay RX (Max) [ms]2"
		self.kVideoMediaDelayTXAvgms = "Video Media Delay TX (Avg) [ms]"
		self.kVideoMediaDelayRXAvgms = "Video Media Delay RX (Avg) [ms]"
		self.kVideoMediaDelayTXMinms = "Video Media Delay TX (Min) [ms]"
		self.kVideoMediaDelayTXMaxms = "Video Media Delay TX (Max) [ms]"


class IxActivityVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixActivity):
		super(IxActivityVoIPPeerWrapper, self).__init__(ixActivity)
		self.__ixActivity = ixActivity
		self.secondaryEnableConstraint = ixActivity.secondaryEnableConstraint
		self.protocol = ixActivity.protocol
		self.userIpMapping = ixActivity.userIpMapping
		self.enableConstraint = ixActivity.enableConstraint
		self.agent = PluginVoIPPeerWrapper(ixActivity.agent)
		self.objectivePercent = ixActivity.objectivePercent
		self.constraintValue = ixActivity.constraintValue
		self.customParameters = IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper(ixActivity.customParameters)
		self.timelineId = ixActivity.timelineId
		self.role = ixActivity.role
		self.timeline = IxTimelineProxyVoIPPeerWrapper(ixActivity.timeline)
		self.activeRole = ixActivity.activeRole
		self.type = ixActivity.type
		self.secondaryConstraintValue = ixActivity.secondaryConstraintValue
		self.enable = ixActivity.enable
		self.protocolAndType = ixActivity.protocolAndType
		self.userObjectiveType = ixActivity.userObjectiveType
		self.destinationIpMapping = ixActivity.destinationIpMapping
		self.name = ixActivity.name
		self.secondaryConstraintType = ixActivity.secondaryConstraintType
		self.userObjectiveValue = ixActivity.userObjectiveValue
		self.constraintType = ixActivity.constraintType

	properties = ["secondaryEnableConstraint", "protocol", "userIpMapping", "enableConstraint", "objectivePercent", "constraintValue", "timelineId", "role", "activeRole", "type", "secondaryConstraintValue", "enable", "protocolAndType", "userObjectiveType", "destinationIpMapping", "name", "secondaryConstraintType", "userObjectiveValue", "constraintType", ]

	def __getattribute__(self, name):
		if name in IxActivityVoIPPeerWrapper.properties and super(IxActivityVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxActivityVoIPPeerWrapper, self).__getattribute__("_IxActivityVoIPPeerWrapper__ixActivity"), name)
		else:
			return super(IxActivityVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxActivityVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxActivityVoIPPeerWrapper, self).__getattribute__("_IxActivityVoIPPeerWrapper__ixActivity"), name, value)
			super(IxActivityVoIPPeerWrapper, self).__setattr__(name, value)


class PluginVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, agent):
		super(PluginVoIPPeerWrapper, self).__init__(agent)
		self.__agent = agent
		self.cmdListLoops = agent.cmdListLoops
		self.pm = IxPropertyMap_VoIPVoIPPeerWrapper(agent.pm)
		self.flowPercentage = agent.flowPercentage

	properties = ["cmdListLoops", "flowPercentage", ]

	def __getattribute__(self, name):
		if name in PluginVoIPPeerWrapper.properties and super(PluginVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(PluginVoIPPeerWrapper, self).__getattribute__("_PluginVoIPPeerWrapper__agent"), name)
		else:
			return super(PluginVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(PluginVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(PluginVoIPPeerWrapper, self).__getattribute__("_PluginVoIPPeerWrapper__agent"), name, value)
			super(PluginVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, customParameters):
		super(IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper, self).__init__(customParameters)
		self.__customParameters = customParameters
		self.lpsActiveChannel = customParameters.lpsActiveChannel
		self.talkTime = customParameters.talkTime
		self.lpsTalkTime = customParameters.lpsTalkTime
		self.interCallDuration = customParameters.interCallDuration
		self.cpsOverwriteValueChecked = customParameters.cpsOverwriteValueChecked
		self.lpsChannelsNo = customParameters.lpsChannelsNo
		self.activeUsersNo = customParameters.activeUsersNo
		self.cpsRegisterTime = customParameters.cpsRegisterTime
		self.cpsTotalChannelsNo = customParameters.cpsTotalChannelsNo
		self.lpsObjectiveValue = customParameters.lpsObjectiveValue
		self.lpsInterLoopDuration = customParameters.lpsInterLoopDuration
		self.cpsOverheadTime = customParameters.cpsOverheadTime
		self.activeUsersChannel = customParameters.activeUsersChannel
		self.activeUsersObjectiveValue = customParameters.activeUsersObjectiveValue
		self.cpsTotalChannelsChecked = customParameters.cpsTotalChannelsChecked
		self.cpsOverwriteValue = customParameters.cpsOverwriteValue
		self.cpsInterCallDuration = customParameters.cpsInterCallDuration
		self.lpsOverheadTime = customParameters.lpsOverheadTime
		self.lpsType = customParameters.lpsType
		self.callTeardownTime = customParameters.callTeardownTime
		self.bhcaObjectiveValue = customParameters.bhcaObjectiveValue
		self.cpsSplitTimeline = customParameters.cpsSplitTimeline
		self.activeUsersTalkTime = customParameters.activeUsersTalkTime
		self.cpsObjectiveValue = customParameters.cpsObjectiveValue
		self.cpsType = customParameters.cpsType
		self.cpsTalkTime = customParameters.cpsTalkTime
		self.bhcaType = customParameters.bhcaType
		self.callSetupTime = customParameters.callSetupTime
		self.channelsNo = customParameters.channelsNo
		self.cpsChannelsNo = customParameters.cpsChannelsNo

	properties = ["lpsActiveChannel", "talkTime", "lpsTalkTime", "interCallDuration", "cpsOverwriteValueChecked", "lpsChannelsNo", "activeUsersNo", "cpsRegisterTime", "cpsTotalChannelsNo", "lpsObjectiveValue", "lpsInterLoopDuration", "cpsOverheadTime", "activeUsersChannel", "activeUsersObjectiveValue", "cpsTotalChannelsChecked", "cpsOverwriteValue", "cpsInterCallDuration", "lpsOverheadTime", "lpsType", "callTeardownTime", "bhcaObjectiveValue", "cpsSplitTimeline", "activeUsersTalkTime", "cpsObjectiveValue", "cpsType", "cpsTalkTime", "bhcaType", "callSetupTime", "channelsNo", "cpsChannelsNo", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper.properties and super(IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper__customParameters"), name)
		else:
			return super(IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper__customParameters"), name, value)
			super(IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper, self).__setattr__(name, value)


class IxTimelineProxyVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, timeline):
		super(IxTimelineProxyVoIPPeerWrapper, self).__init__(timeline)
		self.__timeline = timeline
		self.iterations = timeline.iterations
		self.rampUpType = timeline.rampUpType
		self.rampUpValue = timeline.rampUpValue
		self.rampUpTime = timeline.rampUpTime
		self.rampDownTime = timeline.rampDownTime
		self.standbyTime = timeline.standbyTime
		self.rampDownValue = timeline.rampDownValue
		self.rampUpInterval = timeline.rampUpInterval
		self.offlineTime = timeline.offlineTime
		self.sustainTime = timeline.sustainTime
		self.name = timeline.name
		self.timelineType = timeline.timelineType

	properties = ["iterations", "rampUpType", "rampUpValue", "rampUpTime", "rampDownTime", "standbyTime", "rampDownValue", "rampUpInterval", "offlineTime", "sustainTime", "name", "timelineType", ]

	def __getattribute__(self, name):
		if name in IxTimelineProxyVoIPPeerWrapper.properties and super(IxTimelineProxyVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxTimelineProxyVoIPPeerWrapper, self).__getattribute__("_IxTimelineProxyVoIPPeerWrapper__timeline"), name)
		else:
			return super(IxTimelineProxyVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxTimelineProxyVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxTimelineProxyVoIPPeerWrapper, self).__getattribute__("_IxTimelineProxyVoIPPeerWrapper__timeline"), name, value)
			super(IxTimelineProxyVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyMap_VoIPVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		super(IxPropertyMap_VoIPVoIPPeerWrapper, self).__init__(pm)
		self.__pm = pm
		self.httpSettings = IxPropertyClass_HttpSettingsVoIPPeerWrapper(pm.httpSettings)
		self.customActivityLinkSettings = IxPropertyClass_ixCustomActivityParametersVoIPPeerWrapper(pm.customActivityLinkSettings)
		self.editContact = IxPropertyClass_EditContactVoIPPeerWrapper(pm.editContact)
		self.scenarioSettings = IxPropertyClass_ScenarioSettingsVoIPPeerWrapper(pm.scenarioSettings)
		self.audioSettings = IxPropertyClass_AudioSettingsVoIPPeerWrapper(pm.audioSettings)
		self.szPluginVersion = pm.szPluginVersion
		self.iceOptions = IxPropertyClass_IceOptionsVoIPPeerWrapper(pm.iceOptions)
		self.advancedSettings = IxPropertyClass_AdvancedSettingsVoIPPeerWrapper(pm.advancedSettings)
		self.codecSettings = IxPropertyClass_CodecSettingsVoIPPeerWrapper(pm.codecSettings)
		self.signalingSettings = IxPropertyClass_SignalingSettingsVoIPPeerWrapper(pm.signalingSettings)
		self.smsSettings = IxPropertyClass_SMSSettingsVoIPPeerWrapper(pm.smsSettings)
		self.ceCommands = IxPropertyGroupSequence_VoIP_ceCommandsVoIPPeerWrapper(pm)
		self.videoSettings = IxPropertyClass_VideoSettingsVoIPPeerWrapper(pm.videoSettings)
		self.t30Parameters = IxPropertyClass_T30ParametersVoIPPeerWrapper(pm.t30Parameters)
		self.rtcpSettings = IxPropertyClass_RTCPSettingsVoIPPeerWrapper(pm.rtcpSettings)
		self.executionSettings = IxPropertyClass_ExecutionSettingsVoIPPeerWrapper(pm.executionSettings)
		self.textSettings = IxPropertyClass_TextSettingsVoIPPeerWrapper(pm.textSettings)
		self.smsAddressOriginator = IxPropertyClass_SMSAddressVoIPPeerWrapper(pm.smsAddressOriginator)
		self.ccProfileType = pm.ccProfileType
		self.ccAgentWrapUpTime = pm.ccAgentWrapUpTime
		self.advancedVideo = IxPropertyClass_AdvancedVideoSettingsVoIPPeerWrapper(pm.advancedVideo)
		self.otherSettings = IxPropertyClass_OtherSettingsVoIPPeerWrapper(pm.otherSettings)
		self.dtlsOptions = IxPropertyClass_DtlsOptionsVoIPPeerWrapper(pm.dtlsOptions)
		self.CCProfileName = pm.CCProfileName
		self.rtpSettings = IxPropertyClass_RTPSettingsVoIPPeerWrapper(pm.rtpSettings)
		self.timerSettings = IxPropertyClass_TimerSettingsVoIPPeerWrapper(pm.timerSettings)
		self.autoHeadersSettings = IxPropertyClass_AutoHeadersSettingsVoIPPeerWrapper(pm.autoHeadersSettings)
		self.smsAddressRecipient = IxPropertyClass_SMSAddressVoIPPeerWrapper(pm.smsAddressRecipient)
		self.transferAddress = IxPropertyClass_TransferAddressVoIPPeerWrapper(pm.transferAddress)
		self.ContactCenter = pm.ContactCenter
		self.dialPlan = IxPropertyClass_DialPlanVoIPPeerWrapper(pm.dialPlan)
		self.srtpSettings = IxPropertyClass_SRTPSettingsVoIPPeerWrapper(pm.srtpSettings)
		self.akaConfiguration = IxPropertyClass_AKAConfigurationVoIPPeerWrapper(pm.akaConfiguration)
		self.msrpSettings = IxPropertyClass_MSRPSettingsVoIPPeerWrapper(pm.msrpSettings)
		self.mcpttSettings = IxPropertyClass_McpttSettingsVoIPPeerWrapper(pm.mcpttSettings)
		self.debugInfo = IxPropertyClass_DebugInfoVoIPPeerWrapper(pm.debugInfo)
		self.t38Settings = IxPropertyClass_T38SettingsVoIPPeerWrapper(pm.t38Settings)
		self.sipAdvSettings = IxPropertyClass_SipAdvancedSettingsVoIPPeerWrapper(pm.sipAdvSettings)
		self.milenageConfiguration = IxPropertyClass_MilenageConfigurationVoIPPeerWrapper(pm.milenageConfiguration)
		self.editAutoHeaderRule = IxPropertyClass_EditAutoHeaderRuleVoIPPeerWrapper(pm.editAutoHeaderRule)
		self.tlsSettings = IxPropertyClass_TlsSettingsVoIPPeerWrapper(pm.tlsSettings)
		self.cloudRules = IxPropertyClass_CloudRulesVoIPPeerWrapper(pm.cloudRules)
		self.enableCCportCapture = pm.enableCCportCapture

	properties = ["szPluginVersion", "ccProfileType", "ccAgentWrapUpTime", "CCProfileName", "ContactCenter", "enableCCportCapture", ]

	def __getattribute__(self, name):
		if name in IxPropertyMap_VoIPVoIPPeerWrapper.properties and super(IxPropertyMap_VoIPVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyMap_VoIPVoIPPeerWrapper, self).__getattribute__("_IxPropertyMap_VoIPVoIPPeerWrapper__pm"), name)
		else:
			return super(IxPropertyMap_VoIPVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyMap_VoIPVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyMap_VoIPVoIPPeerWrapper, self).__getattribute__("_IxPropertyMap_VoIPVoIPPeerWrapper__pm"), name, value)
			super(IxPropertyMap_VoIPVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_HttpSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, httpSettings):
		super(IxPropertyClass_HttpSettingsVoIPPeerWrapper, self).__init__(httpSettings)
		self.__httpSettings = httpSettings
		self.userName = httpSettings.userName
		self.httpServer = httpSettings.httpServer
		self.httpRealm = httpSettings.httpRealm
		self.includeTIDinRcsFileUpload = httpSettings.includeTIDinRcsFileUpload
		self.rcsActivityName = httpSettings.rcsActivityName
		self.getRcsInfoFromOtherActivity = httpSettings.getRcsInfoFromOtherActivity
		self.password = httpSettings.password
		self.enableHttp = httpSettings.enableHttp

	properties = ["userName", "httpServer", "httpRealm", "includeTIDinRcsFileUpload", "rcsActivityName", "getRcsInfoFromOtherActivity", "password", "enableHttp", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_HttpSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_HttpSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_HttpSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_HttpSettingsVoIPPeerWrapper__httpSettings"), name)
		else:
			return super(IxPropertyClass_HttpSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_HttpSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_HttpSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_HttpSettingsVoIPPeerWrapper__httpSettings"), name, value)
			super(IxPropertyClass_HttpSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_EditContactVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, editContact):
		super(IxPropertyClass_EditContactVoIPPeerWrapper, self).__init__(editContact)
		self.__editContact = editContact
		self._useEPb = editContact._useEPb
		self.domainName = editContact.domainName
		self._eBp = editContact._eBp
		self._ePhone = editContact._ePhone
		self.ePhoneType = editContact.ePhoneType
		self._eTelURIparams = editContact._eTelURIparams
		self.useDomainName = editContact.useDomainName
		self.editTelPar = editContact.editTelPar
		self._ckETelURI = editContact._ckETelURI

	properties = ["_useEPb", "domainName", "_eBp", "_ePhone", "ePhoneType", "_eTelURIparams", "useDomainName", "editTelPar", "_ckETelURI", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_EditContactVoIPPeerWrapper.properties and super(IxPropertyClass_EditContactVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_EditContactVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_EditContactVoIPPeerWrapper__editContact"), name)
		else:
			return super(IxPropertyClass_EditContactVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_EditContactVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_EditContactVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_EditContactVoIPPeerWrapper__editContact"), name, value)
			super(IxPropertyClass_EditContactVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_ScenarioSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, scenarioSettings):
		super(IxPropertyClass_ScenarioSettingsVoIPPeerWrapper, self).__init__(scenarioSettings)
		self.__scenarioSettings = scenarioSettings
		self.scenarioFile = scenarioSettings.scenarioFile
		self.activeScenarioChannel = scenarioSettings.activeScenarioChannel

	properties = ["scenarioFile", "activeScenarioChannel", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_ScenarioSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_ScenarioSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ScenarioSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_ScenarioSettingsVoIPPeerWrapper__scenarioSettings"), name)
		else:
			return super(IxPropertyClass_ScenarioSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ScenarioSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ScenarioSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_ScenarioSettingsVoIPPeerWrapper__scenarioSettings"), name, value)
			super(IxPropertyClass_ScenarioSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_AudioSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, audioSettings):
		super(IxPropertyClass_AudioSettingsVoIPPeerWrapper, self).__init__(audioSettings)
		self.__audioSettings = audioSettings
		self.channelTypeQoV = audioSettings.channelTypeQoV
		self.channelsQoVPerZionPort = audioSettings.channelsQoVPerZionPort
		self.ttlAudio = audioSettings.ttlAudio
		self.activityIdQoV = audioSettings.activityIdQoV
		self.rtpTosVal = audioSettings.rtpTosVal
		self.useJitComp = audioSettings.useJitComp
		self.audioDuration = audioSettings.audioDuration
		self.enableAudio = audioSettings.enableAudio
		self.portIPsQoV = audioSettings.portIPsQoV
		self.enableAudioOWD = audioSettings.enableAudioOWD
		self.jitMs = audioSettings.jitMs
		self.radioBtnQoVASR = audioSettings.radioBtnQoVASR
		self.silenceMode = audioSettings.silenceMode
		self.playTypeAudio = audioSettings.playTypeAudio
		self.activityNameQoV = audioSettings.activityNameQoV
		self.enableQoV = audioSettings.enableQoV
		self.jitCMs = audioSettings.jitCMs
		self.valueQoV = audioSettings.valueQoV
		self.unitsQoV = audioSettings.unitsQoV
		self.serviceEnabledQoV = audioSettings.serviceEnabledQoV
		self.audioClip = audioSettings.audioClip
		self.languageASR = audioSettings.languageASR
		self.audioDurationUnit = audioSettings.audioDurationUnit
		self.acceptSSRCChanges = audioSettings.acceptSSRCChanges
		self.dodName = audioSettings.dodName
		self.useMos = audioSettings.useMos
		self.useJitter = audioSettings.useJitter
		self.useSilence = audioSettings.useSilence
		self.metricsQoV = audioSettings.metricsQoV
		self.jitCMaxDrop = audioSettings.jitCMaxDrop
		self.enableTosRtp = audioSettings.enableTosRtp
		self.saveDecodedAudio = audioSettings.saveDecodedAudio
		self.outputLevel = audioSettings.outputLevel

	properties = ["channelTypeQoV", "channelsQoVPerZionPort", "ttlAudio", "activityIdQoV", "rtpTosVal", "useJitComp", "audioDuration", "enableAudio", "portIPsQoV", "enableAudioOWD", "jitMs", "radioBtnQoVASR", "silenceMode", "playTypeAudio", "activityNameQoV", "enableQoV", "jitCMs", "valueQoV", "unitsQoV", "serviceEnabledQoV", "audioClip", "languageASR", "audioDurationUnit", "acceptSSRCChanges", "dodName", "useMos", "useJitter", "useSilence", "metricsQoV", "jitCMaxDrop", "enableTosRtp", "saveDecodedAudio", "outputLevel", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AudioSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_AudioSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AudioSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AudioSettingsVoIPPeerWrapper__audioSettings"), name)
		else:
			return super(IxPropertyClass_AudioSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AudioSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AudioSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AudioSettingsVoIPPeerWrapper__audioSettings"), name, value)
			super(IxPropertyClass_AudioSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_IceOptionsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, iceOptions):
		super(IxPropertyClass_IceOptionsVoIPPeerWrapper, self).__init__(iceOptions)
		self.__iceOptions = iceOptions
		self.iceTimeout = iceOptions.iceTimeout
		self.iceInitialRetry = iceOptions.iceInitialRetry
		self.iceRetryCount = iceOptions.iceRetryCount

	properties = ["iceTimeout", "iceInitialRetry", "iceRetryCount", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_IceOptionsVoIPPeerWrapper.properties and super(IxPropertyClass_IceOptionsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_IceOptionsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_IceOptionsVoIPPeerWrapper__iceOptions"), name)
		else:
			return super(IxPropertyClass_IceOptionsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_IceOptionsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_IceOptionsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_IceOptionsVoIPPeerWrapper__iceOptions"), name, value)
			super(IxPropertyClass_IceOptionsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_AdvancedSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, advancedSettings):
		super(IxPropertyClass_AdvancedSettingsVoIPPeerWrapper, self).__init__(advancedSettings)
		self.__advancedSettings = advancedSettings
		self.useCloud = advancedSettings.useCloud
		self.ovrCloudRules = advancedSettings.ovrCloudRules
		self.enableVirtualIPs = advancedSettings.enableVirtualIPs
		self.cloud = advancedSettings.cloud

	properties = ["useCloud", "ovrCloudRules", "enableVirtualIPs", "cloud", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AdvancedSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_AdvancedSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AdvancedSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AdvancedSettingsVoIPPeerWrapper__advancedSettings"), name)
		else:
			return super(IxPropertyClass_AdvancedSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AdvancedSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AdvancedSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AdvancedSettingsVoIPPeerWrapper__advancedSettings"), name, value)
			super(IxPropertyClass_AdvancedSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_CodecSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, codecSettings):
		super(IxPropertyClass_CodecSettingsVoIPPeerWrapper, self).__init__(codecSettings)
		self.__codecSettings = codecSettings
		self.dataCodecs = IxPropertyGroupSequence_CodecSettings_dataCodecsVoIPPeerWrapper(codecSettings)
		self.videoPayloadType = codecSettings.videoPayloadType
		self.codecs = IxPropertyGroupSequence_CodecSettings_codecsVoIPPeerWrapper(codecSettings)
		self.codecs_number = codecSettings.codecs_number

	properties = ["videoPayloadType", "codecs_number", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_CodecSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_CodecSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_CodecSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_CodecSettingsVoIPPeerWrapper__codecSettings"), name)
		else:
			return super(IxPropertyClass_CodecSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_CodecSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_CodecSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_CodecSettingsVoIPPeerWrapper__codecSettings"), name, value)
			super(IxPropertyClass_CodecSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_SignalingSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, signalingSettings):
		super(IxPropertyClass_SignalingSettingsVoIPPeerWrapper, self).__init__(signalingSettings)
		self.__signalingSettings = signalingSettings
		self.tcpWriteImmediate = signalingSettings.tcpWriteImmediate
		self.telURISource = signalingSettings.telURISource
		self.enableSIP = signalingSettings.enableSIP
		self.milenage_c1 = signalingSettings.milenage_c1
		self.milenageConfCombo = signalingSettings.milenageConfCombo
		self.milenage_c3 = signalingSettings.milenage_c3
		self.milenage_c2 = signalingSettings.milenage_c2
		self.milenage_c5 = signalingSettings.milenage_c5
		self.milenage_c4 = signalingSettings.milenage_c4
		self.akaConfCombo = signalingSettings.akaConfCombo
		self.overrideRegistrar = signalingSettings.overrideRegistrar
		self.port = signalingSettings.port
		self.milenage_r2 = signalingSettings.milenage_r2
		self.milenage_r4 = signalingSettings.milenage_r4
		self.milenage_r5 = signalingSettings.milenage_r5
		self.realm = signalingSettings.realm
		self.milenage_r3 = signalingSettings.milenage_r3
		self.milenage_r1 = signalingSettings.milenage_r1
		self.ovrDest = signalingSettings.ovrDest
		self.skipDeleteDNSRecordsAtLoopEnd = signalingSettings.skipDeleteDNSRecordsAtLoopEnd
		self.nUdpMaxSize = signalingSettings.nUdpMaxSize
		self.srvDomain = signalingSettings.srvDomain
		self.telURIDest = signalingSettings.telURIDest
		self.enablePeriodicDNSQueries = signalingSettings.enablePeriodicDNSQueries
		self.useIPSecDoubleSPIPatch = signalingSettings.useIPSecDoubleSPIPatch
		self.securityMechanismValList = IxPropertyGroupSequence_SignalingSettings_securityMechanismValListVoIPPeerWrapper(signalingSettings)
		self.overrideRegistrarAddress = signalingSettings.overrideRegistrarAddress
		self.enableTos = signalingSettings.enableTos
		self.srvAddr = signalingSettings.srvAddr
		self.ovrDestHostPort = signalingSettings.ovrDestHostPort
		self.DNSTimeoutValue = signalingSettings.DNSTimeoutValue
		self.passwd = signalingSettings.passwd
		self.enableVoLTE = signalingSettings.enableVoLTE
		self.autoRegister = signalingSettings.autoRegister
		self.outboundProxy = signalingSettings.outboundProxy
		self.closeTCPConnectionsOnRampdown = signalingSettings.closeTCPConnectionsOnRampdown
		self.user = signalingSettings.user
		self.dontEndMediaOnBye = signalingSettings.dontEndMediaOnBye
		self.useServer = signalingSettings.useServer
		self.ttlSip = signalingSettings.ttlSip
		self.akaExportComplete = signalingSettings.akaExportComplete
		self.mediaBearerType = signalingSettings.mediaBearerType
		self.registrarSrv = signalingSettings.registrarSrv
		self.tosVal = signalingSettings.tosVal
		self.akaUseOPasOPC = signalingSettings.akaUseOPasOPC
		self.fqdn = signalingSettings.fqdn
		self.ovrContact = signalingSettings.ovrContact
		self.akaAbsolutePath = signalingSettings.akaAbsolutePath
		self.enableCCDedicatedBearer = signalingSettings.enableCCDedicatedBearer
		self.akaConfComboSelIndex = signalingSettings.akaConfComboSelIndex
		self.ovrTrans = signalingSettings.ovrTrans
		self.useDnsSrv = signalingSettings.useDnsSrv
		self.ovrTransOption = signalingSettings.ovrTransOption
		self.srvPort = signalingSettings.srvPort

	properties = ["tcpWriteImmediate", "telURISource", "enableSIP", "milenage_c1", "milenageConfCombo", "milenage_c3", "milenage_c2", "milenage_c5", "milenage_c4", "akaConfCombo", "overrideRegistrar", "port", "milenage_r2", "milenage_r4", "milenage_r5", "realm", "milenage_r3", "milenage_r1", "ovrDest", "skipDeleteDNSRecordsAtLoopEnd", "nUdpMaxSize", "srvDomain", "telURIDest", "enablePeriodicDNSQueries", "useIPSecDoubleSPIPatch", "overrideRegistrarAddress", "enableTos", "srvAddr", "ovrDestHostPort", "DNSTimeoutValue", "passwd", "enableVoLTE", "autoRegister", "outboundProxy", "closeTCPConnectionsOnRampdown", "user", "dontEndMediaOnBye", "useServer", "ttlSip", "akaExportComplete", "mediaBearerType", "registrarSrv", "tosVal", "akaUseOPasOPC", "fqdn", "ovrContact", "akaAbsolutePath", "enableCCDedicatedBearer", "akaConfComboSelIndex", "ovrTrans", "useDnsSrv", "ovrTransOption", "srvPort", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_SignalingSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_SignalingSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_SignalingSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SignalingSettingsVoIPPeerWrapper__signalingSettings"), name)
		else:
			return super(IxPropertyClass_SignalingSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_SignalingSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_SignalingSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SignalingSettingsVoIPPeerWrapper__signalingSettings"), name, value)
			super(IxPropertyClass_SignalingSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_SMSSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, smsSettings):
		super(IxPropertyClass_SMSSettingsVoIPPeerWrapper, self).__init__(smsSettings)
		self.__smsSettings = smsSettings
		self.smOrigNumberingPlan = smsSettings.smOrigNumberingPlan
		self.enableSMS = smsSettings.enableSMS
		self.enableSMOrigReplyPath = smsSettings.enableSMOrigReplyPath
		self.smsFilesCount = smsSettings.smsFilesCount
		self.enableSMRecipOverrideSrc = smsSettings.enableSMRecipOverrideSrc
		self.enableSMOrigReqStatusReport = smsSettings.enableSMOrigReqStatusReport
		self.smsAddressOriginator = IxPropertyClass_SMSAddressInfoVoIPPeerWrapper(smsSettings.smsAddressOriginator)
		self.telURI = smsSettings.telURI
		self.pcpuCommonPath = smsSettings.pcpuCommonPath
		self.smOrigTypeOfNo = smsSettings.smOrigTypeOfNo
		self.smscPhoneNo = smsSettings.smscPhoneNo
		self.requestURI = smsSettings.requestURI
		self.smsAddressRecipient = IxPropertyClass_SMSAddressInfoVoIPPeerWrapper(smsSettings.smsAddressRecipient)
		self.enableTelURI = smsSettings.enableTelURI
		self.smRecipNumberingPlan = smsSettings.smRecipNumberingPlan
		self.enableSMRecipReplyPath = smsSettings.enableSMRecipReplyPath
		self.smscNumberingPlan = smsSettings.smscNumberingPlan
		self.enableSMRecipReqStatusReport = smsSettings.enableSMRecipReqStatusReport
		self.smRecipTypeOfNo = smsSettings.smRecipTypeOfNo
		self.verifyUserInfo = smsSettings.verifyUserInfo
		self.smscTypeOfNo = smsSettings.smscTypeOfNo
		self.enableSMOrigOverrideDest = smsSettings.enableSMOrigOverrideDest

	properties = ["smOrigNumberingPlan", "enableSMS", "enableSMOrigReplyPath", "smsFilesCount", "enableSMRecipOverrideSrc", "enableSMOrigReqStatusReport", "telURI", "pcpuCommonPath", "smOrigTypeOfNo", "smscPhoneNo", "requestURI", "enableTelURI", "smRecipNumberingPlan", "enableSMRecipReplyPath", "smscNumberingPlan", "enableSMRecipReqStatusReport", "smRecipTypeOfNo", "verifyUserInfo", "smscTypeOfNo", "enableSMOrigOverrideDest", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_SMSSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_SMSSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_SMSSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SMSSettingsVoIPPeerWrapper__smsSettings"), name)
		else:
			return super(IxPropertyClass_SMSSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_SMSSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_SMSSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SMSSettingsVoIPPeerWrapper__smsSettings"), name, value)
			super(IxPropertyClass_SMSSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_VoIP_ceCommandsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, pm):
		self.__pm = pm
		self.optionsDict = {
			('CommandEx',): "IxPropertyClass_CommandExVoIPPeer",
			('Procedure',): "IxPropertyClass_ProcedureVoIPPeer",
			('START',): "IxPropertyCommandStartVoIPPeer",
			('STOP',): "IxPropertyCommandStopVoIPPeer",
		}

	def getItemIxCommandexCommand(self, objectID):
		itemList = self.__pm.ceCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_CommandEx":
				return IxPropertyClass_CommandExVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxCommandexCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "CommandEx"})
		return IxPropertyClass_CommandExVoIPPeerWrapper(self.__pm.ceCommands.appendItem(**kwargs))

	def getItemIxProcedureCommand(self, objectID):
		itemList = self.__pm.ceCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_Procedure":
				return IxPropertyClass_ProcedureVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxProcedureCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "Procedure"})
		return IxPropertyClass_ProcedureVoIPPeerWrapper(self.__pm.ceCommands.appendItem(**kwargs))

	def getItemIxStartCommand(self, objectID):
		itemList = self.__pm.ceCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandStart":
				return IxPropertyCommandStartVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStartCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "START"})
		return IxPropertyCommandStartVoIPPeerWrapper(self.__pm.ceCommands.appendItem(**kwargs))

	def getItemIxStopCommand(self, objectID):
		itemList = self.__pm.ceCommands
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyCommandStop":
				return IxPropertyCommandStopVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxStopCommand(self):
		kwargs = {}
		kwargs.update({"commandType": "STOP"})
		return IxPropertyCommandStopVoIPPeerWrapper(self.__pm.ceCommands.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__pm.ceCommands
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, commandType=None):
		kwargs = {}
		kwargs.update({"commandType": commandType})
		return self.__pm.ceCommands.appendItem(**kwargs)

	def getList(self):
		return self.__pm.ceCommands

	def clear(self):
		return self.__pm.ceCommands.clear()


class IxPropertyCommandStartVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStart):
		super(IxPropertyCommandStartVoIPPeerWrapper, self).__init__(ixPropertyCommandStart)
		self.__ixPropertyCommandStart = ixPropertyCommandStart
		self.outputList = IxCommandOutputListVoIPPeerWrapper(ixPropertyCommandStart)
		self.cmdName = ixPropertyCommandStart.cmdName
		self.commandType = ixPropertyCommandStart.commandType
		self.commandId = ixPropertyCommandStart.commandId

	properties = ["cmdName", "commandType", "commandId", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandStartVoIPPeerWrapper.properties and super(IxPropertyCommandStartVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandStartVoIPPeerWrapper, self).__getattribute__("_IxPropertyCommandStartVoIPPeerWrapper__ixPropertyCommandStart"), name)
		else:
			return super(IxPropertyCommandStartVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandStartVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandStartVoIPPeerWrapper, self).__getattribute__("_IxPropertyCommandStartVoIPPeerWrapper__ixPropertyCommandStart"), name, value)
			super(IxPropertyCommandStartVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_ProcedureVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Procedure):
		super(IxPropertyClass_ProcedureVoIPPeerWrapper, self).__init__(ixPropertyClass_Procedure)
		self.__ixPropertyClass_Procedure = ixPropertyClass_Procedure
		self.outputList = IxCommandOutputListVoIPPeerWrapper(ixPropertyClass_Procedure)
		self.cmdName = ixPropertyClass_Procedure.cmdName
		self.commandType = ixPropertyClass_Procedure.commandType
		self.commandId = ixPropertyClass_Procedure.commandId

	properties = ["cmdName", "commandType", "commandId", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_ProcedureVoIPPeerWrapper.properties and super(IxPropertyClass_ProcedureVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ProcedureVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_ProcedureVoIPPeerWrapper__ixPropertyClass_Procedure"), name)
		else:
			return super(IxPropertyClass_ProcedureVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ProcedureVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ProcedureVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_ProcedureVoIPPeerWrapper__ixPropertyClass_Procedure"), name, value)
			super(IxPropertyClass_ProcedureVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_CommandExVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_CommandEx):
		super(IxPropertyClass_CommandExVoIPPeerWrapper, self).__init__(ixPropertyClass_CommandEx)
		self.__ixPropertyClass_CommandEx = ixPropertyClass_CommandEx
		self.outputList = IxCommandOutputListVoIPPeerWrapper(ixPropertyClass_CommandEx)
		self.cmdName = ixPropertyClass_CommandEx.cmdName
		self.commandType = ixPropertyClass_CommandEx.commandType
		self.cmdType = ixPropertyClass_CommandEx.cmdType
		self.commandId = ixPropertyClass_CommandEx.commandId

	properties = ["cmdName", "commandType", "cmdType", "commandId", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_CommandExVoIPPeerWrapper.properties and super(IxPropertyClass_CommandExVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_CommandExVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_CommandExVoIPPeerWrapper__ixPropertyClass_CommandEx"), name)
		else:
			return super(IxPropertyClass_CommandExVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_CommandExVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_CommandExVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_CommandExVoIPPeerWrapper__ixPropertyClass_CommandEx"), name, value)
			super(IxPropertyClass_CommandExVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyCommandStopVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStop):
		super(IxPropertyCommandStopVoIPPeerWrapper, self).__init__(ixPropertyCommandStop)
		self.__ixPropertyCommandStop = ixPropertyCommandStop
		self.cmdName = ixPropertyCommandStop.cmdName
		self.commandType = ixPropertyCommandStop.commandType
		self.commandId = ixPropertyCommandStop.commandId

	properties = ["cmdName", "commandType", "commandId", ]

	def __getattribute__(self, name):
		if name in IxPropertyCommandStopVoIPPeerWrapper.properties and super(IxPropertyCommandStopVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyCommandStopVoIPPeerWrapper, self).__getattribute__("_IxPropertyCommandStopVoIPPeerWrapper__ixPropertyCommandStop"), name)
		else:
			return super(IxPropertyCommandStopVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyCommandStopVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyCommandStopVoIPPeerWrapper, self).__getattribute__("_IxPropertyCommandStopVoIPPeerWrapper__ixPropertyCommandStop"), name, value)
			super(IxPropertyCommandStopVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_VideoSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, videoSettings):
		super(IxPropertyClass_VideoSettingsVoIPPeerWrapper, self).__init__(videoSettings)
		self.__videoSettings = videoSettings
		self.hintTrackType = videoSettings.hintTrackType
		self.useSingleNALUnit = videoSettings.useSingleNALUnit
		self.enableVideo = videoSettings.enableVideo
		self.useConference = videoSettings.useConference
		self.tipSettings = IxPropertyClass_VideoTelepresenceSettingsVoIPPeerWrapper(videoSettings.tipSettings)
		self.playTypeVideo = videoSettings.playTypeVideo
		self.rotationScheme = videoSettings.rotationScheme
		self.ttlVideo = videoSettings.ttlVideo
		self.isMP4 = videoSettings.isMP4
		self.confVideoDuration = videoSettings.confVideoDuration
		self.tosValVideo = videoSettings.tosValVideo
		self.enablePACSI = videoSettings.enablePACSI
		self.confDuration = videoSettings.confDuration
		self.enableVideoOWD = videoSettings.enableVideoOWD
		self.enableTosVideo = videoSettings.enableTosVideo
		self.fmtp = videoSettings.fmtp
		self.videoDuration = videoSettings.videoDuration
		self.confDurationUnit = videoSettings.confDurationUnit
		self.videoDurationUnit = videoSettings.videoDurationUnit
		self.ignoreHintTrack = videoSettings.ignoreHintTrack
		self.enableAcceptSSRCChanges = videoSettings.enableAcceptSSRCChanges
		self.useH323AdvancedSettings = videoSettings.useH323AdvancedSettings
		self.videoClip = videoSettings.videoClip
		self.confVideoDurationUnit = videoSettings.confVideoDurationUnit
		self.rtpmap = videoSettings.rtpmap
		self.btnTelepresence = videoSettings.btnTelepresence
		self.useMosVideo = videoSettings.useMosVideo

	properties = ["hintTrackType", "useSingleNALUnit", "enableVideo", "useConference", "playTypeVideo", "rotationScheme", "ttlVideo", "isMP4", "confVideoDuration", "tosValVideo", "enablePACSI", "confDuration", "enableVideoOWD", "enableTosVideo", "fmtp", "videoDuration", "confDurationUnit", "videoDurationUnit", "ignoreHintTrack", "enableAcceptSSRCChanges", "useH323AdvancedSettings", "videoClip", "confVideoDurationUnit", "rtpmap", "btnTelepresence", "useMosVideo", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_VideoSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_VideoSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_VideoSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_VideoSettingsVoIPPeerWrapper__videoSettings"), name)
		else:
			return super(IxPropertyClass_VideoSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_VideoSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_VideoSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_VideoSettingsVoIPPeerWrapper__videoSettings"), name, value)
			super(IxPropertyClass_VideoSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_T30ParametersVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, t30Parameters):
		super(IxPropertyClass_T30ParametersVoIPPeerWrapper, self).__init__(t30Parameters)
		self.__t30Parameters = t30Parameters
		self.t30SendResolution = t30Parameters.t30SendResolution
		self.sendCedBeforeDIS = t30Parameters.sendCedBeforeDIS
		self.t30ReceiveR8x7 = t30Parameters.t30ReceiveR8x7
		self.t30SendPageSize = t30Parameters.t30SendPageSize
		self.t30ReceiveR8x3 = t30Parameters.t30ReceiveR8x3
		self.t30ReceiveProtocol = t30Parameters.t30ReceiveProtocol
		self.sendCNG = t30Parameters.sendCNG
		self.t30SendProtocol = t30Parameters.t30SendProtocol
		self.t30SendCoding = t30Parameters.t30SendCoding
		self.t30ReceiveCoding = t30Parameters.t30ReceiveCoding
		self.t30ReceiveModulations = t30Parameters.t30ReceiveModulations
		self.t30ReceiveMSLT = t30Parameters.t30ReceiveMSLT
		self.t30ReceivePageSize = t30Parameters.t30ReceivePageSize
		self.t30SendMSLT = t30Parameters.t30SendMSLT
		self.t30ReceiveR8x15 = t30Parameters.t30ReceiveR8x15
		self.t30StationId = t30Parameters.t30StationId
		self.t30SendDataRate = t30Parameters.t30SendDataRate
		self.t30Receive200x200 = t30Parameters.t30Receive200x200

	properties = ["t30SendResolution", "sendCedBeforeDIS", "t30ReceiveR8x7", "t30SendPageSize", "t30ReceiveR8x3", "t30ReceiveProtocol", "sendCNG", "t30SendProtocol", "t30SendCoding", "t30ReceiveCoding", "t30ReceiveModulations", "t30ReceiveMSLT", "t30ReceivePageSize", "t30SendMSLT", "t30ReceiveR8x15", "t30StationId", "t30SendDataRate", "t30Receive200x200", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_T30ParametersVoIPPeerWrapper.properties and super(IxPropertyClass_T30ParametersVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_T30ParametersVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_T30ParametersVoIPPeerWrapper__t30Parameters"), name)
		else:
			return super(IxPropertyClass_T30ParametersVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_T30ParametersVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_T30ParametersVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_T30ParametersVoIPPeerWrapper__t30Parameters"), name, value)
			super(IxPropertyClass_T30ParametersVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_RTCPSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, rtcpSettings):
		super(IxPropertyClass_RTCPSettingsVoIPPeerWrapper, self).__init__(rtcpSettings)
		self.__rtcpSettings = rtcpSettings
		self.rtcpSDESTool = rtcpSettings.rtcpSDESTool
		self.rtcpSenderTimer = rtcpSettings.rtcpSenderTimer
		self.rtcpCNAMEType = rtcpSettings.rtcpCNAMEType
		self.hasSDESTool = rtcpSettings.hasSDESTool
		self.rtcpReceiverTimer = rtcpSettings.rtcpReceiverTimer
		self.rtcpIgnoreSSRC = rtcpSettings.rtcpIgnoreSSRC
		self.hasSDESName = rtcpSettings.hasSDESName

	properties = ["rtcpSDESTool", "rtcpSenderTimer", "rtcpCNAMEType", "hasSDESTool", "rtcpReceiverTimer", "rtcpIgnoreSSRC", "hasSDESName", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_RTCPSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_RTCPSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_RTCPSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_RTCPSettingsVoIPPeerWrapper__rtcpSettings"), name)
		else:
			return super(IxPropertyClass_RTCPSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_RTCPSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_RTCPSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_RTCPSettingsVoIPPeerWrapper__rtcpSettings"), name, value)
			super(IxPropertyClass_RTCPSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_ExecutionSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, executionSettings):
		super(IxPropertyClass_ExecutionSettingsVoIPPeerWrapper, self).__init__(executionSettings)
		self.__executionSettings = executionSettings
		self.portRuleCh = executionSettings.portRuleCh
		self.rtpPortRule = executionSettings.rtpPortRule
		self.multipleUsersPerIO = executionSettings.multipleUsersPerIO
		self.gracefulRampDown = executionSettings.gracefulRampDown
		self.loopCount = executionSettings.loopCount
		self.rtpIpRule = executionSettings.rtpIpRule
		self.ipRule = executionSettings.ipRule
		self.rtpPortRuleCh = executionSettings.rtpPortRuleCh
		self.loopPreDelay = executionSettings.loopPreDelay
		self.phoneRuleCount = executionSettings.phoneRuleCount
		self.rampdownSleep = executionSettings.rampdownSleep
		self.loopMidDelay = executionSettings.loopMidDelay
		self.phoneRule = executionSettings.phoneRule
		self.rtpIpRuleCh = executionSettings.rtpIpRuleCh
		self.portRule = executionSettings.portRule
		self.ipRuleCh = executionSettings.ipRuleCh
		self.loopMode = executionSettings.loopMode
		self.aliases = executionSettings.aliases

	properties = ["portRuleCh", "rtpPortRule", "multipleUsersPerIO", "gracefulRampDown", "loopCount", "rtpIpRule", "ipRule", "rtpPortRuleCh", "loopPreDelay", "phoneRuleCount", "rampdownSleep", "loopMidDelay", "phoneRule", "rtpIpRuleCh", "portRule", "ipRuleCh", "loopMode", "aliases", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_ExecutionSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_ExecutionSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ExecutionSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_ExecutionSettingsVoIPPeerWrapper__executionSettings"), name)
		else:
			return super(IxPropertyClass_ExecutionSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ExecutionSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ExecutionSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_ExecutionSettingsVoIPPeerWrapper__executionSettings"), name, value)
			super(IxPropertyClass_ExecutionSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_TextSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, textSettings):
		super(IxPropertyClass_TextSettingsVoIPPeerWrapper, self).__init__(textSettings)
		self.__textSettings = textSettings
		self.tosValText = textSettings.tosValText
		self.textRedundancyLevel = textSettings.textRedundancyLevel
		self.textClip = textSettings.textClip
		self.textChpsMin = textSettings.textChpsMin
		self.textChpsMax = textSettings.textChpsMax
		self.textBufferTime = textSettings.textBufferTime
		self.textDuration = textSettings.textDuration
		self.enableTextOWD = textSettings.enableTextOWD
		self.enableText = textSettings.enableText
		self.textPlayType = textSettings.textPlayType
		self.enableTosText = textSettings.enableTosText
		self.textDurationUnit = textSettings.textDurationUnit
		self.ttlText = textSettings.ttlText

	properties = ["tosValText", "textRedundancyLevel", "textClip", "textChpsMin", "textChpsMax", "textBufferTime", "textDuration", "enableTextOWD", "enableText", "textPlayType", "enableTosText", "textDurationUnit", "ttlText", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_TextSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_TextSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_TextSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_TextSettingsVoIPPeerWrapper__textSettings"), name)
		else:
			return super(IxPropertyClass_TextSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_TextSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_TextSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_TextSettingsVoIPPeerWrapper__textSettings"), name, value)
			super(IxPropertyClass_TextSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_SMSAddressVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, smsAddressOriginator):
		super(IxPropertyClass_SMSAddressVoIPPeerWrapper, self).__init__(smsAddressOriginator)
		self.__smsAddressOriginator = smsAddressOriginator
		self.userPattern = smsAddressOriginator.userPattern
		self.radioBtnPhoneNo = smsAddressOriginator.radioBtnPhoneNo
		self.comboPhoneBook = smsAddressOriginator.comboPhoneBook

	properties = ["userPattern", "radioBtnPhoneNo", "comboPhoneBook", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_SMSAddressVoIPPeerWrapper.properties and super(IxPropertyClass_SMSAddressVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_SMSAddressVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SMSAddressVoIPPeerWrapper__smsAddressOriginator"), name)
		else:
			return super(IxPropertyClass_SMSAddressVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_SMSAddressVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_SMSAddressVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SMSAddressVoIPPeerWrapper__smsAddressOriginator"), name, value)
			super(IxPropertyClass_SMSAddressVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_AdvancedVideoSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, advancedVideo):
		super(IxPropertyClass_AdvancedVideoSettingsVoIPPeerWrapper, self).__init__(advancedVideo)
		self.__advancedVideo = advancedVideo
		self.enableMaxRcmdNalUnitSize = advancedVideo.enableMaxRcmdNalUnitSize
		self.enableCustomMaxFS = advancedVideo.enableCustomMaxFS
		self.customMaxFS = advancedVideo.customMaxFS
		self.customMaxBRandCPB = advancedVideo.customMaxBRandCPB
		self.customMaxDPB = advancedVideo.customMaxDPB
		self.enableMaxStaticMBPS = advancedVideo.enableMaxStaticMBPS
		self.customMaxMBPS = advancedVideo.customMaxMBPS
		self.maxStaticMBPS = advancedVideo.maxStaticMBPS
		self.maxRcmdNalUnitSize = advancedVideo.maxRcmdNalUnitSize
		self.enableMaxNalUnitSize = advancedVideo.enableMaxNalUnitSize
		self.maxNalUnitSize = advancedVideo.maxNalUnitSize
		self.enableCustomMaxBRandCPB = advancedVideo.enableCustomMaxBRandCPB
		self.enableCustomMaxDPB = advancedVideo.enableCustomMaxDPB
		self.enableCustomMaxMBPS = advancedVideo.enableCustomMaxMBPS

	properties = ["enableMaxRcmdNalUnitSize", "enableCustomMaxFS", "customMaxFS", "customMaxBRandCPB", "customMaxDPB", "enableMaxStaticMBPS", "customMaxMBPS", "maxStaticMBPS", "maxRcmdNalUnitSize", "enableMaxNalUnitSize", "maxNalUnitSize", "enableCustomMaxBRandCPB", "enableCustomMaxDPB", "enableCustomMaxMBPS", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AdvancedVideoSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_AdvancedVideoSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AdvancedVideoSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AdvancedVideoSettingsVoIPPeerWrapper__advancedVideo"), name)
		else:
			return super(IxPropertyClass_AdvancedVideoSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AdvancedVideoSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AdvancedVideoSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AdvancedVideoSettingsVoIPPeerWrapper__advancedVideo"), name, value)
			super(IxPropertyClass_AdvancedVideoSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_OtherSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, otherSettings):
		super(IxPropertyClass_OtherSettingsVoIPPeerWrapper, self).__init__(otherSettings)
		self.__otherSettings = otherSettings
		self.bAgentRoundRobinDistribution = otherSettings.bAgentRoundRobinDistribution
		self.VOIP_IPAddress4 = otherSettings.VOIP_IPAddress4
		self.VOIP_IPAddress1 = otherSettings.VOIP_IPAddress1
		self.VOIP_IPAddress0 = otherSettings.VOIP_IPAddress0
		self.VOIP_IPAddress3 = otherSettings.VOIP_IPAddress3
		self.VOIP_IPAddress2 = otherSettings.VOIP_IPAddress2
		self.bUseIce = otherSettings.bUseIce
		self.loadVariablesFromCsv = otherSettings.loadVariablesFromCsv
		self.PCO_List = otherSettings.PCO_List
		self.absolutePathForCsvWithVariables = otherSettings.absolutePathForCsvWithVariables
		self.VOIP_Var2 = otherSettings.VOIP_Var2
		self.bUseSRVCC = otherSettings.bUseSRVCC
		self.ipPreference = otherSettings.ipPreference
		self.mobilityPath = otherSettings.mobilityPath
		self.bUsePCO = otherSettings.bUsePCO
		self.stunPort = otherSettings.stunPort
		self.bUseStun = otherSettings.bUseStun
		self.stunAddr = otherSettings.stunAddr
		self.HTTPipPreference = otherSettings.HTTPipPreference
		self.pathForCsvWithVariables = otherSettings.pathForCsvWithVariables
		self.bTriggerUEInitiatedBearerRequest = otherSettings.bTriggerUEInitiatedBearerRequest
		self.VOIP_Var1 = otherSettings.VOIP_Var1
		self.VOIP_Var0 = otherSettings.VOIP_Var0
		self.VOIP_Var3 = otherSettings.VOIP_Var3
		self.bIceLite = otherSettings.bIceLite
		self.VOIP_Var4 = otherSettings.VOIP_Var4

	properties = ["bAgentRoundRobinDistribution", "VOIP_IPAddress4", "VOIP_IPAddress1", "VOIP_IPAddress0", "VOIP_IPAddress3", "VOIP_IPAddress2", "bUseIce", "loadVariablesFromCsv", "PCO_List", "absolutePathForCsvWithVariables", "VOIP_Var2", "bUseSRVCC", "ipPreference", "mobilityPath", "bUsePCO", "stunPort", "bUseStun", "stunAddr", "HTTPipPreference", "pathForCsvWithVariables", "bTriggerUEInitiatedBearerRequest", "VOIP_Var1", "VOIP_Var0", "VOIP_Var3", "bIceLite", "VOIP_Var4", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_OtherSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_OtherSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_OtherSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_OtherSettingsVoIPPeerWrapper__otherSettings"), name)
		else:
			return super(IxPropertyClass_OtherSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_OtherSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_OtherSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_OtherSettingsVoIPPeerWrapper__otherSettings"), name, value)
			super(IxPropertyClass_OtherSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_DtlsOptionsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, dtlsOptions):
		super(IxPropertyClass_DtlsOptionsVoIPPeerWrapper, self).__init__(dtlsOptions)
		self.__dtlsOptions = dtlsOptions
		self.dtlsRetry = dtlsOptions.dtlsRetry
		self.dtlsTimeout = dtlsOptions.dtlsTimeout
		self.dtlsSessionTicket = dtlsOptions.dtlsSessionTicket

	properties = ["dtlsRetry", "dtlsTimeout", "dtlsSessionTicket", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_DtlsOptionsVoIPPeerWrapper.properties and super(IxPropertyClass_DtlsOptionsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_DtlsOptionsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_DtlsOptionsVoIPPeerWrapper__dtlsOptions"), name)
		else:
			return super(IxPropertyClass_DtlsOptionsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_DtlsOptionsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_DtlsOptionsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_DtlsOptionsVoIPPeerWrapper__dtlsOptions"), name, value)
			super(IxPropertyClass_DtlsOptionsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_RTPSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, rtpSettings):
		super(IxPropertyClass_RTPSettingsVoIPPeerWrapper, self).__init__(rtpSettings)
		self.__rtpSettings = rtpSettings
		self.videoRR_value = rtpSettings.videoRR_value
		self.textRS_value = rtpSettings.textRS_value
		self.textRR_value = rtpSettings.textRR_value
		self.enableRTP = rtpSettings.enableRTP
		self.enableMediaSDPParams = rtpSettings.enableMediaSDPParams
		self.rtpPort = rtpSettings.rtpPort
		self.audioRS_option = rtpSettings.audioRS_option
		self.audioB_option = rtpSettings.audioB_option
		self.audioB_value = rtpSettings.audioB_value
		self.videoRR_option = rtpSettings.videoRR_option
		self.enableRTCPMux = rtpSettings.enableRTCPMux
		self.textRR_option = rtpSettings.textRR_option
		self.textB_option = rtpSettings.textB_option
		self.videoB_value = rtpSettings.videoB_value
		self.enableRTCP = rtpSettings.enableRTCP
		self.enableMDI = rtpSettings.enableMDI
		self.chEnableHwAcc = rtpSettings.chEnableHwAcc
		self.chDisableHwAcc = rtpSettings.chDisableHwAcc
		self.enableAdvStatCalc = rtpSettings.enableAdvStatCalc
		self.audioRR_option = rtpSettings.audioRR_option
		self.enablePerStream = rtpSettings.enablePerStream
		self.audioRS_value = rtpSettings.audioRS_value
		self.videoRS_option = rtpSettings.videoRS_option
		self.videoRS_value = rtpSettings.videoRS_value
		self.audioRR_value = rtpSettings.audioRR_value
		self.textB_value = rtpSettings.textB_value
		self.videoB_option = rtpSettings.videoB_option
		self.textRS_option = rtpSettings.textRS_option
		self.enableNBExec = rtpSettings.enableNBExec

	properties = ["videoRR_value", "textRS_value", "textRR_value", "enableRTP", "enableMediaSDPParams", "rtpPort", "audioRS_option", "audioB_option", "audioB_value", "videoRR_option", "enableRTCPMux", "textRR_option", "textB_option", "videoB_value", "enableRTCP", "enableMDI", "chEnableHwAcc", "chDisableHwAcc", "enableAdvStatCalc", "audioRR_option", "enablePerStream", "audioRS_value", "videoRS_option", "videoRS_value", "audioRR_value", "textB_value", "videoB_option", "textRS_option", "enableNBExec", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_RTPSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_RTPSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_RTPSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_RTPSettingsVoIPPeerWrapper__rtpSettings"), name)
		else:
			return super(IxPropertyClass_RTPSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_RTPSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_RTPSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_RTPSettingsVoIPPeerWrapper__rtpSettings"), name, value)
			super(IxPropertyClass_RTPSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_TimerSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, timerSettings):
		super(IxPropertyClass_TimerSettingsVoIPPeerWrapper, self).__init__(timerSettings)
		self.__timerSettings = timerSettings
		self.ignoreRetransmissions = timerSettings.ignoreRetransmissions
		self.minInterReregister = timerSettings.minInterReregister
		self.autoEndCall2 = timerSettings.autoEndCall2
		self.enableTimers = timerSettings.enableTimers
		self.stopActiveRetrOnMatch = timerSettings.stopActiveRetrOnMatch
		self.refreshInSecs = timerSettings.refreshInSecs
		self.retransmit1xx = timerSettings.retransmit1xx
		self.auto4xxAbort = timerSettings.auto4xxAbort
		self.ovrTimeout = timerSettings.ovrTimeout
		self.sessionRefreshType = timerSettings.sessionRefreshType
		self.auto4xx = timerSettings.auto4xx
		self.procListChanged = timerSettings.procListChanged
		self.T2 = timerSettings.T2
		self.autoProcedureList = IxPropertyGroupSequence_TimerSettings_autoProcedureListVoIPPeerWrapper(timerSettings)
		self.T1 = timerSettings.T1
		self.retransmitACK = timerSettings.retransmitACK
		self.retransmitRsp = timerSettings.retransmitRsp
		self.enableAutoPRACK = timerSettings.enableAutoPRACK
		self.stopActiveRetr = timerSettings.stopActiveRetr
		self.retransmitRspForNonInvite = timerSettings.retransmitRspForNonInvite
		self.enableRetransmissions = timerSettings.enableRetransmissions
		self.rprTimeUntilNextRPR = timerSettings.rprTimeUntilNextRPR
		self.rprScenarioHasPRACK = timerSettings.rprScenarioHasPRACK
		self.expirationValList = IxPropertyGroupSequence_TimerSettings_expirationValListVoIPPeerWrapper(timerSettings)
		self.refreshAfterSecs = timerSettings.refreshAfterSecs
		self.autoProceduresCount = timerSettings.autoProceduresCount
		self.refreshAfterPercent = timerSettings.refreshAfterPercent
		self.rprSendNegotiatedSDP = timerSettings.rprSendNegotiatedSDP

	properties = ["ignoreRetransmissions", "minInterReregister", "autoEndCall2", "enableTimers", "stopActiveRetrOnMatch", "refreshInSecs", "retransmit1xx", "auto4xxAbort", "ovrTimeout", "sessionRefreshType", "auto4xx", "procListChanged", "T2", "T1", "retransmitACK", "retransmitRsp", "enableAutoPRACK", "stopActiveRetr", "retransmitRspForNonInvite", "enableRetransmissions", "rprTimeUntilNextRPR", "rprScenarioHasPRACK", "refreshAfterSecs", "autoProceduresCount", "refreshAfterPercent", "rprSendNegotiatedSDP", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_TimerSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_TimerSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_TimerSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_TimerSettingsVoIPPeerWrapper__timerSettings"), name)
		else:
			return super(IxPropertyClass_TimerSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_TimerSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_TimerSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_TimerSettingsVoIPPeerWrapper__timerSettings"), name, value)
			super(IxPropertyClass_TimerSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_AutoHeadersSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, autoHeadersSettings):
		super(IxPropertyClass_AutoHeadersSettingsVoIPPeerWrapper, self).__init__(autoHeadersSettings)
		self.__autoHeadersSettings = autoHeadersSettings
		self.enableAutoHeaders = autoHeadersSettings.enableAutoHeaders

	properties = ["enableAutoHeaders", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AutoHeadersSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_AutoHeadersSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AutoHeadersSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AutoHeadersSettingsVoIPPeerWrapper__autoHeadersSettings"), name)
		else:
			return super(IxPropertyClass_AutoHeadersSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AutoHeadersSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AutoHeadersSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AutoHeadersSettingsVoIPPeerWrapper__autoHeadersSettings"), name, value)
			super(IxPropertyClass_AutoHeadersSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_TransferAddressVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, transferAddress):
		super(IxPropertyClass_TransferAddressVoIPPeerWrapper, self).__init__(transferAddress)
		self.__transferAddress = transferAddress
		self.overridePhoneNo = transferAddress.overridePhoneNo
		self._useTPb = transferAddress._useTPb
		self._ckTTelURIParams = transferAddress._ckTTelURIParams
		self.transTelPar = transferAddress.transTelPar
		self._tPhone = transferAddress._tPhone
		self.symTransferStr = transferAddress.symTransferStr
		self.tPhoneType = transferAddress.tPhoneType
		self._tTelURIparams = transferAddress._tTelURIparams
		self._tBp = transferAddress._tBp

	properties = ["overridePhoneNo", "_useTPb", "_ckTTelURIParams", "transTelPar", "_tPhone", "symTransferStr", "tPhoneType", "_tTelURIparams", "_tBp", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_TransferAddressVoIPPeerWrapper.properties and super(IxPropertyClass_TransferAddressVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_TransferAddressVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_TransferAddressVoIPPeerWrapper__transferAddress"), name)
		else:
			return super(IxPropertyClass_TransferAddressVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_TransferAddressVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_TransferAddressVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_TransferAddressVoIPPeerWrapper__transferAddress"), name, value)
			super(IxPropertyClass_TransferAddressVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_DialPlanVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, dialPlan):
		super(IxPropertyClass_DialPlanVoIPPeerWrapper, self).__init__(dialPlan)
		self.__dialPlan = dialPlan
		self._useSPb = dialPlan._useSPb
		self.enableEmergencyCalls = dialPlan.enableEmergencyCalls
		self._sPhone = dialPlan._sPhone
		self.destPhoneType = dialPlan.destPhoneType
		self.destTelPar = dialPlan.destTelPar
		self.useAnonymous = dialPlan.useAnonymous
		self.symDestStr = dialPlan.symDestStr
		self._sBp = dialPlan._sBp
		self.makeEmergencyReg = dialPlan.makeEmergencyReg
		self._ckSTelURIParams = dialPlan._ckSTelURIParams
		self._dTelURIparams = dialPlan._dTelURIparams
		self._dBp = dialPlan._dBp
		self.ovrDestPhone = dialPlan.ovrDestPhone
		self._dPhone = dialPlan._dPhone
		self.srcTelPar = dialPlan.srcTelPar
		self._sTelURIparams = dialPlan._sTelURIparams
		self.srcPhoneType = dialPlan.srcPhoneType
		self.emergencyService = dialPlan.emergencyService
		self._useDPb = dialPlan._useDPb
		self._ckDTelURIParams = dialPlan._ckDTelURIParams

	properties = ["_useSPb", "enableEmergencyCalls", "_sPhone", "destPhoneType", "destTelPar", "useAnonymous", "symDestStr", "_sBp", "makeEmergencyReg", "_ckSTelURIParams", "_dTelURIparams", "_dBp", "ovrDestPhone", "_dPhone", "srcTelPar", "_sTelURIparams", "srcPhoneType", "emergencyService", "_useDPb", "_ckDTelURIParams", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_DialPlanVoIPPeerWrapper.properties and super(IxPropertyClass_DialPlanVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_DialPlanVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_DialPlanVoIPPeerWrapper__dialPlan"), name)
		else:
			return super(IxPropertyClass_DialPlanVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_DialPlanVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_DialPlanVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_DialPlanVoIPPeerWrapper__dialPlan"), name, value)
			super(IxPropertyClass_DialPlanVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_SRTPSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, srtpSettings):
		super(IxPropertyClass_SRTPSettingsVoIPPeerWrapper, self).__init__(srtpSettings)
		self.__srtpSettings = srtpSettings
		self.bDisableSRTPEncryption = srtpSettings.bDisableSRTPEncryption
		self.bDisableSRTPAuthentication = srtpSettings.bDisableSRTPAuthentication
		self.bEnableSRTP = srtpSettings.bEnableSRTP
		self.bEnablePreencryption = srtpSettings.bEnablePreencryption
		self.bDisableValidations = srtpSettings.bDisableValidations
		self.bDisableSRTCPEncryption = srtpSettings.bDisableSRTCPEncryption
		self.bStaticMasterKeySalt = srtpSettings.bStaticMasterKeySalt
		self.staticKeyFile = srtpSettings.staticKeyFile
		self.bDisableMasterSalt = srtpSettings.bDisableMasterSalt
		self.staticSingleKeySalt = srtpSettings.staticSingleKeySalt
		self.bAllowOnlySecureStreams = srtpSettings.bAllowOnlySecureStreams
		self.bEnableVideoSRTP = srtpSettings.bEnableVideoSRTP
		self.bIncludeMKI = srtpSettings.bIncludeMKI
		self.bEnableTextSRTP = srtpSettings.bEnableTextSRTP
		self._masterKeySelection = srtpSettings._masterKeySelection

	properties = ["bDisableSRTPEncryption", "bDisableSRTPAuthentication", "bEnableSRTP", "bEnablePreencryption", "bDisableValidations", "bDisableSRTCPEncryption", "bStaticMasterKeySalt", "staticKeyFile", "bDisableMasterSalt", "staticSingleKeySalt", "bAllowOnlySecureStreams", "bEnableVideoSRTP", "bIncludeMKI", "bEnableTextSRTP", "_masterKeySelection", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_SRTPSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_SRTPSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_SRTPSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SRTPSettingsVoIPPeerWrapper__srtpSettings"), name)
		else:
			return super(IxPropertyClass_SRTPSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_SRTPSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_SRTPSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SRTPSettingsVoIPPeerWrapper__srtpSettings"), name, value)
			super(IxPropertyClass_SRTPSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_AKAConfigurationVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, akaConfiguration):
		super(IxPropertyClass_AKAConfigurationVoIPPeerWrapper, self).__init__(akaConfiguration)
		self.__akaConfiguration = akaConfiguration
		self.akaConfigurationList = IxPropertyGroupSequence_AKAConfiguration_akaConfigurationListVoIPPeerWrapper(akaConfiguration)

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_AKAConfigurationVoIPPeerWrapper.properties and super(IxPropertyClass_AKAConfigurationVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AKAConfigurationVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AKAConfigurationVoIPPeerWrapper__akaConfiguration"), name)
		else:
			return super(IxPropertyClass_AKAConfigurationVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AKAConfigurationVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AKAConfigurationVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AKAConfigurationVoIPPeerWrapper__akaConfiguration"), name, value)
			super(IxPropertyClass_AKAConfigurationVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_MSRPSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, msrpSettings):
		super(IxPropertyClass_MSRPSettingsVoIPPeerWrapper, self).__init__(msrpSettings)
		self.__msrpSettings = msrpSettings
		self.domainType = msrpSettings.domainType
		self.filesCount = msrpSettings.filesCount
		self.firstRelayIpEnabled = msrpSettings.firstRelayIpEnabled
		self.automaticMSRPAuth = msrpSettings.automaticMSRPAuth
		self.msrpSendEmptyMsg = msrpSettings.msrpSendEmptyMsg
		self.msrpTransactionTimeout = msrpSettings.msrpTransactionTimeout
		self.msrpInterChunkTimeout = msrpSettings.msrpInterChunkTimeout
		self.tosMSRPVal = msrpSettings.tosMSRPVal
		self.enableMSRP = msrpSettings.enableMSRP
		self.localDomain = msrpSettings.localDomain
		self.relaysCount = msrpSettings.relaysCount
		self.firstRelayIp = msrpSettings.firstRelayIp
		self.advSettings = IxPropertyClass_MSRPAdvancedSettingsVoIPPeerWrapper(msrpSettings.advSettings)
		self.tcpDestPortFromSDPMediaLine = msrpSettings.tcpDestPortFromSDPMediaLine
		self.msrpFirstChunkTimeout = msrpSettings.msrpFirstChunkTimeout
		self.firstRelayIsIPv4 = msrpSettings.firstRelayIsIPv4
		self.msrpPort = msrpSettings.msrpPort
		self.msrpSessionTimeout = msrpSettings.msrpSessionTimeout
		self.enableMSRPTos = msrpSettings.enableMSRPTos
		self.msrpReuseTCP = msrpSettings.msrpReuseTCP
		self.msrpRelayPort = msrpSettings.msrpRelayPort
		self.files = IxPropertyGroupSequence_MSRPSettings_filesVoIPPeerWrapper(msrpSettings)

	properties = ["domainType", "filesCount", "firstRelayIpEnabled", "automaticMSRPAuth", "msrpSendEmptyMsg", "msrpTransactionTimeout", "msrpInterChunkTimeout", "tosMSRPVal", "enableMSRP", "localDomain", "relaysCount", "firstRelayIp", "tcpDestPortFromSDPMediaLine", "msrpFirstChunkTimeout", "firstRelayIsIPv4", "msrpPort", "msrpSessionTimeout", "enableMSRPTos", "msrpReuseTCP", "msrpRelayPort", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_MSRPSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_MSRPSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_MSRPSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_MSRPSettingsVoIPPeerWrapper__msrpSettings"), name)
		else:
			return super(IxPropertyClass_MSRPSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_MSRPSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_MSRPSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_MSRPSettingsVoIPPeerWrapper__msrpSettings"), name, value)
			super(IxPropertyClass_MSRPSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_McpttSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, mcpttSettings):
		super(IxPropertyClass_McpttSettingsVoIPPeerWrapper, self).__init__(mcpttSettings)
		self.__mcpttSettings = mcpttSettings
		self.multicastAddress = mcpttSettings.multicastAddress
		self.mcpttPinHole = mcpttSettings.mcpttPinHole
		self.enableMCPTT = mcpttSettings.enableMCPTT
		self.mbmsSupport = mcpttSettings.mbmsSupport
		self.mcpttPinHoleID = mcpttSettings.mcpttPinHoleID
		self.mbmsMappingType = mcpttSettings.mbmsMappingType
		self.mcpttVersion = mcpttSettings.mcpttVersion
		self.mbmsMapping = mcpttSettings.mbmsMapping
		self.mcpttGroupSize = mcpttSettings.mcpttGroupSize
		self.mcpttGroup = mcpttSettings.mcpttGroup
		self.mbmsMappingFile = mcpttSettings.mbmsMappingFile
		self.mcpttFunction = mcpttSettings.mcpttFunction
		self.mbmsGroupsPerTmgi = mcpttSettings.mbmsGroupsPerTmgi
		self.mcpttPinHoleTime = mcpttSettings.mcpttPinHoleTime
		self.mcpttBearer = mcpttSettings.mcpttBearer
		self.multicastPort = mcpttSettings.multicastPort

	properties = ["multicastAddress", "mcpttPinHole", "enableMCPTT", "mbmsSupport", "mcpttPinHoleID", "mbmsMappingType", "mcpttVersion", "mbmsMapping", "mcpttGroupSize", "mcpttGroup", "mbmsMappingFile", "mcpttFunction", "mbmsGroupsPerTmgi", "mcpttPinHoleTime", "mcpttBearer", "multicastPort", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_McpttSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_McpttSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_McpttSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_McpttSettingsVoIPPeerWrapper__mcpttSettings"), name)
		else:
			return super(IxPropertyClass_McpttSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_McpttSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_McpttSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_McpttSettingsVoIPPeerWrapper__mcpttSettings"), name, value)
			super(IxPropertyClass_McpttSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_DebugInfoVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, debugInfo):
		super(IxPropertyClass_DebugInfoVoIPPeerWrapper, self).__init__(debugInfo)
		self.__debugInfo = debugInfo
		self.inspectMemoryUsage = debugInfo.inspectMemoryUsage
		self.fullDebugLogToSharedPort = debugInfo.fullDebugLogToSharedPort
		self.systemCommandsTimer = debugInfo.systemCommandsTimer
		self.enableCommandSocketFailure = debugInfo.enableCommandSocketFailure
		self.sleepTime = debugInfo.sleepTime
		self.logToSharedPort = debugInfo.logToSharedPort
		self.attachGdb = debugInfo.attachGdb
		self.runWithFullDebug = debugInfo.runWithFullDebug
		self.memoryUsageTimer = debugInfo.memoryUsageTimer
		self.maxLogFileSize = debugInfo.maxLogFileSize
		self.systemCommands = debugInfo.systemCommands
		self.doSleep = debugInfo.doSleep
		self.executeSystemCommands = debugInfo.executeSystemCommands
		self.commandSocketFailure = debugInfo.commandSocketFailure
		self.additionalGdbCommands = debugInfo.additionalGdbCommands

	properties = ["inspectMemoryUsage", "fullDebugLogToSharedPort", "systemCommandsTimer", "enableCommandSocketFailure", "sleepTime", "logToSharedPort", "attachGdb", "runWithFullDebug", "memoryUsageTimer", "maxLogFileSize", "systemCommands", "doSleep", "executeSystemCommands", "commandSocketFailure", "additionalGdbCommands", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_DebugInfoVoIPPeerWrapper.properties and super(IxPropertyClass_DebugInfoVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_DebugInfoVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_DebugInfoVoIPPeerWrapper__debugInfo"), name)
		else:
			return super(IxPropertyClass_DebugInfoVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_DebugInfoVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_DebugInfoVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_DebugInfoVoIPPeerWrapper__debugInfo"), name, value)
			super(IxPropertyClass_DebugInfoVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_T38SettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, t38Settings):
		super(IxPropertyClass_T38SettingsVoIPPeerWrapper, self).__init__(t38Settings)
		self.__t38Settings = t38Settings
		self.t38TranscodingMMR = t38Settings.t38TranscodingMMR
		self.t38UdpEncapsulation = t38Settings.t38UdpEncapsulation
		self.useT38MaxBitrate = t38Settings.useT38MaxBitrate
		self.t38RateMgmt = t38Settings.t38RateMgmt
		self.t38TranscodingJBIG = t38Settings.t38TranscodingJBIG
		self.enableT38 = t38Settings.enableT38
		self.t38TransportType = t38Settings.t38TransportType
		self.t38Port = t38Settings.t38Port
		self.t38FillBitRemoval = t38Settings.t38FillBitRemoval
		self.faxVersion = t38Settings.faxVersion
		self.useT38FillBitRemoval = t38Settings.useT38FillBitRemoval
		self.t38MaxDatagramSize = t38Settings.t38MaxDatagramSize
		self.useT38RateMgmt = t38Settings.useT38RateMgmt
		self.faxImage = t38Settings.faxImage
		self.useT38MaxBufferSize = t38Settings.useT38MaxBufferSize
		self.errorRecoverySchema = t38Settings.errorRecoverySchema
		self.t38MaxBufferSize = t38Settings.t38MaxBufferSize
		self.useFaxVersion = t38Settings.useFaxVersion
		self.useT38MaxDatagramSize = t38Settings.useT38MaxDatagramSize
		self.t38MaxBitrate = t38Settings.t38MaxBitrate
		self.t38PayloadType = t38Settings.t38PayloadType
		self.useErrorRecoverySchema = t38Settings.useErrorRecoverySchema

	properties = ["t38TranscodingMMR", "t38UdpEncapsulation", "useT38MaxBitrate", "t38RateMgmt", "t38TranscodingJBIG", "enableT38", "t38TransportType", "t38Port", "t38FillBitRemoval", "faxVersion", "useT38FillBitRemoval", "t38MaxDatagramSize", "useT38RateMgmt", "faxImage", "useT38MaxBufferSize", "errorRecoverySchema", "t38MaxBufferSize", "useFaxVersion", "useT38MaxDatagramSize", "t38MaxBitrate", "t38PayloadType", "useErrorRecoverySchema", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_T38SettingsVoIPPeerWrapper.properties and super(IxPropertyClass_T38SettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_T38SettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_T38SettingsVoIPPeerWrapper__t38Settings"), name)
		else:
			return super(IxPropertyClass_T38SettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_T38SettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_T38SettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_T38SettingsVoIPPeerWrapper__t38Settings"), name, value)
			super(IxPropertyClass_T38SettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_SipAdvancedSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, sipAdvSettings):
		super(IxPropertyClass_SipAdvancedSettingsVoIPPeerWrapper, self).__init__(sipAdvSettings)
		self.__sipAdvSettings = sipAdvSettings
		self.tcpIdlePeriod = sipAdvSettings.tcpIdlePeriod
		self.closeIdleTcpConnectionsEnable = sipAdvSettings.closeIdleTcpConnectionsEnable
		self.donotCloseTunnelOnSecureTcpConnectionErrorEnable = sipAdvSettings.donotCloseTunnelOnSecureTcpConnectionErrorEnable
		self.donotCloseTCPInsideCallEnable = sipAdvSettings.donotCloseTCPInsideCallEnable
		self.tcpLocalPortStep = sipAdvSettings.tcpLocalPortStep
		self.tcpLocalPortEnd = sipAdvSettings.tcpLocalPortEnd
		self.overrideTCPLocalPort = sipAdvSettings.overrideTCPLocalPort
		self.tcpLocalPortStart = sipAdvSettings.tcpLocalPortStart
		self.enableIsup = sipAdvSettings.enableIsup
		self.recordingServerEnable = sipAdvSettings.recordingServerEnable
		self.closeNonsecureTcpConnectionsEnable = sipAdvSettings.closeNonsecureTcpConnectionsEnable

	properties = ["tcpIdlePeriod", "closeIdleTcpConnectionsEnable", "donotCloseTunnelOnSecureTcpConnectionErrorEnable", "donotCloseTCPInsideCallEnable", "tcpLocalPortStep", "tcpLocalPortEnd", "overrideTCPLocalPort", "tcpLocalPortStart", "enableIsup", "recordingServerEnable", "closeNonsecureTcpConnectionsEnable", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_SipAdvancedSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_SipAdvancedSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_SipAdvancedSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SipAdvancedSettingsVoIPPeerWrapper__sipAdvSettings"), name)
		else:
			return super(IxPropertyClass_SipAdvancedSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_SipAdvancedSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_SipAdvancedSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SipAdvancedSettingsVoIPPeerWrapper__sipAdvSettings"), name, value)
			super(IxPropertyClass_SipAdvancedSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_MilenageConfigurationVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, milenageConfiguration):
		super(IxPropertyClass_MilenageConfigurationVoIPPeerWrapper, self).__init__(milenageConfiguration)
		self.__milenageConfiguration = milenageConfiguration

	properties = []

	def __getattribute__(self, name):
		if name in IxPropertyClass_MilenageConfigurationVoIPPeerWrapper.properties and super(IxPropertyClass_MilenageConfigurationVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_MilenageConfigurationVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_MilenageConfigurationVoIPPeerWrapper__milenageConfiguration"), name)
		else:
			return super(IxPropertyClass_MilenageConfigurationVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_MilenageConfigurationVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_MilenageConfigurationVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_MilenageConfigurationVoIPPeerWrapper__milenageConfiguration"), name, value)
			super(IxPropertyClass_MilenageConfigurationVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_EditAutoHeaderRuleVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, editAutoHeaderRule):
		super(IxPropertyClass_EditAutoHeaderRuleVoIPPeerWrapper, self).__init__(editAutoHeaderRule)
		self.__editAutoHeaderRule = editAutoHeaderRule
		self.autoHeaderType = editAutoHeaderRule.autoHeaderType
		self.option = editAutoHeaderRule.option
		self.valid = editAutoHeaderRule.valid
		self.appendToUri = editAutoHeaderRule.appendToUri
		self.headerValue = editAutoHeaderRule.headerValue

	properties = ["autoHeaderType", "option", "valid", "appendToUri", "headerValue", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_EditAutoHeaderRuleVoIPPeerWrapper.properties and super(IxPropertyClass_EditAutoHeaderRuleVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_EditAutoHeaderRuleVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_EditAutoHeaderRuleVoIPPeerWrapper__editAutoHeaderRule"), name)
		else:
			return super(IxPropertyClass_EditAutoHeaderRuleVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_EditAutoHeaderRuleVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_EditAutoHeaderRuleVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_EditAutoHeaderRuleVoIPPeerWrapper__editAutoHeaderRule"), name, value)
			super(IxPropertyClass_EditAutoHeaderRuleVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_TlsSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, tlsSettings):
		super(IxPropertyClass_TlsSettingsVoIPPeerWrapper, self).__init__(tlsSettings)
		self.__tlsSettings = tlsSettings
		self.tlsCertType = tlsSettings.tlsCertType
		self.tlsPassword = tlsSettings.tlsPassword
		self.tlsPort = tlsSettings.tlsPort
		self.ignoreSubjectAltName = tlsSettings.ignoreSubjectAltName
		self.tlsPrivateKeyCertificate = tlsSettings.tlsPrivateKeyCertificate
		self.tlsTransportType = tlsSettings.tlsTransportType
		self.enableTLS_HTTP = tlsSettings.enableTLS_HTTP
		self.tlsCyphers = IxPropertyGroupSequence_TlsSettings_tlsCyphersVoIPPeerWrapper(tlsSettings)
		self.tlsProtocol = tlsSettings.tlsProtocol
		self.tlsKeyType = tlsSettings.tlsKeyType
		self.tlsCertificatesPath = tlsSettings.tlsCertificatesPath
		self.tlsEnableTcpKeepAlive = tlsSettings.tlsEnableTcpKeepAlive
		self.tlsPublicKeyCertificate = tlsSettings.tlsPublicKeyCertificate
		self.enableTLS = tlsSettings.enableTLS
		self.tlsAuthClient = tlsSettings.tlsAuthClient
		self.tlsMutual = tlsSettings.tlsMutual
		self.enableDTLS = tlsSettings.enableDTLS
		self.enableTLS_MSRP = tlsSettings.enableTLS_MSRP
		self.tlsReuseConnection = tlsSettings.tlsReuseConnection
		self.tlsRefreshInterval = tlsSettings.tlsRefreshInterval
		self.tlsSessionRefresh = tlsSettings.tlsSessionRefresh
		self.tlsDisableUdpAndTcp = tlsSettings.tlsDisableUdpAndTcp
		self.sipScheme = tlsSettings.sipScheme

	properties = ["tlsCertType", "tlsPassword", "tlsPort", "ignoreSubjectAltName", "tlsPrivateKeyCertificate", "tlsTransportType", "enableTLS_HTTP", "tlsProtocol", "tlsKeyType", "tlsCertificatesPath", "tlsEnableTcpKeepAlive", "tlsPublicKeyCertificate", "enableTLS", "tlsAuthClient", "tlsMutual", "enableDTLS", "enableTLS_MSRP", "tlsReuseConnection", "tlsRefreshInterval", "tlsSessionRefresh", "tlsDisableUdpAndTcp", "sipScheme", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_TlsSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_TlsSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_TlsSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_TlsSettingsVoIPPeerWrapper__tlsSettings"), name)
		else:
			return super(IxPropertyClass_TlsSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_TlsSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_TlsSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_TlsSettingsVoIPPeerWrapper__tlsSettings"), name, value)
			super(IxPropertyClass_TlsSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_CloudRulesVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, cloudRules):
		super(IxPropertyClass_CloudRulesVoIPPeerWrapper, self).__init__(cloudRules)
		self.__cloudRules = cloudRules
		self.cloudPhoneBooksAbsolutePath = cloudRules.cloudPhoneBooksAbsolutePath

	properties = ["cloudPhoneBooksAbsolutePath", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_CloudRulesVoIPPeerWrapper.properties and super(IxPropertyClass_CloudRulesVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_CloudRulesVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_CloudRulesVoIPPeerWrapper__cloudRules"), name)
		else:
			return super(IxPropertyClass_CloudRulesVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_CloudRulesVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_CloudRulesVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_CloudRulesVoIPPeerWrapper__cloudRules"), name, value)
			super(IxPropertyClass_CloudRulesVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_CodecSettings_dataCodecsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, codecSettings):
		self.__codecSettings = codecSettings
		self.optionsDict = {
			('Rtp2833Tones',): "IxPropertyClass_Rtp2833TonesVoIPPeer",
			('Rtp2833Events',): "IxPropertyClass_Rtp2833EventsVoIPPeer",
		}

	def getItemIxPropertyClass_Rtp2833EventsVoIPPeer(self, objectID):
		itemList = self.__codecSettings.dataCodecs
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_Rtp2833Events":
				return IxPropertyClass_Rtp2833EventsVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxPropertyClass_Rtp2833EventsVoIPPeer(self):
		kwargs = {}
		kwargs.update({"id": "Rtp2833Events"})
		return IxPropertyClass_Rtp2833EventsVoIPPeerWrapper(self.__codecSettings.dataCodecs.appendItem(**kwargs))

	def getItemIxPropertyClass_Rtp2833TonesVoIPPeer(self, objectID):
		itemList = self.__codecSettings.dataCodecs
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_Rtp2833Tones":
				return IxPropertyClass_Rtp2833TonesVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxPropertyClass_Rtp2833TonesVoIPPeer(self):
		kwargs = {}
		kwargs.update({"id": "Rtp2833Tones"})
		return IxPropertyClass_Rtp2833TonesVoIPPeerWrapper(self.__codecSettings.dataCodecs.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__codecSettings.dataCodecs
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, id=None):
		kwargs = {}
		kwargs.update({"id": id})
		return self.__codecSettings.dataCodecs.appendItem(**kwargs)

	def getList(self):
		return self.__codecSettings.dataCodecs

	def clear(self):
		return self.__codecSettings.dataCodecs.clear()


class IxPropertyClass_Rtp2833EventsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Rtp2833Events):
		super(IxPropertyClass_Rtp2833EventsVoIPPeerWrapper, self).__init__(ixPropertyClass_Rtp2833Events)
		self.__ixPropertyClass_Rtp2833Events = ixPropertyClass_Rtp2833Events
		self.dPayloadType = ixPropertyClass_Rtp2833Events.dPayloadType

	properties = ["dPayloadType", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_Rtp2833EventsVoIPPeerWrapper.properties and super(IxPropertyClass_Rtp2833EventsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_Rtp2833EventsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_Rtp2833EventsVoIPPeerWrapper__ixPropertyClass_Rtp2833Events"), name)
		else:
			return super(IxPropertyClass_Rtp2833EventsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_Rtp2833EventsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_Rtp2833EventsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_Rtp2833EventsVoIPPeerWrapper__ixPropertyClass_Rtp2833Events"), name, value)
			super(IxPropertyClass_Rtp2833EventsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_Rtp2833TonesVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_Rtp2833Tones):
		super(IxPropertyClass_Rtp2833TonesVoIPPeerWrapper, self).__init__(ixPropertyClass_Rtp2833Tones)
		self.__ixPropertyClass_Rtp2833Tones = ixPropertyClass_Rtp2833Tones
		self.dPayloadType = ixPropertyClass_Rtp2833Tones.dPayloadType

	properties = ["dPayloadType", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_Rtp2833TonesVoIPPeerWrapper.properties and super(IxPropertyClass_Rtp2833TonesVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_Rtp2833TonesVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_Rtp2833TonesVoIPPeerWrapper__ixPropertyClass_Rtp2833Tones"), name)
		else:
			return super(IxPropertyClass_Rtp2833TonesVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_Rtp2833TonesVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_Rtp2833TonesVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_Rtp2833TonesVoIPPeerWrapper__ixPropertyClass_Rtp2833Tones"), name, value)
			super(IxPropertyClass_Rtp2833TonesVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_CodecSettings_codecsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, codecSettings):
		self.__codecSettings = codecSettings
		self.optionsDict = {
			('CodecG711a',): "IxPropertyClass_CodecG711aVoIPPeer",
			('CodecG711u',): "IxPropertyClass_CodecG711uVoIPPeer",
		}

	def getItemIxPropertyClass_CodecG711uVoIPPeer(self, objectID):
		itemList = self.__codecSettings.codecs
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_CodecG711u":
				return IxPropertyClass_CodecG711uVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxPropertyClass_CodecG711uVoIPPeer(self):
		kwargs = {}
		kwargs.update({"id": "CodecG711u"})
		return IxPropertyClass_CodecG711uVoIPPeerWrapper(self.__codecSettings.codecs.appendItem(**kwargs))

	def getItemIxPropertyClass_CodecG711aVoIPPeer(self, objectID):
		itemList = self.__codecSettings.codecs
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_CodecG711a":
				return IxPropertyClass_CodecG711aVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItemIxPropertyClass_CodecG711aVoIPPeer(self):
		kwargs = {}
		kwargs.update({"id": "CodecG711a"})
		return IxPropertyClass_CodecG711aVoIPPeerWrapper(self.__codecSettings.codecs.appendItem(**kwargs))

	def getItem(self, objectID):
		itemList = self.__codecSettings.codecs
		for elem in itemList:
			if elem.objectID == objectID:
				return elem
		print("objectID not found")
		return None

	def appendItem(self, id=None):
		kwargs = {}
		kwargs.update({"id": id})
		return self.__codecSettings.codecs.appendItem(**kwargs)

	def getList(self):
		return self.__codecSettings.codecs

	def clear(self):
		return self.__codecSettings.codecs.clear()


class IxPropertyClass_CodecG711uVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_CodecG711u):
		super(IxPropertyClass_CodecG711uVoIPPeerWrapper, self).__init__(ixPropertyClass_CodecG711u)
		self.__ixPropertyClass_CodecG711u = ixPropertyClass_CodecG711u
		self.dPayloadOut = ixPropertyClass_CodecG711u.dPayloadOut
		self.dPayloadIn = ixPropertyClass_CodecG711u.dPayloadIn
		self.frameSize = ixPropertyClass_CodecG711u.frameSize

	properties = ["dPayloadOut", "dPayloadIn", "frameSize", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_CodecG711uVoIPPeerWrapper.properties and super(IxPropertyClass_CodecG711uVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_CodecG711uVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_CodecG711uVoIPPeerWrapper__ixPropertyClass_CodecG711u"), name)
		else:
			return super(IxPropertyClass_CodecG711uVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_CodecG711uVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_CodecG711uVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_CodecG711uVoIPPeerWrapper__ixPropertyClass_CodecG711u"), name, value)
			super(IxPropertyClass_CodecG711uVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_CodecG711aVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_CodecG711a):
		super(IxPropertyClass_CodecG711aVoIPPeerWrapper, self).__init__(ixPropertyClass_CodecG711a)
		self.__ixPropertyClass_CodecG711a = ixPropertyClass_CodecG711a
		self.dPayloadOut = ixPropertyClass_CodecG711a.dPayloadOut
		self.dPayloadIn = ixPropertyClass_CodecG711a.dPayloadIn
		self.frameSize = ixPropertyClass_CodecG711a.frameSize

	properties = ["dPayloadOut", "dPayloadIn", "frameSize", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_CodecG711aVoIPPeerWrapper.properties and super(IxPropertyClass_CodecG711aVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_CodecG711aVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_CodecG711aVoIPPeerWrapper__ixPropertyClass_CodecG711a"), name)
		else:
			return super(IxPropertyClass_CodecG711aVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_CodecG711aVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_CodecG711aVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_CodecG711aVoIPPeerWrapper__ixPropertyClass_CodecG711a"), name, value)
			super(IxPropertyClass_CodecG711aVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_SignalingSettings_securityMechanismValListVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, signalingSettings):
		self.__signalingSettings = signalingSettings

	def getItem(self, objectID):
		itemList = self.__signalingSettings.securityMechanismValList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_SecurityMechanismVal":
				return IxPropertyClass_SecurityMechanismValVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, id=None):
		kwargs = {}
		kwargs.update({"id": id})
		return IxPropertyClass_SecurityMechanismValVoIPPeerWrapper(self.__signalingSettings.securityMechanismValList.appendItem(**kwargs))

	def getList(self):
		return self.__signalingSettings.securityMechanismValList

	def clear(self):
		return self.__signalingSettings.securityMechanismValList.clear()


class IxPropertyClass_SecurityMechanismValVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_SecurityMechanismVal):
		super(IxPropertyClass_SecurityMechanismValVoIPPeerWrapper, self).__init__(ixPropertyClass_SecurityMechanismVal)
		self.__ixPropertyClass_SecurityMechanismVal = ixPropertyClass_SecurityMechanismVal
		self.protocol = ixPropertyClass_SecurityMechanismVal.protocol
		self.encrypt_algorithmStr = ixPropertyClass_SecurityMechanismVal.encrypt_algorithmStr
		self.algorithm = ixPropertyClass_SecurityMechanismVal.algorithm
		self.protocolStr = ixPropertyClass_SecurityMechanismVal.protocolStr
		self.mechanism = ixPropertyClass_SecurityMechanismVal.mechanism
		self.port_c = ixPropertyClass_SecurityMechanismVal.port_c
		self.algorithmStr = ixPropertyClass_SecurityMechanismVal.algorithmStr
		self.mode = ixPropertyClass_SecurityMechanismVal.mode
		self.port_s = ixPropertyClass_SecurityMechanismVal.port_s
		self.spi_start_idx = ixPropertyClass_SecurityMechanismVal.spi_start_idx
		self.modeStr = ixPropertyClass_SecurityMechanismVal.modeStr
		self.encrypt_algorithm = ixPropertyClass_SecurityMechanismVal.encrypt_algorithm
		self.checked = ixPropertyClass_SecurityMechanismVal.checked

	properties = ["protocol", "encrypt_algorithmStr", "algorithm", "protocolStr", "mechanism", "port_c", "algorithmStr", "mode", "port_s", "spi_start_idx", "modeStr", "encrypt_algorithm", "checked", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_SecurityMechanismValVoIPPeerWrapper.properties and super(IxPropertyClass_SecurityMechanismValVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_SecurityMechanismValVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SecurityMechanismValVoIPPeerWrapper__ixPropertyClass_SecurityMechanismVal"), name)
		else:
			return super(IxPropertyClass_SecurityMechanismValVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_SecurityMechanismValVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_SecurityMechanismValVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SecurityMechanismValVoIPPeerWrapper__ixPropertyClass_SecurityMechanismVal"), name, value)
			super(IxPropertyClass_SecurityMechanismValVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_SMSAddressInfoVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, smsAddressOriginator):
		super(IxPropertyClass_SMSAddressInfoVoIPPeerWrapper, self).__init__(smsAddressOriginator)
		self.__smsAddressOriginator = smsAddressOriginator
		self.comboPhoneBookEntry = smsAddressOriginator.comboPhoneBookEntry
		self.phoneType = smsAddressOriginator.phoneType
		self.phoneValue = smsAddressOriginator.phoneValue

	properties = ["comboPhoneBookEntry", "phoneType", "phoneValue", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_SMSAddressInfoVoIPPeerWrapper.properties and super(IxPropertyClass_SMSAddressInfoVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_SMSAddressInfoVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SMSAddressInfoVoIPPeerWrapper__smsAddressOriginator"), name)
		else:
			return super(IxPropertyClass_SMSAddressInfoVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_SMSAddressInfoVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_SMSAddressInfoVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_SMSAddressInfoVoIPPeerWrapper__smsAddressOriginator"), name, value)
			super(IxPropertyClass_SMSAddressInfoVoIPPeerWrapper, self).__setattr__(name, value)


class IxCommandOutputListVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyCommandStart):
		self.__ixPropertyCommandStart = ixPropertyCommandStart

	def getItem(self, objectID):
		itemList = self.__ixPropertyCommandStart.outputList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixCommandOutput":
				return IxCommandOutputVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, id=None):
		kwargs = {}
		kwargs.update({"id": id})
		return IxCommandOutputVoIPPeerWrapper(self.__ixPropertyCommandStart.outputList.appendItem(**kwargs))

	def getList(self):
		return self.__ixPropertyCommandStart.outputList

	def clear(self):
		return self.__ixPropertyCommandStart.outputList.clear()


class IxCommandOutputVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixCommandOutput):
		super(IxCommandOutputVoIPPeerWrapper, self).__init__(ixCommandOutput)
		self.__ixCommandOutput = ixCommandOutput
		self.outputType = ixCommandOutput.outputType
		self.name = ixCommandOutput.name

	properties = ["outputType", "name", ]

	def __getattribute__(self, name):
		if name in IxCommandOutputVoIPPeerWrapper.properties and super(IxCommandOutputVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxCommandOutputVoIPPeerWrapper, self).__getattribute__("_IxCommandOutputVoIPPeerWrapper__ixCommandOutput"), name)
		else:
			return super(IxCommandOutputVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxCommandOutputVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxCommandOutputVoIPPeerWrapper, self).__getattribute__("_IxCommandOutputVoIPPeerWrapper__ixCommandOutput"), name, value)
			super(IxCommandOutputVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_VideoTelepresenceSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, tipSettings):
		super(IxPropertyClass_VideoTelepresenceSettingsVoIPPeerWrapper, self).__init__(tipSettings)
		self.__tipSettings = tipSettings
		self.tipUnrestrictedMedia = tipSettings.tipUnrestrictedMedia
		self.tipLegacyClipAudio = tipSettings.tipLegacyClipAudio
		self.tipRotationScheme = tipSettings.tipRotationScheme
		self.tipLegacyMode = tipSettings.tipLegacyMode
		self.tipVideoRefresh = tipSettings.tipVideoRefresh
		self.tipUsePresentationStream = tipSettings.tipUsePresentationStream
		self.tipRtcpFeedback = tipSettings.tipRtcpFeedback
		self.tipStartAfterUnit = tipSettings.tipStartAfterUnit
		self.tipArithmetingCoding = tipSettings.tipArithmetingCoding
		self.tipConfDuration = tipSettings.tipConfDuration
		self.tipConfDurationUnit = tipSettings.tipConfDurationUnit
		self.tipG722Legacy = tipSettings.tipG722Legacy
		self.tipDuration = tipSettings.tipDuration
		self.tipLegacyClip = tipSettings.tipLegacyClip
		self.tipMoreClips = tipSettings.tipMoreClips
		self.tipDurationUnit = tipSettings.tipDurationUnit
		self.tipInbandSets = tipSettings.tipInbandSets
		self.tipSyntheticPayload = tipSettings.tipSyntheticPayload
		self.tipAudioDurationUnit = tipSettings.tipAudioDurationUnit
		self.tipResolution = tipSettings.tipResolution
		self.tipLegacyModeAudio = tipSettings.tipLegacyModeAudio
		self.tipHighProfile = tipSettings.tipHighProfile
		self.tipAudioActivityMetric = tipSettings.tipAudioActivityMetric
		self.tipGDR = tipSettings.tipGDR
		self.tipVideoClip2 = tipSettings.tipVideoClip2
		self.tipVersion = tipSettings.tipVersion
		self.tipDinamicChannels = tipSettings.tipDinamicChannels
		self.tipEndpointType = tipSettings.tipEndpointType
		self.tipLTRP = tipSettings.tipLTRP
		self.tipStartAfter = tipSettings.tipStartAfter
		self.tipPresentationRotation = tipSettings.tipPresentationRotation
		self.tipAudioClip = tipSettings.tipAudioClip
		self.tipVideoClip = tipSettings.tipVideoClip
		self.tipAudioDuration = tipSettings.tipAudioDuration

	properties = ["tipUnrestrictedMedia", "tipLegacyClipAudio", "tipRotationScheme", "tipLegacyMode", "tipVideoRefresh", "tipUsePresentationStream", "tipRtcpFeedback", "tipStartAfterUnit", "tipArithmetingCoding", "tipConfDuration", "tipConfDurationUnit", "tipG722Legacy", "tipDuration", "tipLegacyClip", "tipMoreClips", "tipDurationUnit", "tipInbandSets", "tipSyntheticPayload", "tipAudioDurationUnit", "tipResolution", "tipLegacyModeAudio", "tipHighProfile", "tipAudioActivityMetric", "tipGDR", "tipVideoClip2", "tipVersion", "tipDinamicChannels", "tipEndpointType", "tipLTRP", "tipStartAfter", "tipPresentationRotation", "tipAudioClip", "tipVideoClip", "tipAudioDuration", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_VideoTelepresenceSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_VideoTelepresenceSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_VideoTelepresenceSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_VideoTelepresenceSettingsVoIPPeerWrapper__tipSettings"), name)
		else:
			return super(IxPropertyClass_VideoTelepresenceSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_VideoTelepresenceSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_VideoTelepresenceSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_VideoTelepresenceSettingsVoIPPeerWrapper__tipSettings"), name, value)
			super(IxPropertyClass_VideoTelepresenceSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_TimerSettings_autoProcedureListVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, timerSettings):
		self.__timerSettings = timerSettings

	def getItem(self, objectID):
		itemList = self.__timerSettings.autoProcedureList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_AutoProcedure":
				return IxPropertyClass_AutoProcedureVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, id=None):
		kwargs = {}
		kwargs.update({"id": id})
		return IxPropertyClass_AutoProcedureVoIPPeerWrapper(self.__timerSettings.autoProcedureList.appendItem(**kwargs))

	def getList(self):
		return self.__timerSettings.autoProcedureList

	def clear(self):
		return self.__timerSettings.autoProcedureList.clear()


class IxPropertyClass_AutoProcedureVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_AutoProcedure):
		super(IxPropertyClass_AutoProcedureVoIPPeerWrapper, self).__init__(ixPropertyClass_AutoProcedure)
		self.__ixPropertyClass_AutoProcedure = ixPropertyClass_AutoProcedure
		self.procName = ixPropertyClass_AutoProcedure.procName
		self.checked = ixPropertyClass_AutoProcedure.checked

	properties = ["procName", "checked", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AutoProcedureVoIPPeerWrapper.properties and super(IxPropertyClass_AutoProcedureVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AutoProcedureVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AutoProcedureVoIPPeerWrapper__ixPropertyClass_AutoProcedure"), name)
		else:
			return super(IxPropertyClass_AutoProcedureVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AutoProcedureVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AutoProcedureVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AutoProcedureVoIPPeerWrapper__ixPropertyClass_AutoProcedure"), name, value)
			super(IxPropertyClass_AutoProcedureVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_TimerSettings_expirationValListVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, timerSettings):
		self.__timerSettings = timerSettings

	def getItem(self, objectID):
		itemList = self.__timerSettings.expirationValList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_ExpirationVal":
				return IxPropertyClass_ExpirationValVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, id=None):
		kwargs = {}
		kwargs.update({"id": id})
		return IxPropertyClass_ExpirationValVoIPPeerWrapper(self.__timerSettings.expirationValList.appendItem(**kwargs))

	def getList(self):
		return self.__timerSettings.expirationValList

	def clear(self):
		return self.__timerSettings.expirationValList.clear()


class IxPropertyClass_ExpirationValVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_ExpirationVal):
		super(IxPropertyClass_ExpirationValVoIPPeerWrapper, self).__init__(ixPropertyClass_ExpirationVal)
		self.__ixPropertyClass_ExpirationVal = ixPropertyClass_ExpirationVal
		self.checked = ixPropertyClass_ExpirationVal.checked
		self.msgPartStr = ixPropertyClass_ExpirationVal.msgPartStr
		self.value = ixPropertyClass_ExpirationVal.value
		self.msgPart = ixPropertyClass_ExpirationVal.msgPart
		self.message = ixPropertyClass_ExpirationVal.message

	properties = ["checked", "msgPartStr", "value", "msgPart", "message", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_ExpirationValVoIPPeerWrapper.properties and super(IxPropertyClass_ExpirationValVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_ExpirationValVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_ExpirationValVoIPPeerWrapper__ixPropertyClass_ExpirationVal"), name)
		else:
			return super(IxPropertyClass_ExpirationValVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_ExpirationValVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_ExpirationValVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_ExpirationValVoIPPeerWrapper__ixPropertyClass_ExpirationVal"), name, value)
			super(IxPropertyClass_ExpirationValVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_AKAConfiguration_akaConfigurationListVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, akaConfiguration):
		self.__akaConfiguration = akaConfiguration

	def getItem(self, objectID):
		itemList = self.__akaConfiguration.akaConfigurationList
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_AKAConfigurationEntry":
				return IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, id=None):
		kwargs = {}
		kwargs.update({"id": id})
		return IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper(self.__akaConfiguration.akaConfigurationList.appendItem(**kwargs))

	def getList(self):
		return self.__akaConfiguration.akaConfigurationList

	def clear(self):
		return self.__akaConfiguration.akaConfigurationList.clear()


class IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_AKAConfigurationEntry):
		super(IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper, self).__init__(ixPropertyClass_AKAConfigurationEntry)
		self.__ixPropertyClass_AKAConfigurationEntry = ixPropertyClass_AKAConfigurationEntry
		self.useOPasOPc = ixPropertyClass_AKAConfigurationEntry.useOPasOPc
		self.sharedSecretPatern = ixPropertyClass_AKAConfigurationEntry.sharedSecretPatern
		self.operatorVariantFilePath = ixPropertyClass_AKAConfigurationEntry.operatorVariantFilePath
		self.sharedSecretFilePath = ixPropertyClass_AKAConfigurationEntry.sharedSecretFilePath
		self.operatorVariantSource = ixPropertyClass_AKAConfigurationEntry.operatorVariantSource
		self.configurationLabel = ixPropertyClass_AKAConfigurationEntry.configurationLabel
		self.operatorVariantPatern = ixPropertyClass_AKAConfigurationEntry.operatorVariantPatern
		self.sharedSecretSource = ixPropertyClass_AKAConfigurationEntry.sharedSecretSource

	properties = ["useOPasOPc", "sharedSecretPatern", "operatorVariantFilePath", "sharedSecretFilePath", "operatorVariantSource", "configurationLabel", "operatorVariantPatern", "sharedSecretSource", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper.properties and super(IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper__ixPropertyClass_AKAConfigurationEntry"), name)
		else:
			return super(IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper__ixPropertyClass_AKAConfigurationEntry"), name, value)
			super(IxPropertyClass_AKAConfigurationEntryVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyClass_MSRPAdvancedSettingsVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, advSettings):
		super(IxPropertyClass_MSRPAdvancedSettingsVoIPPeerWrapper, self).__init__(advSettings)
		self.__advSettings = advSettings
		self.useLocalSDPMediaPortForClientTCPPort = advSettings.useLocalSDPMediaPortForClientTCPPort
		self.saveMsrpRecvChat = advSettings.saveMsrpRecvChat
		self.closeTCPConnectionAfterBye = advSettings.closeTCPConnectionAfterBye

	properties = ["useLocalSDPMediaPortForClientTCPPort", "saveMsrpRecvChat", "closeTCPConnectionAfterBye", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_MSRPAdvancedSettingsVoIPPeerWrapper.properties and super(IxPropertyClass_MSRPAdvancedSettingsVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_MSRPAdvancedSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_MSRPAdvancedSettingsVoIPPeerWrapper__advSettings"), name)
		else:
			return super(IxPropertyClass_MSRPAdvancedSettingsVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_MSRPAdvancedSettingsVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_MSRPAdvancedSettingsVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_MSRPAdvancedSettingsVoIPPeerWrapper__advSettings"), name, value)
			super(IxPropertyClass_MSRPAdvancedSettingsVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_TlsSettings_tlsCyphersVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, tlsSettings):
		self.__tlsSettings = tlsSettings

	def getItem(self, objectID):
		itemList = self.__tlsSettings.tlsCyphers
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_TlsCyphers":
				return IxPropertyClass_TlsCyphersVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, id=None):
		kwargs = {}
		kwargs.update({"id": id})
		return IxPropertyClass_TlsCyphersVoIPPeerWrapper(self.__tlsSettings.tlsCyphers.appendItem(**kwargs))

	def getList(self):
		return self.__tlsSettings.tlsCyphers

	def clear(self):
		return self.__tlsSettings.tlsCyphers.clear()


class IxPropertyClass_TlsCyphersVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_TlsCyphers):
		super(IxPropertyClass_TlsCyphersVoIPPeerWrapper, self).__init__(ixPropertyClass_TlsCyphers)
		self.__ixPropertyClass_TlsCyphers = ixPropertyClass_TlsCyphers
		self.enabled = ixPropertyClass_TlsCyphers.enabled
		self.name = ixPropertyClass_TlsCyphers.name

	properties = ["enabled", "name", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_TlsCyphersVoIPPeerWrapper.properties and super(IxPropertyClass_TlsCyphersVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_TlsCyphersVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_TlsCyphersVoIPPeerWrapper__ixPropertyClass_TlsCyphers"), name)
		else:
			return super(IxPropertyClass_TlsCyphersVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_TlsCyphersVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_TlsCyphersVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_TlsCyphersVoIPPeerWrapper__ixPropertyClass_TlsCyphers"), name, value)
			super(IxPropertyClass_TlsCyphersVoIPPeerWrapper, self).__setattr__(name, value)


class IxPropertyGroupSequence_MSRPSettings_filesVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, msrpSettings):
		self.__msrpSettings = msrpSettings

	def getItem(self, objectID):
		itemList = self.__msrpSettings.files
		for elem in itemList:
			if elem.objectID == objectID and elem.restObjectType == "ixPropertyClass_FileRecord":
				return IxPropertyClass_FileRecordVoIPPeerWrapper(elem)
		print("objectID not found")
		return None

	def appendItem(self, id=None):
		kwargs = {}
		kwargs.update({"id": id})
		return IxPropertyClass_FileRecordVoIPPeerWrapper(self.__msrpSettings.files.appendItem(**kwargs))

	def getList(self):
		return self.__msrpSettings.files

	def clear(self):
		return self.__msrpSettings.files.clear()


class IxPropertyClass_FileRecordVoIPPeerWrapper(RestObjectBaseClass):

	def __init__(self, ixPropertyClass_FileRecord):
		super(IxPropertyClass_FileRecordVoIPPeerWrapper, self).__init__(ixPropertyClass_FileRecord)
		self.__ixPropertyClass_FileRecord = ixPropertyClass_FileRecord
		self.synthetic = ixPropertyClass_FileRecord.synthetic
		self.hasThumbnail = ixPropertyClass_FileRecord.hasThumbnail
		self.name = ixPropertyClass_FileRecord.name
		self.fileHash = ixPropertyClass_FileRecord.fileHash
		self.customMimeType = ixPropertyClass_FileRecord.customMimeType
		self.thumbnailFileName = ixPropertyClass_FileRecord.thumbnailFileName
		self.thumbnailFileSize = ixPropertyClass_FileRecord.thumbnailFileSize
		self.fileClientPath = ixPropertyClass_FileRecord.fileClientPath
		self.thumbnailPath = ixPropertyClass_FileRecord.thumbnailPath
		self.thumbnailMimeType = ixPropertyClass_FileRecord.thumbnailMimeType
		self.type = ixPropertyClass_FileRecord.type
		self.size = ixPropertyClass_FileRecord.size

	properties = ["synthetic", "hasThumbnail", "name", "fileHash", "customMimeType", "thumbnailFileName", "thumbnailFileSize", "fileClientPath", "thumbnailPath", "thumbnailMimeType", "type", "size", ]

	def __getattribute__(self, name):
		if name in IxPropertyClass_FileRecordVoIPPeerWrapper.properties and super(IxPropertyClass_FileRecordVoIPPeerWrapper, self).__getattribute__(name):
			return getattr(super(IxPropertyClass_FileRecordVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_FileRecordVoIPPeerWrapper__ixPropertyClass_FileRecord"), name)
		else:
			return super(IxPropertyClass_FileRecordVoIPPeerWrapper, self).__getattribute__(name)

	def __setattr__(self, name, value):
		if not hasattr(self, name):
			super(IxPropertyClass_FileRecordVoIPPeerWrapper, self).__setattr__(name, value)
		else:
			setattr(super(IxPropertyClass_FileRecordVoIPPeerWrapper, self).__getattribute__("_IxPropertyClass_FileRecordVoIPPeerWrapper__ixPropertyClass_FileRecord"), name, value)
			super(IxPropertyClass_FileRecordVoIPPeerWrapper, self).__setattr__(name, value)


